// Type definitions for non-npm package Titanium 9.2
// Project: https://github.com/appcelerator/titanium_mobile
// Definitions by: Axway Appcelerator <https://github.com/appcelerator>
//                 Jan Vennemann <https://github.com/janvennemann>
//                 Sergey Volkov <https://github.com/drauggres>
//                 Mathias Lorenzen <https://github.com/ffMathy>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.0

// Base definitions that can't be generated yet
/// <reference path="base.d.ts" />

type _Omit<T, K extends keyof any | undefined> = Pick<T, Exclude<keyof T, K>>;
type FunctionPropertyNames<T> = {
    // tslint:disable-next-line:ban-types
    [K in keyof T]: T[K] extends Function ? K : never
}[keyof T];
type Dictionary<T> = Partial<_Omit<T, FunctionPropertyNames<Ti.Proxy>>>;
interface ProxyEventMap {}

/**
 * An extension of the [NSURLConnectionDelegate](https://developer.apple.com/library/mac/documentation/Foundation/Reference/NSURLConnectionDelegate_Protocol/Reference/Reference.html#//apple_ref/occ/intf/NSURLConnectionDelegate) protocol to allow users to participate in authentication and resource management for this HTTPClient.
 */
interface APSConnectionDelegate {
}
/**
 * Options object for the [accept](Titanium.Network.Socket.TCP.accept) method.
 */
interface AcceptDict {
    /**
     * Callback to be fired when the socket enters the [ERROR](Titanium.Network.Socket.ERROR) state.
     */
    error?: (param0: ErrorCallbackArgs) => void;

    /**
     * Timeout, in milliseconds, for all `write` operations.
     */
    timeout?: number;

}
/**
 * Argument object passed to the [accepted](Titanium.Network.Socket.TCP.accepted)
 * callback when a listener accepts a connection.
 */
interface AcceptedCallbackArgs {
    /**
     * Socket which represents the inbound connection.
     */
    inbound?: Titanium.Network.Socket.TCP;

    /**
     * Socket which received the connection.
     */
    socket?: Titanium.Network.Socket.TCP;

}
/**
 * Simple object passed to the <Titanium.Android.Activity> callbacks for
 * onCreate, onDestroy, onPause, onResume, onStart, onStop, onRestart.
 * Additional properties may be set on the Object.
 */
interface ActivityLifecycleCallbackObject {
    /**
     * The Activity firing the callback.
     */
    source?: Titanium.Android.Activity;

}
/**
 * Simple object passed to the
 * [startActivityForResult](Titanium.Android.Activity.startActivityForResult) callback.
 */
interface ActivityResult {
    /**
     * Intent that can contain data returned to the caller. Data can be attached to
     * the intent as "extras").
     */
    intent?: Titanium.Android.Intent;

    /**
     * Unique, automatically generated integer request code.
     */
    requestCode?: number;

    /**
     * Integer result code that the started activity passed to
     * [setResult](Titanium.Android.Activity.setResult).
     */
    resultCode?: number;

}
/**
 * A JavaScript object holding an `animated` property. Used for many UI methods as a means of specifying some transition should be animated.
 */
interface AnimatedOptions {
    /**
     * If `true`, animate a transition for the method/value change.
     * Note that for most uses cases the default is assumed to be `false`. The exceptions tend to be <Titanium.UI.Window> methods.
     */
    animated?: boolean;

}
/**
 * A JavaScript object holding `animated` and `duration` properties. Used on iOS For [TablewView](Titanium.UI.TableView) and [ListView](Titanium.UI.ListView) content offset transitions.
 */
interface AnimatedWithDurationOptions extends AnimatedOptions {
    /**
     * The duration in `milliseconds` for animation
     */
    duration?: number;

}
/**
 * An abstract datatype for specifying an attributed string attribute.
 */
interface Attribute {
    /**
     * Attribute range.
     */
    range: number[];

    /**
     * Attribute to apply to the text.
     */
    type: number;

    /**
     * Attribute value.
     */
    value: any;

}
/**
 * The object returned to the <Titanium.UI.WebView.backForwardList> method.
 */
interface BackForwardList {
    /**
     * The item immediately preceding the current item.
     */
    backItem?: BackForwardListItem;

    /**
     * The portion of the list preceding the current item.
     */
    backList?: BackForwardListItem[];

    /**
     * The current item.
     */
    currentItem?: BackForwardListItem;

    /**
     * The item immediately following the current item.
     */
    forwardItem?: BackForwardListItem;

    /**
     * The portion of the list following the current item.
     */
    forwardList?: BackForwardListItem[];

}
/**
 * The object represents a webpage in the back-forward of a web view.
 */
interface BackForwardListItem {
    /**
     * The URL of the initial request that created this item.
     */
    initialUrl?: string;

    /**
     * The title of the webpage represented by this item.
     */
    title?: string;

    /**
     * The URL of the webpage represented by this item.
     */
    url?: string;

}
/**
 * Object describing a button bar or tabbed bar item.
 */
interface BarItemType {
    /**
     * A succint label associated with the bar item for the device's accessibility service.
     */
    accessibilityLabel?: string;

    /**
     * Whether the button is enabled initially.
     */
    enabled?: boolean;

    /**
     * Button icon. If specified, takes precedence over `title`.
     */
    image?: string | Titanium.Blob | Titanium.Filesystem.File;

    /**
     * Button title, used if no `image` is specified.
     */
    title?: string;

    /**
     * Width for this button.
     */
    width?: number;

}
/**
 * Simple `Error` instance thrown from the
 * [executeAll](Titanium.Database.DB.executeAll) method in case of failure
 */
interface BatchQueryError {
    /**
     * Index of the failed query
     */
    index?: number;

    /**
     * partial `ResultSet`s of any successful queries before the failure
     */
    results?: Titanium.Database.ResultSet[];

}
/**
 * Dictionary to specify a boundary identifier for <Titanium.UI.iOS.CollisionBehavior.addBoundary>.
 */
interface BoundaryIdentifier {
    /**
     * Arbitrary identifier for the boundary
     */
    identifier?: string;

    /**
     * Start point for the boundary
     */
    point1?: Point;

    /**
     * End point for the boundary
     */
    point2?: Point;

}
/**
 * Simple object holding the data for a logical cpu.
 */
interface CPU {
    /**
     * General description of the CPU
     */
    model?: string;

    /**
     * Speed of the CPU in MHz
     */
    speed?: number;

    /**
     * A collection of timings for this logical CPU.
     */
    times?: CPUTimes;

}
/**
 * Simple object holding the data for a logical cpu execution times.
 */
interface CPUTimes {
    /**
     * The number of milliseconds the CPU has spent in idle mode.
     */
    idle?: number;

    /**
     * The number of milliseconds the CPU has spent in irq mode.
     */
    irq?: number;

    /**
     * The number of milliseconds the CPU has spent in nice mode.
     */
    nice?: number;

    /**
     * The number of milliseconds the CPU has spent in sys mode.
     */
    sys?: number;

    /**
     * The number of milliseconds the CPU has spent in user mode.
     */
    user?: number;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface CalendarPermissionResponse {
    /**
     * Error code, if any returned.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates whether the request succeeded.
     */
    success?: boolean;

}
/**
 * A media object from the camera or photo gallery.
 */
interface CameraMediaItemType extends SuccessResponse {
    /**
     * Error code. Returns 0.
     */
    code?: number;

    /**
     * Simple object defining the user's selected crop rectangle, or `null` if the user has not edited the photo. `width`/`height` values are assumed to be in pixels.
     */
    cropRect?: Dimension;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * The live photo object, as a <Titanium.UI.iOS.LivePhoto> and
     * `undefined` if no live photo is selected.
     */
    livePhoto?: Titanium.UI.iOS.LivePhoto;

    /**
     * The media object, as a [Blob](Titanium.Blob).
     */
    media?: Titanium.Blob;

    /**
     * The type of media, either `MEDIA_TYPE_PHOTO`, `MEDIA_TYPE_LIVEPHOTO` or `MEDIA_TYPE_VIDEO` defined in <Titanium.Media>.
     */
    mediaType?: string;

    /**
     * Simple object defining the preview image size. This will be undefined when custom camera overlay is not used. Values are assumed to be in pixels.
     */
    previewRect?: Size;

    /**
     * Indicates if the operation succeeded. Returns `true`.
     */
    success?: boolean;

}
/**
 * A media object from photo gallery when <Titanium.Media.allowMultiple> is `true`.
 */
interface CameraMediaMultipleItemsType extends SuccessResponse {
    /**
     * The list of selected images.
     */
    images?: CameraMediaItemType[];

    /**
     * The list of selected live photo objects.
     */
    livePhotos?: Titanium.UI.iOS.LivePhoto[];

    /**
     * The list of selected videos.
     */
    videos?: CameraMediaItemType[];

}
/**
 * Simple object for specifying options to [showCamera](Titanium.Media.showCamera).
 */
interface CameraOptionsType {
    /**
     * Specifies if the media should be editable after capture/selection.
     */
    allowEditing?: boolean;

    /**
     * Function to call if the user presses the back button.
     */
    androidback?: (param0: FailureResponse) => void;

    /**
     * Specifies if the dialog should be animated upon showing and hiding.
     */
    animated?: boolean;

    /**
     * Controls the type of arrow and position of the popover.
     */
    arrowDirection?: number;

    /**
     * Specifies if the camera should be hidden automatically after the media capture is completed.
     */
    autohide?: boolean;

    /**
     * Determines if the camera preview should rotate or not.
     */
    autorotate?: boolean;

    /**
     * Function to call if the user presses the cancel button.
     */
    cancel?: (param0: FailureResponse) => void;

    /**
     * Function to call upon receiving an error.
     */
    error?: (param0: FailureResponse) => void;

    /**
     * Show the camera in a popover.
     */
    inPopOver?: boolean;

    /**
     * Array of media type constants to allow. Note: If you want to select live photos, iOS only  allows
     * you to select existing live photos from the gallery, capturing new live photos is not supported by
     * iOS public API, yet.
     */
    mediaTypes?: string[];

    /**
     * View to added as an overlay to the camera UI (on top).
     */
    overlay?: Titanium.UI.View;

    /**
     * View to position the camera or photo gallery popover on top of.
     */
    popoverView?: Titanium.UI.View;

    /**
     * Specifies if the media should be saved to the photo gallery upon successful capture.
     */
    saveToPhotoGallery?: boolean;

    /**
     * Indicates if the built-in camera controls should be displayed.
     */
    showControls?: boolean;

    /**
     * Function to call when the camera is closed after a successful capture/selection.
     */
    success?: (param0: CameraMediaItemType) => void;

    /**
     * Transformation matrix to apply to the camera or photogallery view.
     */
    transform?: Titanium.UI.Matrix2D;

    /**
     * Maximum duration (in milliseconds) to allow video capture before completing.
     */
    videoMaximumDuration?: number;

    /**
     * Constant to indicate the video quality during capture.
     */
    videoQuality?: number;

    /**
     * Opens the camera with the specified camera direction.
     */
    whichCamera?: number;

}
/**
 * Dictionary describing the items for <Titanium.UI.Clipboard.setItems>.
 */
interface ClipboardItemsType {
    /**
     * An array of key-value items to add to the clipboard. The key must a valid mime-type
     * matching the mime-type of the value.
     */
    items?: any[];

    /**
     * The privacy options to apply to all the items on the clipboard. The available options are
     * described in `Ti.UI.CLIPBOARD_OPTION_*`. Depending on the key, the value can be a Date or
     * Boolean.
     */
    options?: any;

}
/**
 * Argument object passed to the [connected](Titanium.Network.Socket.TCP.connected) callback when the socket connects.
 */
interface ConnectedCallbackArgs {
    /**
     * Socket instance that has been connected.
     */
    socket?: Titanium.Network.Socket.TCP;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface ContactsAuthorizationResponse extends ErrorResponse {
}
/**
 * Simple object for defining a single image in a cover flow view.
 */
interface CoverFlowImageType {
    /**
     * Display height of the image, in Apple points.
     */
    height?: number;

    /**
     * Image to use, as a local file URL, `Blob`, or `File`.
     */
    image?: string | Titanium.Blob | Titanium.Filesystem.File;

    /**
     * Display width for the image, in Apple points.
     */
    width?: number;

}
/**
 * Arguments to be passed to createBuffer
 */
interface CreateBufferArgs {
    /**
     * The byte order of this buffer.
     */
    byteOrder?: number;

    /**
     * The length of the buffer.
     */
    length?: number;

    /**
     * The type of data encoding to use with `value`.
     */
    type?: string;

    /**
     * An initial value which will be encoded and placed in the buffer. If value is a Number, type must also be set. (this is simply a convenient way of calling <Titanium.Codec.encodeString> or <Titanium.Codec.encodeNumber> and placing the encoded value in the returned buffer.)
     */
    value?: string | number;

}
/**
 * Argument passed to [createStream](Titanium.Stream.createStream).
 */
interface CreateStreamArgs {
    /**
     * Mode to open the stream in.
     */
    mode?: number;

    /**
     * Object that the stream will read from or write to.
     */
    source?: Titanium.Blob | Titanium.Buffer;

}
/**
 * The parameter passed to the <Titanium.UI.WebView.createPDF> or <Titanium.UI.WebView.createWebArchive>callback.
 */
interface DataCreationResult {
    /**
     * The created data.
     */
    data?: Titanium.Blob;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if the data creation successful or not.
     */
    success?: boolean;

}
/**
 * Named parameters for <Titanium.Codec.decodeNumber>.
 */
interface DecodeNumberDict {
    /**
     * byte order to decode with.
     */
    byteOrder?: number;

    /**
     * Index in the `source` buffer of the first byte of data to decode.
     */
    position?: number;

    /**
     * Buffer to decode.
     */
    source: Titanium.Buffer;

    /**
     * The encoding type to use.
     */
    type: string;

}
/**
 * Named parameters for <Titanium.Codec.decodeString>.
 */
interface DecodeStringDict {
    /**
     * Character set to use when encoding this string to bytes.
     */
    charset?: string;

    /**
     * Number of bytes to decode.
     */
    length?: number;

    /**
     * Index in the `source` buffer of the first byte of data to decode.
     */
    position?: number;

    /**
     * Buffer to decode.
     */
    source: Titanium.Buffer;

}
/**
 * A simple object consisting of the position and size measurements. Effectively combines <Size> and <Point> but ensures numeric x/y values.
 */
interface Dimension extends Size {
    /**
     * The x-axis coordinate of the position. When returned by <Titanium.UI.View.rect> the position is relative to it's parent.
     */
    x?: number;

    /**
     * The y-axis coordinate of the position. When returned by <Titanium.UI.View.rect> the position is relative to it's parent.
     */
    y?: number;

}
/**
 * An extension of <Dimension> where Android returns additional absolute X/Y values/properties for <Titanium.UI.View.rect>
 */
interface DimensionWithAbsolutes extends Dimension {
    /**
     * The x-axis coordinate of the position relative to the main window.
     */
    absoluteX?: number;

    /**
     * The y-axis coordinate of the position relative to the main window.
     */
    absoluteY?: number;

}
/**
 * A simple object for specifying options when showing or dismissing a <Titanium.UI.iOS.DocumentViewer>.
 */
interface DocumentViewerOptions {
    /**
     * Indicates whether to animate the transition.
     */
    animated?: boolean;

    /**
     * Anchors the options menu to the specified view.
     */
    view?: Titanium.UI.View;

}
/**
 * Named parameters for <Titanium.Codec.encodeNumber>.
 */
interface EncodeNumberDict {
    /**
     * Byte order to encode with.
     */
    byteOrder?: number;

    /**
     * Destination buffer.
     */
    dest: Titanium.Buffer;

    /**
     * Index in the `dest` buffer of the first byte of encoded data.
     */
    position?: number;

    /**
     * Number to encode.
     */
    source: number;

    /**
     * Encoding type to use.
     */
    type: string;

}
/**
 * Named parameters for <Titanium.Codec.encodeString>.
 */
interface EncodeStringDict {
    /**
     * Character encoding to use when encoding this string to bytes.
     */
    charset?: string;

    /**
     * Destination buffer.
     */
    dest: Titanium.Buffer;

    /**
     * Index in the `dest` buffer of the first byte of the encoded string.
     */
    destPosition?: number;

    /**
     * Source string to encode.
     */
    source: string;

    /**
     * Number of characters in `source` to encode.
     */
    sourceLength?: number;

    /**
     * Position in `source` to start encoding.
     */
    sourcePosition?: number;

}
/**
 * Object passed to the error callback when the socket enters the [ERROR](Titanium.Network.Socket.ERROR) state.
 */
interface ErrorCallbackArgs extends FailureResponse {
    /**
     * Error code. Returns a non-zero value.
     */
    code?: number;

    /**
     * The error code of the error (potentially system-dependent).
     * @deprecated Use the code property for a numeric error code
     */
    errorCode: never;

    /**
     * Socket that experienced the error.
     */
    socket?: Titanium.Network.Socket.TCP;

    /**
     * Indicates if the operation succeeded. Returns `false`.
     */
    success?: boolean;

}
/**
 * Properties used in any event or callback which needs to report a success or failure.
 */
interface ErrorResponse {
    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface EventsAuthorizationResponse {
    /**
     * Error code, if any returned.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates whether the request succeeded.
     */
    success?: boolean;

}
/**
 * Properties used in any event or callback which needs to report a failure.
 */
interface FailureResponse extends ErrorResponse {
    /**
     * Error code. Returns a non-zero value.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if the operation succeeded. Returns `false`.
     */
    success?: boolean;

}
/**
 * An abstract datatype for specifying a text font.
 */
interface Font {
    /**
     * Specifies the font family or specific font to use.
     */
    fontFamily?: string;

    /**
     * Font size, in platform-dependent units.
     */
    fontSize?: number | string;

    /**
     * Font style. Valid values are "italic" or "normal".
     */
    fontStyle?: string;

    /**
     * Font weight. Valid values are "bold", "semibold", "normal", "thin",
     * "light" and "ultralight".
     */
    fontWeight?: string;

    /**
     * The text style for the font.
     */
    textStyle?: string;

}
/**
 * Simple object returned in the callback from the
 * [forwardGeocoder](Titanium.Geolocation.forwardGeocoder) method.
 * Note that Android includes a number of extra fields.
 */
interface ForwardGeocodeResponse extends ErrorResponse {
    /**
     * Estimated accuracy of the geocoding, in meters.
     */
    accuracy?: number;

    /**
     * Full address.
     */
    address?: string;

    /**
     * City name.
     */
    city?: string;

    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Country name.
     */
    country?: string;

    /**
     * Country code.
     */
    countryCode?: string;

    /**
     * Country code. Same as `countryCode`.
     */
    country_code?: string;

    /**
     * Display address. Identical to `address`.
     */
    displayAddress?: string;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Latitude of the geocoded address.
     */
    latitude?: string;

    /**
     * Longitude of the geocoded address.
     */
    longitude?: string;

    /**
     * Postal code.
     */
    postalCode?: string;

    /**
     * First line of region.
     */
    region1?: string;

    /**
     * Not used.
     */
    region2?: string;

    /**
     * Street name, without street address.
     */
    street?: string;

    /**
     * Street name.
     */
    street1?: string;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

}
/**
 * Simple object representing a place, returned in the callback from the
 * [reverseGeocoder](Titanium.Geolocation.reverseGeocoder) method.
 */
interface GeocodedAddress {
    /**
     * Full address.
     */
    address?: string;

    /**
     * City name.
     */
    city?: string;

    /**
     * Country name.
     */
    country?: string;

    /**
     * Country code.
     */
    countryCode?: string;

    /**
     * Country code. To be replaced by `countryCode`.
     * @deprecated
     */
    country_code: never;

    /**
     * Display address. Identical to `address`.
     * @deprecated
     */
    displayAddress: never;

    /**
     * Latitude of the geocoded point.
     */
    latitude?: number;

    /**
     * Longitude of the geocoded point.
     */
    longitude?: number;

    /**
     * Postal code
     */
    postalCode?: string;

    /**
     * First line of region.
     */
    region1?: string;

    /**
     * Not used.
     */
    region2?: string;

    /**
     * Street name, without street address.
     */
    street?: string;

    /**
     * Street name.
     */
    street1?: string;

    /**
     * Postal code. To be replaced by `postalCode`
     * @deprecated
     */
    zipcode: never;

}
/**
 * Dictionary object of parameters used to register the application with local notifications using
 * the <Titanium.App.iOS.registerUserNotificationSettings> method.
 */
interface GetUserNotificationSettings {
    /**
     * The current alert settings.
     */
    alertSetting?: number;

    /**
     * The current alert style used to display notifications.
     */
    alertStyle?: number;

    /**
     * The current authorization status for using notifications.
     */
    authorizationStatus?: number;

    /**
     * The current badge settings.
     */
    badgeSetting?: number;

    /**
     * The current CarPlay settings.
     */
    carPlaySetting?: number;

    /**
     * Set of categories of user notification actions required by the applicaiton to use.
     */
    categories?: Titanium.App.iOS.UserNotificationCategory[];

    /**
     * The authorization status to play sounds for critical alerts.
     * Available in Titanium SDK 7.4.0 and later.
     */
    criticalAlertSetting?: number;

    /**
     * The current lock-screen settings.
     */
    lockScreenSetting?: number;

    /**
     * The current notication-center settings.
     */
    notificationCenterSetting?: number;

    /**
     * A Boolean value indicating the system displays a button for in-app notification settings.
     * Available in Titanium SDK 7.4.0 and later.
     */
    providesAppNotificationSettings?: number;

    /**
     * The current sound settings.
     */
    soundSetting?: number;

    /**
     * Notification types to use.
     */
    types?: number[];

}
/**
 * A simple object defining a color gradient.
 */
interface Gradient {
    /**
     * Set to `true` to continue filling with the final color beyond the `endPoint`.
     */
    backfillEnd?: boolean;

    /**
     * Set to `true` to continue filling with the starting color beyond the `startPoint`.
     */
    backfillStart?: boolean;

    /**
     * An array of colors, as a color name or hex triplet.
     */
    colors?: string[] | GradientColorRef[];

    /**
     * End point for the gradient.
     */
    endPoint?: Point;

    /**
     * For a radial gradient, the radius at the `endPoint`.
     */
    endRadius?: number;

    /**
     * Start point for the gradient.
     */
    startPoint?: Point;

    /**
     * For a radial gradient, the radius at the `startPoint`.
     */
    startRadius?: number;

    /**
     * Type of gradient, either 'linear' or 'radial'.
     */
    type?: string;

}
/**
 * A simple object consisting of a color and an offset.
 */
interface GradientColorRef {
    /**
     * Color value at this point in the gradient, as a color name or hex triplet.
     */
    color?: string | Titanium.UI.Color;

    /**
     * The color's normalized position within the gradient, ranging from 0 (start) to 1 (end).
     */
    offset?: number;

}
/**
 * Simple object holding compass heading data.
 */
interface HeadingData {
    /**
     * Accuracy of the compass heading, in platform-specific units.
     */
    accuracy?: number;

    /**
     * Declination in degrees from magnetic North.
     */
    magneticHeading?: number;

    /**
     * Timestamp for the heading data, in milliseconds.
     */
    timestamp?: number;

    /**
     * Declination in degrees from true North.
     */
    trueHeading?: number;

    /**
     * Raw geomagnetic data for the X axis.
     */
    x?: number;

    /**
     * Raw geomagnetic data for the Y axis.
     */
    y?: number;

    /**
     * Raw geomagnetic data for the Z axis.
     */
    z?: number;

}
/**
 * Argument passed to the [getCurrentHeading](Titanium.Geolocation.getCurrentHeading) callback.
 */
interface HeadingResponse extends ErrorResponse {
    /**
     * Error code.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * If `success` is true, the actual heading data.
     */
    heading?: HeadingData;

    /**
     * Indicates a successful operation.
     */
    success?: boolean;

}
/**
 * Dictionary object of parameters for horizontal-only insets applied to [Table](Titanium.UI.TableView) and [List](Titanium.UI.ListView) views. Only `left` and `right` properties are used (see <Padding>).
 */
interface HorizontalInsets {
    /**
     * Left padding/inset
     */
    left?: number;

    /**
     * Right padding/inset
     */
    right?: number;

}
/**
 * Template that represents the basic appearance of a list item.
 */
interface ItemTemplate {
    /**
     * Contains an array of subview templates to be added (in order) as children to this view.
     */
    childTemplates?: ViewTemplate[];

    /**
     * Contains key-value pairs of view events and their listeners that are applied to the ListItem.
     */
    events?: any;

    /**
     * Contains key-value pairs of view properties and their values that are applied to the ListItem.
     */
    properties?: Dictionary<Titanium.UI.ListItem>;

}
/**
 * See [TextView.setLineSpacing](https://developer.android.com/reference/android/widget/TextView#setLineSpacing(float,%20float))
 */
interface LabelLineSpacing {
    /**
     * The value in pixels that should be added to each line other than the last line. This will be applied after the multiplier
     */
    add?: number;

    /**
     * The value by which each line height other than the last line will be multiplied by
     */
    multiply?: number;

}
/**
 * Dictionary object of parameters used to identify an incoming URL that is handled
 * by the application.
 */
interface LaunchOptionsType {
    /**
     * The application or service that triggered the handled URL.
     */
    source?: string;

    /**
     * The url that was triggered by the application or service.
     */
    url?: string;

}
/**
 * Represents displayed item data.
 */
interface ListDataItem {
    /**
     * Contains key-value pairs of view properties and their values that are applied to the
     * `ListItem`.
     */
    properties?: Dictionary<Titanium.UI.ListItem>;

    /**
     * Template ID configured with the <Titanium.UI.ListView.templates> property or
     * <Titanium.UI.LIST_ITEM_TEMPLATE_DEFAULT>.
     */
    template?: string | number;

    [index: string]: any;
}
/**
 * The arguments for the <Titanium.UI.ListView.prefetch> and <Titanium.UI.ListView.cancelprefetch> events.
 */
interface ListItemEventType {
    /**
     * The item ID bound to the list item that generated the event.
     */
    itemId?: string;

    /**
     * Item index.
     */
    itemIndex?: number;

    /**
     * List section if the item is contained in a list section.
     */
    section?: Titanium.UI.ListSection;

    /**
     * Section index.
     */
    sectionIndex?: number;

}
/**
 * A simple object for specifying the animation properties to use when inserting or deleting
 * sections or cells, or scrolling the list.
 */
interface ListViewAnimationProperties {
    /**
     * Whether this list change should be animated. Ignored if any `animationStyle` value is specified.
     */
    animated?: boolean;

    /**
     * Type of animation to use for cell insertions and deletions.
     */
    animationStyle?: number;

    /**
     * Specifies what position to scroll the selected cell to.
     */
    position?: number;

}
/**
 * A simple object that represents an index entry in a `ListView`.
 */
interface ListViewIndexEntry {
    /**
     * Section index associated with this title.
     */
    index?: number;

    /**
     * Title to display in the index bar.
     */
    title?: string;

}
/**
 * The parameter for [setMarker](Titanium.UI.ListView.setMarker) and [addMarker](Titanium.UI.ListView.addMarker) methods.
 */
interface ListViewMarkerProps {
    /**
     * The itemIndex of the reference item.
     */
    itemIndex?: number;

    /**
     * The sectionIndex of the reference item.
     */
    sectionIndex?: number;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface LocationAccuracyAuthorizationResponse extends ErrorResponse {
    /**
     * The level of location accuracy the app has granted.
     */
    accuracyAuthorization?: number;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface LocationAuthorizationResponse extends ErrorResponse {
}
/**
 * Simple object holding the data for a location update.
 */
interface LocationCoordinates {
    /**
     * Accuracy of the location update, in meters.
     */
    accuracy?: number;

    /**
     * Altitude of the location update, in meters.
     */
    altitude?: number;

    /**
     * Vertical accuracy of the location update, in meters.
     */
    altitudeAccuracy?: number;

    /**
     * The floor of the building on which the user is located.
     */
    floor?: LocationCoordinatesFloor;

    /**
     * Compass heading, in degrees. May be unknown if device is not moving. On
     * iOS, a negative value indicates that the heading data is not valid.
     */
    heading?: number;

    /**
     * Latitude of the location update, in decimal degrees.
     */
    latitude?: number;

    /**
     * Longitude of the location update, in decimal degrees.
     */
    longitude?: number;

    /**
     * Current speed in meters/second. On iOS, a negative value indicates that the
     * heading data is not valid or the accuracy is configured incorrectly.
     * Note: Due to the Apple Geolocation API, set the <Titanium.Geolocation.accuracy>
     * property to <Titanium.Geolocation.ACCURACY_BEST_FOR_NAVIGATION> in order to properly
     * measure speed changes and prevent the app from returning negative values.
     */
    speed?: number;

    /**
     * Timestamp for this location update, in milliseconds.
     */
    timestamp?: number;

}
/**
 * Simple object holding floor of the building on which the user is located.
 */
interface LocationCoordinatesFloor {
    /**
     * The logical floor of the building.
     */
    level?: number;

}
/**
 * Simple object describing a location provider.
 */
interface LocationProviderDict {
    /**
     * Accuracy of the location provider, either fine (1) or coarse (2).
     */
    accuracy?: number;

    /**
     * Name of the location provider.
     */
    name?: string;

    /**
     * Power consumption for this provider, either low (1), medium (2), or high (3).
     */
    power?: number;

}
/**
 * Argument passed to the [getCurrentPosition](Titanium.Geolocation.getCurrentPosition) callback.
 */
interface LocationResults extends ErrorResponse {
    /**
     * If `success` is true, actual location data for this update.
     */
    coords?: LocationCoordinates;

    /**
     * If `success` is true, object describing the location provider generating this update.
     */
    provider?: LocationProviderDict;

}
/**
 * Simple object passed to <Titanium.UI.createMatrix2D> to initialize a matrix.
 */
interface Matrix2DCreationDict {
    /**
     * Point to rotate around, specified as a dictionary object with `x` and `y`
     * properties, where { x: 0.5, y: 0.5 } represents the center of whatever is being
     * rotated.
     */
    anchorPoint?: Point;

    /**
     * Rotation angle, in degrees. See the [rotate](Titanium.UI.Matrix2D.rotate) method
     * for a discussion of rotation.
     */
    rotate?: number;

    /**
     * Scale the matrix by the specified scaling factor. The same scaling factor is used
     * for both horizontal and vertical scaling.
     */
    scale?: number;

}
/**
 * Simple object passed to <Titanium.UI.createMatrix3D> to initialize a matrix.
 */
interface Matrix3DCreationDict {
    /**
     * Scale the matrix by the specified scaling factor.
     */
    scale?: number;

}
/**
 * Simple object passed to <Titanium.UI.create2DMatrix> to initialize a matrix.
 */
interface MatrixCreationDict {
    /**
     * Point to rotate around, specified as a dictionary object with `x` and `y`
     * properties, where { x: 0.5, y: 0.5 } represents the center of whatever is being
     * rotated.
     */
    anchorPoint?: Point;

    /**
     * Rotation angle, in degrees. See the [rotate](Titanium.UI.2DMatrix.rotate) method
     * for a discussion of rotation.
     */
    rotate?: number;

    /**
     * Scale the matrix by the specified scaling factor. The same scaling factor is used
     * for both horizontal and vertical scaling.
     */
    scale?: number;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface MediaAuthorizationResponse extends ErrorResponse {
}
/**
 * A full query descriptor for a filtering predicate.
 */
interface MediaQueryInfoType {
    /**
     * Whether or not the predicate is for an exact match.  The default is `true`.
     */
    exact?: boolean;

    /**
     * The value for the given predicate. See the descriptions in <MediaQueryType> for information about which properties require which values.
     */
    value?: number | string | boolean;

}
/**
 * A specifier for a media library query. By default, filters perform an exact match.
 */
interface MediaQueryType {
    /**
     * The album artist to filter on. Value should be a String.
     */
    albumArtist?: MediaQueryInfoType | string;

    /**
     * The album artist persistent ID to filter on. Value should be a Number.
     */
    albumArtistPersistentID?: MediaQueryInfoType | number;

    /**
     * The album persistent ID to filter on. Value should be a Number.
     */
    albumPersistentID?: MediaQueryInfoType | number;

    /**
     * The album title to filter on. Value should be a String.
     */
    albumTitle?: MediaQueryInfoType | string;

    /**
     * The artist to filter on. Value should be a String.
     */
    artist?: MediaQueryInfoType | string;

    /**
     * The composer to filter on. Value should be a String.
     */
    composer?: MediaQueryInfoType | string;

    /**
     * The composer persistent ID to filter on. Value should be a Number.
     */
    composerPersistentID?: MediaQueryInfoType | number;

    /**
     * The genre to filter on. Value should be a String.
     */
    genre?: MediaQueryInfoType | string;

    /**
     * The genre persistent ID to filter on. Value should be a Number.
     */
    genrePersistentID?: MediaQueryInfoType | number;

    /**
     * A constant that specifies the ordering of the result array.
     */
    grouping?: number;

    /**
     * Filter by whether or not the item is a protected asset.
     * Value should be a Boolean.
     */
    hasProtectedAsset?: MediaQueryInfoType | boolean;

    /**
     * Filter by whether or not the item is a cloud item.
     * Value should be a Boolean.
     */
    isCloudItem?: MediaQueryInfoType | boolean;

    /**
     * Filter by whether or not the item is a compilation.
     * The value should be a Boolean.
     */
    isCompilation?: MediaQueryInfoType | boolean;

    /**
     * The media type to filter on.
     */
    mediaType?: MediaQueryInfoType | number;

    /**
     * The persistent ID to filter on. Value should be a Number.
     */
    persistentID?: MediaQueryInfoType | number;

    /**
     * The play count to filter on. Value should be a Number.
     */
    playCount?: MediaQueryInfoType | number;

    /**
     * The podcast persistent ID to filter on. Value should be a Number.
     */
    podcastPersistentID?: MediaQueryInfoType | number;

    /**
     * The podcast title to filter on. Value should be a String.
     */
    podcastTitle?: MediaQueryInfoType | string;

    /**
     * The title to filter on. Value should be a String.
     */
    title?: MediaQueryInfoType | string;

}
/**
 * Simple object passed to the [scanMediaFiles](Titanium.Media.Android.scanMediaFiles) callback.
 */
interface MediaScannerResponse {
    /**
     * Path to the media file that was scanned.
     */
    path?: string;

    /**
     * URI to the file if it was scanned and added to the media library, or `null`
     * if the file was not added.
     */
    uri?: string;

}
/**
 * Dictionary of options for showing a menu popup with <Titanium.UI.iOS.MenuPopup.show>.
 */
interface MenuPopupShowParams {
    /**
     * Determines whether the menu popup should be opened or closed animated.
     */
    animated?: boolean;

    /**
     * Indicates the arrow direction of the menu popup.
     */
    arrowDirection?: number;

    /**
     * The view where the menu pop is shown at.
     */
    view: Titanium.UI.View;

}
/**
 * Reply message received from watch app.
 */
interface MessageReply {
    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Reply message from watchapp.
     */
    message?: any;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

}
/**
 * An object for setting `min`/`max` value pairs.
 */
interface MinMaxOptions {
    /**
     * Maximum value
     */
    max?: number;

    /**
     * Minimum value
     */
    min?: number;

}
/**
 * Simple object used to describe the size of a movie.
 */
interface MovieSize {
    /**
     * Height of the movie.
     */
    height?: number;

    /**
     * Width of the movie.
     */
    width?: number;

}
/**
 * Simple object for specifying options to [openMusicLibrary](Titanium.Media.openMusicLibrary).
 */
interface MusicLibraryOptionsType {
    /**
     * Set to `true` to allow the user to select multiple items from the library.
     */
    allowMultipleSelections?: boolean;

    /**
     * Boolean if the dialog should be animated when showing and hiding.
     */
    animated?: boolean;

    /**
     * Specifies that the library should be hidden automatically after media selection is completed.
     */
    autohide?: boolean;

    /**
     * Function to call if the user presses the cancel button.
     */
    cancel?: (param0: FailureResponse) => void;

    /**
     * Function to call upon receiving an error.
     */
    error?: (param0: FailureResponse) => void;

    /**
     * An array of media type constants defining selectable media.
     */
    mediaTypes?: number | number[];

    /**
     * Function to call when the music library selection is made.
     */
    success?: (param0: MusicLibraryResponseType) => void;

}
/**
 * Simple object passed to the [openMusicLibrary](Titanium.Media.openMusicLibrary)
 * `success` callback function.
 */
interface MusicLibraryResponseType {
    /**
     * A list of all the items chosen by the user.
     */
    items?: Titanium.Media.Item[];

    /**
     * A single representative of the selected items.
     */
    representative?: Titanium.Media.Item;

    /**
     * Media types in this collection, represented as the bitwise OR of the media type
     * values for all media types represented in `items`.
     */
    types?: number;

}
/**
 * Dictionary object of parameters used to create a notification using
 * <Titanium.App.iOS.scheduleLocalNotification>.
 */
interface NotificationParams {
    /**
     * Alert button text ('Open', by default) or home text ('Press Home to unlock', by default)
     * to display.
     */
    alertAction?: string;

    /**
     * Alert message to display.
     */
    alertBody?: string;

    /**
     * Image to display instead of `Default.png` when launching the application.
     */
    alertLaunchImage?: string;

    /**
     * Alert subtitle to display.
     */
    alertSubtitle?: string;

    /**
     * Alert title to display.
     */
    alertTitle?: string;

    /**
     * Notification attachments to display.
     */
    attachments?: UserNotificationAttachment[];

    /**
     * Application badge value.
     */
    badge?: number;

    /**
     * String identifier of category of actions to be displayed for an interactive notification.
     */
    category?: string;

    /**
     * Date and time for the notification to occur.
     */
    date?: Date;

    /**
     * The notification identifier.
     */
    identifier: string;

    /**
     * Region the notification will be triggered in. Allowed parameter are:
     * - `latitude`: Latitude of the location center, in decimal degrees (required).
     * - `longitude`: Longitude of the location center, in decimal degrees (required).
     * - `triggersOnce`: Whether or not the notification will only fire once (optional, default: true).
     */
    region?: any;

    /**
     * Interval to repeat the notification. One of `weekly`, `daily`, `yearly,` `monthly`.
     */
    repeat?: string;

    /**
     * Path to the sound file to play when notification occurs, relative to the `Resources` folder.
     */
    sound?: string;

    /**
     * The string the notification adds to the category's summary format string.
     */
    summaryArgument?: string;

    /**
     * The number of items the notification adds to the category's summary format string.
     */
    summaryArgumentCount?: string;

    /**
     * Timezone of the date configured for the notification. If not set, the system timezone is used.
     */
    timezone?: string;

    /**
     * Data to pass to the application with the notification event.
     */
    userInfo?: any;

}
/**
 * An object returned when the <Titanium.UI.WebView.onlink> callback is fired.
 */
interface OnLinkURLResponse {
    /**
     * The url of the link that should be navigated to.
     */
    url?: string;

}
/**
 * The optional options to pass to the URL handling (iOS 10+). Pass a
 * dictionary with one or more of the following string-keys:
 *     * `UIApplicationOpenURLOptionsSourceApplicationKey` (String value)
 *     * `UIApplicationOpenURLOptionsAnnotationKey` (Array value)
 *     * `UIApplicationOpenURLOptionsOpenInPlaceKey` (Boolean value)
 *     * `UIApplicationOpenURLOptionUniversalLinksOnly` (Boolean value)
 * Read more about the available keys in the [Apple documentation](https://developer.apple.com/documentation/uikit/uiapplicationopenurloptionskey?language=objc).
 */
interface OpenURLOptions {
    /**
     * When you include this key in the options dictionary, the method opens the URL only if the URL is a valid universal link and there is an installed app capable of opening that URL.
     */
    UIApplicationOpenURLOptionUniversalLinksOnly?: boolean;

    /**
     * contains the information passed to a document interaction controller object's annotation property.
     */
    UIApplicationOpenURLOptionsAnnotationKey?: any[];

    /**
     * When the value of this property is `false`, you must copy the document to maintain access to it. If the flag is not set, you also must copy the document before you can use it.
     */
    UIApplicationOpenURLOptionsOpenInPlaceKey?: boolean;

    /**
     * The value of this key is an String containing the bundle ID of the app that made the request. If the request originated from another app belonging to your team, UIKit sets the value of this key to the ID of that app. If the team identifier of the originating app is different than the team identifier of the current app, the value of the key is nil.
     */
    UIApplicationOpenURLOptionsSourceApplicationKey?: string;

}
/**
 * Simple object passed to the <Titanium.Android.Activity> callbacks for
 * onPrepareOptionsMenu and onCreateOptionsMenu.
 * Additional properties may be set on the Object.
 */
interface OptionsMenuCallbackObject {
    /**
     * The relevant Menu.
     */
    menu?: Titanium.Android.Menu;

}
/**
 * Dictionary object of parameters for the padding/insets applied to all kinds of views.
 */
interface Padding extends HorizontalInsets {
    /**
     * Bottom padding/inset
     */
    bottom?: number;

    /**
     * Top padding/inset
     */
    top?: number;

}
/**
 * An abstract datatype for specifying an Paragraph style attribute.
 */
interface ParagraphAttribute {
    /**
     * The text alignment of the receiver.
     */
    alignment?: number;

    /**
     * A Boolean value indicating whether the system may tighten inter-character spacing
     * before truncating text.
     */
    allowsDefaultTighteningForTruncation?: boolean;

    /**
     * The indentation of the first line of the receiver.
     */
    firstLineHeadIndent?: number | string;

    /**
     * The indentation of the lines of lines other than the first.
     */
    headIndent?: number | string;

    /**
     * The threshold of paragraph for hyphenation.
     */
    hyphenationFactor?: number;

    /**
     * The mode that should be used to break lines in the receiver.
     */
    lineBreakMode?: number;

    /**
     * The line height multiple.
     */
    lineHeightMultiple?: number;

    /**
     * The distance in points between the bottom of one line fragment and the top of the next.
     */
    lineSpacing?: number | string;

    /**
     * The maximum line height of receiver.
     */
    maximumLineHeight?: number | string;

    /**
     * The minimum height of receiver.
     */
    minimumLineHeight?: number | string;

    /**
     * The space after the end of the paragraph.
     */
    paragraphSpacingAfter?: number | string;

    /**
     * The distance between the top of paragraph and the beginning of its text content.
     */
    paragraphSpacingBefore?: number | string;

    /**
     * The trailing indentation of the receiver.
     */
    tailIndent?: number | string;

}
/**
 * Simple object for specifying options to
 * [openPhotoGallery](Titanium.Media.openPhotoGallery).
 */
interface PhotoGalleryOptionsType {
    /**
     * Specifies if the media should be editable after capture/selection.
     */
    allowEditing?: boolean;

    /**
     * Specifies if the user should be able to select multiple photos.
     */
    allowMultiple?: boolean;

    /**
     * Specifies if the video should be transcoded (using highest quality preset) . If set to false no video transcoding will be performed.
     */
    allowTranscoding?: boolean;

    /**
     * Specifies if the dialog should be animated upon showing and hiding.
     */
    animated?: boolean;

    /**
     * Controls the type of arrow and position of the popover.
     */
    arrowDirection?: number;

    /**
     * Specifies if the photo gallery should be hidden automatically after the media
     * selection is completed.
     */
    autohide?: boolean;

    /**
     * Function to call if the user presses the cancel button.
     */
    cancel?: (param0: FailureResponse) => void;

    /**
     * Function to call upon receiving an error.
     */
    error?: (param0: FailureResponse) => void;

    /**
     * Array of media type constants to allow.
     * Live photos is only supported on the iOS platform, starting with iOS 9.1. If you want
     * to allow live photos with <Titanium.Media.MEDIA_TYPE_LIVEPHOTO>, you also need to specify
     * at least <Titanium.Media.MEDIA_TYPE_PHOTO> as a fallback. If you do not allow live
     * photos, they still can be selected, but will be represented as a normal static photo.
     */
    mediaTypes?: string[];

    /**
     * View to position the photo gallery popover on top of.
     */
    popoverView?: Titanium.UI.View;

    /**
     * Specifies number of media item that can be selected.
     */
    selectionLimit?: boolean;

    /**
     * Function to call when the photo gallery is closed after a successful selection.
     */
    success?: ((param0: CameraMediaItemType) => void) | ((param0: CameraMediaMultipleItemsType) => void);

}
/**
 * A pair of coordinates used to describe the location of a <Titanium.UI.View>.
 */
interface Point {
    /**
     * The x-axis coordinate of this point.
     */
    x?: number | string;

    /**
     * The y-axis coordinate of this point.
     */
    y?: number | string;

}
/**
 * Simple `Error` argument provided to the callback from the
 * [executeAllAsync](Titanium.Database.DB.executeAllAsync) method in case of failure
 */
interface PossibleBatchQueryError {
    /**
     * Index of the failed query
     */
    index?: number;

}
/**
 * The parameter passed to the `error` callback of <PreviewImageOptions>.
 */
interface PreviewImageError extends FailureResponse {
    /**
     * Error code, if applicable.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Description of the error.
     * @deprecated
     */
    message?: string;

    /**
     * Indicates if the operation succeeded. Returns `false`.
     */
    success?: boolean;

}
/**
 * Options passed to <Titanium.Media.previewImage>.
 */
interface PreviewImageOptions {
    /**
     * Function called back if the preview fails. Check the `message` property of passed back parameter.
     */
    error?: (param0: PreviewImageError) => void;

    /**
     * The image to preview. Must be a blob based on a file, such as from <Titanium.Filesystem.File.read>.
     */
    image?: Titanium.Blob;

    /**
     * Function to be called back if the preview succeeds. No info is passed.
     */
    success?: (param0: SuccessResponse) => void;

}
/**
 * Argument passed to the callback each time the
 * [pump](Titanium.Stream.pump) operation has new data to deliver.
 */
interface PumpCallbackArgs extends ErrorResponse {
    /**
     * Buffer object holding the data currently being pumped to the handler method.
     */
    buffer?: Titanium.Buffer;

    /**
     * Number of bytes being passed to this invocation of the handler, or
     * -1 in the event of an error or end of stream.
     */
    bytesProcessed?: number;

    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Text description of the error.
     * @deprecated Use error property to determine error message
     */
    errorDescription: never;

    /**
     * Whether an error was encountered. Set to 1 in the case of an error, 0
     * otherwise.
     * @deprecated Use success or code values to determine error conditions
     */
    errorState: never;

    /**
     * Stream being read from.
     */
    source?: Titanium.IOStream;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

    /**
     * Total number of bytes read from the stream so far,
     * including the data passed to this current invocation of the handler.
     */
    totalBytesProcessed?: number;

}
/**
 * Simple object for specifying push notification options to
 * [registerForPushNotifications](Titanium.Network.registerForPushNotifications).
 */
interface PushNotificationConfig {
    /**
     * Callback function invoked upon receiving a new push notification.
     */
    callback?: (param0: PushNotificationData) => void;

    /**
     * Callback function called when an error occurs during registration.
     */
    error?: (param0: PushNotificationErrorArg) => void;

    /**
     * Callback function called when the push registration is successfully completed.
     */
    success?: (param0: PushNotificationSuccessArg) => void;

    /**
     * Array of `NOTIFICATION_TYPE` constants that the application would like to receive.
     */
    types?: number[];

}
/**
 * A simple object representing a push notification.
 */
interface PushNotificationData {
    /**
     * The `userinfo` dictionary passed to the Apple Push Notification Service.
     */
    data?: any;

    /**
     * Boolean indicating if notification was received while app was in background.
     */
    inBackground?: boolean;

}
/**
 * A simple object passed to the
 * [registerForPushNotifications](Titanium.Network.registerForPushNotifications) error callback.
 */
interface PushNotificationErrorArg extends FailureResponse {
    /**
     * Error code. Returns a non-zero value.
     */
    code?: number;

    /**
     * Indicates if the operation succeeded. Returns `false`.
     */
    success?: boolean;

    /**
     * The value of this string is always "remote".
     */
    type?: string;

}
/**
 * A simple object passed to the
 * [registerForPushNotifications](Titanium.Network.registerForPushNotifications) success callback.
 */
interface PushNotificationSuccessArg extends SuccessResponse {
    /**
     * Error code. Returns 0.
     */
    code?: number;

    /**
     * The device token which this device was registered for.
     */
    deviceToken?: string;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if the operation succeeded. Returns `true`.
     */
    success?: boolean;

    /**
     * The value of this string is always "remote".
     */
    type?: string;

}
/**
 * Argument passed to the read callback when an asynchronous [read](Titanium.Stream.read) operation
 * finishes.
 */
interface ReadCallbackArgs extends ErrorResponse {
    /**
     * Number of bytes processed, or -1 in the event of an error or end of stream.
     */
    bytesProcessed?: number;

    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Text description of the error.
     * @deprecated Use error property to determine error message
     */
    errorDescription: never;

    /**
     * Whether an error was encountered. Set to 1 in the case of an error, 0
     * otherwise.
     * @deprecated Use success or code values to determine error conditions
     */
    errorState: never;

    /**
     * Stream being read.
     */
    source?: Titanium.IOStream;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

}
/**
 * An Object describing the current ready state. See [onreadystatechange](Titanium.Network.HTTPClient.onreadystatechange) for more information.
 */
interface ReadyStatePayload {
    /**
     * The state for which `onreadystatechange` was invoked. Set to one of `Titanium.Network.HTTPClient` ready-state constants
     */
    readyState?: number;

}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface RequestCameraAccessResult extends ErrorResponse {
}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface RequestMusicLibraryAccessResult extends ErrorResponse {
}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface RequestPermissionAccessResult extends ErrorResponse {
}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface RequestPhotoGalleryAccessResult extends ErrorResponse {
}
/**
 * Argument passed to the callback when a request finishes successfully or erroneously.
 */
interface RequestStorageAccessResult extends ErrorResponse {
}
/**
 * Simple object returned in the callback from the
 * [reverseGeocoder](Titanium.Geolocation.reverseGeocoder) method.
 */
interface ReverseGeocodeResponse extends ErrorResponse {
    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * An array of reverse-geocoded addresses matching the requested location.
     */
    places?: GeocodedAddress[];

}
/**
 * An Object describing the current audio route.
 */
interface RouteDescription {
    /**
     * An Array of current input ports for the session. See the `AUDIO_SESSION_PORT` constants.
     */
    inputs?: string[];

    /**
     * An Array of current output ports for the session. See the `AUDIO_SESSION_PORT` constants.
     */
    outputs?: string[];

}
/**
 * Represents the custom edit action for a ListItem.
 */
interface RowActionType {
    /**
     * The background color of the row action.
     */
    color?: string;

    /**
     * The [identifier](RowActionType. identifier) of the row action. Only included in the event
     * if previously defined. Available in Titanium 6.0.0 and later.
     */
    identifier?: string;

    /**
     * The style of the row action.
     */
    style: number;

    /**
     * The title of the row action.
     */
    title: string;

}
/**
 * The parameter passed to the <Titanium.Media.takeScreenshot> callback.
 */
interface ScreenshotResult {
    /**
     * The screenshot image.
     */
    media?: Titanium.Blob;

}
/**
 * The search bar token for the <Titanium.UI.SearchBar.insertTokenAtIndex> method.
 */
interface SearchBarToken {
    /**
     * The identifier of the search bar token.
     */
    identifier: string;

    /**
     * The image of the search bar token.
     */
    image?: string;

    /**
     * The text of the search bar token (displayed in the search bar).
     */
    text: string;

}
/**
 * The parameter passed to the <Titanium.UI.WebView.findString>.
 */
interface SearchResult {
    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if string found or not.
     */
    success?: boolean;

}
/**
 * The protocol that the <Titanium.Network.HTTPClient.securityManager> must implement.
 */
interface SecurityManagerProtocol {
    /**
     * The <APSConnectionDelegate> for this connection.
     */
    connectionDelegateForUrl(url: any): APSConnectionDelegate;

    /**
     * Returns an array of objects implementing the [X509KeyManager](https://developer.android.com/reference/javax/net/ssl/X509KeyManager.html) protocol for the SSL Context.
     */
    getKeyManagers(proxy: any): any[];

    /**
     * Returns an array of objects implementing the [X509TrustManager](https://developer.android.com/reference/javax/net/ssl/X509TrustManager.html) protocol for the SSL Context.
     */
    getTrustManagers(proxy: any): any[];

    /**
     * Returns if the security manager will participate in authentication of this end point.
     */
    willHandleURL(url: any): boolean;

}
/**
 * The arguments for the <Titanium.UI.ListView.itemsselected> event.
 */
interface SelectedItem {
    /**
     * Item index.
     */
    itemIndex?: number;

    /**
     * List section if the item is contained in a list section.
     */
    section?: Titanium.UI.ListSection;

    /**
     * Section index.
     */
    sectionIndex?: number;

}
/**
 * The arguments for the <Titanium.UI.TableView.rowsselected> event.
 */
interface SelectedRowObject {
    /**
     * Row index.
     */
    index?: number;

    /**
     * Table view row object.
     */
    row?: Titanium.UI.TableViewRow;

    /**
     * Properties of the row. Use this property rather than `row` to access any custom row properties.
     */
    rowData?: Dictionary<Titanium.UI.TableViewRow>;

    /**
     * Table view section object, if the clicked row is contained in a section.
     */
    section?: Titanium.UI.TableViewSection;

}
/**
 * Options passed to <Titanium.Android.createServiceIntent>.
 */
interface ServiceIntentOptions {
    /**
     * One of the `START_*` constants from <Titanium.Android> to specify the "stickiness" of the Service when Android shuts down the host application.
     */
    startMode?: number;

    /**
     * URL for the service's JavaScript.
     */
    url?: string;

}
/**
 * Object of options for <Titanium.UI.iOS.ApplicationShortcuts.addDynamicShortcut>.
 */
interface ShortcutParams {
    /**
     * The icon to be displayed on the application shortcut. You can either use one of the constants like
     * <Titanium.UI.iOS.SHORTCUT_ICON_TYPE_COMPOSE>, a local image specified by the image path or a reference to a
     * <Titanium.Contacts.Person>.
     */
    icon?: number | string | Titanium.Contacts.Person;

    /**
     * The unique key for the application shortcut. Equates to the underlying `UIApplicationShortcutItemIconType` key
     */
    identifier: string;

    /**
     * The subtitle displayed on the application shortcut.
     */
    subtitle?: string;

    /**
     * The title of the application shortcut.
     */
    title: string;

    /**
     * The userInfo of the application shortcut.
     */
    userInfo?: any;

}
/**
 * Dictionary of options for <Titanium.UI.iPad.Popover.show>.
 */
interface ShowPopoverParams {
    /**
     * Indicates whether to animate showing the popover.
     */
    animated?: boolean;

    /**
     * Sets the arrow position of the popover relative to the attached view object's dimensions
     * when showing the popover.
     */
    rect?: Dimension;

    /**
     * Attaches the popover to the specified view when showing the popover.
     */
    view: Titanium.UI.View;

}
/**
 * A simple object consisting of size measurements.
 */
interface Size {
    /**
     * The height measurement.
     */
    height?: number;

    /**
     * The width measurement.
     */
    width?: number;

}
/**
 * The parameter passed to the <Titanium.UI.WebView.takeSnapshot> callback.
 */
interface SnapshotResult {
    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * The snapshot image.
     */
    snapshot?: Titanium.Blob;

    /**
     * Indicates if the snapshot taken.
     */
    success?: boolean;

}
/**
 * The optional options to pass to the <Titanium.UI.WebView.findString>. Pass a
 * dictionary with one or more of the following string-keys:
 *     * `caseSensitive` (Boolean value)
 *     * `backward` (Boolean value)
 *     * `wraps` (Boolean value)
 */
interface StringSearchOptions {
    /**
     * The direction to search from the current selection. The search will respect the writing direction of the document
     */
    backward?: boolean;

    /**
     * Whether or not the search should be case sensitive.
     */
    caseSensitive?: boolean;

    /**
     * Whether the search should start at the beginning of the document once it reaches the end.
     */
    wraps?: boolean;

}
/**
 * Properties used in any event or callback which needs to report a success.
 */
interface SuccessResponse extends ErrorResponse {
    /**
     * Error code. Returns 0.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Indicates if the operation succeeded. Returns `true`.
     */
    success?: boolean;

}
/**
 * Dictionary to specify edge insets for <Titanium.UI.Tab.iconInsets>. Difference from typical <Padding> is that `right` and `bottom` are ignored and calculated internally from `top`/`left` values.
 */
interface TabIconInsets extends Padding {
    /**
     * Bottom padding/inset
     */
    bottom: never;

    /**
     * Left inset.
     */
    left?: number;

    /**
     * Right padding/inset
     */
    right: never;

    /**
     * Top inset.
     */
    top?: number;

}
/**
 * A simple object for specifying the animation properties to use when inserting or deleting rows, or scrolling the table.
 */
interface TableViewAnimationProperties {
    /**
     * Whether this table change should be animated. Ignored if any `animationStyle` value is specified.
     */
    animated?: boolean;

    /**
     * Type of animation to use for row insertions and deletions.
     */
    animationStyle?: number;

    /**
     * Specifies what position to scroll the selected row to.
     */
    position?: number;

}
/**
 * A simple object that represents an index entry in a `TableView`.
 */
interface TableViewIndexEntry {
    /**
     * Row index associated with this item.
     */
    index?: number;

    /**
     * Title to display in the index bar for this item.
     */
    title?: string;

}
/**
 * Dictionary object of parameters for the <Titanium.UI.TextField.padding> that describes the padding. Most notable difference from typical <Padding> is that `top`/`bottom` are only supported on Android.
 */
interface TextFieldPadding extends Padding {
    /**
     * Bottom padding (Android only, since 6.1.0)
     */
    bottom?: number;

    /**
     * Left padding
     */
    left?: number;

    /**
     * Right padding
     */
    right?: number;

    /**
     * Top padding (Android only, since 6.1.0)
     */
    top?: number;

}
/**
 * Simple object passed to the thumbnail callback in response to the
 * [requestThumbnailImagesAtTimes](Titanium.Media.VideoPlayer.requestThumbnailImagesAtTimes)
 * method.
 */
interface ThumbnailResponse extends ErrorResponse {
    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Thumbnail image, as a `Blob`.
     */
    image?: Titanium.Blob;

    /**
     * Time offset for the thumbnail, in seconds.
     */
    time?: number;

}
/**
 * An abstract type to represent a metadata item inside the `metadata` event (iOS only).
 */
interface TiMetadataItemType {
    /**
     * A dictionary of the additional attributes.
     */
    extraAttributes?: any;

    /**
     * The key of the metadata item, e.g. "title".
     */
    key?: string;

    /**
     * The key-path of the metadata item.
     */
    keySpace?: string;

    /**
     * The value of the metadata item. Can be represented as various types.
     */
    value?: string | number | boolean;

}
/**
 * The top-level Titanium module.
 */
declare namespace Titanium {
    /**
     * Date of the Titanium build.
     */
    const buildDate: string;

    /**
     * Git hash of the Titanium build.
     */
    const buildHash: string;

    /**
     * User-agent string used by Titanium.
     */
    let userAgent: string;

    /**
     * Version of Titanium that is executing.
     */
    const version: string;

    /**
     * Adds the specified callback as an event listener for the named event.
     */
    function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

    /**
     * Creates a new buffer based on the params.
     */
    function createBuffer(params: CreateBufferArgs): Titanium.Buffer;

    /**
     * Fires a synthesized event to any registered listeners.
     */
    function fireEvent(name: string, event?: any): void;

    /**
     * Gets the value of the <Titanium.buildDate> property.
     * @deprecated Access <Titanium.buildDate> instead.
     */
    function getBuildDate(): string;

    /**
     * Gets the value of the <Titanium.buildHash> property.
     * @deprecated Access <Titanium.buildHash> instead.
     */
    function getBuildHash(): string;

    /**
     * Gets the value of the <Titanium.userAgent> property.
     * @deprecated Access <Titanium.userAgent> instead.
     */
    function getUserAgent(): string;

    /**
     * Gets the value of the <Titanium.version> property.
     * @deprecated Access <Titanium.version> instead.
     */
    function getVersion(): string;

    /**
     * Removes the specified callback as an event listener for the named event.
     */
    function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

    /**
     * Sets the value of the <Titanium.userAgent> property.
     * @deprecated Set the value using <Titanium.userAgent> instead.
     */
    function setUserAgent(userAgent: string): void;

    /**
     * The top-level Android module.
     */
    namespace Android {
        /**
         * User switched airplane mode on or off.
         */
        const ACTION_AIRPLANE_MODE_CHANGED: string;

        /**
         * List all applications.
         */
        const ACTION_ALL_APPS: string;

        /**
         * Handle an incoming phone call.
         */
        const ACTION_ANSWER: string;

        /**
         * Used to indicate that the data is an attachment.
         */
        const ACTION_ATTACH_DATA: string;

        /**
         * Listen to battery state change status.
         */
        const ACTION_BATTERY_CHANGED: string;

        /**
         * Indicates low battery condition on the device.
         */
        const ACTION_BATTERY_LOW: string;

        /**
         * Inidicates the battery is now okay after being low.
         */
        const ACTION_BATTERY_OKAY: string;

        /**
         * Indicates the system has finished booting.
         */
        const ACTION_BOOT_COMPLETED: string;

        /**
         * Show activity for reporting a bug.
         */
        const ACTION_BUG_REPORT: string;

        /**
         * Perform a call to someone specified by the `data` property.
         */
        const ACTION_CALL: string;

        /**
         * User pressed the call button.
         */
        const ACTION_CALL_BUTTON: string;

        /**
         * The camera button was pressed.
         */
        const ACTION_CAMERA_BUTTON: string;

        /**
         * Display an activity chooser.
         */
        const ACTION_CHOOSER: string;

        /**
         * User dismissed a temporary system dialog, such as the notification drawer or recent-app drawer.
         */
        const ACTION_CLOSE_SYSTEM_DIALOGS: string;

        /**
         * The device's configuration changed.
         */
        const ACTION_CONFIGURATION_CHANGED: string;

        /**
         * Create a shortcut.
         */
        const ACTION_CREATE_SHORTCUT: string;

        /**
         * Date changed.
         */
        const ACTION_DATE_CHANGED: string;

        /**
         * Default action, which is `Titanium.Android.ACTION_VIEW`
         */
        const ACTION_DEFAULT: string;

        /**
         * Delete the data specified by the Intent's `data` property.
         */
        const ACTION_DELETE: string;

        /**
         * Indicates a low memory condition on the device.
         */
        const ACTION_DEVICE_STORAGE_LOW: string;

        /**
         * Dial a number specified by the Intent's `data` property.
         */
        const ACTION_DIAL: string;

        /**
         * Provide editable access to the data specified by the Intent's `data` property.
         */
        const ACTION_EDIT: string;

        /**
         * Allow the user to select a particular kind of data specified by the Intent's `type` property.
         */
        const ACTION_GET_CONTENT: string;

        /**
         * GTalk connection has been established.
         */
        const ACTION_GTALK_SERVICE_CONNECTED: string;

        /**
         * GTalk connection has been disconnected.
         */
        const ACTION_GTALK_SERVICE_DISCONNECTED: string;

        /**
         * A wired headset has been plugged in or unplugged.
         */
        const ACTION_HEADSET_PLUG: string;

        /**
         * An input method has been changed.
         */
        const ACTION_INPUT_METHOD_CHANGED: string;

        /**
         * Insert an empty item into the given container.
         */
        const ACTION_INSERT: string;

        /**
         * Pick an existing item or insert an empty item, then edit it.
         */
        const ACTION_INSERT_OR_EDIT: string;

        /**
         * Start as the main entry point.
         */
        const ACTION_MAIN: string;

        /**
         * Indicates low memory condition notification acknowledged by user and package management should be started.
         */
        const ACTION_MANAGE_PACKAGE_STORAGE: string;

        /**
         * External media was removed from SD card slot, but mount point was not unmounted.
         */
        const ACTION_MEDIA_BAD_REMOVAL: string;

        /**
         * The media button was pressed.
         */
        const ACTION_MEDIA_BUTTON: string;

        /**
         * External media is present and being disk-checked.
         */
        const ACTION_MEDIA_CHECKING: string;

        /**
         * User has expressed the desire to remove the external storage media.
         */
        const ACTION_MEDIA_EJECT: string;

        /**
         * External media is present and mounted at its mount point.
         */
        const ACTION_MEDIA_MOUNTED: string;

        /**
         * External media is present, but is using an incompatible filesystem or is blank.
         */
        const ACTION_MEDIA_NOFS: string;

        /**
         * External media has been removed.
         */
        const ACTION_MEDIA_REMOVED: string;

        /**
         * The media scanner has finished scanning a directory.
         */
        const ACTION_MEDIA_SCANNER_FINISHED: string;

        /**
         * Request the media scanner to scan a file and add it to the media database.
         */
        const ACTION_MEDIA_SCANNER_SCAN_FILE: string;

        /**
         * The media scanner has started scanning a directory.
         */
        const ACTION_MEDIA_SCANNER_STARTED: string;

        /**
         * External media is unmounted because it is being shared via USB mass storage.
         */
        const ACTION_MEDIA_SHARED: string;

        /**
         * Corresponds to the Android `Intent.ACTION_MEDIA_UNMOUNTABLE` constant.
         */
        const ACTION_MEDIA_UNMOUNTABLE: string;

        /**
         * External media is present, but not mounted at its mount point.
         */
        const ACTION_MEDIA_UNMOUNTED: string;

        /**
         * An outgoing call is about to be placed.
         */
        const ACTION_NEW_OUTGOING_CALL: string;

        /**
         * A new application package has been installed on the device.
         */
        const ACTION_PACKAGE_ADDED: string;

        /**
         * An existing application package has been changed.
         */
        const ACTION_PACKAGE_CHANGED: string;

        /**
         * The user has cleared the data of a package.
         */
        const ACTION_PACKAGE_DATA_CLEARED: string;

        /**
         * An existing application package has been removed from the device.
         */
        const ACTION_PACKAGE_REMOVED: string;

        /**
         * A new version of an application package has been installed, replacing an existing version that was previously installed.
         */
        const ACTION_PACKAGE_REPLACED: string;

        /**
         * The user has restarted a package, and all of its processes have been killed.
         */
        const ACTION_PACKAGE_RESTARTED: string;

        /**
         * Pick an item from the directory indicated by the Intent's `data` property.
         */
        const ACTION_PICK: string;

        /**
         * Pick an activity given an intent.
         */
        const ACTION_PICK_ACTIVITY: string;

        /**
         * External power has been connected to the device.
         */
        const ACTION_POWER_CONNECTED: string;

        /**
         * External power has been disconnected from the device.
         */
        const ACTION_POWER_DISCONNECTED: string;

        /**
         * Show power usage information to the user.
         */
        const ACTION_POWER_USAGE_SUMMARY: string;

        /**
         * Content provider published new events or items.
         */
        const ACTION_PROVIDER_CHANGED: string;

        /**
         * Device rebooted.
         */
        const ACTION_REBOOT: string;

        /**
         * Run the data.
         */
        const ACTION_RUN: string;

        /**
         * Sent when the device goes to sleep and becomes non-interactive.
         */
        const ACTION_SCREEN_OFF: string;

        /**
         * Sent when the device wakes up and becomes interactive.
         */
        const ACTION_SCREEN_ON: string;

        /**
         * Perform a search.
         */
        const ACTION_SEARCH: string;

        /**
         * Start action associated with long pressing on the search key.
         */
        const ACTION_SEARCH_LONG_PRESS: string;

        /**
         * Deliver data to another activity.
         */
        const ACTION_SEND: string;

        /**
         * Deliver data to the recipient specified by the Intent's `data` property.
         */
        const ACTION_SENDTO: string;

        /**
         * Deliver multiple data to another activity.
         */
        const ACTION_SEND_MULTIPLE: string;

        /**
         * Show settings for choosing the system wallpaper.
         */
        const ACTION_SET_WALLPAPER: string;

        /**
         * Device is shutting down.
         */
        const ACTION_SHUTDOWN: string;

        /**
         * Perform data synchronization.
         */
        const ACTION_SYNC: string;

        /**
         * Start the platform-defined tutorial.
         */
        const ACTION_SYSTEM_TUTORIAL: string;

        /**
         * The time was set.
         */
        const ACTION_TIME_CHANGED: string;

        /**
         * The current time changed.  Sent every minute.
         */
        const ACTION_TIME_TICK: string;

        /**
         * A user ID was removed from the system.
         */
        const ACTION_UID_REMOVED: string;

        /**
         * Sent when the user is present after device wakes up.
         */
        const ACTION_USER_PRESENT: string;

        /**
         * Display data to the user.
         */
        const ACTION_VIEW: string;

        /**
         * Start voice command.
         */
        const ACTION_VOICE_COMMAND: string;

        /**
         * The current system wallpaper has changed.
         */
        const ACTION_WALLPAPER_CHANGED: string;

        /**
         * Perform a web search.
         */
        const ACTION_WEB_SEARCH: string;

        /**
         * Notification category indicating an alarm or timer.
         */
        const CATEGORY_ALARM: string;

        /**
         * Set if the activity should be considered as an alternative action to the data the user is currently viewing.
         */
        const CATEGORY_ALTERNATIVE: string;

        /**
         * Activity can browse the Internet.
         */
        const CATEGORY_BROWSABLE: string;

        /**
         * Notification category indicating an incoming call (voice or video) or similar synchronous
         * communication request.
         */
        const CATEGORY_CALL: string;

        /**
         * Activity should be used as the default action to perform on a piece of data.
         */
        const CATEGORY_DEFAULT: string;

        /**
         * Activity is in the development preference panel.
         */
        const CATEGORY_DEVELOPMENT_PREFERENCE: string;

        /**
         * Notification category indicating an asynchronous bulk message (email).
         */
        const CATEGORY_EMAIL: string;

        /**
         * Activity can run inside a parent activity.
         */
        const CATEGORY_EMBED: string;

        /**
         * Notification category indicating an error in background operation or authentication status.
         */
        const CATEGORY_ERROR: string;

        /**
         * Notification category indicating a calendar event.
         */
        const CATEGORY_EVENT: string;

        /**
         * To be used as test code for framework instrumentation tests.
         */
        const CATEGORY_FRAMEWORK_INSTRUMENTATION_TEST: string;

        /**
         * Home activity, the first activity that is displayed when the device boots.
         */
        const CATEGORY_HOME: string;

        /**
         * Provides information about the package it is in.
         */
        const CATEGORY_INFO: string;

        /**
         * Activity is in the device's launcher.
         */
        const CATEGORY_LAUNCHER: string;

        /**
         * Notification category indicating an incoming direct message (SMS, instant message, etc.).
         */
        const CATEGORY_MESSAGE: string;

        /**
         * This activity may be exercised by the monkey or other automated test tools.
         */
        const CATEGORY_MONKEY: string;

        /**
         * Activity can open raw `file://` or `scheme://` URIs.
         */
        const CATEGORY_OPENABLE: string;

        /**
         * This activity is a preference panel.
         */
        const CATEGORY_PREFERENCE: string;

        /**
         * Notification category indicating the progress of a long-running background operation.
         */
        const CATEGORY_PROGRESS: string;

        /**
         * Notification category indicating a promotion or advertisement.
         */
        const CATEGORY_PROMO: string;

        /**
         * Notification category indicating a specific, timely recommendation for a single thing.
         */
        const CATEGORY_RECOMMENDATION: string;

        /**
         * To be used as a sample code example (not part of the normal user experience).
         */
        const CATEGORY_SAMPLE_CODE: string;

        /**
         * Activity should be considered as an alternative selection action to the data the user
         * has currently selected.
         */
        const CATEGORY_SELECTED_ALTERNATIVE: string;

        /**
         * Notification category for a running background service.
         */
        const CATEGORY_SERVICE: string;

        /**
         * Notification category for a social network or sharing update.
         */
        const CATEGORY_SOCIAL: string;

        /**
         * Notification category indicating ongoing information about device or contextual status.
         */
        const CATEGORY_STATUS: string;

        /**
         * Activity to be used in a tab activity.
         */
        const CATEGORY_TAB: string;

        /**
         * To be used as a test (not part of the normal user experience).
         */
        const CATEGORY_TEST: string;

        /**
         * Notification category indicating media transport control for playback.
         */
        const CATEGORY_TRANSPORT: string;

        /**
         * To be used as a unit test (run through the Test Harness).
         */
        const CATEGORY_UNIT_TEST: string;

        /**
         * Use all default settings for a notification; see
         * [Notification.defaults](Titanium.Android.Notification.defaults).
         */
        const DEFAULT_ALL: number;

        /**
         * Use the default light settings for a notification; see
         * [Notification.defaults](Titanium.Android.Notification.defaults).
         */
        const DEFAULT_LIGHTS: number;

        /**
         * Use the default sound settings for a notification; see
         * [Notification.defaults](Titanium.Android.Notification.defaults).
         */
        const DEFAULT_SOUND: number;

        /**
         * Use the default vibration settings for a notification; see
         * [Notification.defaults](Titanium.Android.Notification.defaults).
         */
        const DEFAULT_VIBRATE: number;

        /**
         * Integer indicating how many pending alarms are being delivered with the intent.
         */
        const EXTRA_ALARM_COUNT: string;

        /**
         * String array containing e-mail addresses for blind carbon copying.
         */
        const EXTRA_BCC: string;

        /**
         * String array containing e-mail addresses for carbon copying.
         */
        const EXTRA_CC: string;

        /**
         * Boolean indicating full uninstall (true) or partial uninstall (false).
         */
        const EXTRA_DATA_REMOVED: string;

        /**
         * Boolean indicating to restart the application or not.
         */
        const EXTRA_DONT_KILL_APP: string;

        /**
         * String array containing e-mail addresses.
         */
        const EXTRA_EMAIL: string;

        /**
         * An Intent describing the choices you would like shown.
         */
        const EXTRA_INTENT: string;

        /**
         * A KeyEvent object containing the event that triggered the creation of the Intent it is in.
         */
        const EXTRA_KEY_EVENT: string;

        /**
         * String holding the phone number to call or number that was called.
         */
        const EXTRA_PHONE_NUMBER: string;

        /**
         * Boolean indicating if the package is being replaced.
         */
        const EXTRA_REPLACING: string;

        /**
         * Bitmap icon.
         */
        const EXTRA_SHORTCUT_ICON: string;

        /**
         * Resource of the shortcut.
         */
        const EXTRA_SHORTCUT_ICON_RESOURCE: string;

        /**
         * Intent of a shortcut.
         */
        const EXTRA_SHORTCUT_INTENT: string;

        /**
         * Name of the shortcut.
         */
        const EXTRA_SHORTCUT_NAME: string;

        /**
         * URI containing the stream data.
         */
        const EXTRA_STREAM: string;

        /**
         * Subject line of a message.
         */
        const EXTRA_SUBJECT: string;

        /**
         * Initial data to place in a newly created record.
         */
        const EXTRA_TEMPLATE: string;

        /**
         * Corresponds to the Android `Intent.EXTRA_TEXT` constant.
         */
        const EXTRA_TEXT: string;

        /**
         * Corresponds to the Android `Intent.EXTRA_TITLE` constant.
         */
        const EXTRA_TITLE: string;

        /**
         * UID of the assigned packaged.
         */
        const EXTRA_UID: string;

        /**
         * Not used.
         */
        const FILL_IN_ACTION: number;

        /**
         * Not used.
         */
        const FILL_IN_CATEGORIES: number;

        /**
         * Not used.
         */
        const FILL_IN_COMPONENT: number;

        /**
         * Not used.
         */
        const FILL_IN_DATA: number;

        /**
         * Not used.
         */
        const FILL_IN_PACKAGE: number;

        /**
         * If activity is already running, bring it to the foreground.
         */
        const FLAG_ACTIVITY_BROUGHT_TO_FRONT: number;

        /**
         * If the activity is present, removes any activities on top of it to make it the foreground activity.
         */
        const FLAG_ACTIVITY_CLEAR_TOP: number;

        /**
         * Corresponds to the Android `Intent.FLAG_ACTIVITY_CLEAR_WHEN_TASK_RESET` constant.
         */
        const FLAG_ACTIVITY_CLEAR_WHEN_TASK_RESET: number;

        /**
         * Exclude the activity from recently launched activities.
         */
        const FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS: number;

        /**
         * Return result to the original calling activity.
         */
        const FLAG_ACTIVITY_FORWARD_RESULT: number;

        /**
         * Activity was launched from history.
         */
        const FLAG_ACTIVITY_LAUNCHED_FROM_HISTORY: number;

        /**
         * Start the activity as a new task even if it exists.
         */
        const FLAG_ACTIVITY_MULTIPLE_TASK: number;

        /**
         * Activity will be the start of a new task (collection of activities).
         */
        const FLAG_ACTIVITY_NEW_TASK: number;

        /**
         * Prevent transition animation.
         */
        const FLAG_ACTIVITY_NO_ANIMATION: number;

        /**
         * Do not keep the activity in the history stack.
         */
        const FLAG_ACTIVITY_NO_HISTORY: number;

        /**
         * Disables the [onUserLeaveHint()](https://developer.android.com/reference/android/app/Activity.html#onUserLeaveHint()) callback.
         */
        const FLAG_ACTIVITY_NO_USER_ACTION: number;

        /**
         * Corresponds to the Android `Intent.FLAG_ACTIVITY_PREVIOUS_IS_TOP` constant.
         */
        const FLAG_ACTIVITY_PREVIOUS_IS_TOP: number;

        /**
         * If the activity already exists, place it at the top of the history stack.
         */
        const FLAG_ACTIVITY_REORDER_TO_FRONT: number;

        /**
         * If the task already exists, resets the task to its initial state.
         */
        const FLAG_ACTIVITY_RESET_TASK_IF_NEEDED: number;

        /**
         * Do not launch the activity if it is already running.
         */
        const FLAG_ACTIVITY_SINGLE_TOP: number;

        /**
         * Cancel the notification when it is clicked by the user.
         */
        const FLAG_AUTO_CANCEL: number;

        /**
         * Cancel the current pending intent before creating a new one.
         */
        const FLAG_CANCEL_CURRENT: number;

        /**
         * Enable a log message to print out the resolution of the intent.
         */
        const FLAG_DEBUG_LOG_RESOLUTION: number;

        /**
         * Indicates the intent is coming from a background operation.
         */
        const FLAG_FROM_BACKGROUND: number;

        /**
         * Grant read permission on the URI in the Intent's data or clipboard.
         */
        const FLAG_GRANT_READ_URI_PERMISSION: number;

        /**
         * Grants write permission on the URI in the Intent's data or clipboard.
         */
        const FLAG_GRANT_WRITE_URI_PERMISSION: number;

        /**
         * Repeat audio until the notification is cancelled or the notification window
         * is opened.
         */
        const FLAG_INSISTENT: number;

        /**
         * Do not cancel the notification when the user clicks the Clear All button.
         */
        const FLAG_NO_CLEAR: number;

        /**
         * If the current intent does not exist, do not create it.
         */
        const FLAG_NO_CREATE: number;

        /**
         * The pending intent can only be used once.
         */
        const FLAG_ONE_SHOT: number;

        /**
         * Specifies that a notification is in reference to something that is ongoing, like a phone call.
         */
        const FLAG_ONGOING_EVENT: number;

        /**
         * Play an alert (sound, lights, and/or vibration) once each time the notification is sent, even if it has not been canceled before that.
         */
        const FLAG_ONLY_ALERT_ONCE: number;

        /**
         * When sending a broadcast, only registered receivers will be called.
         */
        const FLAG_RECEIVER_REGISTERED_ONLY: number;

        /**
         * Use LED lights to alert the user to the notification.
         */
        const FLAG_SHOW_LIGHTS: number;

        /**
         * If the current pending intent already exists, only update the current intent's extra data.
         */
        const FLAG_UPDATE_CURRENT: number;

        /**
         * Constant corresponding to connectedDevice in the R.attr.foregroundServiceType attribute. Auto, bluetooth, TV or other devices connection, monitoring and interaction.
         */
        const FOREGROUND_SERVICE_TYPE_CONNECTED_DEVICE: number;

        /**
         * Constant corresponding to location in the R.attr.foregroundServiceType attribute. GPS, map, navigation location update.
         */
        const FOREGROUND_SERVICE_TYPE_LOCATION: number;

        /**
         * A special value indicates to use all types set in manifest file.
         */
        const FOREGROUND_SERVICE_TYPE_MANIFEST: number;

        /**
         * Constant corresponding to mediaPlayback in the R.attr.foregroundServiceType attribute. Music, video, news or other media playback.
         */
        const FOREGROUND_SERVICE_TYPE_MEDIA_PLAYBACK: number;

        /**
         * Constant corresponding to mediaProjection in the R.attr.foregroundServiceType attribute. Managing a media projection session, e.g for screen recording or taking screenshots.
         */
        const FOREGROUND_SERVICE_TYPE_MEDIA_PROJECTION: number;

        /**
         * The default foreground service type if not been set in manifest file.
         */
        const FOREGROUND_SERVICE_TYPE_NONE: number;

        /**
         * Constant corresponding to phoneCall in the R.attr.foregroundServiceType attribute. Ongoing phone call or video conference.
         */
        const FOREGROUND_SERVICE_TYPE_PHONE_CALL: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_DEFAULT: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_HIGH: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_LOW: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_MAX: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_MIN: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_NONE: number;

        /**
         * Used with [NotificationChannel](Titanium.Android.NotificationChannel) to specify an importance level.
         */
        const IMPORTANCE_UNSPECIFIED: number;

        /**
         * Standard Action Bar navigation mode.
         */
        const NAVIGATION_MODE_STANDARD: number;

        /**
         * Action Bar tab navigation mode.
         */
        const NAVIGATION_MODE_TABS: number;

        /**
         * Not used.
         * @deprecated
         */
        const PENDING_INTENT_FOR_ACTIVITY: number;

        /**
         * Not used.
         * @deprecated
         */
        const PENDING_INTENT_FOR_BROADCAST: number;

        /**
         * Not used.
         * @deprecated
         */
        const PENDING_INTENT_FOR_SERVICE: number;

        /**
         * Not used.
         * @deprecated
         */
        const PENDING_INTENT_MAX_VALUE: number;

        /**
         * Default priority if it does not fit into another priority category.
         */
        const PRIORITY_DEFAULT: number;

        /**
         * Use for high priority notifications like real-time chat messages.
         */
        const PRIORITY_HIGH: number;

        /**
         * Use for low priority notifications like software updates.
         */
        const PRIORITY_LOW: number;

        /**
         * Use for urgent or time-critical notifications, for example, turn-by-turn directions or
         * emergency alerts.
         */
        const PRIORITY_MAX: number;

        /**
         * Use for expired events.
         */
        const PRIORITY_MIN: number;

        /**
         * Accessor for Android system resources.
         */
        const R: Titanium.Android.R;

        /**
         * Used with [setResult](Titanium.Android.Activity.setResult) to specify that
         * an activity was canceled.
         */
        const RESULT_CANCELED: number;

        /**
         * Used with [setResult](Titanium.Android.Activity.setResult) to specify a
         * user-defined result.
         */
        const RESULT_FIRST_USER: number;

        /**
         * Used with [setResult](Titanium.Android.Activity.setResult) to specify that
         * an activity succeeded.
         */
        const RESULT_OK: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify the activity should run in the same orientation as the activity behind it
         * in the activity stack.
         */
        const SCREEN_ORIENTATION_BEHIND: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify a landscape screen orientation.
         */
        const SCREEN_ORIENTATION_LANDSCAPE: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify that the sensor should be ignored and the display should not rotate.
         */
        const SCREEN_ORIENTATION_NOSENSOR: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify a portrait screen orientation.
         */
        const SCREEN_ORIENTATION_PORTRAIT: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify that orientation should be determined by the orientation sensor.
         */
        const SCREEN_ORIENTATION_SENSOR: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify that the system should use its default rules for determining the best
         * orientation.
         */
        const SCREEN_ORIENTATION_UNSPECIFIED: number;

        /**
         * Use with [requestedOrientation](Titanium.Android.Activity.requestedOrientation) to
         * specify that the system should use the user's preferred orientation.
         */
        const SCREEN_ORIENTATION_USER: number;

        /**
         * Always show this item as an action button in the action bar.
         */
        const SHOW_AS_ACTION_ALWAYS: number;

        /**
         * The action view can collapse to a normal menu item.
         */
        const SHOW_AS_ACTION_COLLAPSE_ACTION_VIEW: number;

        /**
         * Show this item as an action button if the system decides there is room for it.
         */
        const SHOW_AS_ACTION_IF_ROOM: number;

        /**
         * Never display this item as an action button in the action bar.
         */
        const SHOW_AS_ACTION_NEVER: number;

        /**
         * When this item is in the action bar, always show it with a text label.
         */
        const SHOW_AS_ACTION_WITH_TEXT: number;

        /**
         * A Service start mode indicating that if the host application is stopped by Android, the service should not be restarted automatically.
         */
        const START_NOT_STICKY: number;

        /**
         * A Service start mode indicating that if the host application is stopped by Android, the service should be restarted automatically and the original Intent re-sent.
         */
        const START_REDELIVER_INTENT: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to
         * request that the alarm stream type for notifications be used.
         */
        const STREAM_ALARM: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to request that the
         * default stream type for notifications be used.
         */
        const STREAM_DEFAULT: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to
         * request that the music stream type for notifications be used.
         */
        const STREAM_MUSIC: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to request that the
         * notification stream type for notifications be used.
         */
        const STREAM_NOTIFICATION: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to request that the
         * ring stream type for notifications be used.
         */
        const STREAM_RING: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to request that the
         * system stream type for notifications be used.
         */
        const STREAM_SYSTEM: number;

        /**
         * Use with [audioStreamType](Titanium.Android.Notification.audioStreamType) to request that the
         * voice call stream type for notifications be used.
         */
        const STREAM_VOICE_CALL: number;

        /**
         * QuickSettings tile is active.
         */
        const TILE_STATE_ACTIVE: number;

        /**
         * QuickSettings tile is inactive.
         */
        const TILE_STATE_INACTIVE: number;

        /**
         * QuickSettings tile is unavailble.
         */
        const TILE_STATE_UNAVAILABLE: number;

        /**
         * The URI scheme used for intent URIs.
         */
        const URI_INTENT_SCHEME: number;

        /**
         * Shows basic information about the notification.
         */
        const VISIBILITY_PRIVATE: number;

        /**
         * Shows the notification's full content on the lockscreen. This is the system default if visibility is left unspecified.
         */
        const VISIBILITY_PUBLIC: number;

        /**
         * Shows the most minimal information of the notification on the lockscreen.
         */
        const VISIBILITY_SECRET: number;

        /**
         * Turn the screen on when the wake lock is acquired.
         */
        const WAKE_LOCK_ACQUIRE_CAUSES_WAKEUP: number;

        /**
         * Ensures that the screen and keyboard backlight are on at full brightness.
         */
        const WAKE_LOCK_FULL: number;

        /**
         * When this wake lock is released, poke the user activity timer so the screen stays on for a little longer.
         */
        const WAKE_LOCK_ON_AFTER_RELEASE: number;

        /**
         * Ensures that the CPU is running; the screen and keyboard backlight will be allowed to go off.
         */
        const WAKE_LOCK_PARTIAL: number;

        /**
         * Ensures that the screen is on at full brightness; the keyboard backlight will be allowed to go off.
         */
        const WAKE_LOCK_SCREEN_BRIGHT: number;

        /**
         * Ensures that the screen is on (but may be dimmed); the keyboard backlight will be allowed to go off.
         */
        const WAKE_LOCK_SCREEN_DIM: number;

        /**
         * An action bar is a window feature that identifies the application and user location,
         * and provides user actions and navigation modes.
         */
        class ActionBar extends Titanium.Proxy {
            /**
             * The background image for the action bar, specified as a local file path or URL.
             */
            backgroundImage: string;

            /**
             * Sets a view to be used for a custom navigation mode.
             */
            customView: Titanium.UI.View;

            /**
             * Displays an "up" affordance on the "home" area of the action bar.
             */
            displayHomeAsUp: boolean;

            /**
             * Enable or disable the "home" button in the corner of the action bar.
             */
            homeButtonEnabled: boolean;

            /**
             * Sets the application icon displayed in the "home" area of the action bar, specified as a local file path or URL.
             */
            icon: string;

            /**
             * Sets the application logo displayed in the "home" area of the action bar, specified as a local file path or URL.
             */
            logo: string;

            /**
             * Controls the navigation mode.
             */
            navigationMode: number;

            /**
             * Callback function called when the home icon is clicked.
             */
            onHomeIconItemSelected: (...args: any[]) => void;

            /**
             * Sets the subtitle of the action bar.
             */
            subtitle: string;

            /**
             * Sets the title of the action bar.
             */
            title: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.ActionBar.customView> property.
             * @deprecated Access <Titanium.Android.ActionBar.customView> instead.
             */
            getCustomView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.Android.ActionBar.navigationMode> property.
             * @deprecated Access <Titanium.Android.ActionBar.navigationMode> instead.
             */
            getNavigationMode(): number;

            /**
             * Gets the value of the <Titanium.Android.ActionBar.subtitle> property.
             * @deprecated Access <Titanium.Android.ActionBar.subtitle> instead.
             */
            getSubtitle(): string;

            /**
             * Gets the value of the <Titanium.Android.ActionBar.title> property.
             * @deprecated Access <Titanium.Android.ActionBar.title> instead.
             */
            getTitle(): string;

            /**
             * Hides the action bar if it is currently showing.
             */
            hide(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.backgroundImage> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.backgroundImage> instead.
             */
            setBackgroundImage(backgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.customView> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.customView> instead.
             */
            setCustomView(customView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.displayHomeAsUp> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.displayHomeAsUp> instead.
             */
            setDisplayHomeAsUp(displayHomeAsUp: boolean): void;

            /**
             * Shows or hides the action bar home icon
             */
            setDisplayShowHomeEnabled(show: boolean): void;

            /**
             * Shows or hides the action bar title/subtitle
             */
            setDisplayShowTitleEnabled(show: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.homeButtonEnabled> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.homeButtonEnabled> instead.
             */
            setHomeButtonEnabled(homeButtonEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.icon> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.icon> instead.
             */
            setIcon(icon: string): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.logo> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.logo> instead.
             */
            setLogo(logo: string): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.navigationMode> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.navigationMode> instead.
             */
            setNavigationMode(navigationMode: number): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.onHomeIconItemSelected> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.onHomeIconItemSelected> instead.
             */
            setOnHomeIconItemSelected(onHomeIconItemSelected: (...args: any[]) => void): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.subtitle> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.subtitle> instead.
             */
            setSubtitle(subtitle: string): void;

            /**
             * Sets the value of the <Titanium.Android.ActionBar.title> property.
             * @deprecated Set the value using <Titanium.Android.ActionBar.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Shows the action bar if it is currently hidden.
             */
            show(): void;

        }
        /**
         * Base event for class Titanium.Android.Activity
         */
        interface ActivityBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Android.Activity;

        }
        /**
         * Fired when the activity is already running and an intent different than the one that launched it was received.
         */
        interface Activity_newintent_Event extends ActivityBaseEvent {
            /**
             * The `Intent` passed to the native `onNewIntent` method.
             */
            intent: Titanium.Android.Intent;

        }
        /**
         * Fired when the activity is launched.
         */
        interface Activity_onIntent_Event extends ActivityBaseEvent {
            /**
             * The `Intent` used to launch the Activity.
             */
            intent: Titanium.Android.Intent;

        }
        /**
         * Fired when the activity is about to go into the background as a result of user choice.
         */
        interface Activity_userleavehint_Event extends ActivityBaseEvent {
        }
        /**
         * Called whenever a key, touch, or trackball event is dispatched to the activity.
         */
        interface Activity_userinteraction_Event extends ActivityBaseEvent {
        }
        interface ActivityEventMap extends ProxyEventMap {
            newintent: Activity_newintent_Event;

            onIntent: Activity_onIntent_Event;

            userinteraction: Activity_userinteraction_Event;

            userleavehint: Activity_userleavehint_Event;

        }
        /**
         * The Titanium binding of an Android Activity.
         */
        class Activity extends Titanium.Proxy {
            /**
             * The action bar for this activity.
             */
            readonly actionBar: Titanium.Android.ActionBar;

            /**
             * The last `Intent` received by this activity.
             */
            readonly intent: Titanium.Android.Intent;

            /**
             * Callback function called when the Android activity is created.
             */
            onCreate: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called to initially create an Android options menu
             * for this Activity when the user presses the **Menu** button.
             */
            onCreateOptionsMenu: (param0: OptionsMenuCallbackObject) => void;

            /**
             * Callback function called when the Android activity is destroyed.
             */
            onDestroy: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called when the Android activity is paused.
             */
            onPause: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called to prepare an options menu for display when the user presses
             * the **Menu** button.
             */
            onPrepareOptionsMenu: (param0: OptionsMenuCallbackObject) => void;

            /**
             * Callback function called when the Android activity is restarted.
             */
            onRestart: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called when the Android activity is resumed.
             */
            onResume: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called when the Android activity is started.
             */
            onStart: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Callback function called when the Android activity is stopped.
             */
            onStop: (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Specifies a specific orientation for this activity.
             */
            requestedOrientation: number;

            /**
             * Toolbar instance that serves as ActionBar
             */
            supportToolbar: Titanium.UI.Toolbar;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ActivityEventMap>(name: K, callback: (this: Titanium.Android.Activity, event: ActivityEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Closes this activity.
             */
            finish(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ActivityEventMap>(name: K, event?: ActivityEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.Activity.actionBar> property.
             * @deprecated Access <Titanium.Android.Activity.actionBar> instead.
             */
            getActionBar(): Titanium.Android.ActionBar;

            /**
             * Gets the value of the <Titanium.Android.Activity.intent> property.
             * @deprecated Access <Titanium.Android.Activity.intent> instead.
             */
            getIntent(): Titanium.Android.Intent;

            /**
             * Gets the value of the <Titanium.Android.Activity.onCreate> property.
             * @deprecated Access <Titanium.Android.Activity.onCreate> instead.
             */
            getOnCreate(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onCreateOptionsMenu> property.
             * @deprecated Access <Titanium.Android.Activity.onCreateOptionsMenu> instead.
             */
            getOnCreateOptionsMenu(): (param0: OptionsMenuCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onDestroy> property.
             * @deprecated Access <Titanium.Android.Activity.onDestroy> instead.
             */
            getOnDestroy(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onPause> property.
             * @deprecated Access <Titanium.Android.Activity.onPause> instead.
             */
            getOnPause(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onPrepareOptionsMenu> property.
             * @deprecated Access <Titanium.Android.Activity.onPrepareOptionsMenu> instead.
             */
            getOnPrepareOptionsMenu(): (param0: OptionsMenuCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onRestart> property.
             * @deprecated Access <Titanium.Android.Activity.onRestart> instead.
             */
            getOnRestart(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onResume> property.
             * @deprecated Access <Titanium.Android.Activity.onResume> instead.
             */
            getOnResume(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onStart> property.
             * @deprecated Access <Titanium.Android.Activity.onStart> instead.
             */
            getOnStart(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets the value of the <Titanium.Android.Activity.onStop> property.
             * @deprecated Access <Titanium.Android.Activity.onStop> instead.
             */
            getOnStop(): (param0: ActivityLifecycleCallbackObject) => void;

            /**
             * Gets an Android or Application string using the specified Resource ID and optional format arguments.
             */
            getString(resourceId: number, format: any): string;

            /**
             * Gets the value of the <Titanium.Android.Activity.supportToolbar> property.
             * @deprecated Access <Titanium.Android.Activity.supportToolbar> instead.
             */
            getSupportToolbar(): Titanium.UI.Toolbar;

            /**
             * Declares that the option menu has changed and should be recreated.
             */
            invalidateOptionsMenu(): void;

            /**
             * Programmatically opens the options menu.
             */
            openOptionsMenu(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ActivityEventMap>(name: K, callback: (this: Titanium.Android.Activity, event: ActivityEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Broadcast the passed in `Intent` to all `BroadcastReceiver`s.
             */
            sendBroadcast(intent: Titanium.Android.Intent): void;

            /**
             * Broadcast the passed in `Intent` to all `BroadcastReceiver`s with an optional permission.
             */
            sendBroadcastWithPermission(intent: Titanium.Android.Intent, receiverPermission?: string): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onCreate> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onCreate> instead.
             */
            setOnCreate(onCreate: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onCreateOptionsMenu> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onCreateOptionsMenu> instead.
             */
            setOnCreateOptionsMenu(onCreateOptionsMenu: (param0: OptionsMenuCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onDestroy> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onDestroy> instead.
             */
            setOnDestroy(onDestroy: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onPause> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onPause> instead.
             */
            setOnPause(onPause: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onPrepareOptionsMenu> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onPrepareOptionsMenu> instead.
             */
            setOnPrepareOptionsMenu(onPrepareOptionsMenu: (param0: OptionsMenuCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onRestart> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onRestart> instead.
             */
            setOnRestart(onRestart: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onResume> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onResume> instead.
             */
            setOnResume(onResume: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onStart> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onStart> instead.
             */
            setOnStart(onStart: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.onStop> property.
             * @deprecated Set the value using <Titanium.Android.Activity.onStop> instead.
             */
            setOnStop(onStop: (param0: ActivityLifecycleCallbackObject) => void): void;

            /**
             * Sets the requested Activity orientation.
             */
            setRequestedOrientation(orientation: number): void;

            /**
             * Sets the result of this activity using an `Intent`.
             */
            setResult(resultCode: number, intent?: Titanium.Android.Intent): void;

            /**
             * Sets a toolbar instance to be used as an ActionBar.
             */
            setSupportActionBar(toolbar: Titanium.UI.Toolbar): void;

            /**
             * Sets the value of the <Titanium.Android.Activity.supportToolbar> property.
             * @deprecated Set the value using <Titanium.Android.Activity.supportToolbar> instead.
             */
            setSupportToolbar(supportToolbar: Titanium.UI.Toolbar): void;

            /**
             * Starts a new activity, using the passed in `Intent` as the description.
             */
            startActivity(intent: Titanium.Android.Intent): void;

            /**
             * The same as `startActivity`, but also accepts a callback function for handling the result of the started Activity.
             */
            startActivityForResult(intent: Titanium.Android.Intent, callback: (param0: ActivityResult) => void): void;

        }
        /**
         * Helper object for generating large-format notifications that include a large image attachment.
         */
        class BigPictureStyle extends Titanium.Proxy {
            /**
             * Overrides <Titanium.Android.Notification.contentTitle> in the big form of the notification. This defaults to the value passed to <Titanium.Android.Notification.contentTitle>.
             */
            bigContentTitle: string;

            /**
             * Override the <Titanium.Android.Notification.largeIcon> when the big notification is shown.
             */
            bigLargeIcon: number | string;

            /**
             * Provide the bitmap to be used as the payload for the BigPicture notification.
             */
            bigPicture: number | string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Number of times to retry decoding the bitmap at bigPicture URL.
             */
            decodeRetries: number;

            /**
             * Set the first line of text after the detail section in the big form of the notification.
             */
            summaryText: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.BigPictureStyle.bigContentTitle> property.
             * @deprecated Access <Titanium.Android.BigPictureStyle.bigContentTitle> instead.
             */
            getBigContentTitle(): string;

            /**
             * Gets the value of the <Titanium.Android.BigPictureStyle.bigLargeIcon> property.
             * @deprecated Access <Titanium.Android.BigPictureStyle.bigLargeIcon> instead.
             */
            getBigLargeIcon(): number | string;

            /**
             * Gets the value of the <Titanium.Android.BigPictureStyle.bigPicture> property.
             * @deprecated Access <Titanium.Android.BigPictureStyle.bigPicture> instead.
             */
            getBigPicture(): number | string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.Android.BigPictureStyle.decodeRetries> property.
             * @deprecated Access <Titanium.Android.BigPictureStyle.decodeRetries> instead.
             */
            getDecodeRetries(): number;

            /**
             * Gets the value of the <Titanium.Android.BigPictureStyle.summaryText> property.
             * @deprecated Access <Titanium.Android.BigPictureStyle.summaryText> instead.
             */
            getSummaryText(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.BigPictureStyle.bigContentTitle> property.
             * @deprecated Set the value using <Titanium.Android.BigPictureStyle.bigContentTitle> instead.
             */
            setBigContentTitle(bigContentTitle: string): void;

            /**
             * Sets the value of the <Titanium.Android.BigPictureStyle.bigLargeIcon> property.
             * @deprecated Set the value using <Titanium.Android.BigPictureStyle.bigLargeIcon> instead.
             */
            setBigLargeIcon(bigLargeIcon: number | string): void;

            /**
             * Sets the value of the <Titanium.Android.BigPictureStyle.bigPicture> property.
             * @deprecated Set the value using <Titanium.Android.BigPictureStyle.bigPicture> instead.
             */
            setBigPicture(bigPicture: number | string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.Android.BigPictureStyle.decodeRetries> property.
             * @deprecated Set the value using <Titanium.Android.BigPictureStyle.decodeRetries> instead.
             */
            setDecodeRetries(decodeRetries: number): void;

            /**
             * Sets the value of the <Titanium.Android.BigPictureStyle.summaryText> property.
             * @deprecated Set the value using <Titanium.Android.BigPictureStyle.summaryText> instead.
             */
            setSummaryText(summaryText: string): void;

        }
        /**
         * Helper object for generating large-format notifications that include a lot of text.
         */
        class BigTextStyle extends Titanium.Proxy {
            /**
             * Overrides <Titanium.Android.Notification.contentTitle> in the big form of the notification. This defaults to the value passed to <Titanium.Android.Notification.contentTitle>.
             */
            bigContentTitle: string;

            /**
             * Sets the longer text to be displayed in the big form of the notification in place of the content text.
             */
            bigText: string;

            /**
             * Set the first line of text after the detail section in the big form of the notification.
             */
            summaryText: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.BigTextStyle.bigContentTitle> property.
             * @deprecated Access <Titanium.Android.BigTextStyle.bigContentTitle> instead.
             */
            getBigContentTitle(): string;

            /**
             * Gets the value of the <Titanium.Android.BigTextStyle.bigText> property.
             * @deprecated Access <Titanium.Android.BigTextStyle.bigText> instead.
             */
            getBigText(): string;

            /**
             * Gets the value of the <Titanium.Android.BigTextStyle.summaryText> property.
             * @deprecated Access <Titanium.Android.BigTextStyle.summaryText> instead.
             */
            getSummaryText(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.BigTextStyle.bigContentTitle> property.
             * @deprecated Set the value using <Titanium.Android.BigTextStyle.bigContentTitle> instead.
             */
            setBigContentTitle(bigContentTitle: string): void;

            /**
             * Sets the value of the <Titanium.Android.BigTextStyle.bigText> property.
             * @deprecated Set the value using <Titanium.Android.BigTextStyle.bigText> instead.
             */
            setBigText(bigText: string): void;

            /**
             * Sets the value of the <Titanium.Android.BigTextStyle.summaryText> property.
             * @deprecated Set the value using <Titanium.Android.BigTextStyle.summaryText> instead.
             */
            setSummaryText(summaryText: string): void;

        }
        /**
         * Monitor and handle Android system broadcasts.
         */
        class BroadcastReceiver extends Titanium.Proxy {
            /**
             * The function called when a broadcast is received.
             */
            onReceived: (param0: any) => void;

            /**
             * URL of the JavaScript file to handle the broadcast.
             */
            url: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.BroadcastReceiver.onReceived> property.
             * @deprecated Access <Titanium.Android.BroadcastReceiver.onReceived> instead.
             */
            getOnReceived(): (param0: any) => void;

            /**
             * Gets the value of the <Titanium.Android.BroadcastReceiver.url> property.
             * @deprecated Access <Titanium.Android.BroadcastReceiver.url> instead.
             */
            getUrl(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.BroadcastReceiver.onReceived> property.
             * @deprecated Set the value using <Titanium.Android.BroadcastReceiver.onReceived> instead.
             */
            setOnReceived(onReceived: (param0: any) => void): void;

            /**
             * Sets the value of the <Titanium.Android.BroadcastReceiver.url> property.
             * @deprecated Set the value using <Titanium.Android.BroadcastReceiver.url> instead.
             */
            setUrl(url: string): void;

        }
        /**
         * The Android.Calendar module provides proxies and methods for accessing the native Android
         * calendar functionality.
         * @deprecated Use [Titanium.Calendar](Titanium.Calendar) instead.
         */
        const Calendar: never;
        /**
         * Message objects passed between Android application components.
         */
        class Intent extends Titanium.Proxy {
            /**
             * The action associated with this intent.
             */
            action: string;

            /**
             * The Java class name of the activity associated with this intent
             * ([packageName](Titanium.Android.Intent.packageName) must also be set).
             */
            className: string;

            /**
             * The Intent's Data URI.
             */
            readonly data: string;

            /**
             * Intent flags.
             */
            flags: number;

            /**
             * The fully-qualified Java package name of the activity.
             */
            packageName: string;

            /**
             * The MIME type for this Intent.
             */
            readonly type: string;

            /**
             * The URL to a Titanium JavaScript Activity.
             */
            url: string;

            /**
             * Adds a category to this Intent.
             */
            addCategory(name: string): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds to the existing flags on the `Intent`.
             */
            addFlags(flags: number): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.Intent.action> property.
             * @deprecated Access <Titanium.Android.Intent.action> instead.
             */
            getAction(): string;

            /**
             * Get a <Titanium.Blob> property from this `Intent`.
             */
            getBlobExtra(name: string): Titanium.Blob;

            /**
             * Get a boolean property from this Intent.
             */
            getBooleanExtra(name: string, defaultValue: boolean): boolean;

            /**
             * Gets the value of the <Titanium.Android.Intent.className> property.
             * @deprecated Access <Titanium.Android.Intent.className> instead.
             */
            getClassName(): string;

            /**
             * Get the Data URI from this `Intent`.
             */
            getData(): string;

            /**
             * Get a double property from this `Intent`.
             */
            getDoubleExtra(name: string, defaultValue: number): number;

            /**
             * Gets the value of the <Titanium.Android.Intent.flags> property.
             * @deprecated Access <Titanium.Android.Intent.flags> instead.
             */
            getFlags(): number;

            /**
             * Get an integer property from this `Intent`.
             */
            getIntExtra(name: string, defaultValue: number): number;

            /**
             * Get a long property from this `Intent`.
             */
            getLongExtra(name: string, defaultValue: number): number;

            /**
             * Gets the value of the <Titanium.Android.Intent.packageName> property.
             * @deprecated Access <Titanium.Android.Intent.packageName> instead.
             */
            getPackageName(): string;

            /**
             * Get a string property from this `Intent`.
             */
            getStringExtra(name: string): string;

            /**
             * Gets the value of the <Titanium.Android.Intent.type> property.
             * @deprecated Access <Titanium.Android.Intent.type> instead.
             */
            getType(): string;

            /**
             * Gets the value of the <Titanium.Android.Intent.url> property.
             * @deprecated Access <Titanium.Android.Intent.url> instead.
             */
            getUrl(): string;

            /**
             * Returns `true` if this `Intent` has the specified property.
             */
            hasExtra(name: string): boolean;

            /**
             * Puts an extra property on this `Intent`.
             */
            putExtra(name: string, value: any): void;

            /**
             * Put a URI property on this `Intent` (useful for <Titanium.Android.EXTRA_STREAM>).
             */
            putExtraUri(name: string, value: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Intent.action> property.
             * @deprecated Set the value using <Titanium.Android.Intent.action> instead.
             */
            setAction(action: string): void;

            /**
             * Sets the value of the <Titanium.Android.Intent.className> property.
             * @deprecated Set the value using <Titanium.Android.Intent.className> instead.
             */
            setClassName(className: string): void;

            /**
             * Sets the value of the <Titanium.Android.Intent.flags> property.
             * @deprecated Set the value using <Titanium.Android.Intent.flags> instead.
             */
            setFlags(flags: number): void;

            /**
             * Sets the value of the <Titanium.Android.Intent.packageName> property.
             * @deprecated Set the value using <Titanium.Android.Intent.packageName> instead.
             */
            setPackageName(packageName: string): void;

            /**
             * Sets the value of the <Titanium.Android.Intent.url> property.
             * @deprecated Set the value using <Titanium.Android.Intent.url> instead.
             */
            setUrl(url: string): void;

        }
        /**
         * The Titanium binding of an Android Options Menu.
         */
        class Menu extends Titanium.Proxy {
            /**
             * Array of menu items in this menu.
             */
            readonly items: Titanium.Android.MenuItem[];

            /**
             * Creates a <Titanium.Android.MenuItem> from the passed creation options.
             */
            add(options: any): Titanium.Android.MenuItem;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Clears all items from this menu.
             */
            clear(): void;

            /**
             * Closes the menu, if visible.
             */
            close(): void;

            /**
             * Locates a [MenuItem](Titanium.Android.MenuItem) in this menu, by item ID or reference.
             */
            findItem(item: number | Titanium.Android.MenuItem): Titanium.Android.MenuItem;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Returns the [MenuItem](Titanium.Android.MenuItem) at a specific index.
             */
            getItem(index: number): Titanium.Android.MenuItem;

            /**
             * Gets the value of the <Titanium.Android.Menu.items> property.
             * @deprecated Access <Titanium.Android.Menu.items> instead.
             */
            getItems(): Titanium.Android.MenuItem[];

            /**
             * Returns `true` if this menu has visible items.
             */
            hasVisibleItems(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes all menu items with the specified
             * [groupId](Titanium.Android.MenuItem.groupId).
             */
            removeGroup(groupId: number): void;

            /**
             * Removes a specific [MenuItem](Titanium.Android.MenuItem) identified by its
             * [itemId](Titanium.Android.MenuItem.itemId).
             */
            removeItem(itemId: number): void;

            /**
             * Enables or disables a group of menu items identified by a
             * [groupId](Titanium.Android.MenuItem.groupId).
             */
            setGroupEnabled(groupId: number, enabled: boolean): void;

            /**
             * Shows or hides a group of menu items identified by a
             * [groupId](Titanium.Android.MenuItem.groupId).
             */
            setGroupVisible(groupId: number, visible: boolean): void;

            /**
             * Number of items in this menu.
             */
            size(): number;

        }
        /**
         * Base event for class Titanium.Android.MenuItem
         */
        interface MenuItemBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Android.MenuItem;

        }
        /**
         * Fired when the user clicks the menu item.
         */
        interface MenuItem_click_Event extends MenuItemBaseEvent {
        }
        /**
         * Fired when the action view has been expanded.
         */
        interface MenuItem_expand_Event extends MenuItemBaseEvent {
        }
        /**
         * Fired when the action view has been collapsed.
         */
        interface MenuItem_collapse_Event extends MenuItemBaseEvent {
        }
        interface MenuItemEventMap extends ProxyEventMap {
            click: MenuItem_click_Event;

            collapse: MenuItem_collapse_Event;

            expand: MenuItem_expand_Event;

        }
        /**
         * The Titanium binding of an Android menu item.
         */
        class MenuItem extends Titanium.Proxy {
            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: string;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: string;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: string;

            /**
             * Custom view that replaces the default menu item button.
             */
            actionView: Titanium.UI.View;

            /**
             * True if this menu item's action view has been expanded.
             */
            readonly actionViewExpanded: boolean;

            /**
             * Determines if the item can be checked.
             */
            checkable: boolean;

            /**
             * Determines if the item is checked.
             */
            checked: boolean;

            /**
             * Determines if the item is enabled.
             */
            enabled: boolean;

            /**
             * Group ID for this item.
             */
            readonly groupId: number;

            /**
             * Icon to display for the this menu item.
             */
            icon: number | string;

            /**
             * Item ID for this item.
             */
            readonly itemId: number;

            /**
             * Integer used for controlling the category and sort order for menu items.
             */
            readonly order: number;

            /**
             * A set of flags that controls how this item appears in the action bar.
             */
            showAsAction: number;

            /**
             * Title of the item.
             */
            title: string;

            /**
             * Shortened version of the item's title.
             */
            titleCondensed: string;

            /**
             * Determines whether the menu item is visible.
             */
            visible: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof MenuItemEventMap>(name: K, callback: (this: Titanium.Android.MenuItem, event: MenuItemEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Collapse the action view associated with this menu item.
             */
            collapseActionView(): void;

            /**
             * Expand the action view associated with this menu item.
             */
            expandActionView(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof MenuItemEventMap>(name: K, event?: MenuItemEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.accessibilityHint> property.
             * @deprecated Access <Titanium.Android.MenuItem.accessibilityHint> instead.
             */
            getAccessibilityHint(): string;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.accessibilityLabel> property.
             * @deprecated Access <Titanium.Android.MenuItem.accessibilityLabel> instead.
             */
            getAccessibilityLabel(): string;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.accessibilityValue> property.
             * @deprecated Access <Titanium.Android.MenuItem.accessibilityValue> instead.
             */
            getAccessibilityValue(): string;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.actionView> property.
             * @deprecated Access <Titanium.Android.MenuItem.actionView> instead.
             */
            getActionView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.groupId> property.
             * @deprecated Access <Titanium.Android.MenuItem.groupId> instead.
             */
            getGroupId(): number;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.itemId> property.
             * @deprecated Access <Titanium.Android.MenuItem.itemId> instead.
             */
            getItemId(): number;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.order> property.
             * @deprecated Access <Titanium.Android.MenuItem.order> instead.
             */
            getOrder(): number;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.title> property.
             * @deprecated Access <Titanium.Android.MenuItem.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.Android.MenuItem.titleCondensed> property.
             * @deprecated Access <Titanium.Android.MenuItem.titleCondensed> instead.
             */
            getTitleCondensed(): string;

            /**
             * Returns the [actionViewExpanded](Titanium.Android.MenuItem.actionViewExpanded) state of the menu item.
             */
            isActionViewExpanded(): boolean;

            /**
             * Returns the [checkable](Titanium.Android.MenuItem.checkable) state of the menu item.
             */
            isCheckable(): boolean;

            /**
             * Returns the [checked](Titanium.Android.MenuItem.checked) state of the menu item.
             */
            isChecked(): boolean;

            /**
             * Returns the [enabled](Titanium.Android.MenuItem.enabled) state of the menu item.
             */
            isEnabled(): boolean;

            /**
             * Returns the [visible](Titanium.Android.MenuItem.visible) state of the menu item.
             */
            isVisible(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof MenuItemEventMap>(name: K, callback: (this: Titanium.Android.MenuItem, event: MenuItemEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.accessibilityHint> instead.
             */
            setAccessibilityHint(accessibilityHint: string): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.accessibilityLabel> instead.
             */
            setAccessibilityLabel(accessibilityLabel: string): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.accessibilityValue> instead.
             */
            setAccessibilityValue(accessibilityValue: string): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.actionView> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.actionView> instead.
             */
            setActionView(actionView: Titanium.UI.View): void;

            /**
             * Sets the [checkable](Titanium.Android.MenuItem.checkable) state of the menu item.
             */
            setCheckable(checkable: boolean): void;

            /**
             * Sets the [checked](Titanium.Android.MenuItem.checked) state of the menu item.
             */
            setChecked(enabled: boolean): void;

            /**
             * Sets the [enabled](Titanium.Android.MenuItem.enabled) state of the menu item.
             */
            setEnabled(enabled: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.icon> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.icon> instead.
             */
            setIcon(icon: number | string): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.showAsAction> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.showAsAction> instead.
             */
            setShowAsAction(showAsAction: number): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.title> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.Android.MenuItem.titleCondensed> property.
             * @deprecated Set the value using <Titanium.Android.MenuItem.titleCondensed> instead.
             */
            setTitleCondensed(titleCondensed: string): void;

            /**
             * Sets the [visible](Titanium.Android.MenuItem.visible) state of the menu item.
             */
            setVisible(visible: boolean): void;

        }
        /**
         * UI notifications that can be sent while the application is in the background.
         */
        class Notification extends Titanium.Proxy {
            /**
             * The audio stream type to use when playing the sound.
             */
            audioStreamType: number;

            /**
             * Sets the notification's category.
             */
            category: string;

            /**
             * The channel id specified for the notification.
             */
            channelId: string;

            /**
             * Accent color used behind icon.
             */
            color: string;

            /**
             * The `PendingIntent` to execute when the expanded status entry is clicked.
             */
            contentIntent: Titanium.Android.PendingIntent;

            /**
             * Description text of the notification.
             */
            contentText: string;

            /**
             * Title of the notification.
             */
            contentTitle: string;

            /**
             * Custom layout to display in the notification.
             */
            contentView: Titanium.Android.RemoteViews;

            /**
             * Specifies which values should be taken from the defaults.
             */
            defaults: number;

            /**
             * The `PendingIntent` to execute when the status entry is deleted by the user with the "Clear All Notifications" button.
             */
            deleteIntent: Titanium.Android.PendingIntent;

            /**
             * Set of flags for the notification.
             */
            flags: number;

            /**
             * The group key that the notification will belong to.
             */
            groupKey: string;

            /**
             * Specifies if this is a group summary notification.
             */
            groupSummary: boolean;

            /**
             * Notification icon, specified as an Android resource ID, or a local URL to a density-specific image.
             */
            icon: number | string;

            /**
             * Add a large icon to the notification (and the ticker on some devices) specified as an Android resource ID, or a local URL to a density-specific image.
             */
            largeIcon: number | string;

            /**
             * The color for the LED to blink.
             */
            ledARGB: number;

            /**
             * The number of milliseconds for the LED to be off while it's flashing.
             */
            ledOffMS: number;

            /**
             * The number of milliseconds for the LED to be on while it's flashing.
             */
            ledOnMS: number;

            /**
             * The number of events that this notification represents.
             */
            number: number;

            /**
             * Sets the priority of the notification.
             */
            priority: number;

            /**
             * A URL to the sound to play.
             */
            sound: string;

            /**
             * Style object that can apply a rich notification style.
             */
            style: Titanium.Android.BigTextStyle | Titanium.Android.BigPictureStyle;

            /**
             * Text to scroll across the screen when this item is added to the status bar.
             */
            tickerText: string;

            /**
             * Allows user to conceal private information of the notification on the lockscreen.
             */
            visibility: number;

            /**
             * Will wake up the device for the given time (in milliseconds) when the notification is shown.
             * The application needs to also set the `android.permission.WAKE_LOCK` permission
             * in the Android manifest section of the `tiapp.xml` file.
             * ``` xml
             * <ti:app>
             *     <android>
             *         <manifest>
             *             <uses-permission android:name="android.permission.WAKE_LOCK" />
             *         </manifest>
             *     </android>
             * </ti:app>
             * ```
             */
            wakeLock: wakeLockOptions;

            /**
             * The timestamp for the notification (defaults to the current time).
             */
            when: Date | number;

            /**
             * Add an action button to the notification
             */
            addAction(icon: number | string, title: string, intent: Titanium.Android.PendingIntent): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.Notification.audioStreamType> property.
             * @deprecated Access <Titanium.Android.Notification.audioStreamType> instead.
             */
            getAudioStreamType(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.category> property.
             * @deprecated Access <Titanium.Android.Notification.category> instead.
             */
            getCategory(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.channelId> property.
             * @deprecated Access <Titanium.Android.Notification.channelId> instead.
             */
            getChannelId(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.color> property.
             * @deprecated Access <Titanium.Android.Notification.color> instead.
             */
            getColor(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.contentIntent> property.
             * @deprecated Access <Titanium.Android.Notification.contentIntent> instead.
             */
            getContentIntent(): Titanium.Android.PendingIntent;

            /**
             * Gets the value of the <Titanium.Android.Notification.contentText> property.
             * @deprecated Access <Titanium.Android.Notification.contentText> instead.
             */
            getContentText(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.contentTitle> property.
             * @deprecated Access <Titanium.Android.Notification.contentTitle> instead.
             */
            getContentTitle(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.defaults> property.
             * @deprecated Access <Titanium.Android.Notification.defaults> instead.
             */
            getDefaults(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.deleteIntent> property.
             * @deprecated Access <Titanium.Android.Notification.deleteIntent> instead.
             */
            getDeleteIntent(): Titanium.Android.PendingIntent;

            /**
             * Gets the value of the <Titanium.Android.Notification.flags> property.
             * @deprecated Access <Titanium.Android.Notification.flags> instead.
             */
            getFlags(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.groupKey> property.
             * @deprecated Access <Titanium.Android.Notification.groupKey> instead.
             */
            getGroupKey(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.groupSummary> property.
             * @deprecated Access <Titanium.Android.Notification.groupSummary> instead.
             */
            getGroupSummary(): boolean;

            /**
             * Gets the value of the <Titanium.Android.Notification.icon> property.
             * @deprecated Access <Titanium.Android.Notification.icon> instead.
             */
            getIcon(): number | string;

            /**
             * Gets the value of the <Titanium.Android.Notification.largeIcon> property.
             * @deprecated Access <Titanium.Android.Notification.largeIcon> instead.
             */
            getLargeIcon(): number | string;

            /**
             * Gets the value of the <Titanium.Android.Notification.ledARGB> property.
             * @deprecated Access <Titanium.Android.Notification.ledARGB> instead.
             */
            getLedARGB(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.ledOffMS> property.
             * @deprecated Access <Titanium.Android.Notification.ledOffMS> instead.
             */
            getLedOffMS(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.ledOnMS> property.
             * @deprecated Access <Titanium.Android.Notification.ledOnMS> instead.
             */
            getLedOnMS(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.number> property.
             * @deprecated Access <Titanium.Android.Notification.number> instead.
             */
            getNumber(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.priority> property.
             * @deprecated Access <Titanium.Android.Notification.priority> instead.
             */
            getPriority(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.sound> property.
             * @deprecated Access <Titanium.Android.Notification.sound> instead.
             */
            getSound(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.style> property.
             * @deprecated Access <Titanium.Android.Notification.style> instead.
             */
            getStyle(): Titanium.Android.BigTextStyle | Titanium.Android.BigPictureStyle;

            /**
             * Gets the value of the <Titanium.Android.Notification.tickerText> property.
             * @deprecated Access <Titanium.Android.Notification.tickerText> instead.
             */
            getTickerText(): string;

            /**
             * Gets the value of the <Titanium.Android.Notification.visibility> property.
             * @deprecated Access <Titanium.Android.Notification.visibility> instead.
             */
            getVisibility(): number;

            /**
             * Gets the value of the <Titanium.Android.Notification.wakeLock> property.
             * @deprecated Access <Titanium.Android.Notification.wakeLock> instead.
             */
            getWakeLock(): wakeLockOptions;

            /**
             * Gets the value of the <Titanium.Android.Notification.when> property.
             * @deprecated Access <Titanium.Android.Notification.when> instead.
             */
            getWhen(): Date | number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.audioStreamType> property.
             * @deprecated Set the value using <Titanium.Android.Notification.audioStreamType> instead.
             */
            setAudioStreamType(audioStreamType: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.category> property.
             * @deprecated Set the value using <Titanium.Android.Notification.category> instead.
             */
            setCategory(category: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.channelId> property.
             * @deprecated Set the value using <Titanium.Android.Notification.channelId> instead.
             */
            setChannelId(channelId: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.color> property.
             * @deprecated Set the value using <Titanium.Android.Notification.color> instead.
             */
            setColor(color: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.contentIntent> property.
             * @deprecated Set the value using <Titanium.Android.Notification.contentIntent> instead.
             */
            setContentIntent(contentIntent: Titanium.Android.PendingIntent): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.contentText> property.
             * @deprecated Set the value using <Titanium.Android.Notification.contentText> instead.
             */
            setContentText(contentText: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.contentTitle> property.
             * @deprecated Set the value using <Titanium.Android.Notification.contentTitle> instead.
             */
            setContentTitle(contentTitle: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.contentView> property.
             * @deprecated Set the value using <Titanium.Android.Notification.contentView> instead.
             */
            setContentView(contentView: Titanium.Android.RemoteViews): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.defaults> property.
             * @deprecated Set the value using <Titanium.Android.Notification.defaults> instead.
             */
            setDefaults(defaults: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.deleteIntent> property.
             * @deprecated Set the value using <Titanium.Android.Notification.deleteIntent> instead.
             */
            setDeleteIntent(deleteIntent: Titanium.Android.PendingIntent): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.flags> property.
             * @deprecated Set the value using <Titanium.Android.Notification.flags> instead.
             */
            setFlags(flags: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.groupKey> property.
             * @deprecated Set the value using <Titanium.Android.Notification.groupKey> instead.
             */
            setGroupKey(groupKey: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.groupSummary> property.
             * @deprecated Set the value using <Titanium.Android.Notification.groupSummary> instead.
             */
            setGroupSummary(groupSummary: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.icon> property.
             * @deprecated Set the value using <Titanium.Android.Notification.icon> instead.
             */
            setIcon(icon: number | string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.largeIcon> property.
             * @deprecated Set the value using <Titanium.Android.Notification.largeIcon> instead.
             */
            setLargeIcon(largeIcon: number | string): void;

            /**
             * Sets the latest event info using the built-in notification view for this notification.
             */
            setLatestEventInfo(contentTitle: string, contentText: string, contentIntent: Titanium.Android.PendingIntent): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.ledARGB> property.
             * @deprecated Set the value using <Titanium.Android.Notification.ledARGB> instead.
             */
            setLedARGB(ledARGB: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.ledOffMS> property.
             * @deprecated Set the value using <Titanium.Android.Notification.ledOffMS> instead.
             */
            setLedOffMS(ledOffMS: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.ledOnMS> property.
             * @deprecated Set the value using <Titanium.Android.Notification.ledOnMS> instead.
             */
            setLedOnMS(ledOnMS: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.number> property.
             * @deprecated Set the value using <Titanium.Android.Notification.number> instead.
             */
            setNumber(number: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.priority> property.
             * @deprecated Set the value using <Titanium.Android.Notification.priority> instead.
             */
            setPriority(priority: number): void;

            /**
             * Set the progress this notification represents.
             */
            setProgress(max: number, progress: number, indeterminate: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.sound> property.
             * @deprecated Set the value using <Titanium.Android.Notification.sound> instead.
             */
            setSound(sound: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.style> property.
             * @deprecated Set the value using <Titanium.Android.Notification.style> instead.
             */
            setStyle(style: Titanium.Android.BigTextStyle | Titanium.Android.BigPictureStyle): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.tickerText> property.
             * @deprecated Set the value using <Titanium.Android.Notification.tickerText> instead.
             */
            setTickerText(tickerText: string): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.visibility> property.
             * @deprecated Set the value using <Titanium.Android.Notification.visibility> instead.
             */
            setVisibility(visibility: number): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.wakeLock> property.
             * @deprecated Set the value using <Titanium.Android.Notification.wakeLock> instead.
             */
            setWakeLock(wakeLock: wakeLockOptions): void;

            /**
             * Sets the value of the <Titanium.Android.Notification.when> property.
             * @deprecated Set the value using <Titanium.Android.Notification.when> instead.
             */
            setWhen(when: Date | number): void;

        }
        /**
         * Module for notification channels.
         */
        class NotificationChannel extends Titanium.Proxy {
            /**
             * Whether or not notifications posted to this channel can interrupt the user.
             */
            bypassDnd: boolean;

            /**
             * User visible description of this channel.
             */
            description: string;

            /**
             * Whether notifications posted to this channel should display notification lights
             */
            enableLights: boolean;

            /**
             * Whether notification posted to this channel should vibrate.
             */
            enableVibration: boolean;

            /**
             * Group id this channel belongs to.
             */
            groupId: string;

            /**
             * The channel id specified for the notification channel.
             */
            id: string;

            /**
             * The audio stream type to use when playing the sound.
             */
            importance: number;

            /**
             * The notification light color for notifications posted to this channel.
             */
            lightColor: number;

            /**
             * Whether or not notifications posted to this channel are shown on the lockscreen in full or redacted form.
             */
            lockscreenVisibility: number;

            /**
             * Whether notifications posted to this channel can appear as application icon badges in a Launcher.
             */
            showBadge: boolean;

            /**
             * A URL to the sound to play.
             */
            sound: string;

            /**
             * The vibration pattern for notifications posted to this channel.
             */
            vibratePattern: number[];

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.bypassDnd> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.bypassDnd> instead.
             */
            getBypassDnd(): boolean;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.description> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.description> instead.
             */
            getDescription(): string;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.enableLights> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.enableLights> instead.
             */
            getEnableLights(): boolean;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.enableVibration> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.enableVibration> instead.
             */
            getEnableVibration(): boolean;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.groupId> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.groupId> instead.
             */
            getGroupId(): string;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.id> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.importance> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.importance> instead.
             */
            getImportance(): number;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.lightColor> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.lightColor> instead.
             */
            getLightColor(): number;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.lockscreenVisibility> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.lockscreenVisibility> instead.
             */
            getLockscreenVisibility(): number;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.showBadge> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.showBadge> instead.
             */
            getShowBadge(): boolean;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.sound> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.sound> instead.
             */
            getSound(): string;

            /**
             * Gets the value of the <Titanium.Android.NotificationChannel.vibratePattern> property.
             * @deprecated Access <Titanium.Android.NotificationChannel.vibratePattern> instead.
             */
            getVibratePattern(): number[];

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.bypassDnd> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.bypassDnd> instead.
             */
            setBypassDnd(bypassDnd: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.description> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.description> instead.
             */
            setDescription(description: string): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.enableLights> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.enableLights> instead.
             */
            setEnableLights(enableLights: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.enableVibration> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.enableVibration> instead.
             */
            setEnableVibration(enableVibration: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.groupId> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.groupId> instead.
             */
            setGroupId(groupId: string): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.id> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.id> instead.
             */
            setId(id: string): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.importance> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.importance> instead.
             */
            setImportance(importance: number): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.lightColor> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.lightColor> instead.
             */
            setLightColor(lightColor: number): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.lockscreenVisibility> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.lockscreenVisibility> instead.
             */
            setLockscreenVisibility(lockscreenVisibility: number): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.showBadge> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.showBadge> instead.
             */
            setShowBadge(showBadge: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.sound> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.sound> instead.
             */
            setSound(sound: string): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationChannel.vibratePattern> property.
             * @deprecated Set the value using <Titanium.Android.NotificationChannel.vibratePattern> instead.
             */
            setVibratePattern(vibratePattern: ReadonlyArray<number>): void;

        }
        /**
         * Module for managing notifications.
         */
        class NotificationManager extends Titanium.Module {
            /**
             * Use <Titanium.Android.DEFAULT_ALL> instead.
             */
            static readonly DEFAULT_ALL: number;

            /**
             * Use <Titanium.Android.DEFAULT_LIGHTS> instead.
             */
            static readonly DEFAULT_LIGHTS: number;

            /**
             * Use <Titanium.Android.DEFAULT_SOUND> instead.
             */
            static readonly DEFAULT_SOUND: number;

            /**
             * Use <Titanium.Android.DEFAULT_VIBRATE> instead.
             */
            static readonly DEFAULT_VIBRATE: number;

            /**
             * Use <Titanium.Android.FLAG_AUTO_CANCEL> instead.
             */
            static readonly FLAG_AUTO_CANCEL: number;

            /**
             * Use <Titanium.Android.FLAG_INSISTENT> instead.
             */
            static readonly FLAG_INSISTENT: number;

            /**
             * Use <Titanium.Android.FLAG_NO_CLEAR> instead.
             */
            static readonly FLAG_NO_CLEAR: number;

            /**
             * Use <Titanium.Android.FLAG_ONGOING_EVENT> instead.
             */
            static readonly FLAG_ONGOING_EVENT: number;

            /**
             * Use <Titanium.Android.FLAG_ONLY_ALERT_ONCE> instead.
             */
            static readonly FLAG_ONLY_ALERT_ONCE: number;

            /**
             * Use <Titanium.Android.FLAG_SHOW_LIGHTS> instead.
             */
            static readonly FLAG_SHOW_LIGHTS: number;

            /**
             * Use <Titanium.Android.STREAM_DEFAULT> instead.
             */
            static readonly STREAM_DEFAULT: number;

            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Returns whether showing notifications is enabled for the application.
             */
            static areNotificationsEnabled(): boolean;

            /**
             * Cancels a previously displayed notification.
             */
            static cancel(id: number): void;

            /**
             * Cancels all previously displayed notifications.
             */
            static cancelAll(): void;

            /**
             * Create a notification channel.
             */
            static createNotificationChannel(parameters: Dictionary<Titanium.Android.NotificationChannel>): Titanium.Android.NotificationChannel;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.NotificationManager.apiName> property.
             * @deprecated Access <Titanium.Android.NotificationManager.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.Android.NotificationManager.bubbleParent> property.
             * @deprecated Access <Titanium.Android.NotificationManager.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.Android.NotificationManager.lifecycleContainer> property.
             * @deprecated Access <Titanium.Android.NotificationManager.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds a persistent notification to the status bar.
             */
            static notify(id: number, notification: Titanium.Android.Notification): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationManager.bubbleParent> property.
             * @deprecated Set the value using <Titanium.Android.NotificationManager.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.Android.NotificationManager.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.Android.NotificationManager.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * The Titanium binding of an Android `PendingIntent`.
         */
        class PendingIntent extends Titanium.Proxy {
            /**
             * Flags used for creating the Pending Intent.
             */
            flags: number;

            /**
             * The intent data to pass to the [Activity](Titanium.Android.Activity) launched by this `PendingIntent`.
             */
            intent: Titanium.Android.Intent;

            /**
             * If this property is true, flag <Titanium.Android.FLAG_UPDATE_CURRENT> will be
             * appended to `flags` automatically. Default value is true.
             */
            updateCurrentIntent: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.PendingIntent.flags> property.
             * @deprecated Access <Titanium.Android.PendingIntent.flags> instead.
             */
            getFlags(): number;

            /**
             * Gets the value of the <Titanium.Android.PendingIntent.intent> property.
             * @deprecated Access <Titanium.Android.PendingIntent.intent> instead.
             */
            getIntent(): Titanium.Android.Intent;

            /**
             * Gets the value of the <Titanium.Android.PendingIntent.updateCurrentIntent> property.
             * @deprecated Access <Titanium.Android.PendingIntent.updateCurrentIntent> instead.
             */
            getUpdateCurrentIntent(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Android.PendingIntent.flags> property.
             * @deprecated Set the value using <Titanium.Android.PendingIntent.flags> instead.
             */
            setFlags(flags: number): void;

            /**
             * Sets the value of the <Titanium.Android.PendingIntent.intent> property.
             * @deprecated Set the value using <Titanium.Android.PendingIntent.intent> instead.
             */
            setIntent(intent: Titanium.Android.Intent): void;

            /**
             * Sets the value of the <Titanium.Android.PendingIntent.updateCurrentIntent> property.
             * @deprecated Set the value using <Titanium.Android.PendingIntent.updateCurrentIntent> instead.
             */
            setUpdateCurrentIntent(updateCurrentIntent: boolean): void;

        }
        /**
         * Base event for class Titanium.Android.QuickSettingsService
         */
        interface QuickSettingsServiceBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Android.QuickSettingsService;

        }
        /**
         * For Javascript-based services that you create, `pause` fires after each time the JavaScript
         * code executes.
         */
        interface QuickSettingsService_pause_Event extends QuickSettingsServiceBaseEvent {
            /**
             * Incrementing integer indicating which iteration of an interval-based Service is pausing.
             * For example, if you have an interval-based Service running every 10 seconds, iteration
             * 3 would occur at about 30 seconds after you start the instance (assuming your service
             * code runs quickly).
             */
            iteration: number;

        }
        /**
         * For JavaScript-based Services which you create, `resume` fires each time the JavaScript
         * code executes.
         */
        interface QuickSettingsService_resume_Event extends QuickSettingsServiceBaseEvent {
            /**
             * Incrementing integer indicating which iteration of an interval-based Service is pausing.
             * For example, if you have an interval-based Service running every 10 seconds, iteration
             * 3 would occur at about 30 seconds after you start the instance (assuming your service
             * code runs quickly).
             */
            iteration: number;

        }
        /**
         * Fired when the bound service instance starts.
         */
        interface QuickSettingsService_start_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Fired when the bound service instance stops.
         */
        interface QuickSettingsService_stop_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Fired when the task that comes from the service's application has been removed.
         */
        interface QuickSettingsService_taskremoved_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Tile is listening for events.
         */
        interface QuickSettingsService_startlistening_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Tile has stopped listening for events.
         */
        interface QuickSettingsService_stoplistening_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * The Tile has been added in the quick menu.
         */
        interface QuickSettingsService_tileadded_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * The Tile has been removed from the quick menu.
         */
        interface QuickSettingsService_tileremoved_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * An item from the signle choice menu has been selected.
         */
        interface QuickSettingsService_tiledialogoptionselected_Event extends QuickSettingsServiceBaseEvent {
            /**
             * Index of the selected item from the single choice menu in the dialog.
             */
            itemIndex: number;

        }
        /**
         * Dispatched when the alert dialog has been cancelled.
         */
        interface QuickSettingsService_tiledialogcancelled_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Dispatched when the positive (index 0) button has been clicked.
         */
        interface QuickSettingsService_tiledialogpositive_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Dispatched when the neutral (index 1) button has been clicked.
         */
        interface QuickSettingsService_tiledialogneutral_Event extends QuickSettingsServiceBaseEvent {
        }
        /**
         * Dispatched when the negative (index 2) button has been clicked.
         */
        interface QuickSettingsService_tiledialognegative_Event extends QuickSettingsServiceBaseEvent {
        }
        interface QuickSettingsServiceEventMap extends ProxyEventMap {
            pause: QuickSettingsService_pause_Event;

            resume: QuickSettingsService_resume_Event;

            start: QuickSettingsService_start_Event;

            startlistening: QuickSettingsService_startlistening_Event;

            stop: QuickSettingsService_stop_Event;

            stoplistening: QuickSettingsService_stoplistening_Event;

            taskremoved: QuickSettingsService_taskremoved_Event;

            tileadded: QuickSettingsService_tileadded_Event;

            tiledialogcancelled: QuickSettingsService_tiledialogcancelled_Event;

            tiledialognegative: QuickSettingsService_tiledialognegative_Event;

            tiledialogneutral: QuickSettingsService_tiledialogneutral_Event;

            tiledialogoptionselected: QuickSettingsService_tiledialogoptionselected_Event;

            tiledialogpositive: QuickSettingsService_tiledialogpositive_Event;

            tileremoved: QuickSettingsService_tileremoved_Event;

        }
        /**
         * Android service for creating custom quick settings tiles and handling user's interaction with them.
         */
        class QuickSettingsService extends Titanium.Android.Service {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof QuickSettingsServiceEventMap>(name: K, callback: (this: Titanium.Android.QuickSettingsService, event: QuickSettingsServiceEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof QuickSettingsServiceEventMap>(name: K, event?: QuickSettingsServiceEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Returns the Tile's current icon.
             */
            getIcon(): string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Returns the Tile's current label.
             */
            getLabel(): string;

            /**
             * Returns the Tile's current state.
             */
            getState(): number;

            /**
             * Returns 'true' if the device is currently locked, 'false' otherwise.
             */
            isLocked(): boolean;

            /**
             * Returns 'true' if the device is in secure state, 'false' otherwise.
             */
            isSecure(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof QuickSettingsServiceEventMap>(name: K, callback: (this: Titanium.Android.QuickSettingsService, event: QuickSettingsServiceEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Changes the Tile's icon.
             */
            setIcon(icon: string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Changes the Tile's label.
             */
            setLabel(label: string): void;

            /**
             * Sets the state of the Tile.
             */
            setState(state: number): void;

            /**
             * Opens an Alert dialog.
             */
            showDialog(options: showParams): void;

            /**
             * Colapses the quick settings menu and starts an activity for the passed Intent.
             */
            startActivityAndCollapse(intent: Titanium.Android.Intent): void;

            /**
             * Prompts the user to unlock the device and runs the JS code.
             */
            unlockAndRun(jsCode: string): void;

            /**
             * Applies current tile's properties.
             */
            updateTile(): void;

        }
        /**
         * The Titanium binding of the native Android `R` class, giving access to
         * Android system-wide resources or application resources.
         */
        interface R extends Titanium.Proxy {
            /**
             * Animation resources. See
             * [R.anim](https://developer.android.com/reference/android/R.anim.html)
             * in the Android Developer Reference.
             */
            readonly anim: any;

            /**
             * Animator resources. See
             * [R.animator](https://developer.android.com/reference/android/R.animator.html)
             * in the Android Developer Reference.
             */
            readonly animator: any;

            /**
             * Array resources. See [R.array](https://developer.android.com/reference/android/R.array.html)
             * in the Android Developer Reference.
             */
            readonly array: any;

            /**
             * Attribute resources. See
             * [R.attr](https://developer.android.com/reference/android/R.attr.html)
             * in the Android Developer Reference.
             */
            readonly attr: any;

            /**
             * Boolean resources. See
             * [R.bool](https://developer.android.com/reference/android/R.bool.html)
             * in the Android Developer Reference.
             */
            readonly bool: any;

            /**
             * Color resources. See
             * [R.color](https://developer.android.com/reference/android/R.color.html)
             * in the Android Developer Reference.
             */
            readonly color: any;

            /**
             * Dimension resources.  See
             * [https://developer.android.com/reference/android/R.dimen.html](https://developer.android.com/reference/android/R.dimen.html)
             * in the Android Developer Reference.
             */
            readonly dimen: any;

            /**
             * Drawable resources. See
             * [R.drawable](https://developer.android.com/reference/android/R.drawable.html)
             * in the Android Developer Reference.
             */
            readonly drawable: any;

            /**
             * Fraction resources. See
             * [R.fraction](https://developer.android.com/reference/android/R.fraction.html)
             * in the Android Developer Reference.
             */
            readonly fraction: any;

            /**
             * ID resources.  See
             * [R.id](https://developer.android.com/reference/android/R.id.html)
             * in the Android Developer Reference.
             */
            readonly id: any;

            /**
             * Integer resources. See
             * [R.integer](https://developer.android.com/reference/android/R.integer.html)
             * in the Android Developer Reference.
             */
            readonly integer: any;

            /**
             * Interpolator resources. See
             * [R.fraction](https://developer.android.com/reference/android/R.interpolator.html)
             * in the Android Developer Reference.
             */
            readonly interpolator: any;

            /**
             * Layout resources. See
             * [R.layout](https://developer.android.com/reference/android/R.layout.html)
             * in the Android Developer Reference.
             */
            readonly layout: any;

            /**
             * Menu resources. See
             * [R.menu](https://developer.android.com/reference/android/R.menu.html)
             * in the Android Developer Reference.
             */
            readonly menu: any;

            /**
             * Mipmap resources. See
             * [R.mipmap](https://developer.android.com/reference/android/R.mipmap.html)
             * in the Android Developer Reference.
             */
            readonly mipmap: any;

            /**
             * Plurals resources. See
             * [R.plurals](https://developer.android.com/reference/android/R.plurals.html)
             * in the Android Developer Reference.
             */
            readonly plurals: any;

            /**
             * Raw resources. See
             * [R.raw](https://developer.android.com/reference/android/R.raw.html)
             * in the Android Developer Reference.
             */
            readonly raw: any;

            /**
             * String resources. See
             * [R.string](https://developer.android.com/reference/android/R.string.html)
             * in the Android Developer Reference.
             */
            readonly string: any;

            /**
             * Style resources. See
             * [R.style](https://developer.android.com/reference/android/R.style.html)
             * in the Android Developer Reference.
             */
            readonly style: any;

            /**
             * Styleable resources. See
             * [R.styleable](https://developer.android.com/reference/android/R.styleable.html)
             * in the Android Developer Reference.
             */
            readonly styleable: any;

            /**
             * Transition resources. See
             * [R.transition](https://developer.android.com/reference/android/R.transition.html)
             * in the Android Developer Reference.
             */
            readonly transition: any;

            /**
             * XML resources. See
             * [R.xml](https://developer.android.com/reference/android/R.xml.html)
             * in the Android Developer Reference.
             */
            readonly xml: any;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * The Titanium binding of [Android RemoteViews](https://developer.android.com/reference/android/widget/RemoteViews.html).
         */
        class RemoteViews extends Titanium.Proxy {
            /**
             * Android layout resource ID for the view to display. Required.
             */
            layoutId: number;

            /**
             * Package name that the resource ID lives in. Optional.
             */
            packageName: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Android.RemoteViews.layoutId> property.
             * @deprecated Access <Titanium.Android.RemoteViews.layoutId> instead.
             */
            getLayoutId(): number;

            /**
             * Gets the value of the <Titanium.Android.RemoteViews.packageName> property.
             * @deprecated Access <Titanium.Android.RemoteViews.packageName> instead.
             */
            getPackageName(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Calls a method taking a single `boolean` argument on a view in the remote view
             * hierarchy.  See Android's documentation for
             * [setBoolean](https://developer.android.com/reference/android/widget/RemoteViews.html#setBoolean(int, java.lang.String, boolean)).
             */
            setBoolean(viewId: number, methodName: string, value: boolean): void;

            /**
             * Sets the base time, format string, and started flag for a chronometer
             * in the remote view hierarchy.
             */
            setChronometer(viewId: number, base: Date, format: string, started: boolean): void;

            /**
             * Calls a method taking a single `double` argument on a view in the remote view
             * hierarchy.
             */
            setDouble(viewId: number, methodName: string, value: number): void;

            /**
             * Sets the image for an image view in the remote view hierarchy using an Android drawable resource.
             */
            setImageViewResource(viewId: number, srcId: number): void;

            /**
             * Sets the image for an image view in the remote view hierarchy using a URI.
             */
            setImageViewUri(viewId: number, uri: string): void;

            /**
             * Calls a method taking a single `int` argument on a view in the remote view hierarchy.
             */
            setInt(viewId: number, methodName: string, value: number): void;

            /**
             * Sets the value of the <Titanium.Android.RemoteViews.layoutId> property.
             * @deprecated Set the value using <Titanium.Android.RemoteViews.layoutId> instead.
             */
            setLayoutId(layoutId: number): void;

            /**
             * Launches a <Titanium.Android.PendingIntent> when the specified view is clicked.
             */
            setOnClickPendingIntent(viewId: number, pendingIntent: Titanium.Android.PendingIntent): void;

            /**
             * Sets the value of the <Titanium.Android.RemoteViews.packageName> property.
             * @deprecated Set the value using <Titanium.Android.RemoteViews.packageName> instead.
             */
            setPackageName(packageName: string): void;

            /**
             * Sets the progress, max value, and indeterminate flag of a progress bar in the
             * remote view hierarchy.
             */
            setProgressBar(viewId: number, max: number, progress: number, indeterminate: boolean): void;

            /**
             * Calls a method taking a single String argument on a view in the remote view
             * hierarchy.
             */
            setString(viewId: number, methodName: string, value: string): void;

            /**
             * Sets the text color of a view in the remote view hierarchy.
             */
            setTextColor(viewId: number, color: number): void;

            /**
             * Sets the text of a text view in the remote view hierarchy.
             */
            setTextViewText(viewId: number, text: string): void;

            /**
             * Calls a method taking one URI on a view in the remote view hierarchy.
             */
            setUri(viewId: number, methodName: string, value: string): void;

            /**
             * Sets the visibility of a view in the remote view hierarchy.
             */
            setViewVisibility(viewId: number, visibility: number): void;

        }
        /**
         * Base event for class Titanium.Android.Service
         */
        interface ServiceBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Android.Service;

        }
        /**
         * For Javascript-based services that you create, `pause` fires after each time the JavaScript
         * code executes.
         */
        interface Service_pause_Event extends ServiceBaseEvent {
            /**
             * Incrementing integer indicating which iteration of an interval-based Service is pausing.
             * For example, if you have an interval-based Service running every 10 seconds, iteration
             * 3 would occur at about 30 seconds after you start the instance (assuming your service
             * code runs quickly).
             */
            iteration: number;

        }
        /**
         * For JavaScript-based Services which you create, `resume` fires each time the JavaScript
         * code executes.
         */
        interface Service_resume_Event extends ServiceBaseEvent {
            /**
             * Incrementing integer indicating which iteration of an interval-based Service is pausing.
             * For example, if you have an interval-based Service running every 10 seconds, iteration
             * 3 would occur at about 30 seconds after you start the instance (assuming your service
             * code runs quickly).
             */
            iteration: number;

        }
        /**
         * Fired when the bound service instance starts.
         */
        interface Service_start_Event extends ServiceBaseEvent {
        }
        /**
         * Fired when the bound service instance stops.
         */
        interface Service_stop_Event extends ServiceBaseEvent {
        }
        /**
         * Fired when the task that comes from the service's application has been removed.
         */
        interface Service_taskremoved_Event extends ServiceBaseEvent {
        }
        interface ServiceEventMap extends ProxyEventMap {
            pause: Service_pause_Event;

            resume: Service_resume_Event;

            start: Service_start_Event;

            stop: Service_stop_Event;

            taskremoved: Service_taskremoved_Event;

        }
        /**
         * Android application component that executes in the background.
         */
        class Service extends Titanium.Proxy {
            /**
             * The intent used to start or bind to the Service.
             */
            readonly intent: Titanium.Android.Intent;

            /**
             * A service can be started more than once -- this number (based on an incrementing integer)
             * indicates which "start number" in the sequence the current service instance is.
             */
            readonly serviceInstanceId: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ServiceEventMap>(name: K, callback: (this: Titanium.Android.Service, event: ServiceEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ServiceEventMap>(name: K, event?: ServiceEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Puts the service into the "background" state and removes its foreground notification.
             */
            foregroundCancel(): void;

            /**
             * Puts the service into the "foreground" state and displays a notification.
             */
            foregroundNotify(id: number, notification: Titanium.Android.Notification, foregroundServiceType?: number): void;

            /**
             * Gets the value of the <Titanium.Android.Service.intent> property.
             * @deprecated Access <Titanium.Android.Service.intent> instead.
             */
            getIntent(): Titanium.Android.Intent;

            /**
             * Gets the value of the <Titanium.Android.Service.serviceInstanceId> property.
             * @deprecated Access <Titanium.Android.Service.serviceInstanceId> instead.
             */
            getServiceInstanceId(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ServiceEventMap>(name: K, callback: (this: Titanium.Android.Service, event: ServiceEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Starts the Service.
             */
            start(): void;

            /**
             * Stops this running instance of the Service.
             */
            stop(): void;

        }
    }
    /**
     * The top-level App module is mainly used for accessing information about the
     * application at runtime, and for sending or listening for system events.
     */
    namespace App {
        /**
         * Convenience constant for system event "accessibilityannouncement".
         */
        const EVENT_ACCESSIBILITY_ANNOUNCEMENT: string;

        /**
         * Convenience constant for system event "accessibilitychanged".
         */
        const EVENT_ACCESSIBILITY_CHANGED: string;

        /**
         * The top-level App iOS module, available only to iOS devices, that includes the facilities to
         * create and manage local notifications and background services.
         */
        namespace iOS {
            /**
             * Use with [setMinimumBackgroundFetchInterval](Titanium.App.iOS.setMinimumBackgroundFetchInterval) method.
             * Specifies the smallest fetch interval supported by the system.
             */
            const BACKGROUNDFETCHINTERVAL_MIN: number;

            /**
             * Use with [setMinimumBackgroundFetchInterval](Titanium.App.iOS.setMinimumBackgroundFetchInterval) method.
             * Used to specify a fetch interval large enough to prevent fetch operations from occurring.
             */
            const BACKGROUNDFETCHINTERVAL_NEVER: number;

            /**
             * Convenience constant for system event "accessibilitylayoutchanged".
             */
            const EVENT_ACCESSIBILITY_LAYOUT_CHANGED: string;

            /**
             * Convenience constant for system event "accessibilityscreenchanged".
             */
            const EVENT_ACCESSIBILITY_SCREEN_CHANGED: string;

            /**
             * A dark interface style.
             * @deprecated Use <Titanium.UI.USER_INTERFACE_STYLE_DARK> instead, which is supported cross-platform.
             */
            const USER_INTERFACE_STYLE_DARK: number;

            /**
             * A light interface style.
             * @deprecated Use <Titanium.UI.USER_INTERFACE_STYLE_LIGHT> instead, which is supported cross-platform.
             */
            const USER_INTERFACE_STYLE_LIGHT: number;

            /**
             * An unspecified interface style.
             * @deprecated Use <Titanium.UI.USER_INTERFACE_STYLE_UNSPECIFIED> instead, which is supported cross-platform.
             */
            const USER_INTERFACE_STYLE_UNSPECIFIED: number;

            /**
             * The action will execute in background. Use with the
             * [activationMode](Titanium.App.iOS.UserNotificationAction.activationMode) property.
             */
            const USER_NOTIFICATION_ACTIVATION_MODE_BACKGROUND: number;

            /**
             * The action will launch the application and execute in the foreground.
             * Use with the [activationMode](Titanium.App.iOS.UserNotificationAction.activationMode) property.
             */
            const USER_NOTIFICATION_ACTIVATION_MODE_FOREGROUND: number;

            /**
             * A alert dialog is presented when the notification is received.
             */
            const USER_NOTIFICATION_ALERT_STYLE_ALERT: number;

            /**
             * A banner is presented when the notification is received.
             */
            const USER_NOTIFICATION_ALERT_STYLE_BANNER: number;

            /**
             * No banner or alert dialog is presented when the notification is received.
             */
            const USER_NOTIFICATION_ALERT_STYLE_NONE: number;

            /**
             * The application is authorized to post user notifications.
             */
            const USER_NOTIFICATION_AUTHORIZATION_STATUS_AUTHORIZED: number;

            /**
             * The application is not authorized to post user notifications.
             */
            const USER_NOTIFICATION_AUTHORIZATION_STATUS_DENIED: number;

            /**
             * The user has not yet made a choice regarding whether the application may post
             * user notifications.
             */
            const USER_NOTIFICATION_AUTHORIZATION_STATUS_NOT_DETERMINED: number;

            /**
             * The application is provisionally authorized to post non-interruptive user notifications.
             */
            const USER_NOTIFICATION_AUTHORIZATION_STATUS_PROVISIONAL: number;

            /**
             * Default action behavior with no additional action support.
             */
            const USER_NOTIFICATION_BEHAVIOR_DEFAULT: number;

            /**
             * Provides a textfield with the notification for the user to enter a text response.
             */
            const USER_NOTIFICATION_BEHAVIOR_TEXTINPUT: number;

            /**
             * Allow CarPlay to display notifications of this type.
             */
            const USER_NOTIFICATION_CATEGORY_OPTION_ALLOW_IN_CARPLAY: number;

            /**
             * Send dismiss actions to the UNUserNotificationCenter object's delegate for handling.
             */
            const USER_NOTIFICATION_CATEGORY_OPTION_CUSTOM_DISMISS_ACTION: number;

            /**
             * Show the notification's subtitle, even if the user has disabled notification previews for the app.
             */
            const USER_NOTIFICATION_CATEGORY_OPTION_HIDDEN_PREVIEWS_SHOW_SUBTITLE: number;

            /**
             * Show the notification's title, even if the user has disabled notification previews for the app.
             */
            const USER_NOTIFICATION_CATEGORY_OPTION_HIDDEN_PREVIEWS_SHOW_TITLE: number;

            /**
             * No options.
             */
            const USER_NOTIFICATION_CATEGORY_OPTION_NONE: number;

            /**
             * The notification setting is turned off.
             */
            const USER_NOTIFICATION_SETTING_DISABLED: number;

            /**
             * The notification setting is turned on.
             */
            const USER_NOTIFICATION_SETTING_ENABLED: number;

            /**
             * The application does not support this notification type.
             */
            const USER_NOTIFICATION_SETTING_NOT_SUPPORTED: number;

            /**
             * The application may display an alert upon a notification being received.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_ALERT: number;

            /**
             * The application may badge its icon upon a notification being received.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_BADGE: number;

            /**
             * The ability to play sounds for critical alerts.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_CRITICAL_ALERT: number;

            /**
             * The application may not present any UI upon a notification being received.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_NONE: number;

            /**
             * An option indicating the system should display a button for in-app notification settings.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_PROVIDES_APP_NOTIFICATION_SETTINGS: number;

            /**
             * The ability to post non-interrupting notifications provisionally to the Notification Center.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_PROVISIONAL: number;

            /**
             * The application may play a sound upon a notification being received.
             * Use with the [types](UserNotificationSettings.types) property.
             */
            const USER_NOTIFICATION_TYPE_SOUND: number;

            /**
             * Uniform type identifier for Mac OS icon images.
             */
            const UTTYPE_APPLE_ICNS: string;

            /**
             * Uniform type identifier for protected MPEG-4 audio (iTunes music store format).
             */
            const UTTYPE_APPLE_PROTECTED_MPEG4_AUDIO: string;

            /**
             * Uniform type identifier for all audio content.
             */
            const UTTYPE_AUDIO: string;

            /**
             * Uniform type identifier for Windows bitmap images.
             */
            const UTTYPE_BMP: string;

            /**
             * Uniform type identifier for Rich Text with content embedding, pasteboard format.
             */
            const UTTYPE_FLAT_RTFD: string;

            /**
             * Uniform type identifier for GIF images.
             */
            const UTTYPE_GIF: string;

            /**
             * Uniform type identifier for HTML.
             */
            const UTTYPE_HTML: string;

            /**
             * Uniform type identifier for Windows icon images.
             */
            const UTTYPE_ICO: string;

            /**
             * Uniform type identifier for all image types.
             */
            const UTTYPE_IMAGE: string;

            /**
             * Uniform type identifier for JPEG images.
             */
            const UTTYPE_JPEG: string;

            /**
             * Uniform type identifier for JPEG 2000 images.
             */
            const UTTYPE_JPEG2000: string;

            /**
             * Uniform type identifier for all audiovisual content.
             */
            const UTTYPE_MOVIE: string;

            /**
             * Uniform type identifier for MP3 audio.
             */
            const UTTYPE_MP3: string;

            /**
             * Uniform type identifier for MPEG-1 and MPEG-2 content.
             */
            const UTTYPE_MPEG: string;

            /**
             * Uniform type identifier for MPEG-4 content.
             */
            const UTTYPE_MPEG4: string;

            /**
             * Uniform type identifier for MPEG-4 audio.
             */
            const UTTYPE_MPEG4_AUDIO: string;

            /**
             * Uniform type identifier for PDF data.
             */
            const UTTYPE_PDF: string;

            /**
             * Uniform type identifier for PICT images.
             */
            const UTTYPE_PICT: string;

            /**
             * Uniform type identifier for a plain text type, equivalent to MIME type text/plain.
             */
            const UTTYPE_PLAIN_TEXT: string;

            /**
             * Uniform type identifier for PNG images.
             */
            const UTTYPE_PNG: string;

            /**
             * Uniform type identifier for QuickTime images.
             */
            const UTTYPE_QUICKTIME_IMAGE: string;

            /**
             * Uniform type identifier for QuickTime movies.
             */
            const UTTYPE_QUICKTIME_MOVIE: string;

            /**
             * Uniform type identifier for Rich Text.
             */
            const UTTYPE_RTF: string;

            /**
             * Uniform type identifier for Rich Text Format Directory, that is, Rich Text with content embedding, on-disk format.
             */
            const UTTYPE_RTFD: string;

            /**
             * Uniform type identifier for all text types.
             */
            const UTTYPE_TEXT: string;

            /**
             * Uniform type identifier for TIFF images.
             */
            const UTTYPE_TIFF: string;

            /**
             * Uniform type identifier for MLTE (Textension) format for mixed text and multimedia data.
             */
            const UTTYPE_TXN_TEXT_AND_MULTIMEDIA_DATA: string;

            /**
             * Uniform type identifier for Unicode-16 with byte-order mark (BOM), or if BOM is not present,
             * an external representation byte order (big-endian).
             */
            const UTTYPE_UTF16_EXTERNAL_PLAIN_TEXT: string;

            /**
             * Uniform type identifier for Unicode-16, native byte order, with an optional byte-order mark (BOM).
             */
            const UTTYPE_UTF16_PLAIN_TEXT: string;

            /**
             * Uniform type identifier for Unicode-8 plain text type.
             */
            const UTTYPE_UTF8_PLAIN_TEXT: string;

            /**
             * Uniform type identifier for all video content without audio.
             */
            const UTTYPE_VIDEO: string;

            /**
             * Uniform type identifier for WebKit webarchive format.
             */
            const UTTYPE_WEB_ARCHIVE: string;

            /**
             * Uniform type identifier for XML.
             */
            const UTTYPE_XML: string;

            /**
             * A service that runs when the application is placed in the background.
             */
            class BackgroundService extends Titanium.Proxy {
                /**
                 * A local URL to a JavaScript file containing the code to run in the background.
                 */
                url: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.App.iOS.BackgroundService.url> property.
                 * @deprecated Access <Titanium.App.iOS.BackgroundService.url> instead.
                 */
                getUrl(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.BackgroundService.url> property.
                 * @deprecated Set the value using <Titanium.App.iOS.BackgroundService.url> instead.
                 */
                setUrl(url: string): void;

                /**
                 * Stops the service from running during the current background session to conserve resources.
                 */
                stop(): void;

                /**
                 * Unregisters the background service.
                 */
                unregister(): void;

            }
            /**
             * A local notification to alert the user of new or pending application information.
             */
            class LocalNotification extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Cancels the pending notification.
                 * @deprecated Use [Titanium.App.iOS.UserNotificationCenter.removePendingNotifications](Titanium.App.iOS.UserNotificationCenter.removePendingNotifications) instead.
                 */
                cancel(): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * Base event for class Titanium.App.iOS.SearchQuery
             */
            interface SearchQueryBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.App.iOS.SearchQuery;

            }
            /**
             * Fired when the query finds a new batch of matching items.
             */
            interface SearchQuery_founditems_Event extends SearchQueryBaseEvent {
                /**
                 * The number of items that are currently fetched.
                 */
                foundItemsCount: number;

                /**
                 * An array of indexed items that match the specified query.
                 */
                items: Titanium.App.iOS.SearchableItem[];

            }
            /**
             * Fired when the query completes to inform you about it's success.
             * To receive items, use the `founditems` event.
             */
            interface SearchQuery_completed_Event extends SearchQueryBaseEvent {
                /**
                 * Error message, if any returned. Undefined otherwise.
                 */
                error: string;

                /**
                 * Indicates if the operation succeeded. Returns true if download succeeded, false otherwise.
                 */
                success: boolean;

            }
            interface SearchQueryEventMap extends ProxyEventMap {
                completed: SearchQuery_completed_Event;

                founditems: SearchQuery_founditems_Event;

            }
            /**
             * A search query object manages the criteria to apply when searching app content that you have previously
             * indexed by using the Core Spotlight APIs.
             */
            class SearchQuery extends Titanium.Proxy {
                /**
                 * An array of strings that represent the attributes of indexed items.
                 */
                attributes: string[];

                /**
                 * A formatted string that defines the matching criteria to apply to indexed items.
                 */
                queryString: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof SearchQueryEventMap>(name: K, callback: (this: Titanium.App.iOS.SearchQuery, event: SearchQueryEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Cancels a query operation.
                 */
                cancel(): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof SearchQueryEventMap>(name: K, event?: SearchQueryEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * A Boolean value that indicates if the query has been cancelled (`true`) or not (`false`).
                 */
                isCancelled(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof SearchQueryEventMap>(name: K, callback: (this: Titanium.App.iOS.SearchQuery, event: SearchQueryEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Asynchronously queries the index for items that match the query object's specifications.
                 */
                start(): void;

            }
            /**
             * The SearchableIndex module is used to add or remove Ti.App.iOS.SearchableItem objects from the device search index.
             */
            class SearchableIndex extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Adds an array of Titanium.App.iOS.SearchableItem objects to the default search index.
                 */
                addToDefaultSearchableIndex(Array: ReadonlyArray<Titanium.App.iOS.SearchableItem>, callback: (param0: any) => void): void;

                /**
                 * Removes search items based on an array of domain identifiers.
                 */
                deleteAllSearchableItemByDomainIdenifiers(Array: ReadonlyArray<string>, callback: (param0: any) => void): void;

                /**
                 * Removes all search items added by the application.
                 */
                deleteAllSearchableItems(callback: (param0: any) => void): void;

                /**
                 * Removes search items based on an array of identifiers.
                 */
                deleteSearchableItemsByIdentifiers(Array: ReadonlyArray<string>, callback: (param0: any) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Indicates whether indexing is supported by the device.
                 */
                isSupported(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * Used to create a unique object containing all of the search information that will appear in the device search index.
             */
            class SearchableItem extends Titanium.Proxy {
                /**
                 * Set of metadata properties to display for the item.
                 */
                attributeSet: Titanium.App.iOS.SearchableItemAttributeSet;

                /**
                 * Identifier that represents the "domain" or owner of this item.
                 */
                domainIdentifier: string;

                /**
                 * Searchable items have an expiration date or time to live.  By default it is set to one month.
                 */
                expirationDate: string;

                /**
                 * Unique identifier to your application group.
                 */
                uniqueIdentifier: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItem.domainIdentifier> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItem.domainIdentifier> instead.
                 */
                getDomainIdentifier(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItem.expirationDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItem.expirationDate> instead.
                 */
                getExpirationDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItem.uniqueIdentifier> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItem.uniqueIdentifier> instead.
                 */
                getUniqueIdentifier(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItem.domainIdentifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItem.domainIdentifier> instead.
                 */
                setDomainIdentifier(domainIdentifier: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItem.expirationDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItem.expirationDate> instead.
                 */
                setExpirationDate(expirationDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItem.uniqueIdentifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItem.uniqueIdentifier> instead.
                 */
                setUniqueIdentifier(uniqueIdentifier: string): void;

            }
            /**
             * The SearchableItemAttributeSet module defines metadata properties for SearchItem and UserActivity objects.
             */
            class SearchableItemAttributeSet extends Titanium.Proxy {
                /**
                 * The date that the item was moved into the current location.
                 */
                addedDate: string;

                /**
                 * The title for a collection of media.
                 */
                album: string;

                /**
                 * An array of localized strings of alternate display names for this item.
                 */
                alternateNames: string[];

                /**
                 * The artist for the media.
                 */
                artist: string;

                /**
                 * A class of entity for whom the resource is intended or useful.
                 */
                audiences: string[];

                /**
                 * The audio bit rate.
                 */
                audioBitRate: number;

                /**
                 * The number of channels in the audio data contained in the file.
                 */
                audioChannelCount: number;

                /**
                 * The name of the application that encoded the data contained in the audio file.
                 */
                audioEncodingApplication: string;

                /**
                 * The sample rate of the audio data contained in the file.
                 */
                audioSampleRate: number;

                /**
                 * The track number of a song/composition when it is part of an album.
                 */
                audioTrackNumber: number;

                /**
                 * The codecs used to encode/decode the media.
                 */
                codecs: string[];

                /**
                 * Comment related to a file.
                 */
                comment: string;

                /**
                 * The composer of the song/composition contained in the audio file.
                 */
                composer: string;

                /**
                 * A list of contacts that are somehow associated with this document beyond what is captured as Author.
                 */
                contactKeywords: string[];

                /**
                 * Display of the search container
                 */
                containerDisplayName: string;

                /**
                 * Identifier for the search container
                 */
                containerIdentifier: string;

                /**
                 * Order the search container is displayed.
                 */
                containerOrder: number;

                /**
                 * Title displayed in the search container
                 */
                containerTitle: string;

                /**
                 * The date that the contents of the item were created.
                 */
                contentCreationDate: string;

                /**
                 * An account of the content of the resource.
                 */
                contentDescription: string;

                /**
                 * The date that the contents of the item were last modified.
                 */
                contentModificationDate: string;

                /**
                 * Whether or not the item has explicit content. Set to `1` for explicit or `0` for clean.
                 */
                contentRating: number;

                /**
                 * Used to indicate where the item was obtained from.
                 */
                contentSources: string[];

                /**
                 * UTI Type pedigree for an item.
                 */
                contentType: string;

                /**
                 * Array of strings related to the content tree of the item.
                 */
                contentTypeTree: string[];

                /**
                 * File URL representing the content to be indexed.
                 */
                contentURL: string;

                /**
                 * Used to designate the entity responsible for making contributions to the content of the resource.
                 */
                contributors: string[];

                /**
                 * Copyright of the content.
                 */
                copyright: string;

                /**
                 * Used to designate the extent or scope of the content of the resource.
                 */
                coverage: string[];

                /**
                 * Application used to create the document content (e.g. "Word","Framemaker", etc.).
                 */
                creator: string;

                /**
                 * The delivery type of the item.  Set to `0` for fast start and `1` for RTSP.
                 */
                deliveryType: number;

                /**
                 * Director of the item, for example, the movie director.
                 */
                director: string;

                /**
                 * A localized string to be displayed in the UI for this item.
                 */
                displayName: string;

                /**
                 * The date that the file was last downloaded / received.
                 */
                downloadedDate: string;

                /**
                 * Duration in seconds of the content of the item (if appropriate).
                 */
                duration: number;

                /**
                 * The list of editor/editors that have worked on this item.
                 */
                editors: string[];

                /**
                 * Software used to convert the original content into a PDF stream.
                 */
                encodingApplications: string[];

                /**
                 * Size of the document in MB.
                 */
                fileSize: number;

                /**
                 * Array of font names used in the item.
                 */
                fontNames: string[];

                /**
                 * The fully formatted address of the item (obtained from MapKit).
                 */
                fullyFormattedAddress: string;

                /**
                 * Used to indicates whether the MIDI sequence contained in the file is setup for use with a General MIDI device.
                 */
                generalMIDISequence: number;

                /**
                 * Genre of the item, for example, movie genre.
                 */
                genre: string;

                /**
                 * Used to reference to the resource within a given context.
                 */
                identifier: string;

                /**
                 * Information about the item.
                 */
                information: string;

                /**
                 * Content type of the attribute set.
                 */
                itemContentType: string;

                /**
                 * The musical key of the song/composition contained in an audio file.
                 */
                keySignature: string;

                /**
                 * Represents keywords associated with this particular item. Example keywords might be Birthday etc.
                 */
                keywords: string[];

                /**
                 * Kind that the item represents.
                 */
                kind: string;

                /**
                 * Used to designate the languages of the intellectual content of the resource.
                 */
                languages: string[];

                /**
                 * The date that the item was last used.
                 */
                lastUsedDate: string;

                /**
                 * Whether or not the item is local. Set to `1` if true and `0` otherwise.
                 */
                local: number;

                /**
                 * The lyricist/text writer for song/composition contained in the audio file.
                 */
                lyricist: string;

                /**
                 * Media types present in the content.
                 */
                mediaTypes: string[];

                /**
                 * The date that the last metadata attribute was changed.
                 */
                metadataModificationDate: string;

                /**
                 * The musical genre of the song/composition contained in the audio file.
                 */
                musicalGenre: string;

                /**
                 * Metadata attribute that stores the category of instrument.
                 */
                musicalInstrumentCategory: string;

                /**
                 * Metadata attribute that stores the name of instrument.
                 */
                musicalInstrumentName: string;

                /**
                 * Used to indicate company/Organization that created the document.
                 */
                organizations: string[];

                /**
                 * Original format of the movie.
                 */
                originalFormat: string;

                /**
                 * Original source of the movie.
                 */
                originalSource: string;

                /**
                 * Number of pages in the item.
                 */
                pageCount: number;

                /**
                 * Height in points (72 points per inch) of the document page.
                 */
                pageHeight: number;

                /**
                 * Width in points (72 points per inch) of the document page.
                 */
                pageWidth: number;

                /**
                 * The list of people who are visible in an image or movie or written about in a document.
                 */
                participants: string[];

                /**
                 * The complete path to the item.
                 */
                path: string;

                /**
                 * Performers in the movie.
                 */
                performers: string[];

                /**
                 * User play count of this item.
                 */
                playCount: number;

                /**
                 * The postal code for the item according to guidelines established by the provider.
                 */
                postalCode: string;

                /**
                 * Producer of the content.
                 */
                producer: string;

                /**
                 * The list of projects that this item is part of.
                 */
                projects: string[];

                /**
                 * Used to designate the entity responsible for making the resource available.
                 */
                publishers: string[];

                /**
                 * User rating of this item out of 5 stars.
                 */
                rating: number;

                /**
                 * A description of the rating, for example, the number of reviewers.
                 */
                ratingDescription: string;

                /**
                 * The recording date of the song/composition.
                 */
                recordingDate: string;

                /**
                 * For activities this is the unique identifier for the item this activity is related to.
                 */
                relatedUniqueIdentifier: string;

                /**
                 * Used to provide a link to information about rights held in and over resource.
                 */
                rights: string[];

                /**
                 * Used to indicate the role of the document creator.
                 */
                role: string;

                /**
                 * Security (encryption) method used in the file.
                 */
                securityMethod: string;

                /**
                 * Whether the content is prepared for streaming.  Set to `0` for not streamable and `1` for streamable.
                 */
                streamable: number;

                /**
                 * The sub-location (e.g., street number) for the item according to guidelines established by the provider.
                 */
                subThoroughfare: string;

                /**
                 * Subject of the the item.
                 */
                subject: string;

                /**
                 * Used to determine if navigation is supported.
                 */
                supportsNavigation: number;

                /**
                 * Used to indicate that using the phone number is appropriate.
                 */
                supportsPhoneCall: number;

                /**
                 * The tempo of the music contained in the audio file in Beats Per Minute.
                 */
                tempo: number;

                /**
                 * Theme of the the item.
                 */
                theme: string;

                /**
                 * The location (e.g., street name) for the item according to guidelines established by the provider.
                 */
                thoroughfare: string;

                /**
                 * Image data for thumbnail for this item.
                 */
                thumbnailData: string | Titanium.Blob;

                /**
                 * File URL pointing to a thumbnail image for this item.
                 */
                thumbnailURL: string;

                /**
                 * The time signature of the musical composition contained in the audio/MIDI file.
                 */
                timeSignature: string;

                /**
                 * The title of the particular item.
                 */
                title: string;

                /**
                 * The total bit rate (audio and video combined) of the media.
                 */
                totalBitRate: number;

                /**
                 * URL of the item.
                 */
                url: string;

                /**
                 * A version specifier for this item.
                 */
                version: string;

                /**
                 * The video bit rate.
                 */
                videoBitRate: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.addedDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.addedDate> instead.
                 */
                getAddedDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.album> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.album> instead.
                 */
                getAlbum(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.alternateNames> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.alternateNames> instead.
                 */
                getAlternateNames(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.artist> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.artist> instead.
                 */
                getArtist(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audiences> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audiences> instead.
                 */
                getAudiences(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioBitRate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audioBitRate> instead.
                 */
                getAudioBitRate(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioChannelCount> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audioChannelCount> instead.
                 */
                getAudioChannelCount(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioEncodingApplication> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audioEncodingApplication> instead.
                 */
                getAudioEncodingApplication(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioSampleRate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audioSampleRate> instead.
                 */
                getAudioSampleRate(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioTrackNumber> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.audioTrackNumber> instead.
                 */
                getAudioTrackNumber(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.codecs> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.codecs> instead.
                 */
                getCodecs(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.comment> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.comment> instead.
                 */
                getComment(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.composer> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.composer> instead.
                 */
                getComposer(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contactKeywords> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contactKeywords> instead.
                 */
                getContactKeywords(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerDisplayName> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.containerDisplayName> instead.
                 */
                getContainerDisplayName(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerIdentifier> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.containerIdentifier> instead.
                 */
                getContainerIdentifier(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerOrder> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.containerOrder> instead.
                 */
                getContainerOrder(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerTitle> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.containerTitle> instead.
                 */
                getContainerTitle(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentCreationDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentCreationDate> instead.
                 */
                getContentCreationDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentDescription> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentDescription> instead.
                 */
                getContentDescription(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentModificationDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentModificationDate> instead.
                 */
                getContentModificationDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentRating> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentRating> instead.
                 */
                getContentRating(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentSources> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentSources> instead.
                 */
                getContentSources(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentType> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentType> instead.
                 */
                getContentType(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentTypeTree> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentTypeTree> instead.
                 */
                getContentTypeTree(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentURL> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contentURL> instead.
                 */
                getContentURL(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contributors> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.contributors> instead.
                 */
                getContributors(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.copyright> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.copyright> instead.
                 */
                getCopyright(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.coverage> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.coverage> instead.
                 */
                getCoverage(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.creator> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.creator> instead.
                 */
                getCreator(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.deliveryType> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.deliveryType> instead.
                 */
                getDeliveryType(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.director> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.director> instead.
                 */
                getDirector(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.displayName> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.displayName> instead.
                 */
                getDisplayName(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.downloadedDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.downloadedDate> instead.
                 */
                getDownloadedDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.duration> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.duration> instead.
                 */
                getDuration(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.editors> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.editors> instead.
                 */
                getEditors(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.encodingApplications> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.encodingApplications> instead.
                 */
                getEncodingApplications(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fileSize> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.fileSize> instead.
                 */
                getFileSize(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fontNames> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.fontNames> instead.
                 */
                getFontNames(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fullyFormattedAddress> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.fullyFormattedAddress> instead.
                 */
                getFullyFormattedAddress(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.generalMIDISequence> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.generalMIDISequence> instead.
                 */
                getGeneralMIDISequence(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.genre> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.genre> instead.
                 */
                getGenre(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.identifier> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.identifier> instead.
                 */
                getIdentifier(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.information> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.information> instead.
                 */
                getInformation(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.keySignature> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.keySignature> instead.
                 */
                getKeySignature(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.keywords> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.keywords> instead.
                 */
                getKeywords(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.kind> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.kind> instead.
                 */
                getKind(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.languages> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.languages> instead.
                 */
                getLanguages(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.lastUsedDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.lastUsedDate> instead.
                 */
                getLastUsedDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.local> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.local> instead.
                 */
                getLocal(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.lyricist> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.lyricist> instead.
                 */
                getLyricist(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.mediaTypes> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.mediaTypes> instead.
                 */
                getMediaTypes(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.metadataModificationDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.metadataModificationDate> instead.
                 */
                getMetadataModificationDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalGenre> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.musicalGenre> instead.
                 */
                getMusicalGenre(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentCategory> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentCategory> instead.
                 */
                getMusicalInstrumentCategory(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentName> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentName> instead.
                 */
                getMusicalInstrumentName(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.organizations> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.organizations> instead.
                 */
                getOrganizations(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.originalFormat> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.originalFormat> instead.
                 */
                getOriginalFormat(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.originalSource> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.originalSource> instead.
                 */
                getOriginalSource(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageCount> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.pageCount> instead.
                 */
                getPageCount(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageHeight> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.pageHeight> instead.
                 */
                getPageHeight(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageWidth> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.pageWidth> instead.
                 */
                getPageWidth(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.participants> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.participants> instead.
                 */
                getParticipants(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.path> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.path> instead.
                 */
                getPath(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.performers> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.performers> instead.
                 */
                getPerformers(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.playCount> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.playCount> instead.
                 */
                getPlayCount(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.postalCode> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.postalCode> instead.
                 */
                getPostalCode(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.producer> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.producer> instead.
                 */
                getProducer(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.projects> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.projects> instead.
                 */
                getProjects(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.publishers> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.publishers> instead.
                 */
                getPublishers(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.rating> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.rating> instead.
                 */
                getRating(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.ratingDescription> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.ratingDescription> instead.
                 */
                getRatingDescription(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.recordingDate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.recordingDate> instead.
                 */
                getRecordingDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.relatedUniqueIdentifier> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.relatedUniqueIdentifier> instead.
                 */
                getRelatedUniqueIdentifier(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.rights> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.rights> instead.
                 */
                getRights(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.role> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.role> instead.
                 */
                getRole(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.securityMethod> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.securityMethod> instead.
                 */
                getSecurityMethod(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.streamable> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.streamable> instead.
                 */
                getStreamable(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.subThoroughfare> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.subThoroughfare> instead.
                 */
                getSubThoroughfare(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.subject> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.subject> instead.
                 */
                getSubject(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.supportsNavigation> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.supportsNavigation> instead.
                 */
                getSupportsNavigation(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.supportsPhoneCall> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.supportsPhoneCall> instead.
                 */
                getSupportsPhoneCall(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.tempo> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.tempo> instead.
                 */
                getTempo(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.theme> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.theme> instead.
                 */
                getTheme(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thoroughfare> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.thoroughfare> instead.
                 */
                getThoroughfare(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailData> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailData> instead.
                 */
                getThumbnailData(): string | Titanium.Blob;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailURL> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailURL> instead.
                 */
                getThumbnailURL(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.timeSignature> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.timeSignature> instead.
                 */
                getTimeSignature(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.title> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.title> instead.
                 */
                getTitle(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.totalBitRate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.totalBitRate> instead.
                 */
                getTotalBitRate(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.url> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.url> instead.
                 */
                getUrl(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.version> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.version> instead.
                 */
                getVersion(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.videoBitRate> property.
                 * @deprecated Access <Titanium.App.iOS.SearchableItemAttributeSet.videoBitRate> instead.
                 */
                getVideoBitRate(): number;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.addedDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.addedDate> instead.
                 */
                setAddedDate(addedDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.album> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.album> instead.
                 */
                setAlbum(album: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.alternateNames> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.alternateNames> instead.
                 */
                setAlternateNames(alternateNames: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.artist> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.artist> instead.
                 */
                setArtist(artist: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audiences> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audiences> instead.
                 */
                setAudiences(audiences: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioBitRate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audioBitRate> instead.
                 */
                setAudioBitRate(audioBitRate: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioChannelCount> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audioChannelCount> instead.
                 */
                setAudioChannelCount(audioChannelCount: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioEncodingApplication> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audioEncodingApplication> instead.
                 */
                setAudioEncodingApplication(audioEncodingApplication: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioSampleRate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audioSampleRate> instead.
                 */
                setAudioSampleRate(audioSampleRate: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.audioTrackNumber> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.audioTrackNumber> instead.
                 */
                setAudioTrackNumber(audioTrackNumber: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.codecs> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.codecs> instead.
                 */
                setCodecs(codecs: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.comment> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.comment> instead.
                 */
                setComment(comment: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.composer> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.composer> instead.
                 */
                setComposer(composer: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contactKeywords> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contactKeywords> instead.
                 */
                setContactKeywords(contactKeywords: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerDisplayName> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.containerDisplayName> instead.
                 */
                setContainerDisplayName(containerDisplayName: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerIdentifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.containerIdentifier> instead.
                 */
                setContainerIdentifier(containerIdentifier: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerOrder> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.containerOrder> instead.
                 */
                setContainerOrder(containerOrder: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.containerTitle> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.containerTitle> instead.
                 */
                setContainerTitle(containerTitle: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentCreationDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentCreationDate> instead.
                 */
                setContentCreationDate(contentCreationDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentDescription> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentDescription> instead.
                 */
                setContentDescription(contentDescription: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentModificationDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentModificationDate> instead.
                 */
                setContentModificationDate(contentModificationDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentRating> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentRating> instead.
                 */
                setContentRating(contentRating: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentSources> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentSources> instead.
                 */
                setContentSources(contentSources: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentType> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentType> instead.
                 */
                setContentType(contentType: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentTypeTree> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentTypeTree> instead.
                 */
                setContentTypeTree(contentTypeTree: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contentURL> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contentURL> instead.
                 */
                setContentURL(contentURL: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.contributors> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.contributors> instead.
                 */
                setContributors(contributors: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.copyright> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.copyright> instead.
                 */
                setCopyright(copyright: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.coverage> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.coverage> instead.
                 */
                setCoverage(coverage: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.creator> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.creator> instead.
                 */
                setCreator(creator: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.deliveryType> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.deliveryType> instead.
                 */
                setDeliveryType(deliveryType: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.director> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.director> instead.
                 */
                setDirector(director: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.displayName> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.displayName> instead.
                 */
                setDisplayName(displayName: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.downloadedDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.downloadedDate> instead.
                 */
                setDownloadedDate(downloadedDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.duration> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.duration> instead.
                 */
                setDuration(duration: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.editors> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.editors> instead.
                 */
                setEditors(editors: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.encodingApplications> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.encodingApplications> instead.
                 */
                setEncodingApplications(encodingApplications: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fileSize> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.fileSize> instead.
                 */
                setFileSize(fileSize: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fontNames> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.fontNames> instead.
                 */
                setFontNames(fontNames: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.fullyFormattedAddress> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.fullyFormattedAddress> instead.
                 */
                setFullyFormattedAddress(fullyFormattedAddress: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.generalMIDISequence> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.generalMIDISequence> instead.
                 */
                setGeneralMIDISequence(generalMIDISequence: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.genre> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.genre> instead.
                 */
                setGenre(genre: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.identifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.identifier> instead.
                 */
                setIdentifier(identifier: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.information> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.information> instead.
                 */
                setInformation(information: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.keySignature> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.keySignature> instead.
                 */
                setKeySignature(keySignature: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.keywords> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.keywords> instead.
                 */
                setKeywords(keywords: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.kind> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.kind> instead.
                 */
                setKind(kind: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.languages> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.languages> instead.
                 */
                setLanguages(languages: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.lastUsedDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.lastUsedDate> instead.
                 */
                setLastUsedDate(lastUsedDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.local> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.local> instead.
                 */
                setLocal(local: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.lyricist> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.lyricist> instead.
                 */
                setLyricist(lyricist: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.mediaTypes> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.mediaTypes> instead.
                 */
                setMediaTypes(mediaTypes: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.metadataModificationDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.metadataModificationDate> instead.
                 */
                setMetadataModificationDate(metadataModificationDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalGenre> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.musicalGenre> instead.
                 */
                setMusicalGenre(musicalGenre: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentCategory> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentCategory> instead.
                 */
                setMusicalInstrumentCategory(musicalInstrumentCategory: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentName> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.musicalInstrumentName> instead.
                 */
                setMusicalInstrumentName(musicalInstrumentName: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.organizations> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.organizations> instead.
                 */
                setOrganizations(organizations: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.originalFormat> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.originalFormat> instead.
                 */
                setOriginalFormat(originalFormat: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.originalSource> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.originalSource> instead.
                 */
                setOriginalSource(originalSource: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageCount> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.pageCount> instead.
                 */
                setPageCount(pageCount: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageHeight> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.pageHeight> instead.
                 */
                setPageHeight(pageHeight: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.pageWidth> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.pageWidth> instead.
                 */
                setPageWidth(pageWidth: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.participants> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.participants> instead.
                 */
                setParticipants(participants: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.path> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.path> instead.
                 */
                setPath(path: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.performers> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.performers> instead.
                 */
                setPerformers(performers: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.playCount> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.playCount> instead.
                 */
                setPlayCount(playCount: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.postalCode> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.postalCode> instead.
                 */
                setPostalCode(postalCode: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.producer> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.producer> instead.
                 */
                setProducer(producer: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.projects> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.projects> instead.
                 */
                setProjects(projects: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.publishers> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.publishers> instead.
                 */
                setPublishers(publishers: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.rating> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.rating> instead.
                 */
                setRating(rating: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.ratingDescription> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.ratingDescription> instead.
                 */
                setRatingDescription(ratingDescription: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.recordingDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.recordingDate> instead.
                 */
                setRecordingDate(recordingDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.relatedUniqueIdentifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.relatedUniqueIdentifier> instead.
                 */
                setRelatedUniqueIdentifier(relatedUniqueIdentifier: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.rights> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.rights> instead.
                 */
                setRights(rights: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.role> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.role> instead.
                 */
                setRole(role: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.securityMethod> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.securityMethod> instead.
                 */
                setSecurityMethod(securityMethod: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.streamable> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.streamable> instead.
                 */
                setStreamable(streamable: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.subThoroughfare> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.subThoroughfare> instead.
                 */
                setSubThoroughfare(subThoroughfare: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.subject> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.subject> instead.
                 */
                setSubject(subject: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.supportsNavigation> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.supportsNavigation> instead.
                 */
                setSupportsNavigation(supportsNavigation: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.supportsPhoneCall> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.supportsPhoneCall> instead.
                 */
                setSupportsPhoneCall(supportsPhoneCall: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.tempo> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.tempo> instead.
                 */
                setTempo(tempo: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.theme> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.theme> instead.
                 */
                setTheme(theme: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thoroughfare> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.thoroughfare> instead.
                 */
                setThoroughfare(thoroughfare: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailData> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailData> instead.
                 */
                setThumbnailData(thumbnailData: string | Titanium.Blob): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailURL> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.thumbnailURL> instead.
                 */
                setThumbnailURL(thumbnailURL: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.timeSignature> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.timeSignature> instead.
                 */
                setTimeSignature(timeSignature: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.title> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.title> instead.
                 */
                setTitle(title: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.totalBitRate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.totalBitRate> instead.
                 */
                setTotalBitRate(totalBitRate: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.url> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.url> instead.
                 */
                setUrl(url: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.version> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.version> instead.
                 */
                setVersion(version: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.SearchableItemAttributeSet.videoBitRate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.SearchableItemAttributeSet.videoBitRate> instead.
                 */
                setVideoBitRate(videoBitRate: number): void;

            }
            /**
             * Base event for class Titanium.App.iOS.UserActivity
             */
            interface UserActivityBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.App.iOS.UserActivity;

            }
            /**
             * Fired if the activity context needs to be saved before being continued on another device.
             * To fire the event, set the UserActiviy object's `needsSave ` property to `true`.
             * The receiver should update the activity with current activity state.
             * After the event is fired, iOS will reset the `needsSave` property to false.
             */
            interface UserActivity_useractivitywillsave_Event extends UserActivityBaseEvent {
                /**
                 * The activityType of the User Activity triggering the event.
                 */
                activityType: string;

                /**
                 * The title of the User Activity if defined.
                 */
                title: string;

                /**
                 * Dictionary object containing the userInfo data of the User Activity.
                 */
                userInfo: any;

                /**
                 * The webpageURL of the User Activity if defined.
                 */
                webpageURL: string;

            }
            /**
             * Fired when the user activity was continued on another device.
             */
            interface UserActivity_useractivitywascontinued_Event extends UserActivityBaseEvent {
                /**
                 * The activityType of the User Activity triggering the event.
                 */
                activityType: string;

                /**
                 * The title of the User Activity if defined.
                 */
                title: string;

                /**
                 * Dictionary object containing the userInfo data of the User Activity.
                 */
                userInfo: any;

                /**
                 * The webpageURL of the User Activity if defined.
                 */
                webpageURL: string;

            }
            /**
             * Fired when the user activity get deleted using the <Titanium.App.iOS.UserActivity.deleteAllSavedUserActivities> or
             * <Titanium.App.iOS.UserActivity.deleteSavedUserActivitiesForPersistentIdentifiers> methods.
             */
            interface UserActivity_useractivitydeleted_Event extends UserActivityBaseEvent {
            }
            interface UserActivityEventMap extends ProxyEventMap {
                useractivitydeleted: UserActivity_useractivitydeleted_Event;

                useractivitywascontinued: UserActivity_useractivitywascontinued_Event;

                useractivitywillsave: UserActivity_useractivitywillsave_Event;

            }
            /**
             * The UserActivity module is used to enable device Handoff and to create User Activities.
             */
            class UserActivity extends Titanium.Proxy {
                /**
                 * Name of the activity type.
                 */
                activityType: string;

                /**
                 * Set to true if this user activity should be eligible to be handed off to another device
                 */
                eligibleForHandoff: boolean;

                /**
                 * A Boolean value that determines whether Siri can suggest the user activity as a shortcut to the user.
                 */
                eligibleForPrediction: boolean;

                /**
                 * Set to `true` if the user activity can be publicly accessed by all iOS users.
                 */
                eligibleForPublicIndexing: boolean;

                /**
                 * Set to true if the user activity should be added to the on-device index.
                 */
                eligibleForSearch: boolean;

                /**
                 * Absolute date after which the activity is no longer eligible to be indexed or handed off.
                 */
                expirationDate: string;

                /**
                 * An array of string keywords representing words or phrases that might help the user to find the activity in the application history.
                 */
                keywords: string[];

                /**
                 * Set to true everytime you have updated the user activity and need the changes to be saved before handing it off to another device.
                 */
                needsSave: boolean;

                /**
                 * A value used to identify the user activity.
                 */
                persistentIdentifier: string;

                /**
                 * An array of String keys from the userInfo property which represent the minimal information about the user activity that should be stored for later restoration.
                 */
                requiredUserInfoKeys: string[];

                /**
                 * Determines if user activities are supported (`true`) or not (`false`) by the device.
                 * @deprecated Use [Titanium.App.iOS.UserActivity.isSupported](Titanium.App.iOS.UserActivity.isSupported) instead.
                 */
                supported: boolean;

                /**
                 * An optional, user-visible title for this activity such as a document name or web page title.
                 */
                title: string;

                /**
                 * The userInfo dictionary contains application-specific state needed to continue an activity on another device.
                 */
                userInfo: any;

                /**
                 * When no suitable application is installed on a resuming device and the `webpageURL` property is set,
                 * the user activity will instead be continued in a web browser by loading the specified URL.
                 */
                webpageURL: string;

                /**
                 * Adds a Titanium.App.iOS.SearchableItemAttributeSet to the user activity.
                 */
                addContentAttributeSet(contentAttributeSet: Titanium.App.iOS.SearchableItemAttributeSet): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof UserActivityEventMap>(name: K, callback: (this: Titanium.App.iOS.UserActivity, event: UserActivityEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Marks the activity as currently in use by the user.
                 */
                becomeCurrent(): void;

                /**
                 * Deletes all user activities created by your app.
                 */
                deleteAllSavedUserActivities(): void;

                /**
                 * Deletes user activities created by your app that have the specified persistent identifiers.
                 */
                deleteSavedUserActivitiesForPersistentIdentifiers(persistentIdentifiers: ReadonlyArray<string>): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof UserActivityEventMap>(name: K, event?: UserActivityEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.activityType> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.activityType> instead.
                 */
                getActivityType(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.eligibleForHandoff> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.eligibleForHandoff> instead.
                 */
                getEligibleForHandoff(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.eligibleForPrediction> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.eligibleForPrediction> instead.
                 */
                getEligibleForPrediction(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.eligibleForPublicIndexing> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.eligibleForPublicIndexing> instead.
                 */
                getEligibleForPublicIndexing(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.eligibleForSearch> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.eligibleForSearch> instead.
                 */
                getEligibleForSearch(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.expirationDate> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.expirationDate> instead.
                 */
                getExpirationDate(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.keywords> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.keywords> instead.
                 */
                getKeywords(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.needsSave> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.needsSave> instead.
                 */
                getNeedsSave(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.persistentIdentifier> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.persistentIdentifier> instead.
                 */
                getPersistentIdentifier(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.requiredUserInfoKeys> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.requiredUserInfoKeys> instead.
                 */
                getRequiredUserInfoKeys(): string[];

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.supported> property.
                 * @deprecated Use [Titanium.App.iOS.UserActivity.isSupported](Titanium.App.iOS.UserActivity.isSupported) instead.
                 */
                getSupported(): boolean;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.title> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.title> instead.
                 */
                getTitle(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.userInfo> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.userInfo> instead.
                 */
                getUserInfo(): any;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserActivity.webpageURL> property.
                 * @deprecated Access <Titanium.App.iOS.UserActivity.webpageURL> instead.
                 */
                getWebpageURL(): string;

                /**
                 * Invalidates an activity when it is no longer eligible for continuation.
                 */
                invalidate(): void;

                /**
                 * Determines if user activities are supported (`true`) or not (`false`) by the device.
                 */
                isSupported(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof UserActivityEventMap>(name: K, callback: (this: Titanium.App.iOS.UserActivity, event: UserActivityEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Marks the activity as currently **not** in use and ineligible to be continued.
                 */
                resignCurrent(): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.activityType> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.activityType> instead.
                 */
                setActivityType(activityType: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.eligibleForHandoff> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.eligibleForHandoff> instead.
                 */
                setEligibleForHandoff(eligibleForHandoff: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.eligibleForPrediction> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.eligibleForPrediction> instead.
                 */
                setEligibleForPrediction(eligibleForPrediction: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.eligibleForPublicIndexing> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.eligibleForPublicIndexing> instead.
                 */
                setEligibleForPublicIndexing(eligibleForPublicIndexing: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.eligibleForSearch> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.eligibleForSearch> instead.
                 */
                setEligibleForSearch(eligibleForSearch: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.expirationDate> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.expirationDate> instead.
                 */
                setExpirationDate(expirationDate: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.keywords> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.keywords> instead.
                 */
                setKeywords(keywords: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.needsSave> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.needsSave> instead.
                 */
                setNeedsSave(needsSave: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.persistentIdentifier> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.persistentIdentifier> instead.
                 */
                setPersistentIdentifier(persistentIdentifier: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.requiredUserInfoKeys> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.requiredUserInfoKeys> instead.
                 */
                setRequiredUserInfoKeys(requiredUserInfoKeys: ReadonlyArray<string>): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.supported> property.
                 * @deprecated Use [Titanium.App.iOS.UserActivity.isSupported](Titanium.App.iOS.UserActivity.isSupported) instead.
                 */
                setSupported(supported: boolean): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.title> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.title> instead.
                 */
                setTitle(title: string): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.userInfo> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.userInfo> instead.
                 */
                setUserInfo(userInfo: any): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserActivity.webpageURL> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserActivity.webpageURL> instead.
                 */
                setWebpageURL(webpageURL: string): void;

            }
            /**
             * Base event for class Titanium.App.iOS.UserDefaults
             */
            interface UserDefaultsBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.App.iOS.UserDefaults;

            }
            /**
             * Fired when a property is changed.
             */
            interface UserDefaults_change_Event extends UserDefaultsBaseEvent {
            }
            interface UserDefaultsEventMap extends ProxyEventMap {
                change: UserDefaults_change_Event;

            }
            /**
             * The UserDefaults module is used for storing application-related data in property/value pairs
             * that persist beyond application sessions and device power cycles. UserDefaults allows the suiteName
             * of the UserDefaults to be specified at creation time.
             */
            interface UserDefaults extends Titanium.App.Properties {
                /**
                 * Sets the name of the suite to be used to access UserDefaults.
                 */
                suiteName: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof UserDefaultsEventMap>(name: K, callback: (this: Titanium.App.iOS.UserDefaults, event: UserDefaultsEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof UserDefaultsEventMap>(name: K, event?: UserDefaultsEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserDefaults.suiteName> property.
                 * @deprecated Access <Titanium.App.iOS.UserDefaults.suiteName> instead.
                 */
                getSuiteName(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof UserDefaultsEventMap>(name: K, callback: (this: Titanium.App.iOS.UserDefaults, event: UserDefaultsEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserDefaults.suiteName> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserDefaults.suiteName> instead.
                 */
                setSuiteName(suiteName: string): void;

            }
            /**
             * An action the user selects in response to an interactive notification.
             */
            class UserNotificationAction extends Titanium.Proxy {
                /**
                 * Selects how to activate the application.
                 */
                activationMode: number;

                /**
                 * Set to true if the action requires the device to be unlocked. On the Apple Watch actions never require authentication.
                 */
                authenticationRequired: boolean;

                /**
                 * Custom behavior the user notification supports.
                 */
                behavior: number;

                /**
                 * Indicates if the proxy will bubble an event to its parent.
                 */
                bubbleParent: never;

                /**
                 * Set to true if the action causes destructive behavior to the user's data or the application.
                 */
                destructive: boolean;

                /**
                 * Identifier for this action. Used to identify the action the user pressed.
                 */
                identifier: string;

                /**
                 * Title of the button displayed in the notification.
                 */
                title: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener: never;

                /**
                 * Applies the properties to the proxy.
                 */
                applyProperties: never;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent: never;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationAction.activationMode> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationAction.activationMode> instead.
                 */
                getActivationMode(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationAction.behavior> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationAction.behavior> instead.
                 */
                getBehavior(): number;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationAction.bubbleParent> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationAction.bubbleParent> instead.
                 */
                getBubbleParent: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener: never;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserNotificationAction.activationMode> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserNotificationAction.activationMode> instead.
                 */
                setActivationMode(activationMode: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserNotificationAction.behavior> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserNotificationAction.behavior> instead.
                 */
                setBehavior(behavior: number): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserNotificationAction.bubbleParent> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserNotificationAction.bubbleParent> instead.
                 */
                setBubbleParent: never;

            }
            /**
             * A set of notification actions to associate with a notification.
             */
            class UserNotificationCategory extends Titanium.Proxy {
                /**
                 * Array of notification actions to associate with the group.
                 */
                actionsForDefaultContext: Titanium.App.iOS.UserNotificationAction[];

                /**
                 * Array of notification actions to display for non-dialog-style notification.
                 */
                actionsForMinimalContext: Titanium.App.iOS.UserNotificationAction[];

                /**
                 * Indicates if the proxy will bubble an event to its parent.
                 */
                bubbleParent: never;

                /**
                 * A format string for the summary description used when the system groups the category's notifications.
                 */
                categorySummaryFormat: string;

                /**
                 * The placeholder text to display when notification previews are disabled for the app.
                 */
                hiddenPreviewsBodyPlaceholder: string;

                /**
                 * Identifier for this category.
                 */
                identifier: string;

                /**
                 * The intents related to notifications of this category.
                 */
                intentIdentifiers: string[];

                /**
                 * Options for how to handle notifications of this type.
                 */
                options: number[];

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener: never;

                /**
                 * Applies the properties to the proxy.
                 */
                applyProperties: never;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent: never;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationCategory.bubbleParent> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationCategory.bubbleParent> instead.
                 */
                getBubbleParent: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener: never;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserNotificationCategory.bubbleParent> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserNotificationCategory.bubbleParent> instead.
                 */
                setBubbleParent: never;

            }
            /**
             * The top-level App iOS Notification Center module. It is used to control scheduled notifications
             * and receive details about the system-wide notification settings.
             */
            class UserNotificationCenter extends Titanium.Module {
                /**
                 * The name of the API that this proxy corresponds to.
                 */
                static readonly apiName: string;

                /**
                 * Indicates if the proxy will bubble an event to its parent.
                 */
                static bubbleParent: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                static addEventListener: never;

                /**
                 * Applies the properties to the proxy.
                 */
                static applyProperties: never;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                static fireEvent: never;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationCenter.apiName> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationCenter.apiName> instead.
                 */
                static getApiName(): string;

                /**
                 * Gets the value of the <Titanium.App.iOS.UserNotificationCenter.bubbleParent> property.
                 * @deprecated Access <Titanium.App.iOS.UserNotificationCenter.bubbleParent> instead.
                 */
                static getBubbleParent: never;

                /**
                 * Fetches the delivered notifications asynchronously.
                 */
                static getDeliveredNotifications(callback: (param0: UserNotificationCallbackResponse) => void): void;

                /**
                 * Fetches the pending notifications asynchronously.
                 */
                static getPendingNotifications(callback: (param0: UserNotificationCallbackResponse) => void): void;

                /**
                 * Removes the specified delivered notifications from the notification-center.
                 * If no notifications are specified, all delivered notifications will be removed.
                 */
                static removeDeliveredNotifications(notifications: ReadonlyArray<UserNotificationDictionary>): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                static removeEventListener: never;

                /**
                 * Removes the specified pending notifications to prevent them from being triggered.
                 * If no notifications are specified, all pending notifications will be removed.
                 */
                static removePendingNotifications(notifications: ReadonlyArray<UserNotificationDictionary>): void;

                /**
                 * Notification types and user notification categories the application is registered to use.
                 */
                static requestUserNotificationSettings(callback: (param0: GetUserNotificationSettings) => void): void;

                /**
                 * Sets the value of the <Titanium.App.iOS.UserNotificationCenter.bubbleParent> property.
                 * @deprecated Set the value using <Titanium.App.iOS.UserNotificationCenter.bubbleParent> instead.
                 */
                static setBubbleParent: never;

            }
        }
        /**
         * Base event for class Titanium.App.Android
         */
        interface AndroidBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.App.Android;

        }
        /**
         * Fired when a <Titanium.UI.ShortcutItem> is clicked.
         */
        interface Android_shortcutitemclick_Event extends AndroidBaseEvent {
            /**
             * Identifier of the clicked shortcut item.
             */
            id: string;

        }
        interface AndroidEventMap extends ProxyEventMap {
            shortcutitemclick: Android_shortcutitemclick_Event;

        }
        /**
         * A module used to access Android application resources.
         */
        class Android extends Titanium.Module {
            /**
             * The `R` namespace for application resources.
             */
            static readonly R: Titanium.Android.R;

            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * The version number of the application.
             */
            static readonly appVersionCode: number;

            /**
             * The version name of the application.
             */
            static readonly appVersionName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * Return the intent that was used to launch the application.
             */
            static readonly launchIntent: Titanium.Android.Intent;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener<K extends keyof AndroidEventMap>(name: K, callback: (this: Titanium.App.Android, event: AndroidEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent<K extends keyof AndroidEventMap>(name: K, event?: AndroidEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.App.Android.apiName> property.
             * @deprecated Access <Titanium.App.Android.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.App.Android.appVersionCode> property.
             * @deprecated Access <Titanium.App.Android.appVersionCode> instead.
             */
            static getAppVersionCode(): number;

            /**
             * Gets the value of the <Titanium.App.Android.appVersionName> property.
             * @deprecated Access <Titanium.App.Android.appVersionName> instead.
             */
            static getAppVersionName(): string;

            /**
             * Gets the value of the <Titanium.App.Android.bubbleParent> property.
             * @deprecated Access <Titanium.App.Android.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.App.Android.launchIntent> property.
             * @deprecated Access <Titanium.App.Android.launchIntent> instead.
             */
            static getLaunchIntent(): Titanium.Android.Intent;

            /**
             * Gets the value of the <Titanium.App.Android.lifecycleContainer> property.
             * @deprecated Access <Titanium.App.Android.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener<K extends keyof AndroidEventMap>(name: K, callback: (this: Titanium.App.Android, event: AndroidEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.App.Android.bubbleParent> property.
             * @deprecated Set the value using <Titanium.App.Android.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.App.Android.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.App.Android.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * Base event for class Titanium.App.Properties
         */
        interface PropertiesBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.App.Properties;

        }
        /**
         * Fired when a property is changed.
         */
        interface Properties_change_Event extends PropertiesBaseEvent {
        }
        interface PropertiesEventMap extends ProxyEventMap {
            change: Properties_change_Event;

        }
        /**
         * The App Properties module is used for storing application-related data in property/value pairs
         * that persist beyond application sessions and device power cycles.
         */
        class Properties extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener<K extends keyof PropertiesEventMap>(name: K, callback: (this: Titanium.App.Properties, event: PropertiesEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent<K extends keyof PropertiesEventMap>(name: K, event?: PropertiesEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.App.Properties.apiName> property.
             * @deprecated Access <Titanium.App.Properties.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Returns the value of a property as a boolean data type.
             */
            static getBool(property: string, defaultValue?: boolean): boolean;

            /**
             * Gets the value of the <Titanium.App.Properties.bubbleParent> property.
             * @deprecated Access <Titanium.App.Properties.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Returns the value of a property as a double (double-precision, floating point) data type.
             */
            static getDouble(property: string, defaultValue?: number): number;

            /**
             * Returns the value of a property as an integer data type.
             */
            static getInt(property: string, defaultValue?: number): number;

            /**
             * Gets the value of the <Titanium.App.Properties.lifecycleContainer> property.
             * @deprecated Access <Titanium.App.Properties.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Returns the value of a property as an array data type.
             */
            static getList(property: string, defaultValue?: ReadonlyArray<any>): any[];

            /**
             * Returns the value of a property as an object.
             */
            static getObject(property: string, defaultValue?: any): any;

            /**
             * Returns the value of a property as a string data type.
             */
            static getString(property: string, defaultValue?: string): string;

            /**
             * Indicates whether a property exists.
             */
            static hasProperty(property: string): boolean;

            /**
             * Returns an array of property names.
             */
            static listProperties(): any[];

            /**
             * Removes all properties that have been set by the user on runtime, or does nothing otherwise.
             */
            static removeAllProperties(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener<K extends keyof PropertiesEventMap>(name: K, callback: (this: Titanium.App.Properties, event: PropertiesEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a property if it exists, or does nothing otherwise.
             */
            static removeProperty(property: string): void;

            /**
             * Sets the value of a property as a boolean data type. The property will be created if it
             * does not exist.
             */
            static setBool(property: string, value: boolean): void;

            /**
             * Sets the value of the <Titanium.App.Properties.bubbleParent> property.
             * @deprecated Set the value using <Titanium.App.Properties.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of a property as a double (double-precision, floating point) data type. The
             * property will be created if it does not exist.
             */
            static setDouble(property: string, value: number): void;

            /**
             * Sets the value of a property as an integer data type. The property will be created if it
             * does not exist.
             */
            static setInt(property: string, value: number): void;

            /**
             * Sets the value of the <Titanium.App.Properties.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.App.Properties.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

            /**
             * Sets the value of a property as an array data type. The property will be created if it
             * does not exist.
             */
            static setList(property: string, value: ReadonlyArray<any>): void;

            /**
             * Sets the value of a property as an object data type. The property will be created if it
             * does not exist.
             */
            static setObject(property: string, value: any): void;

            /**
             * Sets the value of a property as a string data type. The property will be created if it
             * does not exist.
             */
            static setString(property: string, value: string): void;

        }
        /**
         * Base event for class Titanium.App.iOS
         */
        interface iOSBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.App.iOS;

        }
        /**
         * Fired when a local notification is received by the application.
         */
        interface iOS_notification_Event extends iOSBaseEvent {
            /**
             * Alert button text ('View', by default) or slider text ('slide to unlock...', by default).
             */
            alertAction: string;

            /**
             * Alert message.
             */
            alertBody: string;

            /**
             * Image displayed instead of `Default.png` when launching the application.
             */
            alertLaunchImage: string;

            /**
             * Application badge value.
             */
            badge: number;

            /**
             * The identifier of the app-defined [category object](Titanium.App.iOS.UserNotificationCategory). Available in Titanium SDK 7.5.0+ and iOS 10+.
             */
            category: string;

            /**
             * Date and time when the notification was configured to fire.
             */
            date: Date;

            /**
             * Boolean indicating if notification was received while app was in background. Available in Titanium SDK 6.2.0.
             * On iOS 10+ this is no longer available since this event will only fire if the app is in foreground.
             */
            inBackground: boolean;

            /**
             * Name of the sound file configured to play when the notification was fired.
             */
            sound: string;

            /**
             * The unique identifier for the thread or conversation related to this notification request.
             * It will be used to visually group notifications together. Available in Titanium SDK 7.5.0+ and iOS 10+.
             */
            threadIdentifier: string;

            /**
             * Timezone of the date when the notification was configured to fire. Available in Titanium SDK 7.4.0+.
             */
            timezone: string;

            /**
             * Custom data object.
             */
            userInfo: any;

        }
        /**
         * Fired when a user selects an action for an interactive local notification.
         */
        interface iOS_localnotificationaction_Event extends iOSBaseEvent {
            /**
             * Alert button text ('Open', by default) or slider text ('slide to unlock...', by default).
             */
            alertAction: string;

            /**
             * Alert message.
             */
            alertBody: string;

            /**
             * Image displayed instead of `Default.png` when launching the application.
             */
            alertLaunchImage: string;

            /**
             * Application badge value.
             */
            badge: number;

            /**
             * The identifier of the app-defined [category object](Titanium.App.iOS.UserNotificationCategory). Available in Titanium SDK 7.5.0+ and iOS 10+.
             */
            category: string;

            /**
             * Date and time when the notification was configured to fire.
             */
            date: Date;

            /**
             * Identifier of the action that was selected of the interactive notification.
             */
            identifier: string;

            /**
             * Boolean indicating if notification was received while app was in background (since Titanium SDK 6.2.0).
             * On iOS 10+ this is no longer available since the event will only fire when opening the app after interacting
             * with a notification from the iOS notification center (which means the app was in background when the
             * notification was received).
             */
            inBackground: boolean;

            /**
             * Path to the sound file configured to play when the notification was fired.
             */
            sound: string;

            /**
             * The unique identifier for the thread or conversation related to this notification request.
             * It will be used to visually group notifications together. Available in Titanium SDK 7.5.0+ and iOS 10+.
             */
            threadIdentifier: string;

            /**
             * Timezone of the date when the notification was configured to fire.
             */
            timezone: string;

            /**
             * User input if the notification used the `USER_NOTIFICATION_BEHAVIOR_TEXTINPUT` behavior.
             */
            typedText: string;

            /**
             * Custom data object.
             */
            userInfo: any;

        }
        /**
         * Fired when a user selects an action for an interactive remote notification.
         */
        interface iOS_remotenotificationaction_Event extends iOSBaseEvent {
            /**
             * Identifier of the category of the interactive notification.
             */
            category: string;

            /**
             * The payload passed to the Apple Push Notification Service.
             */
            data: any;

            /**
             * Identifier of the action that was selected of the interactive notification.
             */
            identifier: string;

        }
        /**
         * Fired when the application is woken up for a fetch operation. Available only on iOS 7 and later.
         */
        interface iOS_backgroundfetch_Event extends iOSBaseEvent {
            /**
             * Unique string identifier for the `backgroundfetch` event. This identifier should be passed as the argument
             * to the [endBackgroundHandler](Titanium.App.iOS.endBackgroundHandler) method.
             */
            handlerId: string;

        }
        /**
         * Fired when the application is woken up by a silent remote notification. Available only on iOS 7 and later.
         */
        interface iOS_silentpush_Event extends iOSBaseEvent {
            /**
             * Unique string identifier for the `silentpush` event. This identifier should be passed as the argument
             * to the [endBackgroundHandler](Titanium.App.iOS.endBackgroundHandler) method.
             */
            handlerId: string;

        }
        /**
         * Fired when the events related to a [urlSession](Modules.URLSession) are waiting to be processed.
         * Available only on iOS 7 and later.
         */
        interface iOS_backgroundtransfer_Event extends iOSBaseEvent {
            /**
             * Unique string identifier for the `backgroundtransfer` event. This identifier should be passed as the argument
             * to the [endBackgroundHandler](Titanium.App.iOS.endBackgroundHandler) method.
             */
            handlerId: string;

            /**
             * The identifier of the URL session requiring attention. If your app was just launched,
             * you can use this identifier to create a new `urlSession` object that can receive the events.
             */
            sessionId: string;

        }
        /**
         * Fired periodically to inform the app about the download's progress of a [urlSession](Modules.URLSession).
         * Available only on iOS 7 and later.
         */
        interface iOS_downloadprogress_Event extends iOSBaseEvent {
            /**
             * The number of bytes transferred since the last time this event was fired.
             */
            bytesWritten: number;

            /**
             * The `urlSession` session identifier. If it does not exist, this property is not provided.
             * This property is available since Titanium Mobile 5.4.0.GA.
             */
            sessionIdentifier: string;

            /**
             * The `urlSession` download task's identifier.
             */
            taskIdentifier: number;

            /**
             * The expected length of the file, as provided by the Content-Length header. If this
             * header was not provided, the value is zero.
             */
            totalBytesExpectedToWrite: number;

            /**
             * The total number of bytes transferred so far.
             */
            totalBytesWritten: number;

        }
        /**
         * Fired periodically to inform the app about the upload's progress of a [urlSession](Modules.URLSession).
         * Available only on iOS 7 and later.
         */
        interface iOS_uploadprogress_Event extends iOSBaseEvent {
            /**
             * The number of bytes transferred since the last time this event was fired.
             */
            bytesSent: number;

            /**
             * The `urlSession` session identifier. If it does not exist, this property is not provided.
             * This property is available since Titanium Mobile 5.4.0.GA.
             */
            sessionIdentifier: string;

            /**
             * The `urlSession` upload task's identifier.
             */
            taskIdentifier: number;

            /**
             * The expected length of the file, as provided by the Content-Length header. If this
             * header was not provided, the value is zero.
             */
            totalBytesExpectedToSend: number;

            /**
             * The total number of bytes transferred so far.
             */
            totalBytesSent: number;

        }
        /**
         * Fired to indicate that a [urlSession's](Modules.URLSession) download task has finished downloading.
         * Available only on iOS 7 and later.
         */
        interface iOS_downloadcompleted_Event extends iOSBaseEvent {
            /**
             * The downloaded data as a Titanium.Blob object.
             */
            data: Titanium.Blob;

            /**
             * The `urlSession` session identifier. If it does not exist, this property is not provided.
             * This property is available since Titanium Mobile 5.4.0.GA.
             */
            sessionIdentifier: string;

            /**
             * The `urlSession` download task's identifier.
             */
            taskIdentifier: number;

        }
        /**
         * Fired to indicate that a [urlSession](Modules.URLSession) task finished transferring data.
         * Available only on iOS 7 and later.
         */
        interface iOS_sessioncompleted_Event extends iOSBaseEvent {
            /**
             * The error code of the error, if any (potentially system-dependent).
             */
            errorCode: number;

            /**
             * A string containing the localized description of the error.
             * This property does not exhist if errorCode is 0, which means there is no error.
             */
            message: string;

            /**
             * The response text for [task](Modules.URLSession.task) and [uploadTask](Modules.URLSession.uploadTask).
             * This property does not exhist for download task. For download task response,
             * use [downloadcompleted](Titanium.App.iOS.downloadcompleted) event.
             */
            responseText: string;

            /**
             * The `urlSession` session identifier. If it does not exist, this property is not provided.
             * This property is available since Titanium Mobile 5.4.0.GA.
             */
            sessionIdentifier: string;

            /**
             * The response status code for tasks.
             */
            statusCode: number;

            /**
             * Indicates if the operation succeeded. Returns true if download succeeded, false otherwise.
             */
            success: boolean;

            /**
             * The `urlSession` download task's identifier.
             */
            taskIdentifier: number;

        }
        /**
         * Fired to indicate that all messages enqueued for a [urlSession](Modules.URLSession) have been delivered.
         * Available only on iOS 7 and later.
         */
        interface iOS_sessioneventscompleted_Event extends iOSBaseEvent {
            /**
             * The `urlSession` session identifier. If it does not exist, this property is not provided.
             * This property is available since Titanium Mobile 5.4.0.GA.
             */
            sessionIdentifier: string;

        }
        /**
         * Fired when the user notification settings are registered.
         */
        interface iOS_usernotificationsettings_Event extends iOSBaseEvent {
            /**
             * Set of categories of user notification actions the application is registered to use.
             */
            categories: Titanium.App.iOS.UserNotificationCategory[];

            /**
             * Notification types the application is registered to use.
             */
            types: number[];

        }
        /**
         * Fired when openParentApplication:reply is called from a WatchKit extension. Available only on iOS 8.2 and later.
         */
        interface iOS_watchkitextensionrequest_Event extends iOSBaseEvent {
            /**
             * Unique string identifier for the `watchkitextensionrequest` event. This identifier should be passed an argument
             * to the [sendWatchExtensionReply](Titanium.App.iOS.sendWatchExtensionReply) method.
             */
            handlerId: string;

            /**
             * The payload passed to the `openParentApplication:reply` method from the WatchKit extension.
             */
            userInfo: any;

        }
        /**
         * Fired when iOS continueactivity calls `continueUserActivity`.
         */
        interface iOS_continueactivity_Event extends iOSBaseEvent {
            /**
             * Unique string identifier for the handoff user activity. The identifier must be defined in your `tiapp.xml` file.
             */
            activityType: string;

            /**
             * With field will contain the searchable Unique Identifier if the continueactivity is fired from a Core Spotlight searh result.
             */
            searchableItemActivityIdentifier: string;

            /**
             * The optional title provided to the user activity or search item.
             */
            title: string;

            /**
             * The optional userInfo provided to the user activity. The userInfo is a custom dictionary and can contain any information needed
             * to create your handoff or Core Spotlight session.
             */
            userInfo: any;

            /**
             * The optional webpageURL provided to the user activity.
             */
            webpageURL: string;

        }
        /**
         * Fired when a user taps the Application Shortcut.
         */
        interface iOS_shortcutitemclick_Event extends iOSBaseEvent {
            /**
             * The unique identifier for the application shortcut.
             */
            itemtype: string;

            /**
             * The subtitle of the application shortcut.
             */
            subtitle: string;

            /**
             * The title of the application shortcut.
             */
            title: string;

            /**
             * The payload passed by the application shortcut.
             */
            userInfo: any;

        }
        /**
         * Fired when a new URL is handled by the application.
         */
        interface iOS_handleurl_Event extends iOSBaseEvent {
            /**
             * The launch options that are related to opening the URL.
             */
            launchOptions: LaunchOptionsType;

        }
        /**
         * Fired when the trait collection of the device changes, e.g. the user interface style.
         */
        interface iOS_traitcollectionchange_Event extends iOSBaseEvent {
        }
        /**
         * Fired after the user takes a screenshot, e.g. by pressing both the home and lock screen buttons.
         */
        interface iOS_screenshotcaptured_Event extends iOSBaseEvent {
        }
        interface iOSEventMap extends ProxyEventMap {
            backgroundfetch: iOS_backgroundfetch_Event;

            backgroundtransfer: iOS_backgroundtransfer_Event;

            continueactivity: iOS_continueactivity_Event;

            downloadcompleted: iOS_downloadcompleted_Event;

            downloadprogress: iOS_downloadprogress_Event;

            handleurl: iOS_handleurl_Event;

            localnotificationaction: iOS_localnotificationaction_Event;

            notification: iOS_notification_Event;

            remotenotificationaction: iOS_remotenotificationaction_Event;

            screenshotcaptured: iOS_screenshotcaptured_Event;

            sessioncompleted: iOS_sessioncompleted_Event;

            sessioneventscompleted: iOS_sessioneventscompleted_Event;

            shortcutitemclick: iOS_shortcutitemclick_Event;

            silentpush: iOS_silentpush_Event;

            traitcollectionchange: iOS_traitcollectionchange_Event;

            uploadprogress: iOS_uploadprogress_Event;

            usernotificationsettings: iOS_usernotificationsettings_Event;

            watchkitextensionrequest: iOS_watchkitextensionrequest_Event;

        }
        /**
         * The top-level App iOS module, available only to iOS devices, that includes the facilities to
         * create and manage local notifications and background services.
         */
        class iOS extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Returns a URL to open the app's settings.
             */
            static readonly applicationOpenSettingsURL: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * Notification types and user notification categories the application is registered to use.
             * @deprecated Use [Titanium.App.iOS.UserNotificationCenter.requestUserNotificationSettings](Titanium.App.iOS.UserNotificationCenter.requestUserNotificationSettings) instead.
             */
            static readonly currentUserNotificationSettings: UserNotificationSettings;

            /**
             * Provides an Array of the NSUserActivityTypes keys defined within your Titanium project.
             */
            static readonly supportedUserActivityTypes: string[];

            /**
             * The style associated with the user interface.
             * @deprecated Use <Titanium.UI.userInterfaceStyle> instead, which is supported cross-platform.
             */
            static readonly userInterfaceStyle: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener<K extends keyof iOSEventMap>(name: K, callback: (this: Titanium.App.iOS, event: iOSEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Cancels all scheduled local notifications.
             * @deprecated Use [Titanium.App.iOS.UserNotificationCenter.removePendingNotifications](Titanium.App.iOS.UserNotificationCenter.removePendingNotifications) instead.
             */
            static cancelAllLocalNotifications(): void;

            /**
             * Cancels a local notification.
             * @deprecated Use [Titanium.App.iOS.UserNotificationCenter.removePendingNotifications](Titanium.App.iOS.UserNotificationCenter.removePendingNotifications) instead.
             */
            static cancelLocalNotification(id: number | string): void;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.SearchQuery>.
             */
            static createSearchQuery(parameters?: Dictionary<Titanium.App.iOS.SearchQuery>): Titanium.App.iOS.SearchQuery;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.SearchableIndex>.
             */
            static createSearchableIndex(parameters?: Dictionary<Titanium.App.iOS.SearchableIndex>): Titanium.App.iOS.SearchableIndex;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.SearchableItem>.
             */
            static createSearchableItem(parameters?: Dictionary<Titanium.App.iOS.SearchableItem>): Titanium.App.iOS.SearchableItem;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.SearchableItemAttributeSet>.
             */
            static createSearchableItemAttributeSet(parameters?: Dictionary<Titanium.App.iOS.SearchableItemAttributeSet>): Titanium.App.iOS.SearchableItemAttributeSet;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.UserActivity>.
             */
            static createUserActivity(parameters?: Dictionary<Titanium.App.iOS.UserActivity>): Titanium.App.iOS.UserActivity;

            /**
             * Creates and returns an instance of Titanium.App.iOS.UserDefaults.
             */
            static createUserDefaults(parameters: Dictionary<Titanium.App.iOS.UserDefaults>): Titanium.App.iOS.UserDefaults;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.UserNotificationAction>.
             */
            static createUserNotificationAction(parameters?: Dictionary<Titanium.App.iOS.UserNotificationAction>): Titanium.App.iOS.UserNotificationAction;

            /**
             * Creates and returns an instance of <Titanium.App.iOS.UserNotificationCategory>.
             */
            static createUserNotificationCategory(parameters?: Dictionary<Titanium.App.iOS.UserNotificationCategory>): Titanium.App.iOS.UserNotificationCategory;

            /**
             * Marks the end of the app execution after initiating the download operation. Available only on iOS 7 and later.
             */
            static endBackgroundHandler(handlerID: string): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent<K extends keyof iOSEventMap>(name: K, event?: iOSEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.App.iOS.apiName> property.
             * @deprecated Access <Titanium.App.iOS.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.App.iOS.applicationOpenSettingsURL> property.
             * @deprecated Access <Titanium.App.iOS.applicationOpenSettingsURL> instead.
             */
            static getApplicationOpenSettingsURL(): string;

            /**
             * Gets the value of the <Titanium.App.iOS.bubbleParent> property.
             * @deprecated Access <Titanium.App.iOS.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.App.iOS.currentUserNotificationSettings> property.
             * @deprecated Use [Titanium.App.iOS.UserNotificationCenter.requestUserNotificationSettings](Titanium.App.iOS.UserNotificationCenter.requestUserNotificationSettings) instead.
             */
            static getCurrentUserNotificationSettings(): UserNotificationSettings;

            /**
             * Gets the value of the <Titanium.App.iOS.supportedUserActivityTypes> property.
             * @deprecated Access <Titanium.App.iOS.supportedUserActivityTypes> instead.
             */
            static getSupportedUserActivityTypes(): string[];

            /**
             * Gets the value of the <Titanium.App.iOS.userInterfaceStyle> property.
             * @deprecated Use <Titanium.UI.userInterfaceStyle> instead, which is supported cross-platform.
             */
            static getUserInterfaceStyle(): number;

            /**
             * Registers a service to run when the application is placed in the background.
             */
            static registerBackgroundService(params: any): Titanium.App.iOS.BackgroundService;

            /**
             * Registers the application to use the requested notification types and categories.
             */
            static registerUserNotificationSettings(params: UserNotificationSettings): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener<K extends keyof iOSEventMap>(name: K, callback: (this: Titanium.App.iOS, event: iOSEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Schedule a local notification.
             */
            static scheduleLocalNotification(params: NotificationParams): Titanium.App.iOS.LocalNotification;

            /**
             * Marks the end of an `openParentApplication:reply` execution by a WatchKit extension.
             * @deprecated Use [Titanium.WatchSession](Titanium.WatchSession) instead, which is supported on iOS 9 and later.
             *
             */
            static sendWatchExtensionReply(handlerId: string, userInfo: any): void;

            /**
             * Sets the value of the <Titanium.App.iOS.bubbleParent> property.
             * @deprecated Set the value using <Titanium.App.iOS.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Specifies the minimum amount of time that must elapse between background fetch operations.
             * Available only on iOS 7 and later.
             */
            static setMinimumBackgroundFetchInterval(fetchInterval: number): void;

        }
    }
    /**
     * The Calendar module provides an API for accessing the native calendar functionality.
     */
    namespace Calendar {
        /**
         * Attendee role is chair.
         */
        const ATTENDEE_ROLE_CHAIR: number;

        /**
         * Attendee is not a participant.
         */
        const ATTENDEE_ROLE_NON_PARTICIPANT: number;

        /**
         * Attendee role is optional.
         */
        const ATTENDEE_ROLE_OPTIONAL: number;

        /**
         * Attendee role is required.
         */
        const ATTENDEE_ROLE_REQUIRED: number;

        /**
         * Attendee role is unknown.
         */
        const ATTENDEE_ROLE_UNKNOWN: number;

        /**
         * Attendee status is accepted.
         */
        const ATTENDEE_STATUS_ACCEPTED: number;

        /**
         * Attendee status is declined.
         */
        const ATTENDEE_STATUS_DECLINED: number;

        /**
         * Attendee status is delegated.
         */
        const ATTENDEE_STATUS_DELEGATED: number;

        /**
         * Attendee status is invited.
         */
        const ATTENDEE_STATUS_INVITED: number;

        /**
         * Attendee status is in process.
         */
        const ATTENDEE_STATUS_IN_PROCESS: number;

        /**
         * There is no Attendee status.
         */
        const ATTENDEE_STATUS_NONE: number;

        /**
         * Attendee status is pending.
         */
        const ATTENDEE_STATUS_PENDING: number;

        /**
         * Attendee status is tentative.
         */
        const ATTENDEE_STATUS_TENTATIVE: number;

        /**
         * Attendee status is unknown.
         */
        const ATTENDEE_STATUS_UNKNOWN: number;

        /**
         * Attendee type is group.
         */
        const ATTENDEE_TYPE_GROUP: number;

        /**
         * There is not attendee type.
         */
        const ATTENDEE_TYPE_NONE: number;

        /**
         * Attendee type is person.
         */
        const ATTENDEE_TYPE_PERSON: number;

        /**
         * Attendee type is required.
         */
        const ATTENDEE_TYPE_REQUIRED: number;

        /**
         * Attendee type is resource.
         */
        const ATTENDEE_TYPE_RESOURCE: number;

        /**
         * Attendee type is room.
         */
        const ATTENDEE_TYPE_ROOM: number;

        /**
         * Attendee type is unknown.
         */
        const ATTENDEE_TYPE_UNKNOWN: number;

        /**
         * An [calendarAuthorization](Titanium.Calendar.calendarAuthorization) value
         * indicating that the application is authorized to use events in the Calendar.
         */
        const AUTHORIZATION_AUTHORIZED: number;

        /**
         * An [calendarAuthorization](Titanium.Calendar.calendarAuthorization) value
         * indicating that the application is not authorized to use events in the Calendar.
         */
        const AUTHORIZATION_DENIED: number;

        /**
         * An [calendarAuthorization](Titanium.Calendar.calendarAuthorization) value
         * indicating that the application is not authorized to use events in the Calendar.
         * the user cannot change this application's status.
         */
        const AUTHORIZATION_RESTRICTED: number;

        /**
         * An [calendarAuthorization](Titanium.Calendar.calendarAuthorization) value
         * indicating that the authorization state is unknown.
         */
        const AUTHORIZATION_UNKNOWN: number;

        /**
         * Event has a busy availability setting.
         */
        const AVAILABILITY_BUSY: number;

        /**
         * Event has a free availability setting.
         */
        const AVAILABILITY_FREE: number;

        /**
         * Availability settings are not supported by the event's calendar.
         */
        const AVAILABILITY_NOTSUPPORTED: number;

        /**
         * Event has a tentative availability setting.
         */
        const AVAILABILITY_TENTATIVE: number;

        /**
         * Event has a tentative availability setting.
         */
        const AVAILABILITY_UNAVAILABLE: number;

        /**
         * Reminder alert delivery method.
         */
        const METHOD_ALERT: number;

        /**
         * Reminder default delivery method.
         */
        const METHOD_DEFAULT: number;

        /**
         * Reminder email delivery method.
         */
        const METHOD_EMAIL: number;

        /**
         * Reminder SMS delivery method.
         */
        const METHOD_SMS: number;

        /**
         * Indicates a daily recurrence rule for a events reccurance frequency.
         */
        const RECURRENCEFREQUENCY_DAILY: number;

        /**
         * Indicates a monthly recurrence rule for a events reccurance frequency.
         */
        const RECURRENCEFREQUENCY_MONTHLY: number;

        /**
         * Indicates a weekly recurrence rule for a events reccurance frequency.
         */
        const RECURRENCEFREQUENCY_WEEKLY: number;

        /**
         * Indicates a yearly recurrence rule for a events reccurance frequency.
         */
        const RECURRENCEFREQUENCY_YEARLY: number;

        /**
         * Relationship is attendee.
         */
        const RELATIONSHIP_ATTENDEE: number;

        /**
         * There is no relationship.
         */
        const RELATIONSHIP_NONE: number;

        /**
         * Attendee is organizer.
         */
        const RELATIONSHIP_ORGANIZER: number;

        /**
         * Attendee is performer.
         */
        const RELATIONSHIP_PERFORMER: number;

        /**
         * Attendee is speaker.
         */
        const RELATIONSHIP_SPEAKER: number;

        /**
         * Relationship is unknown.
         */
        const RELATIONSHIP_UNKNOWN: number;

        /**
         * A birthday calendar source.
         */
        const SOURCE_TYPE_BIRTHDAYS: number;

        /**
         * A calDev calendar source.
         */
        const SOURCE_TYPE_CALDAV: number;

        /**
         * A microsoft exchange calendar source.
         */
        const SOURCE_TYPE_EXCHANGE: number;

        /**
         * A local calendar source.
         */
        const SOURCE_TYPE_LOCAL: number;

        /**
         * A mobileMe calendar source.
         */
        const SOURCE_TYPE_MOBILEME: number;

        /**
         * A subscribed calendar source.
         */
        const SOURCE_TYPE_SUBSCRIBED: number;

        /**
         * A [save](Titanium.Calendar.Event.save)/[remove](Titanium.Calendar.Event.remove) event value,
         * indicating modifications to this event instance should also affect future instances of this event.
         */
        const SPAN_FUTUREEVENTS: number;

        /**
         * A [save](Titanium.Calendar.Event.save)/[remove](Titanium.Calendar.Event.remove) event value,
         * indicating modifications to this event instance should affect only this instance.
         */
        const SPAN_THISEVENT: number;

        /**
         * Alert dismissed state.
         */
        const STATE_DISMISSED: number;

        /**
         * Alert fired state.
         */
        const STATE_FIRED: number;

        /**
         * Alert scheduled status.
         */
        const STATE_SCHEDULED: number;

        /**
         * Event canceled status.
         */
        const STATUS_CANCELED: number;

        /**
         * Event canceled status.
         * @deprecated Use [Titanium.Calendar.STATUS_CANCELED](Titanium.Calendar.STATUS_CANCELED) instead.
         */
        const STATUS_CANCELLED: never;

        /**
         * Event confirmed status.
         */
        const STATUS_CONFIRMED: number;

        /**
         * Event has no status.
         */
        const STATUS_NONE: number;

        /**
         * Event tentative status.
         */
        const STATUS_TENTATIVE: number;

        /**
         * Event confidential visibility.
         */
        const VISIBILITY_CONFIDENTIAL: number;

        /**
         * Event default visibility.
         */
        const VISIBILITY_DEFAULT: number;

        /**
         * Event private visibility.
         */
        const VISIBILITY_PRIVATE: number;

        /**
         * Event public visibility.
         */
        const VISIBILITY_PUBLIC: number;

        /**
         * An object that represents a single alert for an event in an calendar.
         */
        class Alert extends Titanium.Proxy {
            /**
             * The absolute date for the alarm.
             */
            absoluteDate: Date;

            /**
             * Date/time at which this alert alarm is set to trigger.
             */
            readonly alarmTime: Date;

            /**
             * Start date/time for the corresponding event.
             */
            readonly begin: Date;

            /**
             * End date/time for the corresponding event.
             */
            readonly end: Date;

            /**
             * Identifier of the event for which this alert is set.
             */
            readonly eventId: number;

            /**
             * Identifier of this alert.
             */
            readonly id: string;

            /**
             * Reminder notice period in minutes, that determines how long prior to the event this alert
             * should trigger.
             */
            readonly minutes: number;

            /**
             * The offset from the start of an event, at which the alarm fires.
             */
            relativeOffset: number;

            /**
             * The current state of the alert.
             */
            readonly state: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.absoluteDate> property.
             * @deprecated Access <Titanium.Calendar.Alert.absoluteDate> instead.
             */
            getAbsoluteDate(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.alarmTime> property.
             * @deprecated Access <Titanium.Calendar.Alert.alarmTime> instead.
             */
            getAlarmTime(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.begin> property.
             * @deprecated Access <Titanium.Calendar.Alert.begin> instead.
             */
            getBegin(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.end> property.
             * @deprecated Access <Titanium.Calendar.Alert.end> instead.
             */
            getEnd(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.eventId> property.
             * @deprecated Access <Titanium.Calendar.Alert.eventId> instead.
             */
            getEventId(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.id> property.
             * @deprecated Access <Titanium.Calendar.Alert.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.minutes> property.
             * @deprecated Access <Titanium.Calendar.Alert.minutes> instead.
             */
            getMinutes(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.relativeOffset> property.
             * @deprecated Access <Titanium.Calendar.Alert.relativeOffset> instead.
             */
            getRelativeOffset(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Alert.state> property.
             * @deprecated Access <Titanium.Calendar.Alert.state> instead.
             */
            getState(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Calendar.Alert.absoluteDate> property.
             * @deprecated Set the value using <Titanium.Calendar.Alert.absoluteDate> instead.
             */
            setAbsoluteDate(absoluteDate: Date): void;

            /**
             * Sets the value of the <Titanium.Calendar.Alert.relativeOffset> property.
             * @deprecated Set the value using <Titanium.Calendar.Alert.relativeOffset> instead.
             */
            setRelativeOffset(relativeOffset: number): void;

        }
        /**
         * An object that represents a single attendee of an event.
         */
        class Attendee extends Titanium.Proxy {
            /**
             * The attendee email.
             */
            readonly email: string;

            /**
             * Indicates whether this attendee is the event organizer.
             */
            readonly isOrganizer: boolean;

            /**
             * The attendee name.
             */
            readonly name: string;

            /**
             * The role of the attendee.
             */
            readonly role: number;

            /**
             * The status of the attendee.
             */
            readonly status: number;

            /**
             * The type of the attendee.
             */
            readonly type: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.email> property.
             * @deprecated Access <Titanium.Calendar.Attendee.email> instead.
             */
            getEmail(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.isOrganizer> property.
             * @deprecated Access <Titanium.Calendar.Attendee.isOrganizer> instead.
             */
            getIsOrganizer(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.name> property.
             * @deprecated Access <Titanium.Calendar.Attendee.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.role> property.
             * @deprecated Access <Titanium.Calendar.Attendee.role> instead.
             */
            getRole(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.status> property.
             * @deprecated Access <Titanium.Calendar.Attendee.status> instead.
             */
            getStatus(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Attendee.type> property.
             * @deprecated Access <Titanium.Calendar.Attendee.type> instead.
             */
            getType(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * An object that represents a single calendar.
         */
        class Calendar extends Titanium.Proxy {
            /**
             * Indicates whether this calendar can be edited or deleted.
             */
            readonly hidden: boolean;

            /**
             * Identifier of this calendar.
             */
            readonly id: string;

            /**
             * Display name of this calendar.
             */
            readonly name: string;

            /**
             * Indicates whether the calendar is selected.
             */
            readonly selected: boolean;

            /**
             * Displays the source identifier.
             */
            readonly sourceIdentifier: string;

            /**
             * Displays the source title.
             */
            readonly sourceTitle: string;

            /**
             * Displays the source type.
             */
            readonly sourceType: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Creates an event in this calendar.
             */
            createEvent(properties: Dictionary<Titanium.Calendar.Event>): Titanium.Calendar.Event;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the event with the specified identifier.
             */
            getEventById(id: string): Titanium.Calendar.Event;

            /**
             * Gets events that occur between two dates.
             */
            getEventsBetweenDates(date1: Date | string, date2: Date | string): Titanium.Calendar.Event[];

            /**
             * Gets events that occur on a specified date.
             * @deprecated Use [Titanium.Calendar.Calendar.getEventsBetweenDates](Titanium.Calendar.Calendar.getEventsBetweenDates) instead.
             */
            getEventsInDate(year: number, month: number, day: number): Titanium.Calendar.Event[];

            /**
             * Gets events that occur during a specified month.
             * @deprecated Use [Titanium.Calendar.Calendar.getEventsBetweenDates](Titanium.Calendar.Calendar.getEventsBetweenDates) instead.
             */
            getEventsInMonth(year: number, month: number): Titanium.Calendar.Event[];

            /**
             * Gets all events that occur during a specified year.
             * @deprecated Use [Titanium.Calendar.Calendar.getEventsBetweenDates](Titanium.Calendar.Calendar.getEventsBetweenDates) instead.
             */
            getEventsInYear(year: number): Titanium.Calendar.Event[];

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.hidden> property.
             * @deprecated Access <Titanium.Calendar.Calendar.hidden> instead.
             */
            getHidden(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.id> property.
             * @deprecated Access <Titanium.Calendar.Calendar.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.name> property.
             * @deprecated Access <Titanium.Calendar.Calendar.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.selected> property.
             * @deprecated Access <Titanium.Calendar.Calendar.selected> instead.
             */
            getSelected(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.sourceIdentifier> property.
             * @deprecated Access <Titanium.Calendar.Calendar.sourceIdentifier> instead.
             */
            getSourceIdentifier(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.sourceTitle> property.
             * @deprecated Access <Titanium.Calendar.Calendar.sourceTitle> instead.
             */
            getSourceTitle(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Calendar.sourceType> property.
             * @deprecated Access <Titanium.Calendar.Calendar.sourceType> instead.
             */
            getSourceType(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * An object that represents a single event in a calendar.
         */
        class Event extends Titanium.Proxy {
            /**
             * Alarms associated with the calendar item, as an array of <Titanium.Calendar.Alert> objects.
             */
            alerts: Titanium.Calendar.Alert[];

            /**
             * Indicates whether this event is all day.
             */
            allDay: boolean;

            /**
             * The list of event attendees. This list will be empty if the event has no attendees.
             */
            readonly attendees: Titanium.Calendar.Attendee[];

            /**
             * Availability of this event.
             */
            availability: number;

            /**
             * Start date/time of this event.
             */
            begin: Date;

            /**
             * Description of this event.
             */
            readonly description: string;

            /**
             * End date/time of this event.
             */
            end: Date;

            /**
             * Extended properties of this event.
             */
            readonly extendedProperties: any;

            /**
             * Indicates whether an alarm is scheduled for this event.
             */
            readonly hasAlarm: boolean;

            /**
             * Identifier of this event.
             */
            readonly id: string;

            /**
             * Boolean value that indicates whether an event is a detached instance of a
             * repeating event.
             */
            readonly isDetached: boolean;

            /**
             * Location of this event.
             */
            location: string;

            /**
             * Notes for this event.
             */
            notes: string;

            /**
             * The recurrence rules for the calendar item.
             */
            recurrenceRules: Titanium.Calendar.RecurrenceRule[];

            /**
             * Existing reminders for this event.
             */
            readonly reminders: Titanium.Calendar.Reminder[];

            /**
             * Status of this event.
             */
            readonly status: number;

            /**
             * Title of this event.
             */
            title: string;

            /**
             * Visibility of this event.
             */
            readonly visibility: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a recurrence rule to the recurrence rule array.
             */
            addRecurrenceRule(rule: Titanium.Calendar.RecurrenceRule): void;

            /**
             * Creates an alert for this event.
             */
            createAlert(data: Dictionary<Titanium.Calendar.Alert>): Titanium.Calendar.Alert;

            /**
             * Creates an recurrence pattern for a recurring event.
             * All of the properties for the recurrence rule must be set during creation.
             * The recurrence rule properties cannot be modified.
             */
            createRecurrenceRule(data: Dictionary<Titanium.Calendar.RecurrenceRule>): Titanium.Calendar.RecurrenceRule;

            /**
             * Creates a reminder for this event.
             */
            createReminder(data: Dictionary<Titanium.Calendar.Reminder>): Titanium.Calendar.Reminder;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Calendar.Event.alerts> property.
             * @deprecated Access <Titanium.Calendar.Event.alerts> instead.
             */
            getAlerts(): Titanium.Calendar.Alert[];

            /**
             * Gets the value of the <Titanium.Calendar.Event.allDay> property.
             * @deprecated Access <Titanium.Calendar.Event.allDay> instead.
             */
            getAllDay(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Event.attendees> property.
             * @deprecated Access <Titanium.Calendar.Event.attendees> instead.
             */
            getAttendees(): Titanium.Calendar.Attendee[];

            /**
             * Gets the value of the <Titanium.Calendar.Event.availability> property.
             * @deprecated Access <Titanium.Calendar.Event.availability> instead.
             */
            getAvailability(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Event.begin> property.
             * @deprecated Access <Titanium.Calendar.Event.begin> instead.
             */
            getBegin(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Event.description> property.
             * @deprecated Access <Titanium.Calendar.Event.description> instead.
             */
            getDescription(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.end> property.
             * @deprecated Access <Titanium.Calendar.Event.end> instead.
             */
            getEnd(): Date;

            /**
             * Gets the value of the <Titanium.Calendar.Event.extendedProperties> property.
             * @deprecated Access <Titanium.Calendar.Event.extendedProperties> instead.
             */
            getExtendedProperties(): any;

            /**
             * Gets the value of the specified extended property.
             */
            getExtendedProperty(name: string): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.hasAlarm> property.
             * @deprecated Access <Titanium.Calendar.Event.hasAlarm> instead.
             */
            getHasAlarm(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Event.id> property.
             * @deprecated Access <Titanium.Calendar.Event.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.isDetached> property.
             * @deprecated Access <Titanium.Calendar.Event.isDetached> instead.
             */
            getIsDetached(): boolean;

            /**
             * Gets the value of the <Titanium.Calendar.Event.location> property.
             * @deprecated Access <Titanium.Calendar.Event.location> instead.
             */
            getLocation(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.notes> property.
             * @deprecated Access <Titanium.Calendar.Event.notes> instead.
             */
            getNotes(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.recurrenceRules> property.
             * @deprecated Access <Titanium.Calendar.Event.recurrenceRules> instead.
             */
            getRecurrenceRules(): Titanium.Calendar.RecurrenceRule[];

            /**
             * Gets the value of the <Titanium.Calendar.Event.reminders> property.
             * @deprecated Access <Titanium.Calendar.Event.reminders> instead.
             */
            getReminders(): Titanium.Calendar.Reminder[];

            /**
             * Gets the value of the <Titanium.Calendar.Event.status> property.
             * @deprecated Access <Titanium.Calendar.Event.status> instead.
             */
            getStatus(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Event.title> property.
             * @deprecated Access <Titanium.Calendar.Event.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Event.visibility> property.
             * @deprecated Access <Titanium.Calendar.Event.visibility> instead.
             */
            getVisibility(): number;

            /**
             * Updates the event's data with the current information in the Calendar database.
             */
            refresh(): boolean;

            /**
             * Removes an event from the event store.
             */
            remove(span: number): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a recurrence rule to the recurrence rule array.
             */
            removeRecurrenceRule(rule: Titanium.Calendar.RecurrenceRule): void;

            /**
             * Saves changes to an event permanently.
             */
            save(span: number): boolean;

            /**
             * Sets the value of the <Titanium.Calendar.Event.alerts> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.alerts> instead.
             */
            setAlerts(alerts: ReadonlyArray<Titanium.Calendar.Alert>): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.allDay> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.allDay> instead.
             */
            setAllDay(allDay: boolean): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.availability> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.availability> instead.
             */
            setAvailability(availability: number): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.begin> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.begin> instead.
             */
            setBegin(begin: Date): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.end> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.end> instead.
             */
            setEnd(end: Date): void;

            /**
             * Sets the value of the specified extended property.
             */
            setExtendedProperty(name: string, value: string): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.location> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.location> instead.
             */
            setLocation(location: string): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.notes> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.notes> instead.
             */
            setNotes(notes: string): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.recurrenceRules> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.recurrenceRules> instead.
             */
            setRecurrenceRules(recurrenceRules: ReadonlyArray<Titanium.Calendar.RecurrenceRule>): void;

            /**
             * Sets the value of the <Titanium.Calendar.Event.title> property.
             * @deprecated Set the value using <Titanium.Calendar.Event.title> instead.
             */
            setTitle(title: string): void;

        }
        /**
         * An object that is used to describe the recurrence pattern for a recurring event.
         */
        class RecurrenceRule extends Titanium.Proxy {
            /**
             * Identifier for the recurrence rule's calendar.
             */
            readonly calendarID: string;

            /**
             * The days of the month that the event occurs, as an array of number objects.
             * Values can be from 1 to 31 and from -1 to -31. This parameter is only valid for
             * recurrence rules of type
             * [RECURRENCEFREQUENCY_MONTHLY](Titanium.Calendar.RECURRENCEFREQUENCY_MONTHLY).
             */
            readonly daysOfTheMonth: number[];

            /**
             * The days of the week that the event occurs, as an array of objects `daysOfWeek` and `Week`.
             */
            readonly daysOfTheWeek: daysOfTheWeekDictionary[];

            /**
             * The days of the year that the event occurs, as an array of number objects.
             * Values can be from 1 to 366 and from -1 to -366. This parameter is only valid for
             * recurrence rules of type [RECURRENCEFREQUENCY_YEARLY](Titanium.Calendar.RECURRENCEFREQUENCY_YEARLY).
             */
            readonly daysOfTheYear: number[];

            /**
             * End of a recurrence rule.
             */
            readonly end: recurrenceEndDictionary;

            /**
             * Frequency of the recurrence rule.
             */
            readonly frequency: number;

            /**
             * The interval between instances of this recurrence. For example, a weekly
             * recurrence rule with an interval of 2 occurs every other week. Must be greater than 0.
             */
            readonly interval: number;

            /**
             * The months of the year that the event occurs, as an array of Number objects.
             * Values can be from 1 to 12. This parameter is only valid for recurrence rules of
             * type [RECURRENCEFREQUENCY_YEARLY](Titanium.Calendar.RECURRENCEFREQUENCY_YEARLY).
             */
            readonly monthsOfTheYear: number[];

            /**
             * An array of ordinal numbers that filters which recurrences to include in the
             * recurrence rule's frequency. For example, a yearly recurrence rule that has a
             * [daysOfTheWeek](Titanium.Calendar.RecurrenceRule.daysOfTheWeek) value that specifies
             * Monday through Friday, and a `setPositions` array containing 2 and -1, occurs only
             * on the second weekday and last weekday of every year.
             */
            readonly setPositions: number[];

            /**
             * The weeks of the year that the event occurs, as an array of number objects.
             * Values can be from 1 to 53 and from -1 to -53. This parameter is only valid for
             * recurrence rules of type [RECURRENCEFREQUENCY_YEARLY](Titanium.Calendar.RECURRENCEFREQUENCY_YEARLY).
             */
            readonly weeksOfTheYear: number[];

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.calendarID> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.calendarID> instead.
             */
            getCalendarID(): string;

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.daysOfTheMonth> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.daysOfTheMonth> instead.
             */
            getDaysOfTheMonth(): number[];

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.daysOfTheWeek> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.daysOfTheWeek> instead.
             */
            getDaysOfTheWeek(): daysOfTheWeekDictionary[];

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.daysOfTheYear> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.daysOfTheYear> instead.
             */
            getDaysOfTheYear(): number[];

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.end> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.end> instead.
             */
            getEnd(): recurrenceEndDictionary;

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.frequency> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.frequency> instead.
             */
            getFrequency(): number;

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.interval> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.interval> instead.
             */
            getInterval(): number;

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.monthsOfTheYear> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.monthsOfTheYear> instead.
             */
            getMonthsOfTheYear(): number[];

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.setPositions> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.setPositions> instead.
             */
            getSetPositions(): number[];

            /**
             * Gets the value of the <Titanium.Calendar.RecurrenceRule.weeksOfTheYear> property.
             * @deprecated Access <Titanium.Calendar.RecurrenceRule.weeksOfTheYear> instead.
             */
            getWeeksOfTheYear(): number[];

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * An object that represents a single reminder for an event in a calendar.
         */
        class Reminder extends Titanium.Proxy {
            /**
             * Identifier of this reminder.
             */
            readonly id: string;

            /**
             * Method by which this reminder will be delivered.
             */
            readonly method: number;

            /**
             * Reminder notice period in minutes, that determines how long prior to the event this reminder
             * should trigger.
             */
            readonly minutes: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Calendar.Reminder.id> property.
             * @deprecated Access <Titanium.Calendar.Reminder.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.Calendar.Reminder.method> property.
             * @deprecated Access <Titanium.Calendar.Reminder.method> instead.
             */
            getMethod(): number;

            /**
             * Gets the value of the <Titanium.Calendar.Reminder.minutes> property.
             * @deprecated Access <Titanium.Calendar.Reminder.minutes> instead.
             */
            getMinutes(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
    }
    /**
     * The top-level Contacts module, used for accessing and modifying the system contacts address book.
     */
    namespace Contacts {
        /**
         * A [contactsAuthorization](Titanium.Contacts.contactsAuthorization) value
         * indicating that the application is authorized to use the address book.
         */
        const AUTHORIZATION_AUTHORIZED: number;

        /**
         * A [contactsAuthorization](Titanium.Contacts.contactsAuthorization) value
         * indicating that the application is not authorized to use the address book.
         */
        const AUTHORIZATION_DENIED: number;

        /**
         * A [contactsAuthorization](Titanium.Contacts.contactsAuthorization) value
         * indicating that the application is not authorized to use the address book *and*
         * the user cannot change this application's status.
         * @deprecated iOS 9 and later does not use this constant anymore. Use the other available constants instead.
         */
        const AUTHORIZATION_RESTRICTED: never;

        /**
         * A [contactsAuthorization](Titanium.Contacts.contactsAuthorization) value
         * indicating that the authorization state is unknown.
         */
        const AUTHORIZATION_UNKNOWN: number;

        /**
         * Specifies that a contact is an organization.
         */
        const CONTACTS_KIND_ORGANIZATION: number;

        /**
         * Specifies that a contact is a person.
         */
        const CONTACTS_KIND_PERSON: number;

        /**
         * Specifies that group members will be sorted by first name.
         */
        const CONTACTS_SORT_FIRST_NAME: number;

        /**
         * Specifies that group members will be sorted by last name.
         */
        const CONTACTS_SORT_LAST_NAME: number;

        /**
         * An object which represents a group in the system contacts address book.
         */
        class Group extends Titanium.Proxy {
            /**
             * Identifier of the group.
             */
            readonly identifier: string;

            /**
             * Name of this group.
             */
            name: string;

            /**
             * Record identifier of the group. Single value. Deprecated for iOS 9 and later.
             */
            recordId: number;

            /**
             * Adds a person to this group.
             */
            add(person: Titanium.Contacts.Person): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Contacts.Group.identifier> property.
             * @deprecated Access <Titanium.Contacts.Group.identifier> instead.
             */
            getIdentifier(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Group.name> property.
             * @deprecated Access <Titanium.Contacts.Group.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Group.recordId> property.
             * @deprecated Access <Titanium.Contacts.Group.recordId> instead.
             */
            getRecordId(): number;

            /**
             * Gets people that are members of this group.
             */
            members(): Titanium.Contacts.Person[];

            /**
             * Removes a person from this group. For >= iOS9, it is not
             * required to call <Titanium.Contacts.save> after calling this method.
             */
            remove(person: Titanium.Contacts.Person): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Contacts.Group.name> property.
             * @deprecated Set the value using <Titanium.Contacts.Group.name> instead.
             */
            setName(name: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Group.recordId> property.
             * @deprecated Set the value using <Titanium.Contacts.Group.recordId> instead.
             */
            setRecordId(recordId: number): void;

            /**
             * Gets people that are members of this group, sorted in the specified order.
             */
            sortedMembers(sortBy: number): Titanium.Contacts.Person[];

        }
        /**
         * An object that represents a contact record for a person or organization in the system contacts
         * address book.
         */
        class Person extends Titanium.Proxy {
            /**
             * Addresses for the person. Multi-value. Read-only on Android.
             */
            address: any;

            /**
             * Alternate birthday of the person. Single Dictionary.
             */
            alternateBirthday: any;

            /**
             * Date of birth of the person. Single value.
             */
            birthday: string;

            /**
             * Date and time that the person record was created. Single value. Deprecated since iOS 9.
             */
            readonly created: string;

            /**
             * Dates associated with the person. Multi-value.
             */
            date: any;

            /**
             * Department of the person. Single value.
             */
            department: string;

            /**
             * Email addresses for the person. Multi-value. Read-only on Android.
             */
            email: any;

            /**
             * First name of the person. Single value.
             */
            firstName: string;

            /**
             * Phonetic first name of the person.  Single value.
             */
            firstPhonetic: string;

            /**
             * Localized full name of the person. Single value. Read-only on Android.
             */
            readonly fullName: string;

            /**
             * Record identifier of the person. Single value.
             */
            readonly id: number;

            /**
             * Identifier of the person.
             */
            readonly identifier: string;

            /**
             * Image for the person. Single value. Read-only for >= iOS9
             */
            image: Titanium.Blob;

            /**
             * Instant messenger information of the person. Multi-value.
             */
            instantMessage: any;

            /**
             * Job title of the person. Single value.
             */
            jobTitle: string;

            /**
             * Determines the type of information the person record contains; either person or organization.
             * Read-only on Android.
             */
            kind: number;

            /**
             * Last name of the person. Single value.
             */
            lastName: string;

            /**
             * Phonetic last name of the person. Single value.
             */
            lastPhonetic: string;

            /**
             * Middle name of the person. Single value.
             */
            middleName: string;

            /**
             * Phonetic middle name of the person. Single value.
             */
            middlePhonetic: string;

            /**
             * Date and time that the person record was last modified. Single value. Deprecated since iOS 9.
             */
            readonly modified: string;

            /**
             * Nickname of the person. Single value.
             */
            nickname: string;

            /**
             * Notes for the person. Single value.
             */
            note: string;

            /**
             * Organization to which the person belongs. Single value.
             */
            organization: string;

            /**
             * Phone numbers for the person. Multi-value. Read-only on Android.
             */
            phone: any;

            /**
             * Prefix for the person. Single value.
             */
            readonly prefix: string;

            /**
             * Record identifier of the person. Single value. Deprecated since iOS 9.
             */
            recordId: number;

            /**
             * Names of people to which the person is related. Multi-value.
             */
            relatedNames: any;

            /**
             * Social profile information of the person. Multi-value.
             */
            socialProfile: any;

            /**
             * Suffix for the person. Single value.
             */
            readonly suffix: string;

            /**
             * URLs of webpages associated with the person. Multi-value.
             */
            url: any;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Contacts.Person.address> property.
             * @deprecated Access <Titanium.Contacts.Person.address> instead.
             */
            getAddress(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.alternateBirthday> property.
             * @deprecated Access <Titanium.Contacts.Person.alternateBirthday> instead.
             */
            getAlternateBirthday(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.birthday> property.
             * @deprecated Access <Titanium.Contacts.Person.birthday> instead.
             */
            getBirthday(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.created> property.
             * @deprecated Access <Titanium.Contacts.Person.created> instead.
             */
            getCreated(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.date> property.
             * @deprecated Access <Titanium.Contacts.Person.date> instead.
             */
            getDate(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.department> property.
             * @deprecated Access <Titanium.Contacts.Person.department> instead.
             */
            getDepartment(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.email> property.
             * @deprecated Access <Titanium.Contacts.Person.email> instead.
             */
            getEmail(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.firstName> property.
             * @deprecated Access <Titanium.Contacts.Person.firstName> instead.
             */
            getFirstName(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.firstPhonetic> property.
             * @deprecated Access <Titanium.Contacts.Person.firstPhonetic> instead.
             */
            getFirstPhonetic(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.fullName> property.
             * @deprecated Access <Titanium.Contacts.Person.fullName> instead.
             */
            getFullName(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.id> property.
             * @deprecated Access <Titanium.Contacts.Person.id> instead.
             */
            getId(): number;

            /**
             * Gets the value of the <Titanium.Contacts.Person.identifier> property.
             * @deprecated Access <Titanium.Contacts.Person.identifier> instead.
             */
            getIdentifier(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.image> property.
             * @deprecated Access <Titanium.Contacts.Person.image> instead.
             */
            getImage(): Titanium.Blob;

            /**
             * Gets the value of the <Titanium.Contacts.Person.instantMessage> property.
             * @deprecated Access <Titanium.Contacts.Person.instantMessage> instead.
             */
            getInstantMessage(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.jobTitle> property.
             * @deprecated Access <Titanium.Contacts.Person.jobTitle> instead.
             */
            getJobTitle(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.kind> property.
             * @deprecated Access <Titanium.Contacts.Person.kind> instead.
             */
            getKind(): number;

            /**
             * Gets the value of the <Titanium.Contacts.Person.lastName> property.
             * @deprecated Access <Titanium.Contacts.Person.lastName> instead.
             */
            getLastName(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.lastPhonetic> property.
             * @deprecated Access <Titanium.Contacts.Person.lastPhonetic> instead.
             */
            getLastPhonetic(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.middleName> property.
             * @deprecated Access <Titanium.Contacts.Person.middleName> instead.
             */
            getMiddleName(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.middlePhonetic> property.
             * @deprecated Access <Titanium.Contacts.Person.middlePhonetic> instead.
             */
            getMiddlePhonetic(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.modified> property.
             * @deprecated Access <Titanium.Contacts.Person.modified> instead.
             */
            getModified(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.nickname> property.
             * @deprecated Access <Titanium.Contacts.Person.nickname> instead.
             */
            getNickname(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.note> property.
             * @deprecated Access <Titanium.Contacts.Person.note> instead.
             */
            getNote(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.organization> property.
             * @deprecated Access <Titanium.Contacts.Person.organization> instead.
             */
            getOrganization(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.phone> property.
             * @deprecated Access <Titanium.Contacts.Person.phone> instead.
             */
            getPhone(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.prefix> property.
             * @deprecated Access <Titanium.Contacts.Person.prefix> instead.
             */
            getPrefix(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.recordId> property.
             * @deprecated Access <Titanium.Contacts.Person.recordId> instead.
             */
            getRecordId(): number;

            /**
             * Gets the value of the <Titanium.Contacts.Person.relatedNames> property.
             * @deprecated Access <Titanium.Contacts.Person.relatedNames> instead.
             */
            getRelatedNames(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.socialProfile> property.
             * @deprecated Access <Titanium.Contacts.Person.socialProfile> instead.
             */
            getSocialProfile(): any;

            /**
             * Gets the value of the <Titanium.Contacts.Person.suffix> property.
             * @deprecated Access <Titanium.Contacts.Person.suffix> instead.
             */
            getSuffix(): string;

            /**
             * Gets the value of the <Titanium.Contacts.Person.url> property.
             * @deprecated Access <Titanium.Contacts.Person.url> instead.
             */
            getUrl(): any;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.address> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.address> instead.
             */
            setAddress(address: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.alternateBirthday> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.alternateBirthday> instead.
             */
            setAlternateBirthday(alternateBirthday: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.birthday> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.birthday> instead.
             */
            setBirthday(birthday: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.date> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.date> instead.
             */
            setDate(date: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.department> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.department> instead.
             */
            setDepartment(department: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.email> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.email> instead.
             */
            setEmail(email: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.firstName> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.firstName> instead.
             */
            setFirstName(firstName: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.firstPhonetic> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.firstPhonetic> instead.
             */
            setFirstPhonetic(firstPhonetic: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.image> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.image> instead.
             */
            setImage(image: Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.instantMessage> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.instantMessage> instead.
             */
            setInstantMessage(instantMessage: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.jobTitle> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.jobTitle> instead.
             */
            setJobTitle(jobTitle: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.kind> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.kind> instead.
             */
            setKind(kind: number): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.lastName> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.lastName> instead.
             */
            setLastName(lastName: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.lastPhonetic> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.lastPhonetic> instead.
             */
            setLastPhonetic(lastPhonetic: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.middleName> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.middleName> instead.
             */
            setMiddleName(middleName: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.middlePhonetic> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.middlePhonetic> instead.
             */
            setMiddlePhonetic(middlePhonetic: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.nickname> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.nickname> instead.
             */
            setNickname(nickname: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.note> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.note> instead.
             */
            setNote(note: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.organization> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.organization> instead.
             */
            setOrganization(organization: string): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.phone> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.phone> instead.
             */
            setPhone(phone: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.recordId> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.recordId> instead.
             */
            setRecordId(recordId: number): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.relatedNames> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.relatedNames> instead.
             */
            setRelatedNames(relatedNames: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.socialProfile> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.socialProfile> instead.
             */
            setSocialProfile(socialProfile: any): void;

            /**
             * Sets the value of the <Titanium.Contacts.Person.url> property.
             * @deprecated Set the value using <Titanium.Contacts.Person.url> instead.
             */
            setUrl(url: any): void;

        }
    }
    /**
     * The top-level `Database` module, used for creating and accessing the
     * in-application SQLite database.
     */
    namespace Database {
        /**
         * Constant for requesting a column's value returned in double form.
         */
        const FIELD_TYPE_DOUBLE: number;

        /**
         * Constant for requesting a column's value returned in float form.
         */
        const FIELD_TYPE_FLOAT: number;

        /**
         * Constant for requesting a column's value returned in integer form.
         */
        const FIELD_TYPE_INT: number;

        /**
         * Constant for requesting a column's value returned in string form.
         */
        const FIELD_TYPE_STRING: number;

        /**
         * The `Database` instance returned by <Titanium.Database.open> or <Titanium.Database.install>.
         */
        class DB extends Titanium.Proxy {
            /**
             * A `File` object representing the file where this database is stored. Must only be used for
             * setting file properties.
             */
            readonly file: Titanium.Filesystem.File;

            /**
             * The identifier of the last populated row.
             */
            readonly lastInsertRowId: number;

            /**
             * The name of the database.
             */
            readonly name: string;

            /**
             * The number of rows affected by the last query.
             */
            readonly rowsAffected: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Closes the database and releases resources from memory. Once closed, this instance is no
             * longer valid and should not be used. On iOS, also closes all <Titanium.Database.ResultSet>
             * instances that exist.
             */
            close(): void;

            /**
             * Executes an SQL statement against the database and returns a `ResultSet`.
             */
            execute(sql: string, ...vararg: string[]): Titanium.Database.ResultSet;

            /**
             * Executes an SQL statement against the database and returns a `ResultSet`.
             */
            execute(sql: string, vararg?: ReadonlyArray<string>): Titanium.Database.ResultSet;

            /**
             * Executes an SQL statement against the database and returns a `ResultSet`.
             */
            execute(sql: string, ...vararg: any[]): Titanium.Database.ResultSet;

            /**
             * Executes an SQL statement against the database and returns a `ResultSet`.
             */
            execute(sql: string, vararg?: ReadonlyArray<any>): Titanium.Database.ResultSet;

            /**
             * Synchronously executes an array of SQL statements against the database and returns an array of `ResultSet`.
             * On failure, this will throw an [Error](BatchQueryError) that reports the failed index and partial results
             */
            executeAll(queries: ReadonlyArray<string>): Titanium.Database.ResultSet[];

            /**
             * Asynchronously executes an array of SQL statements against the database and fires a callback with a possible Error, and an array of `ResultSet`.
             * On failure, this will call the callback with an [Error](PossibleBatchQueryError) that reports the failed index, and a second argument with the partial results
             */
            executeAllAsync(queries: ReadonlyArray<string>, callback: (param0: PossibleBatchQueryError, param1: Titanium.Database.ResultSet[]) => void): void;

            /**
             * Asynchronously executes an SQL statement against the database and fires a callback with a possible `Error` argument, and a second argument holding a possible `ResultSet`.
             */
            executeAsync(query: string, vararg?: any, callback?: (param0: any, param1: Titanium.Database.ResultSet) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Database.DB.file> property.
             * @deprecated Access <Titanium.Database.DB.file> instead.
             */
            getFile(): Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.Database.DB.lastInsertRowId> property.
             * @deprecated Access <Titanium.Database.DB.lastInsertRowId> instead.
             */
            getLastInsertRowId(): number;

            /**
             * Gets the value of the <Titanium.Database.DB.name> property.
             * @deprecated Access <Titanium.Database.DB.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Database.DB.rowsAffected> property.
             * @deprecated Access <Titanium.Database.DB.rowsAffected> instead.
             */
            getRowsAffected(): number;

            /**
             * Removes the database files for this instance from disk. WARNING: this is a destructive
             * operation and cannot be reversed. All data in the database will be lost; use with caution.
             */
            remove(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * The ResultSet instance returned by <Titanium.Database.DB.execute>.
         */
        class ResultSet extends Titanium.Proxy {
            /**
             * The number of columns in this result set.
             */
            readonly fieldCount: number;

            /**
             * The number of rows in this result set.
             */
            readonly rowCount: number;

            /**
             * Indicates whether the current row is valid.
             */
            readonly validRow: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Closes this result set and release resources. Once closed, the result set must no longer
             * be used.
             */
            close(): void;

            /**
             * Retrieves the value for the specified field in the current row,
             * and casts it to the specified type (String, Integer, Float or Double.)
             */
            field(index: number, type?: number): string | number | Titanium.Blob;

            /**
             * Retrieves the value for the specified field in the current row,
             * and casts it to the specified type (String, Integer, Float or Double.)
             */
            fieldByName(name: string, type?: number): string | number | Titanium.Blob;

            /**
             * Returns the field name for the specified field index.
             */
            fieldName(index: number): string;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Database.ResultSet.fieldCount> property.
             * @deprecated Access <Titanium.Database.ResultSet.fieldCount> instead.
             */
            getFieldCount(): number;

            /**
             * Returns the field name for the specified field index.
             */
            getFieldName(index: number): string;

            /**
             * Gets the value of the <Titanium.Database.ResultSet.rowCount> property.
             * @deprecated Access <Titanium.Database.ResultSet.rowCount> instead.
             */
            getRowCount(): number;

            /**
             * Gets the value of the <Titanium.Database.ResultSet.validRow> property.
             * @deprecated Access <Titanium.Database.ResultSet.validRow> instead.
             */
            getValidRow(): boolean;

            /**
             * Returns whether the current row is valid.
             */
            isValidRow(): boolean;

            /**
             * Advances to the next row in the result set and returns `true` if one exists,
             * or `false` otherwise.
             */
            next(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
    }
    /**
     * The top level filesystem module, used to access files and directories on the device.
     */
    namespace Filesystem {
        /**
         * Constant used to set protection key to NSFileProtectionComplete in file attributes.
         */
        const IOS_FILE_PROTECTION_COMPLETE: string;

        /**
         * Constant used to set protection key to NSFileProtectionCompleteUnlessOpen in file attributes.
         */
        const IOS_FILE_PROTECTION_COMPLETE_UNLESS_OPEN: string;

        /**
         * Constant used to set protection key to NSFileProtectionCompleteUntilFirstUserAuthentication in file attributes.
         */
        const IOS_FILE_PROTECTION_COMPLETE_UNTIL_FIRST_USER_AUTHENTICATION: string;

        /**
         * Constant used to set protection key to NSFileProtectionNone in file attributes.
         */
        const IOS_FILE_PROTECTION_NONE: string;

        /**
         * Constant for append mode for file operations.
         */
        const MODE_APPEND: number;

        /**
         * Constant for read mode for file operations.
         */
        const MODE_READ: number;

        /**
         * Constant for write mode for file operations.
         */
        const MODE_WRITE: number;

        /**
         * Object representing a path to a file or directory in the device's persistent storage.
         */
        class File extends Titanium.Proxy {
            /**
             * `true` if the file is executable.
             */
            readonly executable: boolean;

            /**
             * Set to `true` if the file is hidden.
             */
            hidden: boolean;

            /**
             * Name of the file.
             */
            readonly name: string;

            /**
             * Native path associated with this file object, as a file URL.
             */
            readonly nativePath: string;

            /**
             * A `File` object representing the parent directory of the file identified by this object.
             */
            readonly parent: Titanium.Filesystem.File;

            /**
             * `true` if the file identified by this object is read-only.
             */
            readonly readonly: boolean;

            /**
             * Value indicating whether or not to back up to a cloud service.
             */
            remoteBackup: boolean;

            /**
             * Size, in bytes, of the file identified by this object.
             */
            readonly size: number;

            /**
             * `true` if the file identified by this object is a symbolic link.
             */
            readonly symbolicLink: boolean;

            /**
             * `true` if the file identified by this object is writable.
             */
            readonly writable: boolean;

            /**
             * `true` if the file identified by this object is writable.
             * @deprecated Use [Titanium.Filesystem.File.writable](Titanium.Filesystem.File.writable) instead.
             */
            readonly writeable: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Appends data to the file identified by this file object.
             */
            append(data: string | Titanium.Blob | Titanium.Filesystem.File): boolean;

            /**
             * Copies the file identified by this file object to a new path.
             */
            copy(destinationPath: string): boolean;

            /**
             * Creates a directory at the path identified by this file object.
             */
            createDirectory(recursive?: boolean): boolean;

            /**
             * Creates a file at the path identified by this file object.
             */
            createFile(): boolean;

            /**
             * Returns the creation timestamp for the file identified by this file object.
             * @deprecated Use [createdAt](Titanium.Filesystem.File.createdAt) instead.
             */
            createTimestamp(): number;

            /**
             * Returns the creation Date for the file identified by this file object.
             */
            createdAt(): Date;

            /**
             * Deletes the directory identified by this file object.
             */
            deleteDirectory(recursive?: boolean): boolean;

            /**
             * Deletes the file identified by this file object.
             */
            deleteFile(): boolean;

            /**
             * Returns `true` if the file or directory identified by this file object exists on the device.
             */
            exists(): boolean;

            /**
             * Returns the extension for the file identified by this file object.
             */
            extension(): string;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Returns a listing of the directory identified by this file object, or `null`
             * if this object doesn't identify a directory.
             */
            getDirectoryListing(): string[];

            /**
             * Gets the value of the <Titanium.Filesystem.File.executable> property.
             * @deprecated Access <Titanium.Filesystem.File.executable> instead.
             */
            getExecutable(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.hidden> property.
             * @deprecated Access <Titanium.Filesystem.File.hidden> instead.
             */
            getHidden(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.name> property.
             * @deprecated Access <Titanium.Filesystem.File.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Filesystem.File.nativePath> property.
             * @deprecated Access <Titanium.Filesystem.File.nativePath> instead.
             */
            getNativePath(): string;

            /**
             * Returns the path of the parent directory holding the file identified by this
             * file object, as a String (deprecated) **or** as a `File` object.
             * @deprecated Use the [Titanium.Filesystem.File.parent](Titanium.Filesystem.File.parent) property to receive a `File`
             * reference instead. If you wish to receive the path, use the `nativePath`
             * property of that reference instead.
             *
             */
            getParent(): string | Titanium.Filesystem.File;

            /**
             * Returns the protection key value of this file object.
             * Returns `null` if there's an error.
             */
            getProtectionKey(): string;

            /**
             * Gets the value of the <Titanium.Filesystem.File.readonly> property.
             * @deprecated Access <Titanium.Filesystem.File.readonly> instead.
             */
            getReadonly(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.remoteBackup> property.
             * @deprecated Access <Titanium.Filesystem.File.remoteBackup> instead.
             */
            getRemoteBackup(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.size> property.
             * @deprecated Access <Titanium.Filesystem.File.size> instead.
             */
            getSize(): number;

            /**
             * Gets the value of the <Titanium.Filesystem.File.symbolicLink> property.
             * @deprecated Access <Titanium.Filesystem.File.symbolicLink> instead.
             */
            getSymbolicLink(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.writable> property.
             * @deprecated Access <Titanium.Filesystem.File.writable> instead.
             */
            getWritable(): boolean;

            /**
             * Gets the value of the <Titanium.Filesystem.File.writeable> property.
             * @deprecated Use [Titanium.Filesystem.File.writable](Titanium.Filesystem.File.writable) instead.
             */
            getWriteable: never;

            /**
             * Returns `true` if this file object represents a directory.
             */
            isDirectory(): boolean;

            /**
             * Returns `true` if this file object represents an ordinary file.
             */
            isFile(): boolean;

            /**
             * Returns the last modification time for this file.
             * @deprecated Use [Titanium.Filesystem.File.modifiedAt](Titanium.Filesystem.File.modifiedAt) instead.
             */
            modificationTimestamp(): number;

            /**
             * Returns the last modification Date for the file identified by this file object.
             */
            modifiedAt(): Date;

            /**
             * Moves the file identified by this file object to another path.
             */
            move(newpath: string): boolean;

            /**
             * Opens the file identified by this file object for random access.
             */
            open(mode: number): Titanium.Filesystem.FileStream;

            /**
             * Returns the contents of the file identified by this file object as a `Blob`.
             */
            read(): Titanium.Blob;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Renames the file identified by this file object.
             */
            rename(newname: string): boolean;

            /**
             * Returns the fully-resolved native path associated with this file object.
             */
            resolve(): string;

            /**
             * Sets the value of the <Titanium.Filesystem.File.hidden> property.
             * @deprecated Set the value using <Titanium.Filesystem.File.hidden> instead.
             */
            setHidden(hidden: boolean): void;

            /**
             * Sets the protection key as an attribute to the file identified by this file object.
             */
            setProtectionKey(fileProtectionType: string): boolean;

            /**
             * Sets the value of the <Titanium.Filesystem.File.remoteBackup> property.
             * @deprecated Set the value using <Titanium.Filesystem.File.remoteBackup> instead.
             */
            setRemoteBackup(remoteBackup: boolean): void;

            /**
             * Returns the amount of free space available on the device where the file identified by this file object is stored.
             */
            spaceAvailable(): number;

            /**
             * Writes the specified data to the file identified by this file object.
             */
            write(data: string | Titanium.Filesystem.File | Titanium.Blob, append?: boolean): boolean;

        }
        /**
         * Wrapper around `Titanium.Filesystem.File` that implements the `Titanium.IOStream` interface
         */
        class FileStream extends Titanium.IOStream {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * closes file stream, exception is thrown on error
             */
            close(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
    }
    /**
     * The top level Geolocation module. The Geolocation module is used for accessing device location based information.
     */
    namespace Geolocation {
        /**
         * The user authorized the app to access location data with full accuracy.
         */
        const ACCURACY_AUTHORIZATION_FULL: number;

        /**
         * The user authorized the app to access location data with reduced accuracy.
         */
        const ACCURACY_AUTHORIZATION_REDUCED: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request the best
         * accuracy available.
         */
        const ACCURACY_BEST: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request highest possible
         * accuracy and combine it with additional sensor data.
         */
        const ACCURACY_BEST_FOR_NAVIGATION: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request more
         * accurate location updates with higher battery usage.
         */
        const ACCURACY_HIGH: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request location
         * updates accurate to the nearest 100 meters.
         */
        const ACCURACY_HUNDRED_METERS: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request location
         * updates accurate to the nearest kilometer.
         */
        const ACCURACY_KILOMETER: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request less
         * accurate location updates with lower battery usage.
         */
        const ACCURACY_LOW: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request location
         * updates accurate to the nearest 10 meters.
         */
        const ACCURACY_NEAREST_TEN_METERS: number;

        /**
         * The level of accuracy used when an app isn’t authorized for full accuracy location data.
         */
        const ACCURACY_REDUCED: number;

        /**
         * Use with [accuracy](Titanium.Geolocation.accuracy) to request location
         * updates accurate to the nearest three kilometers.
         */
        const ACCURACY_THREE_KILOMETERS: number;

        /**
         * The location data is used for tracking location changes to the automobile specifically during vehicular navigation.
         */
        const ACTIVITYTYPE_AUTOMOTIVE_NAVIGATION: string;

        /**
         * The location data is used for tracking any pedestrian-related activity.
         */
        const ACTIVITYTYPE_FITNESS: string;

        /**
         * The location data is being used for an unknown activity.
         */
        const ACTIVITYTYPE_OTHER: string;

        /**
         * The location data is used for tracking movements of other types of vehicular
         * navigation that are not automobile related.
         */
        const ACTIVITYTYPE_OTHER_NAVIGATION: string;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the application is authorized to start location services at any time. This authorization
         * includes the use of all location services, including monitoring regions and significant location changes.
         */
        const AUTHORIZATION_ALWAYS: number;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the application is authorized to use location services.
         * @deprecated Use [Titanium.Geolocation.AUTHORIZATION_ALWAYS](Titanium.Geolocation.AUTHORIZATION_ALWAYS) as advised by Apple.
         */
        const AUTHORIZATION_AUTHORIZED: number;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the application is not authorized to use location services, *or*
         * location services are disabled.
         */
        const AUTHORIZATION_DENIED: number;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the application is not authorized to use location servies *and*
         * the user cannot change this application's status.
         */
        const AUTHORIZATION_RESTRICTED: number;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the authorization state is unknown.
         */
        const AUTHORIZATION_UNKNOWN: number;

        /**
         * A [locationServicesAuthorization](Titanium.Geolocation.locationServicesAuthorization) value
         * indicating that the application is authorized to start most location services only while running in the foreground.
         */
        const AUTHORIZATION_WHEN_IN_USE: number;

        /**
         * Error code indicating that the user denied access to the location service.
         */
        const ERROR_DENIED: number;

        /**
         * Error code indicating that the heading could not be determined.
         */
        const ERROR_HEADING_FAILURE: number;

        /**
         * Error code indicating that the user's location could not be determined.
         */
        const ERROR_LOCATION_UNKNOWN: number;

        /**
         * Error code indicating that the network was unavailable.
         */
        const ERROR_NETWORK: number;

        /**
         * Error code indicating that region monitoring is delayed.
         */
        const ERROR_REGION_MONITORING_DELAYED: number;

        /**
         * Error code indicating that region monitoring is denied.
         */
        const ERROR_REGION_MONITORING_DENIED: number;

        /**
         * Error code indicating a region monitoring failure.
         */
        const ERROR_REGION_MONITORING_FAILURE: number;

        /**
         * Module for Android-specific geolocation functionality.
         */
        namespace Android {
            /**
             * Specifies the GPS location provider.
             */
            const PROVIDER_GPS: string;

            /**
             * Specifies the network location provider.
             */
            const PROVIDER_NETWORK: string;

            /**
             * Specifies the passive location provider.
             */
            const PROVIDER_PASSIVE: string;

            /**
             * Represents a source of location information, such as GPS.
             */
            class LocationProvider extends Titanium.Proxy {
                /**
                 * Don't send a location update unless the location has changed at least `minUpdateDistance`
                 * meters since the previous update.
                 */
                minUpdateDistance: number;

                /**
                 * Limits the frequency of location updates to no more than one per `minUpdateTime` seconds.
                 */
                minUpdateTime: number;

                /**
                 * Type of location provider: [PROVIDER_GPS](Titanium.Geolocation.Android.PROVIDER_GPS),
                 * [PROVIDER_NETWORK](Titanium.Geolocation.Android.PROVIDER_NETWORK), or
                 * [PROVIDER_PASSIVE](Titanium.Geolocation.Android.PROVIDER_PASSIVE).
                 */
                name: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationProvider.minUpdateDistance> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationProvider.minUpdateDistance> instead.
                 */
                getMinUpdateDistance(): number;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationProvider.minUpdateTime> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationProvider.minUpdateTime> instead.
                 */
                getMinUpdateTime(): number;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationProvider.name> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationProvider.name> instead.
                 */
                getName(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationProvider.minUpdateDistance> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationProvider.minUpdateDistance> instead.
                 */
                setMinUpdateDistance(minUpdateDistance: number): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationProvider.minUpdateTime> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationProvider.minUpdateTime> instead.
                 */
                setMinUpdateTime(minUpdateTime: number): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationProvider.name> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationProvider.name> instead.
                 */
                setName(name: string): void;

            }
            /**
             * A location rule to filter the results returned by location providers.
             */
            class LocationRule extends Titanium.Proxy {
                /**
                 * Minimum accuracy required for a location update.
                 */
                accuracy: number;

                /**
                 * Controls the freshness of location updates. Do not forward an update
                 * unless it is newer than `maxAge` milliseconds.
                 */
                maxAge: number;

                /**
                 * Controls the frequency of location updates.
                 */
                minAge: number;

                /**
                 * If specified, this rule only applies to updates generated
                 * by the specified provider. If `null`, this rule applies to all updates.
                 */
                name: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationRule.accuracy> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationRule.accuracy> instead.
                 */
                getAccuracy(): number;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationRule.maxAge> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationRule.maxAge> instead.
                 */
                getMaxAge(): number;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationRule.minAge> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationRule.minAge> instead.
                 */
                getMinAge(): number;

                /**
                 * Gets the value of the <Titanium.Geolocation.Android.LocationRule.name> property.
                 * @deprecated Access <Titanium.Geolocation.Android.LocationRule.name> instead.
                 */
                getName(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationRule.accuracy> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationRule.accuracy> instead.
                 */
                setAccuracy(accuracy: number): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationRule.maxAge> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationRule.maxAge> instead.
                 */
                setMaxAge(maxAge: number): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationRule.minAge> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationRule.minAge> instead.
                 */
                setMinAge(minAge: number): void;

                /**
                 * Sets the value of the <Titanium.Geolocation.Android.LocationRule.name> property.
                 * @deprecated Set the value using <Titanium.Geolocation.Android.LocationRule.name> instead.
                 */
                setName(name: string): void;

            }
        }
        /**
         * Module for Android-specific geolocation functionality.
         */
        class Android extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Set to `true` to enable manual configuration of location updates through this module.
             */
            static manualMode: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds and enables the specified location provider, possibly replacing an existing one.
             */
            static addLocationProvider(provider: Titanium.Geolocation.Android.LocationProvider): void;

            /**
             * Adds and enables the specified location rule.
             */
            static addLocationRule(rule: Titanium.Geolocation.Android.LocationRule): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Creates and returns an instance of <Titanium.Geolocation.Android.LocationProvider>.
             */
            static createLocationProvider(parameters?: Dictionary<Titanium.Geolocation.Android.LocationProvider>): Titanium.Geolocation.Android.LocationProvider;

            /**
             * Creates and returns an instance of <Titanium.Geolocation.Android.LocationRule>.
             */
            static createLocationRule(parameters?: Dictionary<Titanium.Geolocation.Android.LocationRule>): Titanium.Geolocation.Android.LocationRule;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Geolocation.Android.apiName> property.
             * @deprecated Access <Titanium.Geolocation.Android.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.Geolocation.Android.bubbleParent> property.
             * @deprecated Access <Titanium.Geolocation.Android.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.Geolocation.Android.lifecycleContainer> property.
             * @deprecated Access <Titanium.Geolocation.Android.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Gets the value of the <Titanium.Geolocation.Android.manualMode> property.
             * @deprecated Access <Titanium.Geolocation.Android.manualMode> instead.
             */
            static getManualMode(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Disables and removes the specified location provider.
             */
            static removeLocationProvider(provider: Titanium.Geolocation.Android.LocationProvider): void;

            /**
             * Disables and removes the specified location rule.
             */
            static removeLocationRule(rule: Titanium.Geolocation.Android.LocationRule): void;

            /**
             * Sets the value of the <Titanium.Geolocation.Android.bubbleParent> property.
             * @deprecated Set the value using <Titanium.Geolocation.Android.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.Geolocation.Android.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.Geolocation.Android.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

            /**
             * Sets the value of the <Titanium.Geolocation.Android.manualMode> property.
             * @deprecated Set the value using <Titanium.Geolocation.Android.manualMode> instead.
             */
            static setManualMode(manualMode: boolean): void;

        }
    }
    /**
     * The top-level Media module.
     */
    namespace Media {
        /**
         * Audio file format 3GPP2.
         */
        const AUDIO_FILEFORMAT_3GP2: number;

        /**
         * Audio file format 3GPP.
         */
        const AUDIO_FILEFORMAT_3GPP: number;

        /**
         * Audio file format Audio Interchange File Format (AIFF).
         */
        const AUDIO_FILEFORMAT_AIFF: number;

        /**
         * Audio file format Adaptive Multi-Rate (AMR).
         */
        const AUDIO_FILEFORMAT_AMR: number;

        /**
         * Audio file format Apple Compressed Audio Format (CAF).
         */
        const AUDIO_FILEFORMAT_CAF: number;

        /**
         * Audio file format MP3.
         */
        const AUDIO_FILEFORMAT_MP3: number;

        /**
         * Audio file format MP4.
         */
        const AUDIO_FILEFORMAT_MP4: number;

        /**
         * Audio file format MP4A.
         */
        const AUDIO_FILEFORMAT_MP4A: number;

        /**
         * Audio file format WAVE.
         */
        const AUDIO_FILEFORMAT_WAVE: number;

        /**
         * Audio format MPEG4 AAC encoding.
         */
        const AUDIO_FORMAT_AAC: number;

        /**
         * Audio format 8-bit [aLaw encoding](https://en.wikipedia.org/wiki/A-law_algorithm).
         */
        const AUDIO_FORMAT_ALAW: number;

        /**
         * Audio format Apple lossless encoding.
         */
        const AUDIO_FORMAT_APPLE_LOSSLESS: number;

        /**
         * Audio format [iLBC encoding](https://en.wikipedia.org/wiki/Internet_Low_Bitrate_Codec).
         */
        const AUDIO_FORMAT_ILBC: number;

        /**
         * Audio format Apple IMA4 encoding.
         */
        const AUDIO_FORMAT_IMA4: number;

        /**
         * Audio format 16-bit, [linear PCM encoding](https://en.wikipedia.org/wiki/Pulse-code_modulation).
         */
        const AUDIO_FORMAT_LINEAR_PCM: number;

        /**
         * Audio format 8-bit [muLaw encoding](https://en.wikipedia.org/wiki/M-law_algorithm).
         */
        const AUDIO_FORMAT_ULAW: number;

        /**
         * Line-type constant for headphones.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_HEADPHONES: never;

        /**
         * Line-type constant for headphones and microphone.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_HEADPHONES_AND_MIC: never;

        /**
         * Line-type constant for headset in/out.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_HEADSET_INOUT: never;

        /**
         * Line-type constant for line-out.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_LINEOUT: never;

        /**
         * Line-type constant for microphone.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_MICROPHONE: never;

        /**
         * Line-type constant indicated mute switch is on.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_MUTED: never;

        /**
         * Line-type constant indicating receiver and microphone.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_RECEIVER_AND_MIC: never;

        /**
         * For long-duration sounds such as rain, car engine noise, and so on.
         */
        const AUDIO_SESSION_CATEGORY_AMBIENT: string;

        /**
         * Session mode for playing recorded music or other sounds that are central to the successful use of your application.
         */
        const AUDIO_SESSION_CATEGORY_PLAYBACK: string;

        /**
         * Session mode for recording (input) and playback (output) of audio, such as for a VOIP (voice over IP) application.
         */
        const AUDIO_SESSION_CATEGORY_PLAY_AND_RECORD: string;

        /**
         * Session mode for recording audio; it silences playback audio.
         */
        const AUDIO_SESSION_CATEGORY_RECORD: string;

        /**
         * Session mode for long-duration sounds such as rain, car engine noise, and so on.
         */
        const AUDIO_SESSION_CATEGORY_SOLO_AMBIENT: string;

        /**
         * For long-duration sounds such as rain, car engine noise, and so on.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_CATEGORY` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SESSION_MODE_AMBIENT: never;

        /**
         * Session mode for playing recorded music or other sounds that are central to the successful use of your application.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_CATEGORY` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SESSION_MODE_PLAYBACK: never;

        /**
         * Session mode for recording (input) and playback (output) of audio, such as for a VOIP (voice over IP) application.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_CATEGORY` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SESSION_MODE_PLAY_AND_RECORD: never;

        /**
         * Session mode for recording audio; it silences playback audio.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_CATEGORY_*` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SESSION_MODE_RECORD: never;

        /**
         * Session mode for long-duration sounds such as rain, car engine noise, and so on.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_CATEGORY` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SESSION_MODE_SOLO_AMBIENT: never;

        /**
         * Constant that specifies audio should output to the default audio route. See <Titanium.Media.setOverrideAudioRoute> for more information.
         */
        const AUDIO_SESSION_OVERRIDE_ROUTE_NONE: number;

        /**
         * Constant that specifies audio should output to the speaker. See <Titanium.Media.setOverrideAudioRoute> for more information.
         */
        const AUDIO_SESSION_OVERRIDE_ROUTE_SPEAKER: number;

        /**
         * Constant for output on a remote Air Play device. This is an output port.
         */
        const AUDIO_SESSION_PORT_AIRPLAY: string;

        /**
         * Constant for output on a Bluetooth A2DP device. This is an output port.
         */
        const AUDIO_SESSION_PORT_BLUETOOTHA2DP: string;

        /**
         * Constant for input or output on a Bluetooth Hands-Free Profile device. This can be both an input and output port.
         */
        const AUDIO_SESSION_PORT_BLUETOOTHHFP: string;

        /**
         * Constant for output on a Bluetooth Low Energy device. This is an output port. This is available on iOS7 and later.
         */
        const AUDIO_SESSION_PORT_BLUETOOTHLE: string;

        /**
         * Constant for built-in microphone on an iOS device. This is an input port.
         */
        const AUDIO_SESSION_PORT_BUILTINMIC: string;

        /**
         * Constant for the speaker you hold to your ear when on a phone call. This is an output port.
         */
        const AUDIO_SESSION_PORT_BUILTINRECEIVER: string;

        /**
         * Constant for built-in speaker on an iOS device. This is an output port.
         */
        const AUDIO_SESSION_PORT_BUILTINSPEAKER: string;

        /**
         * Constant for Input or output via Car Audio. This can be both an input and output port. This is available on iOS7 and later.
         */
        const AUDIO_SESSION_PORT_CARAUDIO: string;

        /**
         * Constant for output via High-Definition Multimedia Interface. This is an output port
         */
        const AUDIO_SESSION_PORT_HDMI: string;

        /**
         * Constant for headphone or headset output. This is an output port.
         */
        const AUDIO_SESSION_PORT_HEADPHONES: string;

        /**
         * Constant for microphone on a wired headset. This is an input port.
         */
        const AUDIO_SESSION_PORT_HEADSETMIC: string;

        /**
         * Constant for line level input on a dock connector. This is an input port.
         */
        const AUDIO_SESSION_PORT_LINEIN: string;

        /**
         * Constant for line level output on a dock connector. This is an output port.
         */
        const AUDIO_SESSION_PORT_LINEOUT: string;

        /**
         * Constant for input or output on a Universal Serial Bus device. This can be both an input and output port.
         */
        const AUDIO_SESSION_PORT_USBAUDIO: string;

        /**
         * Line-type constant for speaker output.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_SPEAKER: never;

        /**
         * Audio data is being buffered from the network.
         */
        const AUDIO_STATE_BUFFERING: number;

        /**
         * Audio playback is being initialized.
         */
        const AUDIO_STATE_INITIALIZED: number;

        /**
         * Playback is paused.
         */
        const AUDIO_STATE_PAUSED: number;

        /**
         * Audio playback is active.
         */
        const AUDIO_STATE_PLAYING: number;

        /**
         * Audio playback is starting.
         */
        const AUDIO_STATE_STARTING: number;

        /**
         * Audio playback is stopped.
         */
        const AUDIO_STATE_STOPPED: number;

        /**
         * Audio playback is stopping.
         */
        const AUDIO_STATE_STOPPING: number;

        /**
         * Player is waiting for audio data from the network.
         */
        const AUDIO_STATE_WAITING_FOR_DATA: number;

        /**
         * Player is waiting for audio data to fill the queue.
         */
        const AUDIO_STATE_WAITING_FOR_QUEUE: number;

        /**
         * Line-type constant indicating that audio is unavailable.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_UNAVAILABLE: never;

        /**
         * Line-type constant indicating that line-type is unknown or not determined.
         * @deprecated Deprecated in favor of the `AUDIO_SESSION_PORT` constants defined in [Titanium.Media](Titanium.Media).
         */
        const AUDIO_UNKNOWN: never;

        /**
         * Constant specifying that app is authorized to use camera. This is available on iOS7 and later.
         */
        const CAMERA_AUTHORIZATION_AUTHORIZED: number;

        /**
         * Constant specifying that app is denied usage of camera. This is available on iOS7 and later.
         */
        const CAMERA_AUTHORIZATION_DENIED: number;

        /**
         * Constant specifying that app is not yet authorized to use camera. This is available on iOS7 and later.
         * @deprecated Use [Titanium.Media.CAMERA_AUTHORIZATION_UNKNOWN](Titanium.Media.CAMERA_AUTHORIZATION_UNKNOWN) instead.
         */
        const CAMERA_AUTHORIZATION_NOT_DETERMINED: never;

        /**
         * Constant specifying that app is restricted from using camera. This is available on iOS7 and later.
         */
        const CAMERA_AUTHORIZATION_RESTRICTED: number;

        /**
         * Constant specifying that app is not yet authorized to use camera. This is available on iOS7 and later.
         */
        const CAMERA_AUTHORIZATION_UNKNOWN: number;

        /**
         * Constant specifying to have the device determine to use the flash or not.
         */
        const CAMERA_FLASH_AUTO: number;

        /**
         * Constant specifying to never fire the flash.
         */
        const CAMERA_FLASH_OFF: number;

        /**
         * Constant specifying to always fire the flash.
         */
        const CAMERA_FLASH_ON: number;

        /**
         * Constant specifying the front camera.
         */
        const CAMERA_FRONT: number;

        /**
         * Constant indicating the rear camera.
         */
        const CAMERA_REAR: number;

        /**
         * Constant for media device busy error.
         */
        const DEVICE_BUSY: number;

        /**
         * Media type constant for live photo media.
         */
        const MEDIA_TYPE_LIVEPHOTO: string;

        /**
         * Media type constant for photo media.
         */
        const MEDIA_TYPE_PHOTO: string;

        /**
         * Media type constant for video media.
         */
        const MEDIA_TYPE_VIDEO: string;

        /**
         * Constant for grouping query results by album.
         */
        const MUSIC_MEDIA_GROUP_ALBUM: number;

        /**
         * Constant for grouping query results by album and artist.
         */
        const MUSIC_MEDIA_GROUP_ALBUM_ARTIST: number;

        /**
         * Constant for grouping query results by artist.
         */
        const MUSIC_MEDIA_GROUP_ARTIST: number;

        /**
         * Constant for grouping query results by composer.
         */
        const MUSIC_MEDIA_GROUP_COMPOSER: number;

        /**
         * Constant for grouping query results by genre.
         */
        const MUSIC_MEDIA_GROUP_GENRE: number;

        /**
         * Constant for grouping query results by playlist.
         */
        const MUSIC_MEDIA_GROUP_PLAYLIST: number;

        /**
         * Constant for grouping query results by podcast title.
         */
        const MUSIC_MEDIA_GROUP_PODCAST_TITLE: number;

        /**
         * Constant for grouping query results by title.
         */
        const MUSIC_MEDIA_GROUP_TITLE: number;

        /**
         * Music library media containing any type of content.
         */
        const MUSIC_MEDIA_TYPE_ALL: number;

        /**
         * Music library media containing any type of audio content.
         */
        const MUSIC_MEDIA_TYPE_ANY_AUDIO: number;

        /**
         * Music library media containing audiobook content.
         */
        const MUSIC_MEDIA_TYPE_AUDIOBOOK: number;

        /**
         * Music library media containing music content.
         */
        const MUSIC_MEDIA_TYPE_MUSIC: number;

        /**
         * Music library media containing podcast content.
         */
        const MUSIC_MEDIA_TYPE_PODCAST: number;

        /**
         * Constant for "Repeat All" setting.
         */
        const MUSIC_PLAYER_REPEAT_ALL: number;

        /**
         * Constant for user's default repeat setting.
         */
        const MUSIC_PLAYER_REPEAT_DEFAULT: number;

        /**
         * Constant for "No Repeat" setting.
         */
        const MUSIC_PLAYER_REPEAT_NONE: number;

        /**
         * Constant for "Repeat one item" setting.
         */
        const MUSIC_PLAYER_REPEAT_ONE: number;

        /**
         * Constant for shuffling complete albums setting.
         */
        const MUSIC_PLAYER_SHUFFLE_ALBUMS: number;

        /**
         * Constant for user's default shuffle setting.
         */
        const MUSIC_PLAYER_SHUFFLE_DEFAULT: number;

        /**
         * Constant for "no shuffle" setting.
         */
        const MUSIC_PLAYER_SHUFFLE_NONE: number;

        /**
         * Constant for shuffling songs setting.
         */
        const MUSIC_PLAYER_SHUFFLE_SONGS: number;

        /**
         * Constant for interrupted state.
         */
        const MUSIC_PLAYER_STATE_INTERRUPTED: number;

        /**
         * Constant for paused state.
         */
        const MUSIC_PLAYER_STATE_PAUSED: number;

        /**
         * Constant for playing state.
         */
        const MUSIC_PLAYER_STATE_PLAYING: number;

        /**
         * Constant for backward seek state.
         */
        const MUSIC_PLAYER_STATE_SEEK_BACKWARD: number;

        /**
         * Constant for forward seek state.
         */
        const MUSIC_PLAYER_STATE_SEEK_FORWARD: number;

        /**
         * Constant for stopped state.
         */
        const MUSIC_PLAYER_STATE_STOPPED: number;

        /**
         * Constant for media no camera error.
         */
        const NO_CAMERA: number;

        /**
         * Constant for media no video error.
         */
        const NO_VIDEO: number;

        /**
         * Media type constant for high-quality video recording.
         */
        const QUALITY_HIGH: number;

        /**
         * Media type constant for low-quality video recording.
         */
        const QUALITY_LOW: number;

        /**
         * Media type constant for medium-quality video recording.
         */
        const QUALITY_MEDIUM: number;

        /**
         * Constant for unknown media error.
         */
        const UNKNOWN_ERROR: number;

        /**
         * Constant for default video controls.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_CONTROL_DEFAULT: never;

        /**
         * Constant for video controls for an embedded view.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_CONTROL_EMBEDDED: never;

        /**
         * Constant for fullscreen video controls.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_CONTROL_FULLSCREEN: never;

        /**
         * Constant for video controls hidden.
         */
        const VIDEO_CONTROL_HIDDEN: number;

        /**
         * Constant for no video controls.
         */
        const VIDEO_CONTROL_NONE: number;

        /**
         * Constant for video controls volume only.
         * @deprecated Use [Titanium.Media.VIDEO_CONTROL_EMBEDDED](Titanium.Media.VIDEO_CONTROL_EMBEDDED) instead.
         */
        const VIDEO_CONTROL_VOLUME_ONLY: never;

        /**
         * Video playback ended normally.
         */
        const VIDEO_FINISH_REASON_PLAYBACK_ENDED: number;

        /**
         * Video playback ended abnormally.
         */
        const VIDEO_FINISH_REASON_PLAYBACK_ERROR: number;

        /**
         * Video playback ended by user action (such as clicking the `Done` button).
         */
        const VIDEO_FINISH_REASON_USER_EXITED: number;

        /**
         * Indicates that the player can no longer play media items because of an error.
         */
        const VIDEO_LOAD_STATE_FAILED: number;

        /**
         * Current media is playable.
         */
        const VIDEO_LOAD_STATE_PLAYABLE: number;

        /**
         * Playback will be automatically started in this state when `autoplay` is true.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_LOAD_STATE_PLAYTHROUGH_OK: never;

        /**
         * Playback will be automatically paused in this state, if started.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_LOAD_STATE_STALLED: never;

        /**
         * Current load state is not known.
         */
        const VIDEO_LOAD_STATE_UNKNOWN: number;

        /**
         * A audio type of media in the movie returned by [Titanium.Media.VideoPlayer](Titanium.Media.VideoPlayer) `mediaTypes` property.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_MEDIA_TYPE_AUDIO: never;

        /**
         * An unknown type of media in the movie returned by [Titanium.Media.VideoPlayer](Titanium.Media.VideoPlayer) `mediaTypes` property.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_MEDIA_TYPE_NONE: never;

        /**
         * A video type of media in the movie returned by [Titanium.Media.VideoPlayer](Titanium.Media.VideoPlayer) `mediaTypes` property.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_MEDIA_TYPE_VIDEO: never;

        /**
         * Video playback has been interrupted.
         */
        const VIDEO_PLAYBACK_STATE_INTERRUPTED: number;

        /**
         * Video playback is paused.
         */
        const VIDEO_PLAYBACK_STATE_PAUSED: number;

        /**
         * Video is being played.
         */
        const VIDEO_PLAYBACK_STATE_PLAYING: number;

        /**
         * Video playback is rewinding.
         * @deprecated This constant has been removed on iOS by using the official Apple AVPlayer that does not expose this functionality so far.
         */
        const VIDEO_PLAYBACK_STATE_SEEKING_BACKWARD: never;

        /**
         * Video playback is seeking forward.
         * @deprecated This constant has been removed on iOS by using the official Apple AVPlayer that does not expose this functionality so far.
         */
        const VIDEO_PLAYBACK_STATE_SEEKING_FORWARD: never;

        /**
         * Video playback is stopped.
         */
        const VIDEO_PLAYBACK_STATE_STOPPED: number;

        /**
         * Constant for disabling repeat on video playback.
         */
        const VIDEO_REPEAT_MODE_NONE: number;

        /**
         * Constant for repeating one video (i.e., the one video will repeat constantly) during playback.
         */
        const VIDEO_REPEAT_MODE_ONE: number;

        /**
         * Scale video to fill the screen, clipping edges if necessary.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SCALING_ASPECT_FILL: never;

        /**
         * Scale video to fit the screen, letterboxing if necessary.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SCALING_ASPECT_FIT: never;

        /**
         * Video is scaled until both dimensions fit the screen exactly, stretching if necessary.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SCALING_MODE_FILL: never;

        /**
         * Video scaling is disabled.
         * @deprecated This property has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SCALING_NONE: never;

        /**
         * Specifies that the video should be stretched to fill the bounds of layer.
         */
        const VIDEO_SCALING_RESIZE: string;

        /**
         * Specifies that the player should preserve the aspect ratio of video and fit the video within the bounds of layer.
         */
        const VIDEO_SCALING_RESIZE_ASPECT: string;

        /**
         * Specifies that the player should preserve the aspect ratio of video and fill the bounds of layer.
         */
        const VIDEO_SCALING_RESIZE_ASPECT_FILL: string;

        /**
         * Video source type is a file.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SOURCE_TYPE_FILE: never;

        /**
         * Video source type is a remote stream.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SOURCE_TYPE_STREAMING: never;

        /**
         * Video source type is unknown.
         * @deprecated This property has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
         */
        const VIDEO_SOURCE_TYPE_UNKNOWN: never;

        /**
         * Use the closest sync (or key) frame at given the time.
         */
        const VIDEO_TIME_OPTION_CLOSEST_SYNC: number;

        /**
         * Use the exact time.
         */
        const VIDEO_TIME_OPTION_EXACT: number;

        /**
         * Use the closest keyframe in the time.
         */
        const VIDEO_TIME_OPTION_NEAREST_KEYFRAME: number;

        /**
         * Use the sync (or key) frame located right after or at given the time.
         */
        const VIDEO_TIME_OPTION_NEXT_SYNC: number;

        /**
         * Use the sync (or key) frame located right before or at given the time.
         */
        const VIDEO_TIME_OPTION_PREVIOUS_SYNC: number;

        /**
         * Android-specific media-related functionality.
         */
        class Android extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.Android.apiName> property.
             * @deprecated Access <Titanium.Media.Android.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.Media.Android.bubbleParent> property.
             * @deprecated Access <Titanium.Media.Android.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.Media.Android.lifecycleContainer> property.
             * @deprecated Access <Titanium.Media.Android.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Scans newly created or downloaded media files to make them available to other
             * Android media providers, such as the Gallery.
             */
            static scanMediaFiles(paths: ReadonlyArray<string>, mimeTypes: ReadonlyArray<string>, callback: (param0: MediaScannerResponse) => void): void;

            /**
             * Sets the value of the <Titanium.Media.Android.bubbleParent> property.
             * @deprecated Set the value using <Titanium.Media.Android.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.Android.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.Media.Android.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

            /**
             * Set the system homescreen wallpaper.
             */
            static setSystemWallpaper(image: Titanium.Blob, scale: boolean): void;

        }
        /**
         * Base event for class Titanium.Media.AudioPlayer
         */
        interface AudioPlayerBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Media.AudioPlayer;

        }
        /**
         * Fired when the state of the playback changes.
         */
        interface AudioPlayer_change_Event extends AudioPlayerBaseEvent {
            /**
             * Text description of the state of playback.
             */
            description: number;

            /**
             * Current state of playback.
             */
            state: number;

        }
        /**
         * Fired when the audio has finished playing.
         */
        interface AudioPlayer_complete_Event extends AudioPlayerBaseEvent {
            /**
             * Error code.
             * Error code will be 0 if `success` is `true`, nonzero otherwise. If the error
             * was generated by the operating system, that system's error value is used.
             * Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. Will be undefined if `success` is `true`.
             */
            error: string;

            /**
             * Indicates if the sound was played successfully.
             * Returns `true` if request succeeded, `false` otherwise.
             */
            success: boolean;

        }
        /**
         * Fired when the timed metadata was encountered most recently within the media as it plays.
         */
        interface AudioPlayer_metadata_Event extends AudioPlayerBaseEvent {
            /**
             * An array of metadata items containing relevant information about the current media item.
             */
            items: TiMetadataItemType[];

        }
        /**
         * Fired when there's an error.
         */
        interface AudioPlayer_error_Event extends AudioPlayerBaseEvent {
            /**
             * Error code. Different between android and iOS.
             */
            code: number;

            /**
             * Error message.
             */
            error: string;

        }
        /**
         * Fired once per second with the current progress during playback.
         */
        interface AudioPlayer_progress_Event extends AudioPlayerBaseEvent {
            /**
             * Current progress, in milliseconds.
             */
            progress: number;

        }
        /**
         * Fired once the [seekToTime](Titanium.Media.AudioPlayer.seek) method completes.
         */
        interface AudioPlayer_seek_Event extends AudioPlayerBaseEvent {
            /**
             * The event for any prior seek request that is still in process will be invoked
             * immediately with the `finished` parameter set to `false`.
             * If the new request completes without being interrupted by another seek
             * request or by any other operation this event will be invoked with
             * the `finished` parameter set to `true`.
             */
            finished: boolean;

        }
        interface AudioPlayerEventMap extends ProxyEventMap {
            change: AudioPlayer_change_Event;

            complete: AudioPlayer_complete_Event;

            error: AudioPlayer_error_Event;

            metadata: AudioPlayer_metadata_Event;

            progress: AudioPlayer_progress_Event;

            seek: AudioPlayer_seek_Event;

        }
        /**
         * An audio player object used for streaming audio to the device, and low-level control of the audio playback.
         */
        class AudioPlayer extends Titanium.Proxy {
            /**
             * Used to identify the volume of audio streams for alarms.
             */
            readonly AUDIO_TYPE_ALARM: number;

            /**
             * Used to identify the volume of audio streams for media playback.
             */
            readonly AUDIO_TYPE_MEDIA: number;

            /**
             * Used to identify the volume of audio streams for notifications.
             */
            readonly AUDIO_TYPE_NOTIFICATION: number;

            /**
             * Used to identify the volume of audio streams for the phone ring.
             */
            readonly AUDIO_TYPE_RING: number;

            /**
             * Used to identify the volume of audio streams for DTMF tones or beeps.
             */
            readonly AUDIO_TYPE_SIGNALLING: number;

            /**
             * Used to identify the volume of audio streams for voice calls.
             */
            readonly AUDIO_TYPE_VOICE: number;

            /**
             * Audio data is being buffered from the network.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_BUFFERING](Titanium.Media.AUDIO_STATE_BUFFERING) instead.
             */
            readonly STATE_BUFFERING: number;

            /**
             * Audio playback is being initialized.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_INITIALIZED](Titanium.Media.AUDIO_STATE_INITIALIZED) instead.
             */
            readonly STATE_INITIALIZED: number;

            /**
             * Playback is paused.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_PAUSED](Titanium.Media.AUDIO_STATE_PAUSED) instead.
             */
            readonly STATE_PAUSED: number;

            /**
             * Audio playback is active.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_PLAYING](Titanium.Media.AUDIO_STATE_PLAYING) instead.
             */
            readonly STATE_PLAYING: number;

            /**
             * Audio playback is starting.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_STARTING](Titanium.Media.AUDIO_STATE_STARTING) instead.
             */
            readonly STATE_STARTING: number;

            /**
             * Audio playback is stopped.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_STOPPED](Titanium.Media.AUDIO_STATE_STOPPED) instead.
             */
            readonly STATE_STOPPED: number;

            /**
             * Audio playback is stopping.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_STOPPING](Titanium.Media.AUDIO_STATE_STOPPING) instead.
             */
            readonly STATE_STOPPING: number;

            /**
             * Player is waiting for audio data from the network.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_WAITING_FOR_DATA](Titanium.Media.AUDIO_STATE_WAITING_FOR_DATA) instead.
             */
            readonly STATE_WAITING_FOR_DATA: number;

            /**
             * Player is waiting for audio data to fill the queue.
             * @deprecated Use [Titanium.Media.AUDIO_STATE_WAITING_FOR_QUEUE](Titanium.Media.AUDIO_STATE_WAITING_FOR_QUEUE) instead.
             */
            readonly STATE_WAITING_FOR_QUEUE: number;

            /**
             * Boolean to indicate if audio should continue playing even if the associated
             * Android [Activity](Titanium.Android.Activity) is paused.
             */
            allowBackground: boolean;

            /**
             * Indicates whether the player allows switching to "external playback" mode.
             */
            allowsExternalPlayback: boolean;

            /**
             * Focuses on the current audio player and stops other audio playing.
             */
            audioFocus: boolean;

            /**
             * Changes the audio-stream-type.
             */
            audioType: number;

            /**
             * Bit rate of the current playback stream.
             */
            bitRate: number;

            /**
             * Size of the buffer used for streaming, in milliseconds.
             */
            bufferSize: number;

            /**
             * Estimated duration in milliseconds of the file being played.
             */
            readonly duration: number;

            /**
             * Indicates whether the player is currently playing video in "external playback" mode.
             */
            readonly externalPlaybackActive: boolean;

            /**
             * Boolean indicating if the player is idle.
             */
            readonly idle: boolean;

            /**
             * Indicates whether or not audio output of the player is muted.
             */
            muted: boolean;

            /**
             * Boolean indicating if audio playback is paused.
             */
            paused: boolean;

            /**
             * Boolean indicating if audio is currently playing.
             */
            readonly playing: boolean;

            /**
             * Current playback progress, in milliseconds.
             */
            readonly progress: number;

            /**
             * Indicates the desired rate of playback; 0.0 means "paused", 1.0 indicates a
             * desire to play at the natural rate of the current item. In addition, 2.0
             * would mean that the audio plays twice as fast.
             */
            rate: number;

            /**
             * Current state of playback, specified using one of the `STATE` constants defined on this object.
             */
            readonly state: number;

            /**
             * Current playback position of the audio.
             */
            time: number;

            /**
             * URL for the audio stream.
             */
            url: string;

            /**
             * Volume of the audio, from 0.0 (muted) to 1.0 (loudest).
             */
            volume: number;

            /**
             * Boolean indicating if the playback is waiting for audio data from the network.
             */
            readonly waiting: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof AudioPlayerEventMap>(name: K, callback: (this: Titanium.Media.AudioPlayer, event: AudioPlayerEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof AudioPlayerEventMap>(name: K, event?: AudioPlayerEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.allowBackground> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.allowBackground> instead.
             */
            getAllowBackground(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.allowsExternalPlayback> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.allowsExternalPlayback> instead.
             */
            getAllowsExternalPlayback(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.audioFocus> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.audioFocus> instead.
             */
            getAudioFocus(): boolean;

            /**
             * Returns the audio session id.
             */
            getAudioSessionId(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.audioType> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.audioType> instead.
             */
            getAudioType(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.bitRate> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.bitRate> instead.
             */
            getBitRate(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.bufferSize> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.bufferSize> instead.
             */
            getBufferSize(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.duration> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.externalPlaybackActive> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.externalPlaybackActive> instead.
             */
            getExternalPlaybackActive(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.idle> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.idle> instead.
             */
            getIdle(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.muted> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.muted> instead.
             */
            getMuted(): boolean;

            /**
             * Returns the value of the [paused](Titanium.Media.AudioPlayer.paused) property.
             */
            getPaused(): boolean;

            /**
             * Returns the value of the [playing](Titanium.Media.AudioPlayer.playing) property.
             */
            getPlaying(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.progress> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.progress> instead.
             */
            getProgress(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.rate> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.rate> instead.
             */
            getRate(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.state> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.state> instead.
             */
            getState(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.time> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.time> instead.
             */
            getTime(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.url> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.url> instead.
             */
            getUrl(): string;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.volume> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.volume> instead.
             */
            getVolume(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioPlayer.waiting> property.
             * @deprecated Access <Titanium.Media.AudioPlayer.waiting> instead.
             */
            getWaiting(): boolean;

            /**
             * Returns the value of the [paused](Titanium.Media.AudioPlayer.paused) property.
             */
            isPaused(): boolean;

            /**
             * Returns the value of the [playing](Titanium.Media.AudioPlayer.playing) property.
             */
            isPlaying(): boolean;

            /**
             * Pauses audio playback.
             */
            pause(): void;

            /**
             * Starts or resumes audio playback.
             * @deprecated Use the cross-platform API [Titanium.Media.AudioPlayer.start](Titanium.Media.AudioPlayer.start) instead.
             */
            play(): void;

            /**
             * Stops buffering audio data and releases audio resources.
             */
            release(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof AudioPlayerEventMap>(name: K, callback: (this: Titanium.Media.AudioPlayer, event: AudioPlayerEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Restarts (stops and stars) audio playback.
             */
            restart(): void;

            /**
             * Moves the playback cursor and invokes the specified block when the seek
             * operation has either been completed or been interrupted.
             */
            seekToTime(time: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.allowBackground> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.allowBackground> instead.
             */
            setAllowBackground(allowBackground: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.allowsExternalPlayback> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.allowsExternalPlayback> instead.
             */
            setAllowsExternalPlayback(allowsExternalPlayback: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.audioFocus> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.audioFocus> instead.
             */
            setAudioFocus(audioFocus: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.audioType> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.audioType> instead.
             */
            setAudioType(audioType: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.bitRate> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.bitRate> instead.
             */
            setBitRate(bitRate: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.bufferSize> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.bufferSize> instead.
             */
            setBufferSize(bufferSize: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.muted> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.muted> instead.
             */
            setMuted(muted: boolean): void;

            /**
             * Sets the value of the [paused](Titanium.Media.AudioPlayer.paused) property.
             * @deprecated Use the cross-platform API [Titanium.Media.AudioPlayer.pause](Titanium.Media.AudioPlayer.pause) instead.
             */
            setPaused(paused: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.rate> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.rate> instead.
             */
            setRate(rate: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.time> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.time> instead.
             */
            setTime(time: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.url> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.url> instead.
             */
            setUrl(url: string): void;

            /**
             * Sets the value of the <Titanium.Media.AudioPlayer.volume> property.
             * @deprecated Set the value using <Titanium.Media.AudioPlayer.volume> instead.
             */
            setVolume(volume: number): void;

            /**
             * Starts or resumes audio playback.
             */
            start(): void;

            /**
             * Converts a [state](Titanium.Media.AudioPlayer.state) value into a text description
             * suitable for display.
             */
            stateDescription(state: number): string;

            /**
             * Stops audio playback.
             */
            stop(): void;

        }
        /**
         * An audio recorder object used for recording audio from the device microphone.
         */
        class AudioRecorder extends Titanium.Proxy {
            /**
             * Audio compression to be used for the recording.
             */
            compression: number;

            /**
             * Audio format to be used for the recording.
             */
            format: number;

            /**
             * Indicates if the audio recorder is paused.
             */
            readonly paused: boolean;

            /**
             * Indicates if the audio recorder is recording.
             */
            readonly recording: boolean;

            /**
             * Indicates if the audio recorder is stopped.
             */
            readonly stopped: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.AudioRecorder.compression> property.
             * @deprecated Access <Titanium.Media.AudioRecorder.compression> instead.
             */
            getCompression(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioRecorder.format> property.
             * @deprecated Access <Titanium.Media.AudioRecorder.format> instead.
             */
            getFormat(): number;

            /**
             * Gets the value of the <Titanium.Media.AudioRecorder.paused> property.
             * @deprecated Access <Titanium.Media.AudioRecorder.paused> instead.
             */
            getPaused(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioRecorder.recording> property.
             * @deprecated Access <Titanium.Media.AudioRecorder.recording> instead.
             */
            getRecording(): boolean;

            /**
             * Gets the value of the <Titanium.Media.AudioRecorder.stopped> property.
             * @deprecated Access <Titanium.Media.AudioRecorder.stopped> instead.
             */
            getStopped(): boolean;

            /**
             * Pauses the current audio recording.
             */
            pause(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Resumes a paused recording.
             */
            resume(): void;

            /**
             * Sets the value of the <Titanium.Media.AudioRecorder.compression> property.
             * @deprecated Set the value using <Titanium.Media.AudioRecorder.compression> instead.
             */
            setCompression(compression: number): void;

            /**
             * Sets the value of the <Titanium.Media.AudioRecorder.format> property.
             * @deprecated Set the value using <Titanium.Media.AudioRecorder.format> instead.
             */
            setFormat(format: number): void;

            /**
             * Starts an audio recording.
             */
            start(): void;

            /**
             * Stops the current audio recording and returns the recorded audio file.
             */
            stop(): Titanium.Filesystem.File;

        }
        /**
         * A representation of a media item returned by [openMusicLibrary](Titanium.Media.openMusicLibrary) or [queryMusicLibrary](Titanium.Media.queryMusicLibrary).
         */
        class Item extends Titanium.Proxy {
            /**
             * Artist credited for the album containing this item.
             */
            readonly albumArtist: string;

            /**
             * The persistent identifier for an album artist.
             */
            readonly albumArtistPersistentID: number;

            /**
             * The key for the persistent identifier for an album.
             */
            readonly albumPersistentID: number;

            /**
             * Title of the album containing this item.
             */
            readonly albumTitle: string;

            /**
             * Number of tracks for the album containing this item.
             */
            readonly albumTrackCount: number;

            /**
             * Track number for this item.
             */
            readonly albumTrackNumber: number;

            /**
             * Artist credited for this item.
             */
            readonly artist: string;

            /**
             * Image for the item's artwork as a `Blob` object,  or `null` if no artwork is
             * available.
             */
            readonly artwork: Titanium.Blob;

            /**
             * A URL pointing to the media item.
             */
            readonly assetURL: string;

            /**
             * The number of musical beats per minute for the media item, corresponding
             * to the "BPM" field in the Info tab in the "Get Info" dialog in iTunes.
             */
            readonly beatsPerMinute: number;

            /**
             * The user's place in the media item the most recent time it was played.
             */
            readonly bookmarkTime: string;

            /**
             * Textual information about the media item, corresponding to the "Comments"
             * field in in the Info tab in the Get Info dialog in iTunes.
             */
            readonly comments: string;

            /**
             * Composer of this item.
             */
            readonly composer: string;

            /**
             * Date when the item was added to the music library.
             */
            readonly dateAdded: Date;

            /**
             * Total number of discs for the album containing this item.
             */
            readonly discCount: number;

            /**
             * Disc number for this item in the album.
             */
            readonly discNumber: number;

            /**
             * Genre of this item.
             */
            readonly genre: string;

            /**
             * The persistent identifier for a genre.
             */
            readonly genrePersistentID: number;

            /**
             * True if the item represents a protected asset.
             */
            readonly hasProtectedAsset: boolean;

            /**
             * True if the media item is an iCloud item.
             */
            readonly isCloudItem: boolean;

            /**
             * True if this item is part of a compilation album.
             */
            readonly isCompilation: boolean;

            /**
             * True if this item is marked as "Explicit".
             */
            readonly isExplicit: boolean;

            /**
             * The most recent calendar date on which the user played the media item.
             */
            readonly lastPlayedDate: Date;

            /**
             * Lyrics for this item.
             */
            readonly lyrics: string;

            /**
             * The type of the media.
             */
            readonly mediaType: number;

            /**
             * The key for the persistent identifier for the media item.
             */
            readonly persistentID: string;

            /**
             * Number of times the item has been played.
             */
            readonly playCount: number;

            /**
             * Length (in seconds) of this item.
             */
            readonly playbackDuration: number;

            /**
             * Used to enqueue store tracks by their ID.
             */
            readonly playbackStoreID: number;

            /**
             * The persistent identifier for an audio podcast.
             */
            readonly podcastPersistentID: number;

            /**
             * Title of a podcast item.
             */
            readonly podcastTitle: string;

            /**
             * Rating for this item.
             */
            readonly rating: number;

            /**
             * Date when this this item was released.
             */
            readonly releaseDate: Date;

            /**
             * Number of times this item has been skipped.
             */
            readonly skipCount: number;

            /**
             * Title of this item.
             */
            readonly title: string;

            /**
             * Corresponds to the "Grouping" field in the Info tab in the "Get Info"
             * dialog in iTunes.
             */
            readonly userGrouping: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.Item.albumArtist> property.
             * @deprecated Access <Titanium.Media.Item.albumArtist> instead.
             */
            getAlbumArtist(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.albumArtistPersistentID> property.
             * @deprecated Access <Titanium.Media.Item.albumArtistPersistentID> instead.
             */
            getAlbumArtistPersistentID(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.albumPersistentID> property.
             * @deprecated Access <Titanium.Media.Item.albumPersistentID> instead.
             */
            getAlbumPersistentID(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.albumTitle> property.
             * @deprecated Access <Titanium.Media.Item.albumTitle> instead.
             */
            getAlbumTitle(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.albumTrackCount> property.
             * @deprecated Access <Titanium.Media.Item.albumTrackCount> instead.
             */
            getAlbumTrackCount(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.albumTrackNumber> property.
             * @deprecated Access <Titanium.Media.Item.albumTrackNumber> instead.
             */
            getAlbumTrackNumber(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.artist> property.
             * @deprecated Access <Titanium.Media.Item.artist> instead.
             */
            getArtist(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.artwork> property.
             * @deprecated Access <Titanium.Media.Item.artwork> instead.
             */
            getArtwork(): Titanium.Blob;

            /**
             * Gets the value of the <Titanium.Media.Item.assetURL> property.
             * @deprecated Access <Titanium.Media.Item.assetURL> instead.
             */
            getAssetURL(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.beatsPerMinute> property.
             * @deprecated Access <Titanium.Media.Item.beatsPerMinute> instead.
             */
            getBeatsPerMinute(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.bookmarkTime> property.
             * @deprecated Access <Titanium.Media.Item.bookmarkTime> instead.
             */
            getBookmarkTime(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.comments> property.
             * @deprecated Access <Titanium.Media.Item.comments> instead.
             */
            getComments(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.composer> property.
             * @deprecated Access <Titanium.Media.Item.composer> instead.
             */
            getComposer(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.dateAdded> property.
             * @deprecated Access <Titanium.Media.Item.dateAdded> instead.
             */
            getDateAdded(): Date;

            /**
             * Gets the value of the <Titanium.Media.Item.discCount> property.
             * @deprecated Access <Titanium.Media.Item.discCount> instead.
             */
            getDiscCount(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.discNumber> property.
             * @deprecated Access <Titanium.Media.Item.discNumber> instead.
             */
            getDiscNumber(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.genre> property.
             * @deprecated Access <Titanium.Media.Item.genre> instead.
             */
            getGenre(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.genrePersistentID> property.
             * @deprecated Access <Titanium.Media.Item.genrePersistentID> instead.
             */
            getGenrePersistentID(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.hasProtectedAsset> property.
             * @deprecated Access <Titanium.Media.Item.hasProtectedAsset> instead.
             */
            getHasProtectedAsset(): boolean;

            /**
             * Gets the value of the <Titanium.Media.Item.isCloudItem> property.
             * @deprecated Access <Titanium.Media.Item.isCloudItem> instead.
             */
            getIsCloudItem(): boolean;

            /**
             * Gets the value of the <Titanium.Media.Item.isCompilation> property.
             * @deprecated Access <Titanium.Media.Item.isCompilation> instead.
             */
            getIsCompilation(): boolean;

            /**
             * Gets the value of the <Titanium.Media.Item.isExplicit> property.
             * @deprecated Access <Titanium.Media.Item.isExplicit> instead.
             */
            getIsExplicit(): boolean;

            /**
             * Gets the value of the <Titanium.Media.Item.lastPlayedDate> property.
             * @deprecated Access <Titanium.Media.Item.lastPlayedDate> instead.
             */
            getLastPlayedDate(): Date;

            /**
             * Gets the value of the <Titanium.Media.Item.lyrics> property.
             * @deprecated Access <Titanium.Media.Item.lyrics> instead.
             */
            getLyrics(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.mediaType> property.
             * @deprecated Access <Titanium.Media.Item.mediaType> instead.
             */
            getMediaType(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.persistentID> property.
             * @deprecated Access <Titanium.Media.Item.persistentID> instead.
             */
            getPersistentID(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.playCount> property.
             * @deprecated Access <Titanium.Media.Item.playCount> instead.
             */
            getPlayCount(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.playbackDuration> property.
             * @deprecated Access <Titanium.Media.Item.playbackDuration> instead.
             */
            getPlaybackDuration(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.playbackStoreID> property.
             * @deprecated Access <Titanium.Media.Item.playbackStoreID> instead.
             */
            getPlaybackStoreID(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.podcastPersistentID> property.
             * @deprecated Access <Titanium.Media.Item.podcastPersistentID> instead.
             */
            getPodcastPersistentID(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.podcastTitle> property.
             * @deprecated Access <Titanium.Media.Item.podcastTitle> instead.
             */
            getPodcastTitle(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.rating> property.
             * @deprecated Access <Titanium.Media.Item.rating> instead.
             */
            getRating(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.releaseDate> property.
             * @deprecated Access <Titanium.Media.Item.releaseDate> instead.
             */
            getReleaseDate(): Date;

            /**
             * Gets the value of the <Titanium.Media.Item.skipCount> property.
             * @deprecated Access <Titanium.Media.Item.skipCount> instead.
             */
            getSkipCount(): number;

            /**
             * Gets the value of the <Titanium.Media.Item.title> property.
             * @deprecated Access <Titanium.Media.Item.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.Media.Item.userGrouping> property.
             * @deprecated Access <Titanium.Media.Item.userGrouping> instead.
             */
            getUserGrouping(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * Base event for class Titanium.Media.MusicPlayer
         */
        interface MusicPlayerBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Media.MusicPlayer;

        }
        /**
         * Fired when the currently playing media item changes.
         */
        interface MusicPlayer_playingchange_Event extends MusicPlayerBaseEvent {
        }
        /**
         * Fired when the music player's playback state changes.
         */
        interface MusicPlayer_statechange_Event extends MusicPlayerBaseEvent {
        }
        interface MusicPlayerEventMap extends ProxyEventMap {
            playingchange: MusicPlayer_playingchange_Event;

            statechange: MusicPlayer_statechange_Event;

        }
        /**
         * This object represents a music controller.
         */
        class MusicPlayer extends Titanium.Proxy {
            /**
             * Current point in song playback, in seconds.
             */
            currentPlaybackTime: number;

            /**
             * An `Item` object representing the currently playing media item.
             */
            readonly nowPlaying: Titanium.Media.Item;

            /**
             * Playback state.
             */
            readonly playbackState: number;

            /**
             * Repeat setting.
             */
            repeatMode: number;

            /**
             * Shuffle setting.
             */
            shuffleMode: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof MusicPlayerEventMap>(name: K, callback: (this: Titanium.Media.MusicPlayer, event: MusicPlayerEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof MusicPlayerEventMap>(name: K, event?: MusicPlayerEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.MusicPlayer.currentPlaybackTime> property.
             * @deprecated Access <Titanium.Media.MusicPlayer.currentPlaybackTime> instead.
             */
            getCurrentPlaybackTime(): number;

            /**
             * Gets the value of the <Titanium.Media.MusicPlayer.nowPlaying> property.
             * @deprecated Access <Titanium.Media.MusicPlayer.nowPlaying> instead.
             */
            getNowPlaying(): Titanium.Media.Item;

            /**
             * Gets the value of the <Titanium.Media.MusicPlayer.playbackState> property.
             * @deprecated Access <Titanium.Media.MusicPlayer.playbackState> instead.
             */
            getPlaybackState(): number;

            /**
             * Gets the value of the <Titanium.Media.MusicPlayer.repeatMode> property.
             * @deprecated Access <Titanium.Media.MusicPlayer.repeatMode> instead.
             */
            getRepeatMode(): number;

            /**
             * Gets the value of the <Titanium.Media.MusicPlayer.shuffleMode> property.
             * @deprecated Access <Titanium.Media.MusicPlayer.shuffleMode> instead.
             */
            getShuffleMode(): number;

            /**
             * Pauses playback of the current media item.
             */
            pause(): void;

            /**
             * Begins playback of the current media item.
             */
            play(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof MusicPlayerEventMap>(name: K, callback: (this: Titanium.Media.MusicPlayer, event: MusicPlayerEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Begins seeking backward in the currently playing media.
             */
            seekBackward(): void;

            /**
             * Begins seeking forward in the currently playing media item.
             */
            seekForward(): void;

            /**
             * Sets the value of the <Titanium.Media.MusicPlayer.currentPlaybackTime> property.
             * @deprecated Set the value using <Titanium.Media.MusicPlayer.currentPlaybackTime> instead.
             */
            setCurrentPlaybackTime(currentPlaybackTime: number): void;

            /**
             * Sets the media queue.
             */
            setQueue(queue: Titanium.Media.Item | Titanium.Media.Item[] | string): void;

            /**
             * Sets the value of the <Titanium.Media.MusicPlayer.repeatMode> property.
             * @deprecated Set the value using <Titanium.Media.MusicPlayer.repeatMode> instead.
             */
            setRepeatMode(repeatMode: number): void;

            /**
             * Sets the value of the <Titanium.Media.MusicPlayer.shuffleMode> property.
             * @deprecated Set the value using <Titanium.Media.MusicPlayer.shuffleMode> instead.
             */
            setShuffleMode(shuffleMode: number): void;

            /**
             * Skips to the beginning of the currently playing media item.
             */
            skipToBeginning(): void;

            /**
             * Skips to the next media item in the queue.
             */
            skipToNext(): void;

            /**
             * Skips to the previous media item in the queue.
             */
            skipToPrevious(): void;

            /**
             * Stops playback of the current media queue.
             */
            stop(): void;

            /**
             * Ends a seek operation and returns to the previous playback state.
             * See also: [seekForward](Titanium.Media.MusicPlayer.seekForward) and
             * [seekBackward](Titanium.Media.MusicPlayer.seekBackward).
             */
            stopSeeking(): void;

        }
        /**
         * Base event for class Titanium.Media.Sound
         */
        interface SoundBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Media.Sound;

        }
        /**
         * Fired when the state of the playback changes.
         */
        interface Sound_change_Event extends SoundBaseEvent {
            /**
             * Text description of the state of playback.
             */
            description: string;

            /**
             * Current state of playback.
             */
            state: number;

        }
        /**
         * Fired when the audio has finished playing.
         */
        interface Sound_complete_Event extends SoundBaseEvent {
            /**
             * Error code.
             * Error code will be 0 if `success` is `true`, nonzero otherwise. If the error
             * was generated by the operating system, that system's error value is used.
             * Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. Will be undefined if `success` is `true`.
             */
            error: string;

            /**
             * Indicates if the sound was played successfully.
             * Returns `true` if request succeeded, `false` otherwise.
             */
            success: boolean;

        }
        /**
         * Fired when an error occurs while playing the audio.
         */
        interface Sound_error_Event extends SoundBaseEvent {
            /**
             * Error code.
             * If the error was generated by the operating system, that system's error value
             * is used. Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. May be undefined.
             */
            error: string;

            /**
             * Error message. Use the error property instead.
             * @deprecated
             */
            message: string;

            /**
             * Indicates a successful operation. Returns `false`.
             */
            success: boolean;

        }
        /**
         * Fired  when audio playback is interrupted by the device.
         */
        interface Sound_interrupted_Event extends SoundBaseEvent {
        }
        /**
         * Fired when audio playback is resumed after an interruption.
         */
        interface Sound_resume_Event extends SoundBaseEvent {
            /**
             * Indicates if the resume was from an interruption.
             */
            interruption: boolean;

        }
        interface SoundEventMap extends ProxyEventMap {
            change: Sound_change_Event;

            complete: Sound_complete_Event;

            error: Sound_error_Event;

            interrupted: Sound_interrupted_Event;

            resume: Sound_resume_Event;

        }
        /**
         * An object for playing basic audio resources.
         */
        class Sound extends Titanium.Proxy {
            /**
             * Used to identify the volume of audio streams for alarms.
             */
            readonly AUDIO_TYPE_ALARM: number;

            /**
             * Used to identify the volume of audio streams for media playback.
             */
            readonly AUDIO_TYPE_MEDIA: number;

            /**
             * Used to identify the volume of audio streams for notifications.
             */
            readonly AUDIO_TYPE_NOTIFICATION: number;

            /**
             * Used to identify the volume of audio streams for the phone ring.
             */
            readonly AUDIO_TYPE_RING: number;

            /**
             * Used to identify the volume of audio streams for DTMF tones or beeps.
             */
            readonly AUDIO_TYPE_SIGNALLING: number;

            /**
             * Used to identify the volume of audio streams for voice calls.
             */
            readonly AUDIO_TYPE_VOICE: number;

            /**
             * Audio data is being buffered from the network.
             */
            readonly STATE_BUFFERING: number;

            /**
             * Audio playback is being initialized.
             */
            readonly STATE_INITIALIZED: number;

            /**
             * Playback is paused.
             */
            readonly STATE_PAUSED: number;

            /**
             * Audio playback is active.
             */
            readonly STATE_PLAYING: number;

            /**
             * Audio playback is starting.
             */
            readonly STATE_STARTING: number;

            /**
             * Audio playback is stopped.
             */
            readonly STATE_STOPPED: number;

            /**
             * Audio playback is stopping.
             */
            readonly STATE_STOPPING: number;

            /**
             * Player is waiting for audio data from the network.
             */
            readonly STATE_WAITING_FOR_DATA: number;

            /**
             * Player is waiting for audio data to fill the queue.
             */
            readonly STATE_WAITING_FOR_QUEUE: number;

            /**
             * Determines whether the audio should continue playing even when its activity is paused.
             */
            allowBackground: boolean;

            /**
             * Changes the audio-stream-type.
             */
            audioType: number;

            /**
             * Duration of the audio resource.
             */
            readonly duration: number;

            /**
             * Determines whether the audio should loop upon completion.
             */
            looping: boolean;

            /**
             * Indicates if the audio is paused.
             */
            paused: boolean;

            /**
             * Indicates if the audio is playing.
             */
            readonly playing: boolean;

            /**
             * Current playback position of the audio.
             */
            time: number;

            /**
             * URL identifying the audio resource.
             */
            url: string;

            /**
             * Volume of the audio from 0.0 (muted) to 1.0 (loudest).
             */
            volume: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof SoundEventMap>(name: K, callback: (this: Titanium.Media.Sound, event: SoundEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof SoundEventMap>(name: K, event?: SoundEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.Sound.audioType> property.
             * @deprecated Access <Titanium.Media.Sound.audioType> instead.
             */
            getAudioType(): number;

            /**
             * Gets the value of the <Titanium.Media.Sound.duration> property.
             * @deprecated Access <Titanium.Media.Sound.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.Media.Sound.time> property.
             * @deprecated Access <Titanium.Media.Sound.time> instead.
             */
            getTime(): number;

            /**
             * Gets the value of the <Titanium.Media.Sound.url> property.
             * @deprecated Access <Titanium.Media.Sound.url> instead.
             */
            getUrl(): string;

            /**
             * Gets the value of the <Titanium.Media.Sound.volume> property.
             * @deprecated Access <Titanium.Media.Sound.volume> instead.
             */
            getVolume(): number;

            /**
             * Returns the value of the [looping](Titanium.Media.Sound.looping) property.
             */
            isLooping(): boolean;

            /**
             * Returns the value of the [paused](Titanium.Media.Sound.paused) property.
             */
            isPaused(): boolean;

            /**
             * Returns the value of the [playing](Titanium.Media.Sound.playing) property.
             */
            isPlaying(): boolean;

            /**
             * Pauses the audio.
             */
            pause(): void;

            /**
             * Starting playing the sound, or resume playing a paused sound.
             */
            play(): void;

            /**
             * Releases all internal resources.
             */
            release(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof SoundEventMap>(name: K, callback: (this: Titanium.Media.Sound, event: SoundEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Resets the audio playback position to the beginning.
             */
            reset(): void;

            /**
             * Sets the value of the <Titanium.Media.Sound.audioType> property.
             * @deprecated Set the value using <Titanium.Media.Sound.audioType> instead.
             */
            setAudioType(audioType: number): void;

            /**
             * Sets the value of the [looping](Titanium.Media.Sound.looping) property.
             */
            setLooping(looping: boolean): void;

            /**
             * Sets the value of the [paused](Titanium.Media.Sound.paused) property.
             */
            setPaused(paused: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.Sound.time> property.
             * @deprecated Set the value using <Titanium.Media.Sound.time> instead.
             */
            setTime(time: number): void;

            /**
             * Sets the value of the <Titanium.Media.Sound.url> property.
             * @deprecated Set the value using <Titanium.Media.Sound.url> instead.
             */
            setUrl(url: string): void;

            /**
             * Sets the value of the <Titanium.Media.Sound.volume> property.
             * @deprecated Set the value using <Titanium.Media.Sound.volume> instead.
             */
            setVolume(volume: number): void;

            /**
             * Stops playing the audio and resets the playback position to the beginning of the clip.
             */
            stop(): void;

        }
        /**
         * An object for playing system sounds.
         * @deprecated This iOS-only API has been deprecated and moved to the [Ti.SystemAlert](https://github.com/appcelerator-modules/ti.systemalert) module in 8.0.0.
         */
        class SystemAlert extends Titanium.Proxy {
            /**
             * URL identifying the audio resource.
             */
            url: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.SystemAlert.url> property.
             * @deprecated Access <Titanium.Media.SystemAlert.url> instead.
             */
            getUrl(): string;

            /**
             * Start playing the system alert.
             */
            play(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Media.SystemAlert.url> property.
             * @deprecated Set the value using <Titanium.Media.SystemAlert.url> instead.
             */
            setUrl(url: string): void;

        }
        /**
         * Base event for class Titanium.Media.VideoPlayer
         */
        interface VideoPlayerBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Media.VideoPlayer;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface VideoPlayer_click_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface VideoPlayer_dblclick_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface VideoPlayer_doubletap_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface VideoPlayer_focus_Event extends VideoPlayerBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface VideoPlayer_keypressed_Event extends VideoPlayerBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface VideoPlayer_longclick_Event extends VideoPlayerBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface VideoPlayer_longpress_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface VideoPlayer_pinch_Event extends VideoPlayerBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface VideoPlayer_postlayout_Event extends VideoPlayerBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface VideoPlayer_singletap_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface VideoPlayer_swipe_Event extends VideoPlayerBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface VideoPlayer_touchcancel_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface VideoPlayer_touchend_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface VideoPlayer_touchmove_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface VideoPlayer_touchstart_Event extends VideoPlayerBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface VideoPlayer_twofingertap_Event extends VideoPlayerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when movie playback ends or a user exits playback.
         */
        interface VideoPlayer_complete_Event extends VideoPlayerBaseEvent {
            /**
             * Error code.
             * Error code will be 0 if `success` is `true`, nonzero otherwise. If the error
             * was generated by the operating system, that system's error value is used.
             * Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. Will be undefined if `success` is `true`.
             */
            error: string;

            /**
             * Reason that playback ended.
             */
            reason: number;

            /**
             * Indicates if the video was played successfully. User exit counts as a success.
             * Returns `true` if `reason` is not
             * [VIDEO_FINISH_REASON_PLAYBACK_ERROR](Titanium.Media.VIDEO_FINISH_REASON_PLAYBACK_ERROR),
             * `false` otherwise.
             */
            success: boolean;

        }
        /**
         * Fired when the video duration is available.
         */
        interface VideoPlayer_durationavailable_Event extends VideoPlayerBaseEvent {
            /**
             * Video duration, in milliseconds.
             */
            duration: number;

        }
        /**
         * Fired when movie playback encounters an error.
         */
        interface VideoPlayer_error_Event extends VideoPlayerBaseEvent {
            /**
             * Error code.
             * If the error was generated by the operating system, that system's error value
             * is used. Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. May be undefined.
             */
            error: string;

            /**
             * Reason for error as a string.
             * @deprecated
             */
            message: string;

            /**
             * Indicates a successful operation. Returns `false`.
             */
            success: boolean;

        }
        /**
         * Fired when the movie play loads.
         */
        interface VideoPlayer_load_Event extends VideoPlayerBaseEvent {
        }
        /**
         * Fired when the network [loadState](Titanium.Media.VideoPlayer.loadState) changes.
         */
        interface VideoPlayer_loadstate_Event extends VideoPlayerBaseEvent {
            /**
             * Current value of the [loadState](Titanium.Media.VideoPlayer.loadState) property.
             */
            loadState: number;

        }
        /**
         * Fired when the natural size of the current movie is determined.
         */
        interface VideoPlayer_naturalsizeavailable_Event extends VideoPlayerBaseEvent {
            /**
             * Current value of the [naturalSize](Titanium.Media.VideoPlayer.naturalSize) property.
             */
            naturalSize: number;

        }
        /**
         * Fired when the [playbackState](Titanium.Media.VideoPlayer.playbackState) changes.
         */
        interface VideoPlayer_playbackstate_Event extends VideoPlayerBaseEvent {
            /**
             * Current value of the [playbackState](Titanium.Media.VideoPlayer.playbackState) property.
             */
            playbackState: number;

        }
        /**
         * Fired when the currently playing movie changes.
         */
        interface VideoPlayer_playing_Event extends VideoPlayerBaseEvent {
            /**
             * URL of the media.
             */
            url: string;

        }
        /**
         * Fired when the movie has preloaded and is ready to play.
         */
        interface VideoPlayer_preload_Event extends VideoPlayerBaseEvent {
        }
        /**
         * Fired when the movie player is resized.
         */
        interface VideoPlayer_resize_Event extends VideoPlayerBaseEvent {
        }
        interface VideoPlayerEventMap extends ProxyEventMap {
            click: VideoPlayer_click_Event;

            complete: VideoPlayer_complete_Event;

            dblclick: VideoPlayer_dblclick_Event;

            doubletap: VideoPlayer_doubletap_Event;

            durationavailable: VideoPlayer_durationavailable_Event;

            error: VideoPlayer_error_Event;

            focus: VideoPlayer_focus_Event;

            keypressed: VideoPlayer_keypressed_Event;

            load: VideoPlayer_load_Event;

            loadstate: VideoPlayer_loadstate_Event;

            longclick: VideoPlayer_longclick_Event;

            longpress: VideoPlayer_longpress_Event;

            naturalsizeavailable: VideoPlayer_naturalsizeavailable_Event;

            pinch: VideoPlayer_pinch_Event;

            playbackstate: VideoPlayer_playbackstate_Event;

            playing: VideoPlayer_playing_Event;

            postlayout: VideoPlayer_postlayout_Event;

            preload: VideoPlayer_preload_Event;

            resize: VideoPlayer_resize_Event;

            singletap: VideoPlayer_singletap_Event;

            swipe: VideoPlayer_swipe_Event;

            touchcancel: VideoPlayer_touchcancel_Event;

            touchend: VideoPlayer_touchend_Event;

            touchmove: VideoPlayer_touchmove_Event;

            touchstart: VideoPlayer_touchstart_Event;

            twofingertap: VideoPlayer_twofingertap_Event;

        }
        /**
         * A native control for playing videos.
         */
        class VideoPlayer extends Titanium.UI.View {
            /**
             * Whether or not the current movie can be played on a remote device.
             */
            allowsAirPlay: boolean;

            /**
             * Indicates if a movie should automatically start playback.
             */
            autoplay: boolean;

            /**
             * Sets the background view for customization which is always displayed behind movie content.
             * @deprecated Use [Titanium.Media.VideoPlayer.overlayView](Titanium.Media.VideoPlayer.overlayView) instead.
             */
            backgroundView: Titanium.UI.View;

            /**
             * URL of the media to play.
             * @deprecated Use [Titanium.Media.VideoPlayer.url](Titanium.Media.VideoPlayer.url) instead.
             */
            contentURL: never;

            /**
             * Current playback time of the current movie in milliseconds.
             */
            currentPlaybackTime: number;

            /**
             * The duration of the current movie in milliseconds, or 0.0 if not known.
             */
            duration: number;

            /**
             * The end time of movie playback, in milliseconds.
             */
            endPlaybackTime: number;

            /**
             * Determines if the movie is presented in the entire screen (obscuring all other application content).
             * @deprecated This method has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            fullscreen: never;

            /**
             * The start time of movie playback, in milliseconds.
             */
            initialPlaybackTime: number;

            /**
             * Returns the network load state of the movie player.
             * @deprecated On iOS, use [Titanium.Media.VideoPlayer.moviePlayerStatus](Titanium.Media.VideoPlayer.moviePlayerStatus) instead.
             */
            readonly loadState: number;

            /**
             * Media object to play, as either a `File`,  a `Blob`, or a URL.
             */
            media: Titanium.Blob | Titanium.Filesystem.File | string;

            /**
             * The style of the playback controls.
             * @deprecated On iOS, use [Titanium.Media.VideoPlayer.showsControls](Titanium.Media.VideoPlayer.showsControls) instead.
             */
            mediaControlStyle: never;

            /**
             * The types of media in the movie, or <Titanium.Media.VIDEO_MEDIA_TYPE_NONE> if not known.
             */
            mediaTypes: number;

            /**
             * Returns the status of the movie player.
             */
            readonly moviePlayerStatus: number;

            /**
             * Returns the natural size of the movie.
             */
            naturalSize: MovieSize;

            /**
             * Use the overlay view to add additional custom views between the video content and the controls.
             */
            overlayView: Titanium.UI.View;

            /**
             * Whether or not the receiver allows Picture in Picture playback.
             */
            pictureInPictureEnabled: boolean;

            /**
             * Currently playable duration of the movie, in milliseconds, for progressively
             * downloaded network content, or 0.0 if not known.
             */
            readonly playableDuration: number;

            /**
             * Current playback state of the video player.
             */
            readonly playbackState: number;

            /**
             * Boolean to indicate if the player has started playing.
             */
            readonly playing: boolean;

            /**
             * Determines how the movie player repeats when reaching the end of playback.
             */
            repeatMode: number;

            /**
             * Determines how the content scales to fit the view.
             */
            scalingMode: number;

            /**
             * Whether or not the receiver shows playback controls. Default is true.
             */
            showsControls: boolean;

            /**
             * The playback type of the movie.
             * @deprecated This method has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            sourceType: never;

            /**
             * URL of the media to play.
             */
            url: string | string[];

            /**
             * Volume of the audio portion of the video.
             */
            volume: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof VideoPlayerEventMap>(name: K, callback: (this: Titanium.Media.VideoPlayer, event: VideoPlayerEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Cancels all pending asynchronous thumbnail requests.
             */
            cancelAllThumbnailImageRequests(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof VideoPlayerEventMap>(name: K, event?: VideoPlayerEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.allowsAirPlay> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.allowsAirPlay> instead.
             */
            getAllowsAirPlay(): boolean;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.autoplay> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.autoplay> instead.
             */
            getAutoplay(): boolean;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.backgroundView> property.
             * @deprecated Use [Titanium.Media.VideoPlayer.overlayView](Titanium.Media.VideoPlayer.overlayView) instead.
             */
            getBackgroundView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.contentURL> property.
             * @deprecated Use [Titanium.Media.VideoPlayer.url](Titanium.Media.VideoPlayer.url) instead.
             */
            getContentURL: never;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.currentPlaybackTime> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.currentPlaybackTime> instead.
             */
            getCurrentPlaybackTime(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.duration> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.endPlaybackTime> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.endPlaybackTime> instead.
             */
            getEndPlaybackTime(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.fullscreen> property.
             * @deprecated This method has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            getFullscreen: never;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.initialPlaybackTime> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.initialPlaybackTime> instead.
             */
            getInitialPlaybackTime(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.loadState> property.
             * @deprecated On iOS, use [Titanium.Media.VideoPlayer.moviePlayerStatus](Titanium.Media.VideoPlayer.moviePlayerStatus) instead.
             */
            getLoadState(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.mediaControlStyle> property.
             * @deprecated On iOS, use [Titanium.Media.VideoPlayer.showsControls](Titanium.Media.VideoPlayer.showsControls) instead.
             */
            getMediaControlStyle: never;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.mediaTypes> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.mediaTypes> instead.
             */
            getMediaTypes(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.moviePlayerStatus> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.moviePlayerStatus> instead.
             */
            getMoviePlayerStatus(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.naturalSize> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.naturalSize> instead.
             */
            getNaturalSize(): MovieSize;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.overlayView> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.overlayView> instead.
             */
            getOverlayView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.pictureInPictureEnabled> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.pictureInPictureEnabled> instead.
             */
            getPictureInPictureEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.playableDuration> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.playableDuration> instead.
             */
            getPlayableDuration(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.playbackState> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.playbackState> instead.
             */
            getPlaybackState(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.playing> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.playing> instead.
             */
            getPlaying(): boolean;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.repeatMode> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.repeatMode> instead.
             */
            getRepeatMode(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.scalingMode> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.scalingMode> instead.
             */
            getScalingMode(): number;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.showsControls> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.showsControls> instead.
             */
            getShowsControls(): boolean;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.sourceType> property.
             * @deprecated This method has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            getSourceType: never;

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.url> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.url> instead.
             */
            getUrl(): string | string[];

            /**
             * Gets the value of the <Titanium.Media.VideoPlayer.volume> property.
             * @deprecated Access <Titanium.Media.VideoPlayer.volume> instead.
             */
            getVolume(): number;

            /**
             * Pauses playing the video.
             */
            pause(): void;

            /**
             * Starts playing the video.
             */
            play(): void;

            /**
             * Releases the internal video resources immediately.
             */
            release(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof VideoPlayerEventMap>(name: K, callback: (this: Titanium.Media.VideoPlayer, event: VideoPlayerEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Asynchronously request thumbnail images for one or more points in time in the video.
             */
            requestThumbnailImagesAtTimes(times: ReadonlyArray<number>, option: number, callback: (param0: ThumbnailResponse) => void): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.allowsAirPlay> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.allowsAirPlay> instead.
             */
            setAllowsAirPlay(allowsAirPlay: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.autoplay> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.autoplay> instead.
             */
            setAutoplay(autoplay: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.backgroundView> property.
             * @deprecated Use [Titanium.Media.VideoPlayer.overlayView](Titanium.Media.VideoPlayer.overlayView) instead.
             */
            setBackgroundView(backgroundView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.contentURL> property.
             * @deprecated Use [Titanium.Media.VideoPlayer.url](Titanium.Media.VideoPlayer.url) instead.
             */
            setContentURL: never;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.currentPlaybackTime> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.currentPlaybackTime> instead.
             */
            setCurrentPlaybackTime(currentPlaybackTime: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.duration> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.duration> instead.
             */
            setDuration(duration: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.endPlaybackTime> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.endPlaybackTime> instead.
             */
            setEndPlaybackTime(endPlaybackTime: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.fullscreen> property.
             * @deprecated This method has been removed for iOS in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            setFullscreen: never;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.initialPlaybackTime> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.initialPlaybackTime> instead.
             */
            setInitialPlaybackTime(initialPlaybackTime: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.media> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.media> instead.
             */
            setMedia(media: Titanium.Blob | Titanium.Filesystem.File | string): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.mediaControlStyle> property.
             * @deprecated On iOS, use [Titanium.Media.VideoPlayer.showsControls](Titanium.Media.VideoPlayer.showsControls) instead.
             */
            setMediaControlStyle: never;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.mediaTypes> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.mediaTypes> instead.
             */
            setMediaTypes(mediaTypes: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.naturalSize> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.naturalSize> instead.
             */
            setNaturalSize(naturalSize: MovieSize): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.overlayView> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.overlayView> instead.
             */
            setOverlayView(overlayView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.pictureInPictureEnabled> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.pictureInPictureEnabled> instead.
             */
            setPictureInPictureEnabled(pictureInPictureEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.repeatMode> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.repeatMode> instead.
             */
            setRepeatMode(repeatMode: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.scalingMode> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.scalingMode> instead.
             */
            setScalingMode(scalingMode: number): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.showsControls> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.showsControls> instead.
             */
            setShowsControls(showsControls: boolean): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.sourceType> property.
             * @deprecated This method has been removed in Titanium SDK 7.0.0 as of the official deprecation by Apple.
             */
            setSourceType: never;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.url> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.url> instead.
             */
            setUrl(url: string | string[]): void;

            /**
             * Sets the value of the <Titanium.Media.VideoPlayer.volume> property.
             * @deprecated Set the value using <Titanium.Media.VideoPlayer.volume> instead.
             */
            setVolume(volume: number): void;

            /**
             * Stops playing the video.
             */
            stop(): void;

            /**
             * Returns a thumbnail image for the video at the specified time.
             * @deprecated Use [Titanium.Media.VideoPlayer.requestThumbnailImagesAtTimes](Titanium.Media.VideoPlayer.requestThumbnailImagesAtTimes) instead.
             */
            thumbnailImageAtTime: never;

        }
    }
    /**
     * The top level network module.
     */
    namespace Network {
        /**
         * Special hostname value for listening sockets, representing all
         * locally available network interfaces.
         * @deprecated
         */
        const INADDR_ANY: never;

        /**
         * A [networkType](Titanium.Network.networkType) value indicating that the device is
         * communicating over a local-area network.
         */
        const NETWORK_LAN: number;

        /**
         * A [networkType](Titanium.Network.networkType) value indicating that the device is
         * communicating over a mobile network.
         */
        const NETWORK_MOBILE: number;

        /**
         * A [networkType](Titanium.Network.networkType) value indicating that no
         * network is available.
         */
        const NETWORK_NONE: number;

        /**
         * A [networkType](Titanium.Network.networkType) value indicating that the
         * current network type is unknown.
         */
        const NETWORK_UNKNOWN: number;

        /**
         * A [networkType](Titanium.Network.networkType) value indicating that the
         * device is communicating over a WiFi network.
         */
        const NETWORK_WIFI: number;

        /**
         * Constant value for an Alert style push notification.
         */
        const NOTIFICATION_TYPE_ALERT: number;

        /**
         * Constant value for a Badge style push notification.
         */
        const NOTIFICATION_TYPE_BADGE: number;

        /**
         * Constant value for a Newsstand style push notification. Only available on iOS5 and later
         */
        const NOTIFICATION_TYPE_NEWSSTAND: number;

        /**
         * Constant value for a Sound style push notification.
         */
        const NOTIFICATION_TYPE_SOUND: number;

        /**
         * Constant value specifying that the progress of a download can not be calculated.
         */
        const PROGRESS_UNKNOWN: number;

        /**
         * Constant value specifying read-only mode for sockets.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const READ_MODE: never;

        /**
         * Constant value specifying read-write mode for sockets.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const READ_WRITE_MODE: never;

        /**
         * Constant value representing a socket in the CLOSED state.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const SOCKET_CLOSED: never;

        /**
         * Constant value representing a socket in the CONNECTED state.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const SOCKET_CONNECTED: never;

        /**
         * Constant value representing a socket in the ERROR state.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const SOCKET_ERROR: never;

        /**
         * Constant value representing a socket in the INITIALIZED state.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const SOCKET_INITIALIZED: never;

        /**
         * Constant value representing a socket in the LISTENING state.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const SOCKET_LISTENING: never;

        /**
         * Constant value specifying TLS version 1.0 for SSL.
         */
        const TLS_VERSION_1_0: number;

        /**
         * Constant value specifying TLS version 1.1 for SSL.
         */
        const TLS_VERSION_1_1: number;

        /**
         * Constant value specifying TLS version 1.2 for SSL.
         */
        const TLS_VERSION_1_2: number;

        /**
         * Constant value specifying TLS version 1.3 for SSL.
         */
        const TLS_VERSION_1_3: number;

        /**
         * Constant value specifying write-only mode for sockets.
         * @deprecated Used with the deprecated [Titanium.Network.TCPSocket](Titanium.Network.TCPSocket) only.
         * See [Socket](Titanium.Network.Socket) for constants used with
         * [TCP](Titanium.Network.Socket.TCP) sockets.
         *
         */
        const WRITE_MODE: never;

        /**
         * Socket module, used for creating sockets.
         */
        namespace Socket {
            /**
             * State value representing a closed socket.
             */
            const CLOSED: number;

            /**
             * State value representing a connected socket.
             */
            const CONNECTED: number;

            /**
             * State value indicating an error has occurred on the socket.
             */
            const ERROR: number;

            /**
             * State value representing an initialized socket.
             */
            const INITIALIZED: number;

            /**
             * State value representing a socket that is listening for connections.
             */
            const LISTENING: number;

            /**
             * TCP socket that implements the `Titanium.IOStream` interface.
             */
            class TCP extends Titanium.IOStream {
                /**
                 * Callback to be fired when a listener accepts a connection.
                 */
                accepted: (param0: AcceptedCallbackArgs) => void;

                /**
                 * Callback to be fired when the socket enters the "connected" state.
                 */
                connected: (param0: ConnectedCallbackArgs) => void;

                /**
                 * Callback to be fired when the socket enters the [ERROR](Titanium.Network.Socket.ERROR) state.
                 */
                error: (param0: ErrorCallbackArgs) => void;

                /**
                 * The host to connect to or listen on.
                 */
                host: string;

                /**
                 * Max number of pending incoming connections to be allowed when the socket is in the [LISTENING](Titanium.Network.Socket.LISTENING) state.
                 */
                listenQueueSize: number;

                /**
                 * The port to connect to or listen on.
                 */
                port: number;

                /**
                 * Current state of the socket.
                 */
                readonly state: number;

                /**
                 * Timeout, in milliseconds, for `connect` and all `write` operations.
                 */
                timeout: number;

                /**
                 * Tells a [LISTENING](Titanium.Network.Socket.LISTENING) socket to accept a connection request at the top of a listener's request queue when one becomes available.
                 */
                accept(options: AcceptDict): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Closes a socket.
                 */
                close(): void;

                /**
                 * Attempts to connect the socket to its host/port.
                 */
                connect(): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.accepted> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.accepted> instead.
                 */
                getAccepted(): (param0: AcceptedCallbackArgs) => void;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.connected> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.connected> instead.
                 */
                getConnected(): (param0: ConnectedCallbackArgs) => void;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.error> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.error> instead.
                 */
                getError(): (param0: ErrorCallbackArgs) => void;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.host> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.host> instead.
                 */
                getHost(): string;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.listenQueueSize> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.listenQueueSize> instead.
                 */
                getListenQueueSize(): number;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.port> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.port> instead.
                 */
                getPort(): number;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.state> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.state> instead.
                 */
                getState(): number;

                /**
                 * Gets the value of the <Titanium.Network.Socket.TCP.timeout> property.
                 * @deprecated Access <Titanium.Network.Socket.TCP.timeout> instead.
                 */
                getTimeout(): number;

                /**
                 * Attempts to start listening on the socket's host/port.
                 */
                listen(): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.accepted> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.accepted> instead.
                 */
                setAccepted(accepted: (param0: AcceptedCallbackArgs) => void): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.connected> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.connected> instead.
                 */
                setConnected(connected: (param0: ConnectedCallbackArgs) => void): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.error> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.error> instead.
                 */
                setError(error: (param0: ErrorCallbackArgs) => void): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.host> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.host> instead.
                 */
                setHost(host: string): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.listenQueueSize> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.listenQueueSize> instead.
                 */
                setListenQueueSize(listenQueueSize: number): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.port> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.port> instead.
                 */
                setPort(port: number): void;

                /**
                 * Sets the value of the <Titanium.Network.Socket.TCP.timeout> property.
                 * @deprecated Set the value using <Titanium.Network.Socket.TCP.timeout> instead.
                 */
                setTimeout(timeout: number): void;

            }
        }
        /**
         * Base event for class Titanium.Network.BonjourBrowser
         */
        interface BonjourBrowserBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Network.BonjourBrowser;

        }
        /**
         * Fired when the discovered services list is updated
         */
        interface BonjourBrowser_updatedservices_Event extends BonjourBrowserBaseEvent {
            /**
             * An array of BonjourService objects corresponding to currently available services.  If you cache this value, including using it as table data, be aware that it could become out of date at any time due to the asynchronous nature of Bonjour service discovery.
             */
            services: Titanium.Network.BonjourService[];

        }
        interface BonjourBrowserEventMap extends ProxyEventMap {
            updatedservices: BonjourBrowser_updatedservices_Event;

        }
        /**
         * A browser for the discovery and retrieval of Bonjour services available on the network.
         */
        class BonjourBrowser extends Titanium.Proxy {
            /**
             * The domain the browser is searching in
             */
            domain: string;

            /**
             * Whether or not the browser is currently searching
             */
            isSearching: boolean;

            /**
             * The type of the service the browser searches for
             */
            serviceType: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof BonjourBrowserEventMap>(name: K, callback: (this: Titanium.Network.BonjourBrowser, event: BonjourBrowserEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof BonjourBrowserEventMap>(name: K, event?: BonjourBrowserEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Network.BonjourBrowser.domain> property.
             * @deprecated Access <Titanium.Network.BonjourBrowser.domain> instead.
             */
            getDomain(): string;

            /**
             * Gets the value of the <Titanium.Network.BonjourBrowser.isSearching> property.
             * @deprecated Access <Titanium.Network.BonjourBrowser.isSearching> instead.
             */
            getIsSearching(): boolean;

            /**
             * Gets the value of the <Titanium.Network.BonjourBrowser.serviceType> property.
             * @deprecated Access <Titanium.Network.BonjourBrowser.serviceType> instead.
             */
            getServiceType(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof BonjourBrowserEventMap>(name: K, callback: (this: Titanium.Network.BonjourBrowser, event: BonjourBrowserEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Conduct a search for Bonjour services matching the type and domain specified during creation
             */
            search(): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourBrowser.domain> property.
             * @deprecated Set the value using <Titanium.Network.BonjourBrowser.domain> instead.
             */
            setDomain(domain: string): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourBrowser.isSearching> property.
             * @deprecated Set the value using <Titanium.Network.BonjourBrowser.isSearching> instead.
             */
            setIsSearching(isSearching: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourBrowser.serviceType> property.
             * @deprecated Set the value using <Titanium.Network.BonjourBrowser.serviceType> instead.
             */
            setServiceType(serviceType: string): void;

            /**
             * Halt an ongoing search
             */
            stopSearch(): void;

        }
        /**
         * Base event for class Titanium.Network.BonjourService
         */
        interface BonjourServiceBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.Network.BonjourService;

        }
        /**
         * Fired when the service has been published (or errored).
         */
        interface BonjourService_publish_Event extends BonjourServiceBaseEvent {
            /**
             * Error code
             */
            code: number;

            /**
             * Error message
             */
            error: string;

            /**
             * Reports if the publish operation was successful
             */
            success: boolean;

        }
        /**
         * Fired when the service has been resolved (or errored). If successful, the [socket](Titanium.Network.BonjourService.socket) property should now be available.
         */
        interface BonjourService_resolve_Event extends BonjourServiceBaseEvent {
            /**
             * Error code
             */
            code: number;

            /**
             * Error message
             */
            error: string;

            /**
             * Reports if the resolve operation was successful
             */
            success: boolean;

        }
        /**
         * Fired when a service's publish or resolution was stopped via <Titanium.Network.BonjourService.stop>
         */
        interface BonjourService_stop_Event extends BonjourServiceBaseEvent {
            /**
             * Error code
             */
            code: number;

            /**
             * Error message
             */
            error: string;

            /**
             * Reports if the stop operation was successful
             */
            success: boolean;

        }
        interface BonjourServiceEventMap extends ProxyEventMap {
            publish: BonjourService_publish_Event;

            resolve: BonjourService_resolve_Event;

            stop: BonjourService_stop_Event;

        }
        /**
         * Describes a service on the network which is published by Bonjour.
         */
        class BonjourService extends Titanium.Proxy {
            /**
             * the domain of the service
             */
            domain: string;

            /**
             * whether or not the service is local to the device
             */
            isLocal: boolean;

            /**
             * the name of the service
             */
            name: string;

            /**
             * the TCPSocket object that is used to connect to the service
             */
            socket: Titanium.Network.Socket.TCP;

            /**
             * the type of the service
             */
            type: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof BonjourServiceEventMap>(name: K, callback: (this: Titanium.Network.BonjourService, event: BonjourServiceEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof BonjourServiceEventMap>(name: K, event?: BonjourServiceEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Network.BonjourService.domain> property.
             * @deprecated Access <Titanium.Network.BonjourService.domain> instead.
             */
            getDomain(): string;

            /**
             * Gets the value of the <Titanium.Network.BonjourService.isLocal> property.
             * @deprecated Access <Titanium.Network.BonjourService.isLocal> instead.
             */
            getIsLocal(): boolean;

            /**
             * Gets the value of the <Titanium.Network.BonjourService.name> property.
             * @deprecated Access <Titanium.Network.BonjourService.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Network.BonjourService.socket> property.
             * @deprecated Access <Titanium.Network.BonjourService.socket> instead.
             */
            getSocket(): Titanium.Network.Socket.TCP;

            /**
             * Gets the value of the <Titanium.Network.BonjourService.type> property.
             * @deprecated Access <Titanium.Network.BonjourService.type> instead.
             */
            getType(): string;

            /**
             * Asynchronously publish a Bonjour service to the network.  Only works if isLocal is TRUE
             */
            publish(socket: Titanium.Network.Socket.TCP, callback?: (param0: Error, param1: boolean) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof BonjourServiceEventMap>(name: K, callback: (this: Titanium.Network.BonjourService, event: BonjourServiceEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Asynchronously resolve a Bonjour service from the network.  Must be done before attempting to access the service's socket information, if a remote service.  You cannot resolve a locally published service.
             */
            resolve(timeout?: number, callback?: (param0: Error, param1: boolean) => void): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourService.domain> property.
             * @deprecated Set the value using <Titanium.Network.BonjourService.domain> instead.
             */
            setDomain(domain: string): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourService.isLocal> property.
             * @deprecated Set the value using <Titanium.Network.BonjourService.isLocal> instead.
             */
            setIsLocal(isLocal: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourService.name> property.
             * @deprecated Set the value using <Titanium.Network.BonjourService.name> instead.
             */
            setName(name: string): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourService.socket> property.
             * @deprecated Set the value using <Titanium.Network.BonjourService.socket> instead.
             */
            setSocket(socket: Titanium.Network.Socket.TCP): void;

            /**
             * Sets the value of the <Titanium.Network.BonjourService.type> property.
             * @deprecated Set the value using <Titanium.Network.BonjourService.type> instead.
             */
            setType(type: string): void;

            /**
             * Asynchronously halts a currently running attempt to publish or resolve a service.
             */
            stop(callback?: (param0: Error, param1: boolean) => void): void;

        }
        /**
         * Cookie object used to manage the system cookie store and HTTP client cookie store.
         */
        class Cookie extends Titanium.Proxy {
            /**
             * The comment describing the purpose of this cookie
             */
            comment: string;

            /**
             * The domain attribute of the cookie.
             */
            domain: string;

            /**
             * The expiration Date of the cookie.
             */
            expiryDate: string;

            /**
             * The httponly attribute of the cookie.
             */
            httponly: boolean;

            /**
             * Sets the Max-Age attribute of a Cookie, in delta-seconds.
             */
            maxAge: number;

            /**
             * The name of the cookie.
             */
            readonly name: string;

            /**
             * The origual url attribute of the cookie.
             */
            originalUrl: string;

            /**
             * The path attribute of the cookie.
             */
            path: string;

            /**
             * The secure attribute of the cookie.
             */
            secure: boolean;

            /**
             * The value of the cookie.
             */
            value: string;

            /**
             * The version of the cookie specification to which this cookie conforms.
             */
            version: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Network.Cookie.comment> property.
             * @deprecated Access <Titanium.Network.Cookie.comment> instead.
             */
            getComment(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.domain> property.
             * @deprecated Access <Titanium.Network.Cookie.domain> instead.
             */
            getDomain(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.expiryDate> property.
             * @deprecated Access <Titanium.Network.Cookie.expiryDate> instead.
             */
            getExpiryDate(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.httponly> property.
             * @deprecated Access <Titanium.Network.Cookie.httponly> instead.
             */
            getHttponly(): boolean;

            /**
             * Gets the value of the <Titanium.Network.Cookie.maxAge> property.
             * @deprecated Access <Titanium.Network.Cookie.maxAge> instead.
             */
            getMaxAge(): number;

            /**
             * Gets the value of the <Titanium.Network.Cookie.name> property.
             * @deprecated Access <Titanium.Network.Cookie.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.originalUrl> property.
             * @deprecated Access <Titanium.Network.Cookie.originalUrl> instead.
             */
            getOriginalUrl(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.path> property.
             * @deprecated Access <Titanium.Network.Cookie.path> instead.
             */
            getPath(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.secure> property.
             * @deprecated Access <Titanium.Network.Cookie.secure> instead.
             */
            getSecure(): boolean;

            /**
             * Gets the value of the <Titanium.Network.Cookie.value> property.
             * @deprecated Access <Titanium.Network.Cookie.value> instead.
             */
            getValue(): string;

            /**
             * Gets the value of the <Titanium.Network.Cookie.version> property.
             * @deprecated Access <Titanium.Network.Cookie.version> instead.
             */
            getVersion(): number;

            /**
             * Returns true if the cookie is valid.
             */
            isValid(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.comment> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.comment> instead.
             */
            setComment(comment: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.domain> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.domain> instead.
             */
            setDomain(domain: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.expiryDate> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.expiryDate> instead.
             */
            setExpiryDate(expiryDate: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.httponly> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.httponly> instead.
             */
            setHttponly(httponly: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.maxAge> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.maxAge> instead.
             */
            setMaxAge(maxAge: number): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.originalUrl> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.originalUrl> instead.
             */
            setOriginalUrl(originalUrl: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.path> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.path> instead.
             */
            setPath(path: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.secure> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.secure> instead.
             */
            setSecure(secure: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.value> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.value> instead.
             */
            setValue(value: string): void;

            /**
             * Sets the value of the <Titanium.Network.Cookie.version> property.
             * @deprecated Set the value using <Titanium.Network.Cookie.version> instead.
             */
            setVersion(version: number): void;

        }
        /**
         * HTTP client object that (mostly) implements the XMLHttpRequest specification.
         */
        class HTTPClient extends Titanium.Proxy {
            /**
             * Ready state constant indicating that the request is complete.
             */
            readonly DONE: number;

            /**
             * Ready state constant indicating that response headers have been received.
             */
            readonly HEADERS_RECEIVED: number;

            /**
             * Ready state constant indicating that response data is being received from the remote server.
             */
            readonly LOADING: number;

            /**
             * Ready state constant indicating that the connection has been opened, but the request has
             * not yet been sent.
             */
            readonly OPENED: number;

            /**
             * Ready state constant indicating that HTTPClient request has not been opened or sent.
             */
            readonly UNSENT: number;

            /**
             * All of the response headers.
             */
            readonly allResponseHeaders: string;

            /**
             * Determines whether automatic encoding is enabled for the specified URL.
             */
            autoEncodeUrl: boolean;

            /**
             * Determines whether automatic automatic handling of HTTP redirects is enabled.
             */
            autoRedirect: boolean;

            /**
             * Determines whether HTTP responses are cached.
             */
            cache: boolean;

            /**
             * Indicates whether the response was successful.
             */
            readonly connected: boolean;

            /**
             * Connection type, normally either `GET`, `POST` or `PATCH`.
             */
            readonly connectionType: string;

            /**
             * Sets the domain parameter for authentication credentials.
             */
            domain: string;

            /**
             * Determines whether the client should attempt to keep a persistent connection.
             */
            enableKeepAlive: boolean;

            /**
             * Target local file or file path to receive data.
             */
            file: string | Titanium.Filesystem.File;

            /**
             * Absolute URL of the request.
             */
            readonly location: string;

            /**
             * Function to be called at regular intervals as the request data is being received.
             */
            ondatastream: (param0: any) => void;

            /**
             * Function to be called upon a error response.
             */
            onerror: (param0: FailureResponse) => void;

            /**
             * Function to be called upon a successful response.
             */
            onload: (param0: SuccessResponse) => void;

            /**
             * Function to be called for each [readyState](Titanium.Network.HTTPClient.readyState) change.
             */
            onreadystatechange: (param0: any) => void;

            /**
             * Function to be called at regular intervals as the request data is being transmitted.
             */
            onsendstream: (param0: any) => void;

            /**
             * Sets the password parameter for authentication credentials.
             */
            password: string;

            /**
             * The current ready state of this HTTP request.
             */
            readonly readyState: number;

            /**
             * Response data as a `Blob` object.
             */
            readonly responseData: Titanium.Blob;

            /**
             * Returns all the response headers returned with the request.
             */
            readonly responseHeaders: any;

            /**
             * Response as text.
             */
            readonly responseText: string;

            /**
             * Response object as an XML DOM Document object.
             */
            readonly responseXML: Titanium.XML.Document;

            /**
             * The Security Manager for this client.
             */
            securityManager: SecurityManagerProtocol;

            /**
             * Response HTTP status code.
             */
            readonly status: number;

            /**
             * Human-readable status message associated with the status code.
             */
            readonly statusText: string;

            /**
             * Timeout in milliseconds when the connection should be aborted.
             */
            timeout: number;

            /**
             * The maximum amount of time (in milliseconds) that a resource request should be allowed to take.
             */
            timeoutForResource: number;

            /**
             * Sets the TLS version to use for handshakes.
             */
            tlsVersion: number;

            /**
             * Sets the username parameter for authentication credentials.
             */
            username: string;

            /**
             * Determines how SSL certification validation is performed on connection.
             */
            validatesSecureCertificate: boolean;

            /**
             * A Boolean value that indicates whether the session should wait for connectivity to become available, or fail immediately.
             */
            waitsForConnectivity: boolean;

            /**
             * Cancels a pending request.
             */
            abort(): void;

            /**
             * Registers a new AuthSchemeFactory for a given scheme.
             * @deprecated
             */
            addAuthFactory: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a custom key manager.
             * @deprecated
             */
            addKeyManager: never;

            /**
             * Adds a custom trust manager.
             * @deprecated
             */
            addTrustManager: never;

            /**
             * Clears any cookies stored for the host.
             */
            clearCookies(host: string): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.allResponseHeaders> property.
             * @deprecated Access <Titanium.Network.HTTPClient.allResponseHeaders> instead.
             */
            getAllResponseHeaders(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.autoEncodeUrl> property.
             * @deprecated Access <Titanium.Network.HTTPClient.autoEncodeUrl> instead.
             */
            getAutoEncodeUrl(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.autoRedirect> property.
             * @deprecated Access <Titanium.Network.HTTPClient.autoRedirect> instead.
             */
            getAutoRedirect(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.cache> property.
             * @deprecated Access <Titanium.Network.HTTPClient.cache> instead.
             */
            getCache(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.connected> property.
             * @deprecated Access <Titanium.Network.HTTPClient.connected> instead.
             */
            getConnected(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.connectionType> property.
             * @deprecated Access <Titanium.Network.HTTPClient.connectionType> instead.
             */
            getConnectionType(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.domain> property.
             * @deprecated Access <Titanium.Network.HTTPClient.domain> instead.
             */
            getDomain(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.enableKeepAlive> property.
             * @deprecated Access <Titanium.Network.HTTPClient.enableKeepAlive> instead.
             */
            getEnableKeepAlive(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.file> property.
             * @deprecated Access <Titanium.Network.HTTPClient.file> instead.
             */
            getFile(): string | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.location> property.
             * @deprecated Access <Titanium.Network.HTTPClient.location> instead.
             */
            getLocation(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.ondatastream> property.
             * @deprecated Access <Titanium.Network.HTTPClient.ondatastream> instead.
             */
            getOndatastream(): (param0: any) => void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.onerror> property.
             * @deprecated Access <Titanium.Network.HTTPClient.onerror> instead.
             */
            getOnerror(): (param0: FailureResponse) => void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.onload> property.
             * @deprecated Access <Titanium.Network.HTTPClient.onload> instead.
             */
            getOnload(): (param0: SuccessResponse) => void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.onreadystatechange> property.
             * @deprecated Access <Titanium.Network.HTTPClient.onreadystatechange> instead.
             */
            getOnreadystatechange(): (param0: any) => void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.onsendstream> property.
             * @deprecated Access <Titanium.Network.HTTPClient.onsendstream> instead.
             */
            getOnsendstream(): (param0: any) => void;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.password> property.
             * @deprecated Access <Titanium.Network.HTTPClient.password> instead.
             */
            getPassword(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.readyState> property.
             * @deprecated Access <Titanium.Network.HTTPClient.readyState> instead.
             */
            getReadyState(): number;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.responseData> property.
             * @deprecated Access <Titanium.Network.HTTPClient.responseData> instead.
             */
            getResponseData(): Titanium.Blob;

            /**
             * Returns the value of the specified response header.
             */
            getResponseHeader(name: string): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.responseHeaders> property.
             * @deprecated Access <Titanium.Network.HTTPClient.responseHeaders> instead.
             */
            getResponseHeaders(): any;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.responseText> property.
             * @deprecated Access <Titanium.Network.HTTPClient.responseText> instead.
             */
            getResponseText(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.responseXML> property.
             * @deprecated Access <Titanium.Network.HTTPClient.responseXML> instead.
             */
            getResponseXML(): Titanium.XML.Document;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.securityManager> property.
             * @deprecated Access <Titanium.Network.HTTPClient.securityManager> instead.
             */
            getSecurityManager(): SecurityManagerProtocol;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.status> property.
             * @deprecated Access <Titanium.Network.HTTPClient.status> instead.
             */
            getStatus(): number;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.statusText> property.
             * @deprecated Access <Titanium.Network.HTTPClient.statusText> instead.
             */
            getStatusText(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.timeout> property.
             * @deprecated Access <Titanium.Network.HTTPClient.timeout> instead.
             */
            getTimeout(): number;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.timeoutForResource> property.
             * @deprecated Access <Titanium.Network.HTTPClient.timeoutForResource> instead.
             */
            getTimeoutForResource(): number;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.tlsVersion> property.
             * @deprecated Access <Titanium.Network.HTTPClient.tlsVersion> instead.
             */
            getTlsVersion(): number;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.username> property.
             * @deprecated Access <Titanium.Network.HTTPClient.username> instead.
             */
            getUsername(): string;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.validatesSecureCertificate> property.
             * @deprecated Access <Titanium.Network.HTTPClient.validatesSecureCertificate> instead.
             */
            getValidatesSecureCertificate(): boolean;

            /**
             * Gets the value of the <Titanium.Network.HTTPClient.waitsForConnectivity> property.
             * @deprecated Access <Titanium.Network.HTTPClient.waitsForConnectivity> instead.
             */
            getWaitsForConnectivity(): boolean;

            /**
             * Opens the request and prepares the connection.
             */
            open(method: string, url: string, async?: boolean): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sends the request.
             */
            send(data?: any): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.autoEncodeUrl> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.autoEncodeUrl> instead.
             */
            setAutoEncodeUrl(autoEncodeUrl: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.autoRedirect> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.autoRedirect> instead.
             */
            setAutoRedirect(autoRedirect: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.cache> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.cache> instead.
             */
            setCache(cache: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.domain> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.domain> instead.
             */
            setDomain(domain: string): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.enableKeepAlive> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.enableKeepAlive> instead.
             */
            setEnableKeepAlive(enableKeepAlive: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.file> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.file> instead.
             */
            setFile(file: string | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.ondatastream> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.ondatastream> instead.
             */
            setOndatastream(ondatastream: (param0: any) => void): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.onerror> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.onerror> instead.
             */
            setOnerror(onerror: (param0: FailureResponse) => void): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.onload> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.onload> instead.
             */
            setOnload(onload: (param0: SuccessResponse) => void): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.onreadystatechange> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.onreadystatechange> instead.
             */
            setOnreadystatechange(onreadystatechange: (param0: any) => void): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.onsendstream> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.onsendstream> instead.
             */
            setOnsendstream(onsendstream: (param0: any) => void): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.password> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.password> instead.
             */
            setPassword(password: string): void;

            /**
             * Sets the value for the specified request header. Must be called after `open` but before `send`.
             */
            setRequestHeader(name: string, value: string): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.securityManager> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.securityManager> instead.
             */
            setSecurityManager(securityManager: SecurityManagerProtocol): void;

            /**
             * Sets the request timeout.
             */
            setTimeout(timeout: number): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.timeoutForResource> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.timeoutForResource> instead.
             */
            setTimeoutForResource(timeoutForResource: number): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.tlsVersion> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.tlsVersion> instead.
             */
            setTlsVersion(tlsVersion: number): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.username> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.username> instead.
             */
            setUsername(username: string): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.validatesSecureCertificate> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.validatesSecureCertificate> instead.
             */
            setValidatesSecureCertificate(validatesSecureCertificate: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.HTTPClient.waitsForConnectivity> property.
             * @deprecated Set the value using <Titanium.Network.HTTPClient.waitsForConnectivity> instead.
             */
            setWaitsForConnectivity(waitsForConnectivity: boolean): void;

        }
        /**
         * Socket module, used for creating sockets.
         */
        class Socket extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Returns a new TCP socket object.
             */
            static createTCP(params?: Dictionary<Titanium.Network.Socket.TCP>): Titanium.Network.Socket.TCP;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Network.Socket.apiName> property.
             * @deprecated Access <Titanium.Network.Socket.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.Network.Socket.bubbleParent> property.
             * @deprecated Access <Titanium.Network.Socket.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.Network.Socket.lifecycleContainer> property.
             * @deprecated Access <Titanium.Network.Socket.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Network.Socket.bubbleParent> property.
             * @deprecated Set the value using <Titanium.Network.Socket.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.Network.Socket.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.Network.Socket.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * The TCPSocket instance returned from <Titanium.Network.createTCPSocket>.  This object
         * represents a socket which either listens locally on the device for connections,
         * or connects to a remote machine.
         * @deprecated Use [Titanium.Network.Socket.TCP](Titanium.Network.Socket.TCP) where possible.
         *
         */
        const TCPSocket: never;
    }
    /**
     * The top-level Platform module.  The Platform module is used to access the device's platform-related
     * functionality.
     */
    namespace Platform {
        /**
         * Constant to indicate that the system is plugged in and currently being charged.
         */
        const BATTERY_STATE_CHARGING: number;

        /**
         * Constant to indicate that the battery is fully charged.
         */
        const BATTERY_STATE_FULL: number;

        /**
         * Constant to indicate that the battery state is not known or monitoring is disabled.
         */
        const BATTERY_STATE_UNKNOWN: number;

        /**
         * Constant to indicate that the system is unplugged.
         */
        const BATTERY_STATE_UNPLUGGED: number;

        /**
         * The Android-specific Platform module, used to access the device's platform-related functionality.
         */
        class Android extends Titanium.Module {
            /**
             * Android API level identifier of the Operating System.
             */
            static readonly API_LEVEL: number;

            /**
             * Constant to indicate that the physical size category of the current device/emulator is large
             */
            static readonly PHYSICAL_SIZE_CATEGORY_LARGE: number;

            /**
             * Constant to indicate that the physical size category of the current device/emulator is normal
             */
            static readonly PHYSICAL_SIZE_CATEGORY_NORMAL: number;

            /**
             * Constant to indicate that the physical size category of the current device/emulator is small
             */
            static readonly PHYSICAL_SIZE_CATEGORY_SMALL: number;

            /**
             * Constant to indicate that the physical size category of the current device/emulator is undefined
             */
            static readonly PHYSICAL_SIZE_CATEGORY_UNDEFINED: number;

            /**
             * Constant to indicate that the physical size category of the current device/emulator is extra large
             */
            static readonly PHYSICAL_SIZE_CATEGORY_XLARGE: number;

            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * The physical size category of the Android device or emulator.
             */
            static readonly physicalSizeCategory: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Platform.Android.apiName> property.
             * @deprecated Access <Titanium.Platform.Android.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.Platform.Android.bubbleParent> property.
             * @deprecated Access <Titanium.Platform.Android.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.Platform.Android.lifecycleContainer> property.
             * @deprecated Access <Titanium.Platform.Android.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Gets the value of the <Titanium.Platform.Android.physicalSizeCategory> property.
             * @deprecated Access <Titanium.Platform.Android.physicalSizeCategory> instead.
             */
            static getPhysicalSizeCategory(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.Platform.Android.bubbleParent> property.
             * @deprecated Set the value using <Titanium.Platform.Android.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.Platform.Android.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.Platform.Android.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * The Display Caps object returned by the <Titanium.Platform.displayCaps> property.
         */
        class DisplayCaps extends Titanium.Proxy {
            /**
             * Logical density of the display.
             */
            readonly density: string;

            /**
             * Display density expressed as dots-per-inch.
             */
            readonly dpi: number;

            /**
             * Logical density of the display, as a scaling factor for the Density Independent Pixel (dip)
             * unit.
             */
            readonly logicalDensityFactor: number;

            /**
             * Absolute height of the display in relation to UI orientation. Measured in platform-specific
             * units; pixels on Android and density-independent pixels (dip) on iOS.
             */
            readonly platformHeight: number;

            /**
             * Absolute width of the display in relation to UI orientation. Measured in platform-specific
             * units; pixels on Android and density-independent pixels (dip) on iOS.
             */
            readonly platformWidth: number;

            /**
             * Physical pixels per inch of the display in the X dimension.
             */
            readonly xdpi: number;

            /**
             * Physical pixels per inch of the display in the Y dimension.
             */
            readonly ydpi: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.density> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.density> instead.
             */
            getDensity(): string;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.dpi> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.dpi> instead.
             */
            getDpi(): number;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.logicalDensityFactor> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.logicalDensityFactor> instead.
             */
            getLogicalDensityFactor(): number;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.platformHeight> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.platformHeight> instead.
             */
            getPlatformHeight(): number;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.platformWidth> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.platformWidth> instead.
             */
            getPlatformWidth(): number;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.xdpi> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.xdpi> instead.
             */
            getXdpi(): number;

            /**
             * Gets the value of the <Titanium.Platform.DisplayCaps.ydpi> property.
             * @deprecated Access <Titanium.Platform.DisplayCaps.ydpi> instead.
             */
            getYdpi(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
    }
    /**
     * The main <Titanium.UI> module.
     */
    namespace UI {
        /**
         * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
         * slowly and speeds up.
         */
        const ANIMATION_CURVE_EASE_IN: number;

        /**
         * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
         * slowly, and speeds up, then slows down at the end of the animation.
         */
        const ANIMATION_CURVE_EASE_IN_OUT: number;

        /**
         * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
         * quickly, then slows down at the end of the animation.
         */
        const ANIMATION_CURVE_EASE_OUT: number;

        /**
         * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that proceeds
         * at a constant rate.
         */
        const ANIMATION_CURVE_LINEAR: number;

        /**
         * Use with <Attribute.type> to specify a background color.
         */
        const ATTRIBUTE_BACKGROUND_COLOR: number;

        /**
         * Use with <Attribute.type> to apply a different baseline to the text.
         */
        const ATTRIBUTE_BASELINE_OFFSET: number;

        /**
         * Use with <Attribute.type> to stretch the text horizontally.
         */
        const ATTRIBUTE_EXPANSION: number;

        /**
         * Use with <Attribute.type> to specify a font.
         */
        const ATTRIBUTE_FONT: number;

        /**
         * Use with <Attribute.type> to specify a font color.
         */
        const ATTRIBUTE_FOREGROUND_COLOR: number;

        /**
         * Use with <Attribute.type> to specify kerning (space between characters).
         */
        const ATTRIBUTE_KERN: number;

        /**
         * Use with <Attribute.value> to use a letterpress text effect.
         */
        const ATTRIBUTE_LETTERPRESS_STYLE: number;

        /**
         * Use with <Attribute.type> to enable or disable ligatures.
         */
        const ATTRIBUTE_LIGATURE: number;

        /**
         * Use with <Attribute.type> to wrap and truncate the text.
         * @deprecated Use [ParagraphAttribute.lineBreakMode](ParagraphAttribute.lineBreakMode) instead.
         */
        const ATTRIBUTE_LINE_BREAK: number;

        /**
         * Use with <Attribute.value> to wrap words at word boundaries.
         */
        const ATTRIBUTE_LINE_BREAK_BY_CHAR_WRAPPING: number;

        /**
         * Use with <Attribute.value> to set lines to not draw past the edge of the text container.
         */
        const ATTRIBUTE_LINE_BREAK_BY_CLIPPING: number;

        /**
         * Use with <Attribute.value> to use ellipsis glyph at the beginning of the line for missing text.
         */
        const ATTRIBUTE_LINE_BREAK_BY_TRUNCATING_HEAD: number;

        /**
         * Use with <Attribute.value> to use ellipsis glyph at the middle of the line for missing text.
         */
        const ATTRIBUTE_LINE_BREAK_BY_TRUNCATING_MIDDLE: number;

        /**
         * Use with <Attribute.value> to use ellipsis glyph at the end of the line for missing text.
         */
        const ATTRIBUTE_LINE_BREAK_BY_TRUNCATING_TAIL: number;

        /**
         * Use with <Attribute.value> to wrap words at word boundaries.
         */
        const ATTRIBUTE_LINE_BREAK_BY_WORD_WRAPPING: number;

        /**
         * Use with <Attribute.type> to create a link.
         */
        const ATTRIBUTE_LINK: number;

        /**
         * Use with <Attribute.type> to skew the text.
         */
        const ATTRIBUTE_OBLIQUENESS: number;

        /**
         * Use with <Attribute.type> to manages the behaviour of string set.
         */
        const ATTRIBUTE_PARAGRAPH_STYLE: number;

        /**
         * Use with <Attribute.type> to display a shadow behind the text.
         */
        const ATTRIBUTE_SHADOW: number;

        /**
         * Use with <Attribute.type> to change the color of the horizontal line.
         */
        const ATTRIBUTE_STRIKETHROUGH_COLOR: number;

        /**
         * Use with <Attribute.type> to place a horizontal line through the text.
         */
        const ATTRIBUTE_STRIKETHROUGH_STYLE: number;

        /**
         * Use with <Attribute.type> to specify a color for the stroke text.
         */
        const ATTRIBUTE_STROKE_COLOR: number;

        /**
         * Use with <Attribute.type> to specify the width of the stroke text.
         */
        const ATTRIBUTE_STROKE_WIDTH: number;

        /**
         * Use with <Attribute.type> to place the text in a lower position.
         */
        const ATTRIBUTE_SUBSCRIPT_STYLE: number;

        /**
         * Use with <Attribute.type> to place the text in an upper position.
         */
        const ATTRIBUTE_SUPERSCRIPT_STYLE: number;

        /**
         * Use with <Attribute.type> to apply a text effect.
         */
        const ATTRIBUTE_TEXT_EFFECT: number;

        /**
         * Use with <Attribute.type> to place a horizontal line under the text.
         */
        const ATTRIBUTE_UNDERLINES_STYLE: number;

        /**
         * Use with <Attribute.value> to draw a line only underneath or through words.
         */
        const ATTRIBUTE_UNDERLINE_BY_WORD: number;

        /**
         * Use with <Attribute.type> to change the color of the horizontal line.
         */
        const ATTRIBUTE_UNDERLINE_COLOR: number;

        /**
         * Use with <Attribute.value> to draw a dashed line.
         */
        const ATTRIBUTE_UNDERLINE_PATTERN_DASH: number;

        /**
         * Use with <Attribute.value> to draw an alternating line of dashes and dots.
         */
        const ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT: number;

        /**
         * Use with <Attribute.value> to draw an alternating line of dashes and two dots.
         */
        const ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT_DOT: number;

        /**
         * Use with <Attribute.value> to draw a dotted line.
         */
        const ATTRIBUTE_UNDERLINE_PATTERN_DOT: number;

        /**
         * Use with <Attribute.value> to draw a solid line.
         */
        const ATTRIBUTE_UNDERLINE_PATTERN_SOLID: number;

        /**
         * Use with <Attribute.value> to draw a double line.
         */
        const ATTRIBUTE_UNDERLINE_STYLE_DOUBLE: number;

        /**
         * Use with <Attribute.value> to not draw a line.
         */
        const ATTRIBUTE_UNDERLINE_STYLE_NONE: number;

        /**
         * Use with <Attribute.value> to draw a single line.
         */
        const ATTRIBUTE_UNDERLINE_STYLE_SINGLE: number;

        /**
         * Use with <Attribute.value> to draw a thick line.
         */
        const ATTRIBUTE_UNDERLINE_STYLE_THICK: number;

        /**
         * Use with <Attribute.type> to control the direction of the text.
         */
        const ATTRIBUTE_WRITING_DIRECTION: number;

        /**
         * Use with <Attribute.value> to use the embedded text direction.
         */
        const ATTRIBUTE_WRITING_DIRECTION_EMBEDDING: number;

        /**
         * Use with <Attribute.value> to write text left to right.
         */
        const ATTRIBUTE_WRITING_DIRECTION_LEFT_TO_RIGHT: number;

        /**
         * Use with <Attribute.value> to use the
         * [Unicode Bidirection Algorithm rules P2 and P3](http://www.unicode.org/reports/tr9/#The_Paragraph_Level)
         * to determine which direction to use.
         */
        const ATTRIBUTE_WRITING_DIRECTION_NATURAL: number;

        /**
         * Use with <Attribute.value> to override the text direction.
         */
        const ATTRIBUTE_WRITING_DIRECTION_OVERRIDE: number;

        /**
         * Use with <Attribute.value> to write text right to left.
         */
        const ATTRIBUTE_WRITING_DIRECTION_RIGHT_TO_LEFT: number;

        /**
         * Converts strings formatted as addresses into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_MAP_ADDRESSES](Titanium.UI.AUTOLINK_MAP_ADDRESSES) instead.
         */
        const AUTODETECT_ADDRESS: never;

        /**
         * Converts all detectable types of data into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_ALL](Titanium.UI.AUTOLINK_ALL) instead.
         */
        const AUTODETECT_ALL: never;

        /**
         * Converts strings formatted as calendar events into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_CALENDAR](Titanium.UI.AUTOLINK_CALENDAR) instead.
         */
        const AUTODETECT_CALENDAR: never;

        /**
         * Converts strings formatted as URLs into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_URLS](Titanium.UI.AUTOLINK_URLS) instead.
         */
        const AUTODETECT_LINK: never;

        /**
         * Disables converting strings into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_NONE](Titanium.UI.AUTOLINK_NONE) instead.
         */
        const AUTODETECT_NONE: never;

        /**
         * Converts strings formatted as phone numbers into clickable links.
         * @deprecated Use [Titanium.UI.AUTOLINK_PHONE_NUMBERS](Titanium.UI.AUTOLINK_PHONE_NUMBERS) instead.
         */
        const AUTODETECT_PHONE: never;

        /**
         * Specifies the expectation of an address.
         */
        const AUTOFILL_TYPE_ADDRESS: string;

        /**
         * Specifies the expectation of a city name.
         */
        const AUTOFILL_TYPE_ADDRESS_CITY: string;

        /**
         * Specifies the expectation of a city name combined with a state name.
         */
        const AUTOFILL_TYPE_ADDRESS_CITY_STATE: string;

        /**
         * Specifies the expectation of the first line of a street address.
         */
        const AUTOFILL_TYPE_ADDRESS_LINE1: string;

        /**
         * Specifies the expectation of the second line of a street address.
         */
        const AUTOFILL_TYPE_ADDRESS_LINE2: string;

        /**
         * Specifies the expectation of a state name.
         */
        const AUTOFILL_TYPE_ADDRESS_STATE: string;

        /**
         * Specifies the expectation of a card expiration date.
         */
        const AUTOFILL_TYPE_CARD_EXPIRATION_DATE: string;

        /**
         * Specifies the expectation of a card expiration day.
         */
        const AUTOFILL_TYPE_CARD_EXPIRATION_DAY: string;

        /**
         * Specifies the expectation of a card expiration month.
         */
        const AUTOFILL_TYPE_CARD_EXPIRATION_MONTH: string;

        /**
         * Specifies the expectation of a card expiration year.
         */
        const AUTOFILL_TYPE_CARD_EXPIRATION_YEAR: string;

        /**
         * Specifies the expectation of a card number.
         */
        const AUTOFILL_TYPE_CARD_NUMBER: string;

        /**
         * Specifies the expectation of a card security code.
         */
        const AUTOFILL_TYPE_CARD_SECURITY_CODE: string;

        /**
         * Specifies the expectation of a country name.
         */
        const AUTOFILL_TYPE_COUNTRY_NAME: string;

        /**
         * Specifies the expectation of an email address.
         */
        const AUTOFILL_TYPE_EMAIL: string;

        /**
         * Specifies the expectation of a family name.
         */
        const AUTOFILL_TYPE_FAMILY_NAME: string;

        /**
         * Specifies the expectation of a given name.
         */
        const AUTOFILL_TYPE_GIVEN_NAME: string;

        /**
         * Specifies the expectation of a job title.
         */
        const AUTOFILL_TYPE_JOB_TITLE: string;

        /**
         * Specifies the expectation of a location, such as a point of interest, an address, or another way to identify a location.
         */
        const AUTOFILL_TYPE_LOCATION: string;

        /**
         * Specifies the expectation of a middle name.
         */
        const AUTOFILL_TYPE_MIDDLE_NAME: string;

        /**
         * Specifies the expectation of a name.
         */
        const AUTOFILL_TYPE_NAME: string;

        /**
         * Specifies the expectation of a prefix or title, such as 'Dr.'
         */
        const AUTOFILL_TYPE_NAME_PREFIX: string;

        /**
         * Specifies the expectation of a suffix, such as 'Jr.'
         */
        const AUTOFILL_TYPE_NAME_SUFFIX: string;

        /**
         * Specifies the expectation of a new password.
         */
        const AUTOFILL_TYPE_NEW_PASSWORD: string;

        /**
         * Specifies the expectation of a nickname.
         */
        const AUTOFILL_TYPE_NICKNAME: string;

        /**
         * Specifies the expectation of a single-factor SMS login code.
         */
        const AUTOFILL_TYPE_ONE_TIME_CODE: string;

        /**
         * Specifies the expectation of an organization name.
         */
        const AUTOFILL_TYPE_ORGANIZATION_NAME: string;

        /**
         * Specifies the expectation of a password.
         */
        const AUTOFILL_TYPE_PASSWORD: string;

        /**
         * Specifies the expectation of a telephone number.
         */
        const AUTOFILL_TYPE_PHONE: string;

        /**
         * Specifies the expectation of a postal code.
         */
        const AUTOFILL_TYPE_POSTAL_CODE: string;

        /**
         * Specifies the expectation of a sublocality.
         */
        const AUTOFILL_TYPE_SUBLOCALITY: string;

        /**
         * Specifies the expectation of a URL.
         */
        const AUTOFILL_TYPE_URL: string;

        /**
         * Specifies the expectation of an account or login name.
         */
        const AUTOFILL_TYPE_USERNAME: string;

        /**
         * Converts all detectable types of data into clickable links.
         */
        const AUTOLINK_ALL: number;

        /**
         * Converts strings formatted as calendar events into clickable links.
         */
        const AUTOLINK_CALENDAR: number;

        /**
         * Converts strings formatted as email addresses into clickable links.
         */
        const AUTOLINK_EMAIL_ADDRESSES: number;

        /**
         * Converts strings formatted as addresses into clickable links.
         */
        const AUTOLINK_MAP_ADDRESSES: number;

        /**
         * Disables converting strings into clickable links.
         */
        const AUTOLINK_NONE: number;

        /**
         * Converts strings formatted as phone numbers into clickable links.
         */
        const AUTOLINK_PHONE_NUMBERS: number;

        /**
         * Converts strings formatted as URLs into clickable links.
         */
        const AUTOLINK_URLS: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_CLEAR: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_COLOR: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_COLOR_BURN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_COLOR_DODGE: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_COPY: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DARKEN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DESTINATION_ATOP: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DESTINATION_IN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DESTINATION_OUT: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DESTINATION_OVER: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_DIFFERENCE: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_EXCLUSION: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_HARD_LIGHT: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_HUE: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_LIGHTEN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_LUMINOSITY: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_MULTIPLY: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_NORMAL: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_OVERLAY: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_PLUS_DARKER: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_PLUS_LIGHTER: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SATURATION: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SCREEN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SOFT_LIGHT: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SOURCE_ATOP: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SOURCE_IN: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_SOURCE_OUT: number;

        /**
         * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
         */
        const BLEND_MODE_XOR: number;

        /**
         * Specifies the time and date that you want the system to remove the clipboard items from the clipboard.
         */
        const CLIPBOARD_OPTION_EXPIRATION_DATE: string;

        /**
         * Specifies that the clipboard items should not be available to other devices through Handoff.
         */
        const CLIPBOARD_OPTION_LOCAL_ONLY: string;

        /**
         * Specifies that all the edges of the window can extend.
         */
        const EXTEND_EDGE_ALL: number;

        /**
         * Specifies that the bottom edge of the window can extend.
         */
        const EXTEND_EDGE_BOTTOM: number;

        /**
         * Specifies that the left edge of the window can extend.
         */
        const EXTEND_EDGE_LEFT: number;

        /**
         * Specifies that none of the edges of the window can extend.
         */
        const EXTEND_EDGE_NONE: number;

        /**
         * Specifies that the right edge of the window can extend.
         */
        const EXTEND_EDGE_RIGHT: number;

        /**
         * Specifies that the top edge of the window can extend.
         */
        const EXTEND_EDGE_TOP: number;

        /**
         * Constant value for face-down orientation.
         */
        const FACE_DOWN: number;

        /**
         * Constant value for face-up orientation.
         */
        const FACE_UP: number;

        /**
         * FILL behavior for UI layout.
         */
        const FILL: string;

        /**
         * Release free space when hiding an object.
         */
        const HIDDEN_BEHAVIOR_GONE: number;

        /**
         * Keeps free space when hiding an object.
         */
        const HIDDEN_BEHAVIOR_INVISIBLE: number;

        /**
         * Use when creating a TextField to specify the hintType as animated.
         */
        const HINT_TYPE_ANIMATED: number;

        /**
         * Use when creating a TextField to specify the hintType as static.
         */
        const HINT_TYPE_STATIC: number;

        /**
         * Use a bezel-style border on the input field.
         */
        const INPUT_BORDERSTYLE_BEZEL: number;

        /**
         * Use a simple line border on the input field.
         */
        const INPUT_BORDERSTYLE_LINE: number;

        /**
         * Use no border on the input field.
         */
        const INPUT_BORDERSTYLE_NONE: number;

        /**
         * Use a rounded-rectangle border on the input field.
         */
        const INPUT_BORDERSTYLE_ROUNDED: number;

        /**
         * Always show buttons on the input field.
         */
        const INPUT_BUTTONMODE_ALWAYS: number;

        /**
         * Never show buttons on the input field.
         */
        const INPUT_BUTTONMODE_NEVER: number;

        /**
         * Show buttons on the input field when it loses focus.
         */
        const INPUT_BUTTONMODE_ONBLUR: number;

        /**
         * Show buttons on the input field when it gains focus.
         */
        const INPUT_BUTTONMODE_ONFOCUS: number;

        /**
         * Use a keyboard with a number pad only, with the pad keyboard layout. Accepts only numbers.
         */
        const INPUT_TYPE_CLASS_NUMBER: number;

        /**
         * Use an ASCII keyboard, with the standard keyboard layout.
         */
        const INPUT_TYPE_CLASS_TEXT: number;

        /**
         * Use a keyboard appearance suitable for entering text on an alert.
         * @deprecated
         */
        const KEYBOARD_APPEARANCE_ALERT: never;

        /**
         * Use the platform-specific dark keyboard appearance.
         */
        const KEYBOARD_APPEARANCE_DARK: number;

        /**
         * Use the platform-specific default keyboard appearance.
         */
        const KEYBOARD_APPEARANCE_DEFAULT: number;

        /**
         * Use the platform-specific light keyboard appearance.
         */
        const KEYBOARD_APPEARANCE_LIGHT: number;

        /**
         * Use a keyboard supporting all characters except emoji. Defaults to English letters layout on iOS.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_ASCII](Titanium.UI.KEYBOARD_TYPE_ASCII) instead.
         */
        const KEYBOARD_ASCII: never;

        /**
         * Use a number pad keyboard layout showing only numbers, decimal separator, and sign character.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_DECIMAL_PAD](Titanium.UI.KEYBOARD_TYPE_DECIMAL_PAD) instead.
         */
        const KEYBOARD_DECIMAL_PAD: never;

        /**
         * Use the default keyboard, depending on the platform.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_DEFAULT](Titanium.UI.KEYBOARD_TYPE_DEFAULT) instead.
         */
        const KEYBOARD_DEFAULT: never;

        /**
         * Use a keyboard suitable for composing email, with the standard keyboard layout.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_EMAIL](Titanium.UI.KEYBOARD_TYPE_EMAIL) instead.
         */
        const KEYBOARD_EMAIL: never;

        /**
         * Use a keyboard suitable for entering names and phone numbers, with the pad keyboard layout.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_NAMEPHONE_PAD](Titanium.UI.KEYBOARD_TYPE_NAMEPHONE_PAD) instead.
         */
        const KEYBOARD_NAMEPHONE_PAD: never;

        /**
         * Use a keyboard supporting all characters except emoji, defaulting to numbers layout on iOS.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_NUMBERS_PUNCTUATION](Titanium.UI.KEYBOARD_TYPE_NUMBERS_PUNCTUATION) instead.
         */
        const KEYBOARD_NUMBERS_PUNCTUATION: never;

        /**
         * Use a number pad keyboard layout only showing numbers for entering positive integers.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_NUMBER_PAD](Titanium.UI.KEYBOARD_TYPE_NUMBER_PAD) instead.
         */
        const KEYBOARD_NUMBER_PAD: never;

        /**
         * Use a keyboard with a phone-style number pad, with the pad keyboard layout.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_PHONE_PAD](Titanium.UI.KEYBOARD_TYPE_PHONE_PAD) instead.
         */
        const KEYBOARD_PHONE_PAD: never;

        /**
         * Use a keyboard supporting all characters except emoji. Defaults to English letters layout on iOS.
         */
        const KEYBOARD_TYPE_ASCII: number;

        /**
         * Use a number pad keyboard layout showing only numbers, decimal separator, and sign character.
         */
        const KEYBOARD_TYPE_DECIMAL_PAD: number;

        /**
         * Use the default keyboard, depending on the platform.
         */
        const KEYBOARD_TYPE_DEFAULT: number;

        /**
         * Use a keyboard suitable for composing email, with the standard keyboard layout.
         */
        const KEYBOARD_TYPE_EMAIL: number;

        /**
         * Use a keyboard suitable for entering names and phone numbers, with the pad keyboard layout.
         */
        const KEYBOARD_TYPE_NAMEPHONE_PAD: number;

        /**
         * Use a keyboard supporting all characters except emoji, defaulting to numbers layout on iOS.
         */
        const KEYBOARD_TYPE_NUMBERS_PUNCTUATION: number;

        /**
         * Use a number pad keyboard layout only showing numbers for entering positive integers.
         */
        const KEYBOARD_TYPE_NUMBER_PAD: number;

        /**
         * Use a keyboard with a phone-style number pad, with the pad keyboard layout.
         */
        const KEYBOARD_TYPE_PHONE_PAD: number;

        /**
         * Use a keyboard optimized for twitter text entry, with easy access to the @ and
         */
        const KEYBOARD_TYPE_TWITTER: number;

        /**
         * Use a keyboard optimized for entering URLs, with the standard keyboard layout.
         */
        const KEYBOARD_TYPE_URL: number;

        /**
         * Use a keyboard optimized for web search terms and URL entry.
         */
        const KEYBOARD_TYPE_WEBSEARCH: number;

        /**
         * Use a keyboard optimized for entering URLs, with the standard keyboard layout.
         * @deprecated Use [Titanium.UI.KEYBOARD_TYPE_URL](Titanium.UI.KEYBOARD_TYPE_URL) instead.
         */
        const KEYBOARD_URL: never;

        /**
         * Standard landscape orientation (home button on left).
         */
        const LANDSCAPE_LEFT: number;

        /**
         * Reverse landscape orientation (home button on right).
         */
        const LANDSCAPE_RIGHT: number;

        /**
         * Displays a checkmark on the right side of an item in a list view.
         */
        const LIST_ACCESSORY_TYPE_CHECKMARK: number;

        /**
         * Displays a detail disclosure button on the right side of an item in a list view.
         */
        const LIST_ACCESSORY_TYPE_DETAIL: number;

        /**
         * Displays a disclosure indicator on the right side of an item in a list view.
         */
        const LIST_ACCESSORY_TYPE_DISCLOSURE: number;

        /**
         * Do not display anything on the right side of an item in a list view.
         */
        const LIST_ACCESSORY_TYPE_NONE: number;

        /**
         * A built-in style for an item with a right-aligned title label on the left side of the cell,
         * which is next to a left-aligned subtitle label.
         */
        const LIST_ITEM_TEMPLATE_CONTACTS: number;

        /**
         * A built-in style for an item with an image view and left-aligned title label.
         */
        const LIST_ITEM_TEMPLATE_DEFAULT: number;

        /**
         * A built-in style for a item with an image view; a left-aligned title label; and a
         * right-aligned subtitle label.
         */
        const LIST_ITEM_TEMPLATE_SETTINGS: number;

        /**
         * A built-in style for an item with an image view; a black, left-aligned title label across the
         * top of the cell and a subtitle label below it.
         */
        const LIST_ITEM_TEMPLATE_SUBTITLE: number;

        /**
         * Specifies a long duration for an Android Toast notification (<Titanium.UI.Notification>).
         */
        const NOTIFICATION_DURATION_LONG: number;

        /**
         * Specifies a short duration for an Android Toast notification (<Titanium.UI.Notification>).
         */
        const NOTIFICATION_DURATION_SHORT: number;

        /**
         * Use a picker with a countdown timer appearance, showing hours and minutes.
         */
        const PICKER_TYPE_COUNT_DOWN_TIMER: number;

        /**
         * Use a date picker.
         */
        const PICKER_TYPE_DATE: number;

        /**
         * Use a date and time picker.
         */
        const PICKER_TYPE_DATE_AND_TIME: number;

        /**
         * Use a plain picker (for values other than date or time).
         */
        const PICKER_TYPE_PLAIN: number;

        /**
         * Use a time picker.
         */
        const PICKER_TYPE_TIME: number;

        /**
         * Orientation constant for portrait mode orientation.
         */
        const PORTRAIT: number;

        /**
         * Set the return key text to "Continue".
         */
        const RETURNKEY_CONTINUE: number;

        /**
         * Use the default return key on the virtual keyboard.
         */
        const RETURNKEY_DEFAULT: number;

        /**
         * Set the return key text to "Done".
         */
        const RETURNKEY_DONE: number;

        /**
         * Set the return key text to "Emergency Call".
         */
        const RETURNKEY_EMERGENCY_CALL: number;

        /**
         * Set the return key text to "Go".
         */
        const RETURNKEY_GO: number;

        /**
         * Set the return key text to "Google".
         */
        const RETURNKEY_GOOGLE: number;

        /**
         * Set the return key text to "Join".
         */
        const RETURNKEY_JOIN: number;

        /**
         * Set the return key text to "Next".
         */
        const RETURNKEY_NEXT: number;

        /**
         * Set the return key text to "Route".
         */
        const RETURNKEY_ROUTE: number;

        /**
         * Set the return key text to "Search".
         */
        const RETURNKEY_SEARCH: number;

        /**
         * Set the return key text to "Send".
         */
        const RETURNKEY_SEND: number;

        /**
         * Set the return key text to "Yahoo".
         */
        const RETURNKEY_YAHOO: number;

        /**
         * The value returned by <Titanium.UI.semanticColorType> when the device is in dark/night mode.
         * @deprecated Use [USER_INTERFACE_STYLE_DARK](Titanium.UI.USER_INTERFACE_STYLE_DARK) instead.
         */
        const SEMANTIC_COLOR_TYPE_DARK: string;

        /**
         * The value returned by <Titanium.UI.semanticColorType> when the device is in light/normal mode.
         * @deprecated Use [USER_INTERFACE_STYLE_LIGHT](Titanium.UI.USER_INTERFACE_STYLE_LIGHT) instead.
         */
        const SEMANTIC_COLOR_TYPE_LIGHT: string;

        /**
         * SIZE behavior for UI layout.
         */
        const SIZE: string;

        /**
         * The row divider is hidden.
         */
        const TABLE_VIEW_SEPARATOR_STYLE_NONE: number;

        /**
         * The row divider is shown as a single line.
         */
        const TABLE_VIEW_SEPARATOR_STYLE_SINGLE_LINE: number;

        /**
         * Center align text.
         */
        const TEXT_ALIGNMENT_CENTER: number | string;

        /**
         * Justify align text.
         */
        const TEXT_ALIGNMENT_JUSTIFY: number | string;

        /**
         * Left align text.
         */
        const TEXT_ALIGNMENT_LEFT: number | string;

        /**
         * Right align text.
         */
        const TEXT_ALIGNMENT_RIGHT: number | string;

        /**
         * Auto-capitalize all text in the input field.
         */
        const TEXT_AUTOCAPITALIZATION_ALL: number;

        /**
         * Do not auto-capitalize.
         */
        const TEXT_AUTOCAPITALIZATION_NONE: number;

        /**
         * Use sentence-style auto-capitalization in the input field.
         */
        const TEXT_AUTOCAPITALIZATION_SENTENCES: number;

        /**
         * Auto-capitalize the first letter of each word in the input field.
         */
        const TEXT_AUTOCAPITALIZATION_WORDS: number;

        /**
         * Add ellipses before the first character that doesnt fit.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_CHAR_WRAP: number;

        /**
         * Lines are simply not drawn past the edge of the text container.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_CLIP: number;

        /**
         * Add ellipses at the end of the label if the text is too large to fit.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_END: number;

        /**
         * Turns on a marquee effect of the label if the text is too large to fit. (This requires <Titanium.UI.Label.focusable> to be true)
         */
        const TEXT_ELLIPSIZE_TRUNCATE_MARQUEE: number;

        /**
         * Add ellipses in the middle of the label if the text is too large to fit.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_MIDDLE: number;

        /**
         * Disables ellipsizing of the label. The text will be cut off if it is too long.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_NONE: number;

        /**
         * Add ellipses at the beginning of the label if the text is too large to fit.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_START: number;

        /**
         * Add ellipses at word boundaries, unless the word itself doesn't fit on a single line.
         */
        const TEXT_ELLIPSIZE_TRUNCATE_WORD_WRAP: number;

        /**
         * The font used for body texts.
         */
        const TEXT_STYLE_BODY: string;

        /**
         * The font used for callouts.
         */
        const TEXT_STYLE_CALLOUT: string;

        /**
         * The font used for standard captions.
         */
        const TEXT_STYLE_CAPTION1: string;

        /**
         * The font used for alternate captions.
         */
        const TEXT_STYLE_CAPTION2: string;

        /**
         * The font used in footnotes.
         */
        const TEXT_STYLE_FOOTNOTE: string;

        /**
         * The font used for headings.
         */
        const TEXT_STYLE_HEADLINE: string;

        /**
         * Specifies the text style for the <Font> Object.
         */
        const TEXT_STYLE_LARGE_TITLE: string;

        /**
         * The font used for subheadings.
         */
        const TEXT_STYLE_SUBHEADLINE: string;

        /**
         * The font used for first level hierarchical headings.
         */
        const TEXT_STYLE_TITLE1: string;

        /**
         * The font used for second level hierarchical headings.
         */
        const TEXT_STYLE_TITLE2: string;

        /**
         * The font used for third level hierarchical headings.
         */
        const TEXT_STYLE_TITLE3: string;

        /**
         * Align text to the bottom of the view.
         */
        const TEXT_VERTICAL_ALIGNMENT_BOTTOM: number | string;

        /**
         * Vertically align text to the center of the view.
         */
        const TEXT_VERTICAL_ALIGNMENT_CENTER: number | string;

        /**
         * Align text to the top of the view.
         */
        const TEXT_VERTICAL_ALIGNMENT_TOP: number | string;

        /**
         * Unit constant representing units in centimeters.
         */
        const UNIT_CM: string;

        /**
         * Unit constant representing units in density-independent pixels.
         */
        const UNIT_DIP: string;

        /**
         * Unit constant representing units in inches.
         */
        const UNIT_IN: string;

        /**
         * Unit constant representing units in millimeters.
         */
        const UNIT_MM: string;

        /**
         * Unit constant representing units in pixels.
         */
        const UNIT_PX: string;

        /**
         * Orientation constant representing an unknown orientation.
         */
        const UNKNOWN: number;

        /**
         * Orientation constant for inverted portait orientation.
         */
        const UPSIDE_PORTRAIT: number;

        /**
         * Authentication error code reported via <Titanium.UI.WebView.error>.
         */
        const URL_ERROR_AUTHENTICATION: number;

        /**
         * Bad url error code reported via <Titanium.UI.WebView.error>.
         */
        const URL_ERROR_BAD_URL: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> for a failure to connect to host.
         */
        const URL_ERROR_CONNECT: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> for a failure to access a file resource on a host, except "file not found", which has its own constant.
         */
        const URL_ERROR_FILE: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when a requested file does not exist on the host.
         */
        const URL_ERROR_FILE_NOT_FOUND: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when a host name cannot be resolved, such as via a DNS lookup error.
         */
        const URL_ERROR_HOST_LOOKUP: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when a redirect loop is detected.
         */
        const URL_ERROR_REDIRECT_LOOP: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> for an SSL failure.
         */
        const URL_ERROR_SSL_FAILED: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when a timeout occurs.
         */
        const URL_ERROR_TIMEOUT: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when an unknown error occurs.
         */
        const URL_ERROR_UNKNOWN: number;

        /**
         * Error code reported via <Titanium.UI.WebView.error> when a url contains an unsupported scheme.
         */
        const URL_ERROR_UNSUPPORTED_SCHEME: number;

        /**
         * A dark interface style.
         */
        const USER_INTERFACE_STYLE_DARK: number;

        /**
         * A light interface style.
         */
        const USER_INTERFACE_STYLE_LIGHT: number;

        /**
         * An unspecified interface style.
         */
        const USER_INTERFACE_STYLE_UNSPECIFIED: number;

        /**
         * The Android-specific UI capabilities. All properties, methods and events in this namespace will
         * only work on Android systems.
         */
        namespace Android {
            /**
             * Window flag which makes the Android system's navigation bar semi-transparent.
             */
            const FLAG_TRANSLUCENT_NAVIGATION: number;

            /**
             * Window flag which makes the Android system's top status bar semi-transparent.
             */
            const FLAG_TRANSLUCENT_STATUS: number;

            /**
             * Raw bit controlling whether the right/bottom edge is clipped to its container, based on the gravity direction being applied.
             */
            const GRAVITY_AXIS_CLIP: number;

            /**
             * Raw bit controlling how the right/bottom edge is placed.
             */
            const GRAVITY_AXIS_PULL_AFTER: number;

            /**
             * Raw bit controlling how the left/top edge is placed.
             */
            const GRAVITY_AXIS_PULL_BEFORE: number;

            /**
             * Raw bit indicating the gravity for an axis has been specified.
             */
            const GRAVITY_AXIS_SPECIFIED: number;

            /**
             * Bits defining the horizontal axis.
             */
            const GRAVITY_AXIS_X_SHIFT: number;

            /**
             * Bits defining the vertical axis.
             */
            const GRAVITY_AXIS_Y_SHIFT: number;

            /**
             * Push object to the bottom of its container, not changing its size.
             */
            const GRAVITY_BOTTOM: number;

            /**
             * Place the object in the center of its container in both the vertical and horizontal axis, not changing its size.
             */
            const GRAVITY_CENTER: number;

            /**
             * Place object in the horizontal center of its container, not changing its size.
             */
            const GRAVITY_CENTER_HORIZONTAL: number;

            /**
             * Place object in the vertical center of its container, not changing its size.
             */
            const GRAVITY_CENTER_VERTICAL: number;

            /**
             * Flag to clip the edges of the object to its container along the horizontal axis.
             */
            const GRAVITY_CLIP_HORIZONTAL: number;

            /**
             * Flag to clip the edges of the object to its container along the vertical axis.
             */
            const GRAVITY_CLIP_VERTICAL: number;

            /**
             * Special constant to enable clipping to an overall display along the horizontal dimension.
             */
            const GRAVITY_DISPLAY_CLIP_HORIZONTAL: number;

            /**
             * Special constant to enable clipping to an overall display along the vertical dimension.
             */
            const GRAVITY_DISPLAY_CLIP_VERTICAL: number;

            /**
             * Push object to x-axis position at the end of its container, not changing its size.
             */
            const GRAVITY_END: number;

            /**
             * Grow the horizontal and vertical size of the object if needed so it completely fills its container.
             */
            const GRAVITY_FILL: number;

            /**
             * Grow the horizontal size of the object if needed so it completely fills its container.
             */
            const GRAVITY_FILL_HORIZONTAL: number;

            /**
             * Grow the vertical size of the object if needed so it completely fills its container.
             */
            const GRAVITY_FILL_VERTICAL: number;

            /**
             * Binary mask to get the absolute horizontal gravity of a gravity.
             */
            const GRAVITY_HORIZONTAL_GRAVITY_MASK: number;

            /**
             * Push object to the left of its container, not changing its size.
             */
            const GRAVITY_LEFT: number;

            /**
             * Constant indicating that no gravity has been set
             */
            const GRAVITY_NO_GRAVITY: number;

            /**
             * Binary mask for the horizontal gravity and script specific direction bit.
             */
            const GRAVITY_RELATIVE_HORIZONTAL_GRAVITY_MASK: number;

            /**
             * Raw bit controlling whether the layout direction is relative or not (GRAVITY_START/GRAVITY_END instead of absolute GRAVITY_LEFT/GRAVITY_RIGHT).
             */
            const GRAVITY_RELATIVE_LAYOUT_DIRECTION: number;

            /**
             * Push object to the right of its container, not changing its size.
             */
            const GRAVITY_RIGHT: number;

            /**
             * Push object to x-axis position at the start of its container, not changing its size.
             */
            const GRAVITY_START: number;

            /**
             * Push object to the top of its container, not changing its size.
             */
            const GRAVITY_TOP: number;

            /**
             * Binary mask to get the vertical gravity of a gravity.
             */
            const GRAVITY_VERTICAL_GRAVITY_MASK: number;

            /**
             * Converts all detectable types of data into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_ALL](Titanium.UI.AUTOLINK_ALL) instead.
             */
            const LINKIFY_ALL: never;

            /**
             * Converts strings formatted as email addresses into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_EMAIL_ADDRESSES](Titanium.UI.AUTOLINK_EMAIL_ADDRESSES) instead.
             */
            const LINKIFY_EMAIL_ADDRESSES: never;

            /**
             * Converts strings formatted as addresses into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_MAP_ADDRESSES](Titanium.UI.AUTOLINK_MAP_ADDRESSES) instead.
             */
            const LINKIFY_MAP_ADDRESSES: never;

            /**
             * Converts strings formatted as phone numbers into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_PHONE_NUMBERS](Titanium.UI.AUTOLINK_PHONE_NUMBERS) instead.
             */
            const LINKIFY_PHONE_NUMBERS: never;

            /**
             * Converts strings formatted as URLs into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_URLS](Titanium.UI.AUTOLINK_URLS) instead.
             */
            const LINKIFY_WEB_URLS: never;

            /**
             * Always allow a user to over-scroll this view, provided it is a view that can scroll.
             */
            const OVER_SCROLL_ALWAYS: number;

            /**
             * Allow a user to over-scroll this view only if the content is large enough to meaningfully scroll, provided it is a view that can scroll.
             */
            const OVER_SCROLL_IF_CONTENT_SCROLLS: number;

            /**
             * Never allow a user to over-scroll this view.
             */
            const OVER_SCROLL_NEVER: number;

            /**
             * Android A_8 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_A_8: number;

            /**
             * Android LA_88 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_LA_88: number;

            /**
             * Android L_8 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_L_8: number;

            /**
             * Android OPAQUE pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_OPAQUE: number;

            /**
             * Android RGBA_4444 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGBA_4444: number;

            /**
             * Android RGBA_5551 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGBA_5551: number;

            /**
             * Android RGBA_8888 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGBA_8888: number;

            /**
             * Android RGBX_8888 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGBX_8888: number;

            /**
             * Android RGB_332 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGB_332: number;

            /**
             * Android RGB_565 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGB_565: number;

            /**
             * Android RGB_888 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_RGB_888: number;

            /**
             * Android TRANSLUCENT pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_TRANSLUCENT: number;

            /**
             * Android A_8 pixel format for <Titanium.UI.Window>. Selecting the correct pixel format can
             * improve image clarity and performance.
             */
            const PIXEL_FORMAT_TRANSPARENT: number;

            /**
             * Android UNKNOWN pixel format for <Titanium.UI.Window>. Selecting the correct pixel format
             * can improve image clarity and performance.
             */
            const PIXEL_FORMAT_UNKNOWN: number;

            /**
             * Used with the <Titanium.UI.Android.ProgressIndicator.type> property to indicate an ongoing
             * activity of determinate length.
             */
            const PROGRESS_INDICATOR_DETERMINANT: number;

            /**
             * Display <Titanium.UI.Android.ProgressIndicator> as a modal dialog. (default)
             */
            const PROGRESS_INDICATOR_DIALOG: number;

            /**
             * Used with the <Titanium.UI.Android.ProgressIndicator.type> property to indicate an ongoing
             * activity of indeterminate length. (default)
             */
            const PROGRESS_INDICATOR_INDETERMINANT: number;

            /**
             * Display <Titanium.UI.Android.ProgressIndicator> as a horizontal progress bar in the title of
             * the window.
             */
            const PROGRESS_INDICATOR_STATUS_BAR: number;

            /**
             * Pan the current heavyweight window when the input method (ie software keyboard) is shown, to
             * ensure that its contents are not obscured.
             */
            const SOFT_INPUT_ADJUST_PAN: number;

            /**
             * Resize the current heavyweight window when the input method (ie software keyboard) is shown,
             * to ensure that its contents are not obscured.
             */
            const SOFT_INPUT_ADJUST_RESIZE: number;

            /**
             * Use the system-default behavior to determine how the soft input area (ie software keyboard)
             * is accomodated by the current heavyweight window when it receives focus (default.)
             */
            const SOFT_INPUT_ADJUST_UNSPECIFIED: number;

            /**
             * Always hide the soft input area (ie software keyboard) when the current heavyweight window
             * receives focus.
             */
            const SOFT_INPUT_STATE_ALWAYS_HIDDEN: number;

            /**
             * Always show the soft input area (ie software keyboard) when the current heavyweight window
             * receives focus.
             */
            const SOFT_INPUT_STATE_ALWAYS_VISIBLE: number;

            /**
             * Attempt to hide the soft input area (ie software keyboard) when the current heavyweight
             * window receives focus.
             */
            const SOFT_INPUT_STATE_HIDDEN: number;

            /**
             * Use the system-default behavior to determine whether to show the soft input area
             * (ie software keyboard) when the current heavyweight window receives focus.
             */
            const SOFT_INPUT_STATE_UNSPECIFIED: number;

            /**
             * Attempt to show the soft input area (ie software keyboard) when the current heavyweight
             * window receives focus.
             */
            const SOFT_INPUT_STATE_VISIBLE: number;

            /**
             * Use Android default behavior to handle keyboard visibility when a view receives focus.
             * (default)
             */
            const SOFT_KEYBOARD_DEFAULT_ON_FOCUS: number;

            /**
             * Attempt to hide the soft keyboard when a view receives focus. Note: system can override
             * request.
             */
            const SOFT_KEYBOARD_HIDE_ON_FOCUS: number;

            /**
             * Attempt to show the soft keyboard when a view receives focus. Note: system can override
             * request.
             */
            const SOFT_KEYBOARD_SHOW_ON_FOCUS: number;

            /**
             * Display a checkbox.
             */
            const SWITCH_STYLE_CHECKBOX: number;

            /**
             * Display a switch.
             */
            const SWITCH_STYLE_SWITCH: number;

            /**
             * Display a toggle button.
             */
            const SWITCH_STYLE_TOGGLEBUTTON: number;

            /**
             * TabGroup style taking advantage of a bottom navigation controller for switching between tabs.
             */
            const TABS_STYLE_BOTTOM_NAVIGATION: number;

            /**
             * The default TabGroup style that places the Tabs bellow the ActionBar and above the Window content.
             */
            const TABS_STYLE_DEFAULT: number;

            /**
             * Captures layout bounds of target views before and after the scene change and animates those changes during the transition.
             */
            const TRANSITION_CHANGE_BOUNDS: number;

            /**
             * Captures the clip bounds before and after the scene change and animates those changes during the transition.
             */
            const TRANSITION_CHANGE_CLIP_BOUNDS: number;

            /**
             * Captures an ImageView's matrix before and after the scene change and animates it during the transition.
             */
            const TRANSITION_CHANGE_IMAGE_TRANSFORM: number;

            /**
             * Captures scale and rotation for Views before and after the scene change and animates those changes during the transition.
             */
            const TRANSITION_CHANGE_TRANSFORM: number;

            /**
             * Moves views in or out from the edges of the scene.
             */
            const TRANSITION_EXPLODE: number;

            /**
             * Fades in the views.
             */
            const TRANSITION_FADE_IN: number;

            /**
             * Fades out the views.
             */
            const TRANSITION_FADE_OUT: number;

            /**
             * Resets transition to platform default.
             */
            const TRANSITION_NONE: number;

            /**
             * Moves views to bottom.
             */
            const TRANSITION_SLIDE_BOTTOM: number;

            /**
             * Moves views to left.
             */
            const TRANSITION_SLIDE_LEFT: number;

            /**
             * Moves views to right.
             */
            const TRANSITION_SLIDE_RIGHT: number;

            /**
             * Moves views to top.
             */
            const TRANSITION_SLIDE_TOP: number;

            /**
             * Use with [WebView.cacheMode](Titanium.UI.WebView.cacheMode) to override how the cache is used in a web view.
             */
            const WEBVIEW_LOAD_CACHE_ELSE_NETWORK: number;

            /**
             * Use with [WebView.cacheMode](Titanium.UI.WebView.cacheMode) to override how the cache is used in a web view.
             */
            const WEBVIEW_LOAD_CACHE_ONLY: number;

            /**
             * Use with [WebView.cacheMode](Titanium.UI.WebView.cacheMode) to override how the cache is used in a web view.
             */
            const WEBVIEW_LOAD_DEFAULT: number;

            /**
             * Use with [WebView.cacheMode](Titanium.UI.WebView.cacheMode) to override how the cache is used in a web view.
             */
            const WEBVIEW_LOAD_NO_CACHE: number;

            /**
             * Use with [WebView.pluginState](Titanium.UI.WebView.pluginState) to disable plugins in a web view.
             */
            const WEBVIEW_PLUGINS_OFF: number;

            /**
             * Use with [WebView.pluginState](Titanium.UI.WebView.pluginState) to enable plugins in a web view.
             */
            const WEBVIEW_PLUGINS_ON: number;

            /**
             * Display a placeholder and only load plugins when user selects it.
             */
            const WEBVIEW_PLUGINS_ON_DEMAND: number;

            /**
             * Base event for class Titanium.UI.Android.CardView
             */
            interface CardViewBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.Android.CardView;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface CardView_click_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface CardView_dblclick_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface CardView_doubletap_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the view element gains focus.
             */
            interface CardView_focus_Event extends CardViewBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface CardView_keypressed_Event extends CardViewBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long click.
             */
            interface CardView_longclick_Event extends CardViewBaseEvent {
            }
            /**
             * Fired when the device detects a long press.
             */
            interface CardView_longpress_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface CardView_pinch_Event extends CardViewBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface CardView_postlayout_Event extends CardViewBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface CardView_singletap_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface CardView_swipe_Event extends CardViewBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface CardView_touchcancel_Event extends CardViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface CardView_touchend_Event extends CardViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface CardView_touchmove_Event extends CardViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface CardView_touchstart_Event extends CardViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface CardView_twofingertap_Event extends CardViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            interface CardViewEventMap extends ProxyEventMap {
                click: CardView_click_Event;

                dblclick: CardView_dblclick_Event;

                doubletap: CardView_doubletap_Event;

                focus: CardView_focus_Event;

                keypressed: CardView_keypressed_Event;

                longclick: CardView_longclick_Event;

                longpress: CardView_longpress_Event;

                pinch: CardView_pinch_Event;

                postlayout: CardView_postlayout_Event;

                singletap: CardView_singletap_Event;

                swipe: CardView_swipe_Event;

                touchcancel: CardView_touchcancel_Event;

                touchend: CardView_touchend_Event;

                touchmove: CardView_touchmove_Event;

                touchstart: CardView_touchstart_Event;

                twofingertap: CardView_twofingertap_Event;

            }
            /**
             * CardView provides a layout container with rounded corners and a shadow indicating the view is elevated.
             */
            class CardView extends Titanium.UI.View {
                /**
                 * Background color for CardView as a color name or hex triplet.
                 */
                backgroundColor: string;

                /**
                 * A background gradient for the view.
                 */
                backgroundGradient: never;

                /**
                 * Background image for the view, specified as a local file path or URL.
                 */
                backgroundImage: never;

                /**
                 * Determines whether to tile a background across a view.
                 */
                backgroundRepeat: never;

                /**
                 * Border color of the view, as a color name or hex triplet.
                 */
                borderColor: never;

                /**
                 * Corner radius for CardView.
                 */
                borderRadius: number;

                /**
                 * Background color for CardView as a color name or hex triplet.
                 * @deprecated Use [Titanium.UI.Android.CardView.backgroundColor](Titanium.UI.Android.CardView.backgroundColor) instead.
                 */
                cardBackgroundColor: never;

                /**
                 * Corner radius for CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.borderRadius](Titanium.UI.Android.CardView.borderRadius) instead.
                 */
                cardCornerRadius: never;

                /**
                 * Elevation for CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.elevation](Titanium.UI.Android.CardView.elevation) instead.
                 */
                cardElevation: never;

                /**
                 * Maximum Elevation for CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.maxElevation](Titanium.UI.Android.CardView.maxElevation) instead.
                 */
                cardMaxElevation: never;

                /**
                 * Add padding to CardView on API level 20 and before to prevent intersections between
                 * the Card content and rounded corners.
                 * @deprecated Use [Titanium.UI.Android.CardView.preventCornerOverlap](Titanium.UI.Android.CardView.preventCornerOverlap) instead.
                 */
                cardPreventCornerOverlap: never;

                /**
                 * Add padding on API level 21 and above to have the same measurements with previous versions.
                 * @deprecated Use [Titanium.UI.Android.CardView.useCompatPadding](Titanium.UI.Android.CardView.useCompatPadding) instead.
                 */
                cardUseCompatPadding: never;

                /**
                 * Inner padding between the edges of the Card and children of the CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.padding](Titanium.UI.Android.CardView.padding) instead.
                 */
                contentPadding: never;

                /**
                 * Inner padding between the bottom edge of the Card and children of the CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingBottom](Titanium.UI.Android.CardView.paddingBottom) instead.
                 */
                contentPaddingBottom: never;

                /**
                 * Inner padding between the left edge of the Card and children of the CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingLeft](Titanium.UI.Android.CardView.paddingLeft) instead.
                 */
                contentPaddingLeft: never;

                /**
                 * Inner padding between the right edge of the Card and children of the CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingRight](Titanium.UI.Android.CardView.paddingRight) instead.
                 */
                contentPaddingRight: never;

                /**
                 * Inner padding between the top edge of the Card and children of the CardView.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingTop](Titanium.UI.Android.CardView.paddingTop) instead.
                 */
                contentPaddingTop: never;

                /**
                 * Elevation for CardView.
                 */
                elevation: number;

                /**
                 * Maximum Elevation for CardView.
                 */
                maxElevation: number;

                /**
                 * Inner padding between the edges of the Card and children of the CardView.
                 */
                padding: number;

                /**
                 * Inner padding between the bottom edge of the Card and children of the CardView.
                 */
                paddingBottom: number;

                /**
                 * Inner padding between the left edge of the Card and children of the CardView.
                 */
                paddingLeft: number;

                /**
                 * Inner padding between the right edge of the Card and children of the CardView.
                 */
                paddingRight: number;

                /**
                 * Inner padding between the top edge of the Card and children of the CardView.
                 */
                paddingTop: number;

                /**
                 * Add padding to CardView on API level 20 and before to prevent intersections between
                 * the Card content and rounded corners.
                 */
                preventCornerOverlap: boolean;

                /**
                 * Add padding on API level 21 and above to have the same measurements with previous versions.
                 */
                useCompatPadding: boolean;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof CardViewEventMap>(name: K, callback: (this: Titanium.UI.Android.CardView, event: CardViewEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof CardViewEventMap>(name: K, event?: CardViewEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.backgroundColor> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.backgroundColor> instead.
                 */
                getBackgroundColor(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.backgroundGradient> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.backgroundGradient> instead.
                 */
                getBackgroundGradient: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.backgroundImage> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.backgroundImage> instead.
                 */
                getBackgroundImage: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.backgroundRepeat> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.backgroundRepeat> instead.
                 */
                getBackgroundRepeat: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.borderColor> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.borderColor> instead.
                 */
                getBorderColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.borderRadius> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.borderRadius> instead.
                 */
                getBorderRadius(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardBackgroundColor> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.backgroundColor](Titanium.UI.Android.CardView.backgroundColor) instead.
                 */
                getCardBackgroundColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardCornerRadius> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.borderRadius](Titanium.UI.Android.CardView.borderRadius) instead.
                 */
                getCardCornerRadius: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardElevation> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.elevation](Titanium.UI.Android.CardView.elevation) instead.
                 */
                getCardElevation: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardMaxElevation> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.maxElevation](Titanium.UI.Android.CardView.maxElevation) instead.
                 */
                getCardMaxElevation: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardPreventCornerOverlap> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.preventCornerOverlap](Titanium.UI.Android.CardView.preventCornerOverlap) instead.
                 */
                getCardPreventCornerOverlap: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.cardUseCompatPadding> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.useCompatPadding](Titanium.UI.Android.CardView.useCompatPadding) instead.
                 */
                getCardUseCompatPadding: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.contentPadding> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.padding](Titanium.UI.Android.CardView.padding) instead.
                 */
                getContentPadding: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.contentPaddingBottom> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingBottom](Titanium.UI.Android.CardView.paddingBottom) instead.
                 */
                getContentPaddingBottom: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.contentPaddingLeft> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingLeft](Titanium.UI.Android.CardView.paddingLeft) instead.
                 */
                getContentPaddingLeft: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.contentPaddingRight> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingRight](Titanium.UI.Android.CardView.paddingRight) instead.
                 */
                getContentPaddingRight: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.contentPaddingTop> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingTop](Titanium.UI.Android.CardView.paddingTop) instead.
                 */
                getContentPaddingTop: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.elevation> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.elevation> instead.
                 */
                getElevation(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.maxElevation> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.maxElevation> instead.
                 */
                getMaxElevation(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.padding> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.padding> instead.
                 */
                getPadding(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.paddingBottom> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.paddingBottom> instead.
                 */
                getPaddingBottom(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.paddingLeft> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.paddingLeft> instead.
                 */
                getPaddingLeft(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.paddingRight> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.paddingRight> instead.
                 */
                getPaddingRight(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.paddingTop> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.paddingTop> instead.
                 */
                getPaddingTop(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.preventCornerOverlap> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.preventCornerOverlap> instead.
                 */
                getPreventCornerOverlap(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.CardView.useCompatPadding> property.
                 * @deprecated Access <Titanium.UI.Android.CardView.useCompatPadding> instead.
                 */
                getUseCompatPadding(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof CardViewEventMap>(name: K, callback: (this: Titanium.UI.Android.CardView, event: CardViewEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.backgroundColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.backgroundColor> instead.
                 */
                setBackgroundColor(backgroundColor: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.backgroundGradient> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.backgroundGradient> instead.
                 */
                setBackgroundGradient: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.backgroundImage> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.backgroundImage> instead.
                 */
                setBackgroundImage: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.backgroundRepeat> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.backgroundRepeat> instead.
                 */
                setBackgroundRepeat: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.borderColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.borderColor> instead.
                 */
                setBorderColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.borderRadius> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.borderRadius> instead.
                 */
                setBorderRadius(borderRadius: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardBackgroundColor> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.backgroundColor](Titanium.UI.Android.CardView.backgroundColor) instead.
                 */
                setCardBackgroundColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardCornerRadius> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.borderRadius](Titanium.UI.Android.CardView.borderRadius) instead.
                 */
                setCardCornerRadius: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardElevation> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.elevation](Titanium.UI.Android.CardView.elevation) instead.
                 */
                setCardElevation: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardMaxElevation> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.maxElevation](Titanium.UI.Android.CardView.maxElevation) instead.
                 */
                setCardMaxElevation: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardPreventCornerOverlap> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.preventCornerOverlap](Titanium.UI.Android.CardView.preventCornerOverlap) instead.
                 */
                setCardPreventCornerOverlap: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.cardUseCompatPadding> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.useCompatPadding](Titanium.UI.Android.CardView.useCompatPadding) instead.
                 */
                setCardUseCompatPadding: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.contentPadding> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.padding](Titanium.UI.Android.CardView.padding) instead.
                 */
                setContentPadding: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.contentPaddingBottom> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingBottom](Titanium.UI.Android.CardView.paddingBottom) instead.
                 */
                setContentPaddingBottom: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.contentPaddingLeft> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingLeft](Titanium.UI.Android.CardView.paddingLeft) instead.
                 */
                setContentPaddingLeft: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.contentPaddingRight> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingRight](Titanium.UI.Android.CardView.paddingRight) instead.
                 */
                setContentPaddingRight: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.contentPaddingTop> property.
                 * @deprecated Use [Titanium.UI.Android.CardView.paddingTop](Titanium.UI.Android.CardView.paddingTop) instead.
                 */
                setContentPaddingTop: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.elevation> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.elevation> instead.
                 */
                setElevation(elevation: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.maxElevation> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.maxElevation> instead.
                 */
                setMaxElevation(maxElevation: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.padding> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.padding> instead.
                 */
                setPadding(padding: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.paddingBottom> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.paddingBottom> instead.
                 */
                setPaddingBottom(paddingBottom: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.paddingLeft> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.paddingLeft> instead.
                 */
                setPaddingLeft(paddingLeft: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.paddingRight> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.paddingRight> instead.
                 */
                setPaddingRight(paddingRight: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.paddingTop> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.paddingTop> instead.
                 */
                setPaddingTop(paddingTop: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.preventCornerOverlap> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.preventCornerOverlap> instead.
                 */
                setPreventCornerOverlap(preventCornerOverlap: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.CardView.useCompatPadding> property.
                 * @deprecated Set the value using <Titanium.UI.Android.CardView.useCompatPadding> instead.
                 */
                setUseCompatPadding(useCompatPadding: boolean): void;

            }
            /**
             * Base event for class Titanium.UI.Android.DrawerLayout
             */
            interface DrawerLayoutBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.Android.DrawerLayout;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface DrawerLayout_click_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface DrawerLayout_dblclick_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface DrawerLayout_doubletap_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the view element gains focus.
             */
            interface DrawerLayout_focus_Event extends DrawerLayoutBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface DrawerLayout_keypressed_Event extends DrawerLayoutBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long click.
             */
            interface DrawerLayout_longclick_Event extends DrawerLayoutBaseEvent {
            }
            /**
             * Fired when the device detects a long press.
             */
            interface DrawerLayout_longpress_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface DrawerLayout_pinch_Event extends DrawerLayoutBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface DrawerLayout_postlayout_Event extends DrawerLayoutBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface DrawerLayout_singletap_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface DrawerLayout_swipe_Event extends DrawerLayoutBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface DrawerLayout_touchcancel_Event extends DrawerLayoutBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface DrawerLayout_touchend_Event extends DrawerLayoutBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface DrawerLayout_touchmove_Event extends DrawerLayoutBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface DrawerLayout_touchstart_Event extends DrawerLayoutBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface DrawerLayout_twofingertap_Event extends DrawerLayoutBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the drawer view is opened.
             */
            interface DrawerLayout_open_Event extends DrawerLayoutBaseEvent {
                /**
                 * Contains the drawer frame type. Either `left` or `right`.
                 */
                drawer: string;

            }
            /**
             * Fired when the drawer view is closed.
             */
            interface DrawerLayout_close_Event extends DrawerLayoutBaseEvent {
                /**
                 * Contains the drawer frame type. Either `left` or `right`.
                 */
                drawer: string;

            }
            /**
             * Fired when the motion state of the drawer view changes.
             */
            interface DrawerLayout_change_Event extends DrawerLayoutBaseEvent {
                /**
                 * Whether or not the drawer is currently dragging.
                 */
                dragging: boolean;

                /**
                 * Contains the drawer frame type. Either `left` or `right`.
                 */
                drawer: string;

                /**
                 * Whether or not the drawer is currently idle.
                 */
                idle: boolean;

                /**
                 * Whether or not the drawer is currently settling.
                 */
                settling: boolean;

                /**
                 * The current drawer state.
                 */
                state: number;

            }
            /**
             * Fired when the drawer view changes it's position.
             */
            interface DrawerLayout_slide_Event extends DrawerLayoutBaseEvent {
                /**
                 * Contains the drawer frame type. Either `left` or `right`.
                 */
                drawer: string;

                /**
                 * The current drawer offset.
                 */
                offset: number;

            }
            interface DrawerLayoutEventMap extends ProxyEventMap {
                change: DrawerLayout_change_Event;

                click: DrawerLayout_click_Event;

                close: DrawerLayout_close_Event;

                dblclick: DrawerLayout_dblclick_Event;

                doubletap: DrawerLayout_doubletap_Event;

                focus: DrawerLayout_focus_Event;

                keypressed: DrawerLayout_keypressed_Event;

                longclick: DrawerLayout_longclick_Event;

                longpress: DrawerLayout_longpress_Event;

                open: DrawerLayout_open_Event;

                pinch: DrawerLayout_pinch_Event;

                postlayout: DrawerLayout_postlayout_Event;

                singletap: DrawerLayout_singletap_Event;

                slide: DrawerLayout_slide_Event;

                swipe: DrawerLayout_swipe_Event;

                touchcancel: DrawerLayout_touchcancel_Event;

                touchend: DrawerLayout_touchend_Event;

                touchmove: DrawerLayout_touchmove_Event;

                touchstart: DrawerLayout_touchstart_Event;

                twofingertap: DrawerLayout_twofingertap_Event;

            }
            /**
             * A panel that displays the app's main navigation options on the left edge of the screen.
             */
            class DrawerLayout extends Titanium.UI.View {
                /**
                 * Use with [DrawerLayout.drawerLockMode](Titanium.UI.Android.DrawerLayout.drawerLockMode) to specify the drawer is locked closed.
                 */
                readonly LOCK_MODE_LOCKED_CLOSED: number;

                /**
                 * Use with [DrawerLayout.drawerLockMode](Titanium.UI.Android.DrawerLayout.drawerLockMode) to specify the drawer is locked opened.
                 */
                readonly LOCK_MODE_LOCKED_OPEN: number;

                /**
                 * Use with [DrawerLayout.drawerLockMode](Titanium.UI.Android.DrawerLayout.drawerLockMode) to specify the drawer is reset to default lock state.
                 */
                readonly LOCK_MODE_UNDEFINED: number;

                /**
                 * Use with [DrawerLayout.drawerLockMode](Titanium.UI.Android.DrawerLayout.drawerLockMode) to specify the drawer is unlocked.
                 */
                readonly LOCK_MODE_UNLOCKED: number;

                /**
                 * Get or set the center view
                 */
                centerView: Titanium.UI.View;

                /**
                 * Determine the drawer indicator status
                 */
                drawerIndicatorEnabled: boolean;

                /**
                 * Get or set the drawerLockMode
                 */
                drawerLockMode: number;

                /**
                 * Determine whether the left drawer is open
                 */
                isLeftOpen: boolean;

                /**
                 * Determine whether the left drawer is visible
                 */
                isLeftVisible: boolean;

                /**
                 * Determine whether the right drawer is open
                 */
                isRightOpen: boolean;

                /**
                 * Determine whether the right drawer is visible
                 */
                isRightVisible: boolean;

                /**
                 * Get or set the view of the left drawer
                 */
                leftView: Titanium.UI.View;

                /**
                 * Get or set the width of the left drawer
                 */
                leftWidth: number;

                /**
                 * Get or set the view of the right drawer
                 */
                rightView: Titanium.UI.View;

                /**
                 * Get or set the width of the right drawer
                 */
                rightWidth: number;

                /**
                 * A Toolbar instance to use as a toolbar.
                 */
                toolbar: Titanium.UI.Toolbar;

                /**
                 * Determine whether to enable the toolbar.
                 */
                toolbarEnabled: boolean;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof DrawerLayoutEventMap>(name: K, callback: (this: Titanium.UI.Android.DrawerLayout, event: DrawerLayoutEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Close the left view.
                 */
                closeLeft(): void;

                /**
                 * Close the right view.
                 */
                closeRight(): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof DrawerLayoutEventMap>(name: K, event?: DrawerLayoutEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.centerView> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.centerView> instead.
                 */
                getCenterView(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.drawerIndicatorEnabled> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.drawerIndicatorEnabled> instead.
                 */
                getDrawerIndicatorEnabled(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.drawerLockMode> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.drawerLockMode> instead.
                 */
                getDrawerLockMode(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.isLeftOpen> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.isLeftOpen> instead.
                 */
                getIsLeftOpen(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.isLeftVisible> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.isLeftVisible> instead.
                 */
                getIsLeftVisible(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.isRightOpen> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.isRightOpen> instead.
                 */
                getIsRightOpen(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.isRightVisible> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.isRightVisible> instead.
                 */
                getIsRightVisible(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.leftView> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.leftView> instead.
                 */
                getLeftView(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.leftWidth> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.leftWidth> instead.
                 */
                getLeftWidth(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.rightView> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.rightView> instead.
                 */
                getRightView(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.rightWidth> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.rightWidth> instead.
                 */
                getRightWidth(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.toolbar> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.toolbar> instead.
                 */
                getToolbar(): Titanium.UI.Toolbar;

                /**
                 * Gets the value of the <Titanium.UI.Android.DrawerLayout.toolbarEnabled> property.
                 * @deprecated Access <Titanium.UI.Android.DrawerLayout.toolbarEnabled> instead.
                 */
                getToolbarEnabled(): boolean;

                /**
                 * Disallow touch events on a specific view.
                 */
                interceptTouchEvent(view: Titanium.UI.View, disallowIntercept: boolean): void;

                /**
                 * Open the left view.
                 */
                openLeft(): void;

                /**
                 * Open the right view.
                 */
                openRight(): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof DrawerLayoutEventMap>(name: K, callback: (this: Titanium.UI.Android.DrawerLayout, event: DrawerLayoutEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.centerView> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.centerView> instead.
                 */
                setCenterView(centerView: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.drawerIndicatorEnabled> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.drawerIndicatorEnabled> instead.
                 */
                setDrawerIndicatorEnabled(drawerIndicatorEnabled: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.drawerLockMode> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.drawerLockMode> instead.
                 */
                setDrawerLockMode(drawerLockMode: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.isLeftOpen> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.isLeftOpen> instead.
                 */
                setIsLeftOpen(isLeftOpen: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.isLeftVisible> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.isLeftVisible> instead.
                 */
                setIsLeftVisible(isLeftVisible: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.isRightOpen> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.isRightOpen> instead.
                 */
                setIsRightOpen(isRightOpen: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.isRightVisible> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.isRightVisible> instead.
                 */
                setIsRightVisible(isRightVisible: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.leftView> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.leftView> instead.
                 */
                setLeftView(leftView: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.leftWidth> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.leftWidth> instead.
                 */
                setLeftWidth(leftWidth: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.rightView> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.rightView> instead.
                 */
                setRightView(rightView: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.rightWidth> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.rightWidth> instead.
                 */
                setRightWidth(rightWidth: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.toolbar> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.toolbar> instead.
                 */
                setToolbar(toolbar: Titanium.UI.Toolbar): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.DrawerLayout.toolbarEnabled> property.
                 * @deprecated Set the value using <Titanium.UI.Android.DrawerLayout.toolbarEnabled> instead.
                 */
                setToolbarEnabled(toolbarEnabled: boolean): void;

                /**
                 * Toggle the visibility of the left view.
                 */
                toggleLeft(): void;

                /**
                 * Toggle the visibility of the right view.
                 */
                toggleRight(): void;

            }
            /**
             * Base event for class Titanium.UI.Android.ProgressIndicator
             */
            interface ProgressIndicatorBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.Android.ProgressIndicator;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface ProgressIndicator_click_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface ProgressIndicator_dblclick_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface ProgressIndicator_doubletap_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the view element gains focus.
             */
            interface ProgressIndicator_focus_Event extends ProgressIndicatorBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface ProgressIndicator_keypressed_Event extends ProgressIndicatorBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long click.
             */
            interface ProgressIndicator_longclick_Event extends ProgressIndicatorBaseEvent {
            }
            /**
             * Fired when the device detects a long press.
             */
            interface ProgressIndicator_longpress_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface ProgressIndicator_pinch_Event extends ProgressIndicatorBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface ProgressIndicator_postlayout_Event extends ProgressIndicatorBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface ProgressIndicator_singletap_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface ProgressIndicator_swipe_Event extends ProgressIndicatorBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface ProgressIndicator_touchcancel_Event extends ProgressIndicatorBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface ProgressIndicator_touchend_Event extends ProgressIndicatorBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface ProgressIndicator_touchmove_Event extends ProgressIndicatorBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface ProgressIndicator_touchstart_Event extends ProgressIndicatorBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface ProgressIndicator_twofingertap_Event extends ProgressIndicatorBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the user has canceled the progress indicator dialog.
             */
            interface ProgressIndicator_cancel_Event extends ProgressIndicatorBaseEvent {
            }
            interface ProgressIndicatorEventMap extends ProxyEventMap {
                cancel: ProgressIndicator_cancel_Event;

                click: ProgressIndicator_click_Event;

                dblclick: ProgressIndicator_dblclick_Event;

                doubletap: ProgressIndicator_doubletap_Event;

                focus: ProgressIndicator_focus_Event;

                keypressed: ProgressIndicator_keypressed_Event;

                longclick: ProgressIndicator_longclick_Event;

                longpress: ProgressIndicator_longpress_Event;

                pinch: ProgressIndicator_pinch_Event;

                postlayout: ProgressIndicator_postlayout_Event;

                singletap: ProgressIndicator_singletap_Event;

                swipe: ProgressIndicator_swipe_Event;

                touchcancel: ProgressIndicator_touchcancel_Event;

                touchend: ProgressIndicator_touchend_Event;

                touchmove: ProgressIndicator_touchmove_Event;

                touchstart: ProgressIndicator_touchstart_Event;

                twofingertap: ProgressIndicator_twofingertap_Event;

            }
            /**
             * A progress dialog or a horizontal progress bar in the title of the window.
             */
            class ProgressIndicator extends Titanium.UI.View {
                /**
                 * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
                 */
                accessibilityHidden: never;

                /**
                 * Briefly describes what performing an action (such as a click) on the view will do.
                 */
                accessibilityHint: never;

                /**
                 * A succint label identifying the view for the device's accessibility service.
                 */
                accessibilityLabel: never;

                /**
                 * A string describing the value (if any) of the view for the device's accessibility service.
                 */
                accessibilityValue: never;

                /**
                 * Coordinate of the view about which to pivot an animation.
                 */
                anchorPoint: never;

                /**
                 * Background color of the view, as a color name or hex triplet.
                 */
                backgroundColor: never;

                /**
                 * Disabled background color of the view, as a color name or hex triplet.
                 */
                backgroundDisabledColor: never;

                /**
                 * Disabled background image for the view, specified as a local file path or URL.
                 */
                backgroundDisabledImage: never;

                /**
                 * Focused background color of the view, as a color name or hex triplet.
                 */
                backgroundFocusedColor: never;

                /**
                 * Focused background image for the view, specified as a local file path or URL.
                 */
                backgroundFocusedImage: never;

                /**
                 * A background gradient for the view.
                 */
                backgroundGradient: never;

                /**
                 * Background image for the view, specified as a local file path or URL.
                 */
                backgroundImage: never;

                /**
                 * Determines whether to tile a background across a view.
                 */
                backgroundRepeat: never;

                /**
                 * Selected background color of the view, as a color name or hex triplet.
                 */
                backgroundSelectedColor: never;

                /**
                 * Selected background image url for the view, specified as a local file path or URL.
                 */
                backgroundSelectedImage: never;

                /**
                 * Border color of the view, as a color name or hex triplet.
                 */
                borderColor: never;

                /**
                 * Radius for the rounded corners of the view's border.
                 */
                borderRadius: never;

                /**
                 * Border width of the view.
                 */
                borderWidth: never;

                /**
                 * View's bottom position, in platform-specific units.
                 */
                bottom: never;

                /**
                 * When `true` allows the user to cancel the progress dialog by pressing the BACK button.
                 */
                cancelable: boolean;

                /**
                 * When `cancelable` is set to `true` and this is set to `true`, the dialog is canceled when touched outside the window's bounds.
                 */
                canceledOnTouchOutside: boolean;

                /**
                 * View's center position, in the parent view's coordinates.
                 */
                center: never;

                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * Whether view should be focusable while navigating with the trackball.
                 */
                focusable: never;

                /**
                 * View height, in platform-specific units.
                 */
                height: never;

                /**
                 * Determines whether the layout has wrapping behavior.
                 */
                horizontalWrap: never;

                /**
                 * Determines whether to keep the device screen on.
                 */
                keepScreenOn: never;

                /**
                 * Specifies how the view positions its children.
                 * One of: 'composite', 'vertical', or 'horizontal'.
                 */
                layout: never;

                /**
                 * View's left position, in platform-specific units.
                 */
                left: never;

                /**
                 * Location for the progress indicator.
                 */
                location: number;

                /**
                 * Maximum value of the progress bar.
                 */
                max: number;

                /**
                 * Message text.
                 */
                message: string;

                /**
                 * Key identifying a string in the locale file to use for the message text.
                 */
                messageid: string;

                /**
                 * Minimum value of the progress bar.
                 */
                min: number;

                /**
                 * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
                 */
                opacity: never;

                /**
                 * When on, animate call overrides current animation if applicable.
                 */
                overrideCurrentAnimation: never;

                /**
                 * The bounding box of the view relative to its parent, in system units.
                 */
                readonly rect: never;

                /**
                 * View's right position, in platform-specific units.
                 */
                right: never;

                /**
                 * The size of the view in system units.
                 */
                readonly size: never;

                /**
                 * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
                 */
                softKeyboardOnFocus: never;

                /**
                 * The view's top position.
                 */
                top: never;

                /**
                 * Determines whether view should receive touch events.
                 */
                touchEnabled: never;

                /**
                 * Transformation matrix to apply to the view.
                 */
                transform: never;

                /**
                 * Type for the progress indicator.
                 */
                type: number;

                /**
                 * Determines whether the view is visible.
                 */
                visible: never;

                /**
                 * View's width, in platform-specific units.
                 */
                width: never;

                /**
                 * Z-index stack order position, relative to other sibling views.
                 */
                zIndex: never;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof ProgressIndicatorEventMap>(name: K, callback: (this: Titanium.UI.Android.ProgressIndicator, event: ProgressIndicatorEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Animates this view.
                 */
                animate: never;

                /**
                 * Translates a point from this view's coordinate system to another view's coordinate system.
                 */
                convertPointToView: never;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof ProgressIndicatorEventMap>(name: K, event?: ProgressIndicatorEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityHidden> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.accessibilityHidden> instead.
                 */
                getAccessibilityHidden: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityHint> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.accessibilityHint> instead.
                 */
                getAccessibilityHint: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityLabel> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.accessibilityLabel> instead.
                 */
                getAccessibilityLabel: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityValue> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.accessibilityValue> instead.
                 */
                getAccessibilityValue: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.anchorPoint> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.anchorPoint> instead.
                 */
                getAnchorPoint: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundColor> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundColor> instead.
                 */
                getBackgroundColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundDisabledColor> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundDisabledColor> instead.
                 */
                getBackgroundDisabledColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundDisabledImage> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundDisabledImage> instead.
                 */
                getBackgroundDisabledImage: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundFocusedColor> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundFocusedColor> instead.
                 */
                getBackgroundFocusedColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundFocusedImage> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundFocusedImage> instead.
                 */
                getBackgroundFocusedImage: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundGradient> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundGradient> instead.
                 */
                getBackgroundGradient: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundImage> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundImage> instead.
                 */
                getBackgroundImage: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundRepeat> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundRepeat> instead.
                 */
                getBackgroundRepeat: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundSelectedColor> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundSelectedColor> instead.
                 */
                getBackgroundSelectedColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundSelectedImage> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.backgroundSelectedImage> instead.
                 */
                getBackgroundSelectedImage: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.borderColor> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.borderColor> instead.
                 */
                getBorderColor: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.borderRadius> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.borderRadius> instead.
                 */
                getBorderRadius: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.borderWidth> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.borderWidth> instead.
                 */
                getBorderWidth: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.bottom> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.bottom> instead.
                 */
                getBottom: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.cancelable> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.cancelable> instead.
                 */
                getCancelable(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.canceledOnTouchOutside> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.canceledOnTouchOutside> instead.
                 */
                getCanceledOnTouchOutside(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.center> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.center> instead.
                 */
                getCenter: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.children> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.focusable> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.focusable> instead.
                 */
                getFocusable: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.height> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.height> instead.
                 */
                getHeight: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.horizontalWrap> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.horizontalWrap> instead.
                 */
                getHorizontalWrap: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.keepScreenOn> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.keepScreenOn> instead.
                 */
                getKeepScreenOn: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.layout> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.layout> instead.
                 */
                getLayout: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.left> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.left> instead.
                 */
                getLeft: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.location> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.location> instead.
                 */
                getLocation(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.max> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.max> instead.
                 */
                getMax(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.message> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.message> instead.
                 */
                getMessage(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.messageid> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.messageid> instead.
                 */
                getMessageid(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.min> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.min> instead.
                 */
                getMin(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.opacity> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.opacity> instead.
                 */
                getOpacity: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.overrideCurrentAnimation> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.overrideCurrentAnimation> instead.
                 */
                getOverrideCurrentAnimation: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.rect> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.rect> instead.
                 */
                getRect: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.right> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.right> instead.
                 */
                getRight: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.size> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.size> instead.
                 */
                getSize: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.softKeyboardOnFocus> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.softKeyboardOnFocus> instead.
                 */
                getSoftKeyboardOnFocus: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.top> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.top> instead.
                 */
                getTop: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.touchEnabled> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.touchEnabled> instead.
                 */
                getTouchEnabled: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.transform> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.transform> instead.
                 */
                getTransform: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.type> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.type> instead.
                 */
                getType(): number;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.visible> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.visible> instead.
                 */
                getVisible: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.width> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.width> instead.
                 */
                getWidth: never;

                /**
                 * Gets the value of the <Titanium.UI.Android.ProgressIndicator.zIndex> property.
                 * @deprecated Access <Titanium.UI.Android.ProgressIndicator.zIndex> instead.
                 */
                getZIndex: never;

                /**
                 * Hides the progress indicator and stops the animation.
                 */
                hide(options?: AnimatedOptions): void;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof ProgressIndicatorEventMap>(name: K, callback: (this: Titanium.UI.Android.ProgressIndicator, event: ProgressIndicatorEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityHidden> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.accessibilityHidden> instead.
                 */
                setAccessibilityHidden: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityHint> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.accessibilityHint> instead.
                 */
                setAccessibilityHint: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityLabel> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.accessibilityLabel> instead.
                 */
                setAccessibilityLabel: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.accessibilityValue> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.accessibilityValue> instead.
                 */
                setAccessibilityValue: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.anchorPoint> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.anchorPoint> instead.
                 */
                setAnchorPoint: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundColor> instead.
                 */
                setBackgroundColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundDisabledColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundDisabledColor> instead.
                 */
                setBackgroundDisabledColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundDisabledImage> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundDisabledImage> instead.
                 */
                setBackgroundDisabledImage: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundFocusedColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundFocusedColor> instead.
                 */
                setBackgroundFocusedColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundFocusedImage> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundFocusedImage> instead.
                 */
                setBackgroundFocusedImage: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundGradient> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundGradient> instead.
                 */
                setBackgroundGradient: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundImage> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundImage> instead.
                 */
                setBackgroundImage: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundRepeat> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundRepeat> instead.
                 */
                setBackgroundRepeat: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundSelectedColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundSelectedColor> instead.
                 */
                setBackgroundSelectedColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.backgroundSelectedImage> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.backgroundSelectedImage> instead.
                 */
                setBackgroundSelectedImage: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.borderColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.borderColor> instead.
                 */
                setBorderColor: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.borderRadius> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.borderRadius> instead.
                 */
                setBorderRadius: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.borderWidth> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.borderWidth> instead.
                 */
                setBorderWidth: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.bottom> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.bottom> instead.
                 */
                setBottom: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.cancelable> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.cancelable> instead.
                 */
                setCancelable(cancelable: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.canceledOnTouchOutside> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.canceledOnTouchOutside> instead.
                 */
                setCanceledOnTouchOutside(canceledOnTouchOutside: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.center> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.center> instead.
                 */
                setCenter: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.focusable> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.focusable> instead.
                 */
                setFocusable: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.height> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.height> instead.
                 */
                setHeight: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.horizontalWrap> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.horizontalWrap> instead.
                 */
                setHorizontalWrap: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.keepScreenOn> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.keepScreenOn> instead.
                 */
                setKeepScreenOn: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.layout> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.layout> instead.
                 */
                setLayout: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.left> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.left> instead.
                 */
                setLeft: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.location> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.location> instead.
                 */
                setLocation(location: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.max> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.max> instead.
                 */
                setMax(max: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.message> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.message> instead.
                 */
                setMessage(message: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.messageid> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.messageid> instead.
                 */
                setMessageid(messageid: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.min> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.min> instead.
                 */
                setMin(min: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.opacity> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.opacity> instead.
                 */
                setOpacity: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.overrideCurrentAnimation> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.overrideCurrentAnimation> instead.
                 */
                setOverrideCurrentAnimation: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.right> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.right> instead.
                 */
                setRight: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.softKeyboardOnFocus> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.softKeyboardOnFocus> instead.
                 */
                setSoftKeyboardOnFocus: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.top> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.top> instead.
                 */
                setTop: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.touchEnabled> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.touchEnabled> instead.
                 */
                setTouchEnabled: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.transform> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.transform> instead.
                 */
                setTransform: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.type> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.type> instead.
                 */
                setType(type: number): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.visible> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.visible> instead.
                 */
                setVisible: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.width> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.width> instead.
                 */
                setWidth: never;

                /**
                 * Sets the value of the <Titanium.UI.Android.ProgressIndicator.zIndex> property.
                 * @deprecated Set the value using <Titanium.UI.Android.ProgressIndicator.zIndex> instead.
                 */
                setZIndex: never;

                /**
                 * Shows the progress indicator and starts the animation.
                 */
                show(options?: AnimatedOptions): void;

                /**
                 * Returns an image of the rendered view, as a Blob.
                 */
                toImage: never;

            }
            /**
             * Base event for class Titanium.UI.Android.SearchView
             */
            interface SearchViewBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.Android.SearchView;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface SearchView_click_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface SearchView_dblclick_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface SearchView_doubletap_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the search view gains focus.
             */
            interface SearchView_focus_Event extends SearchViewBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface SearchView_keypressed_Event extends SearchViewBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long click.
             */
            interface SearchView_longclick_Event extends SearchViewBaseEvent {
            }
            /**
             * Fired when the device detects a long press.
             */
            interface SearchView_longpress_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface SearchView_pinch_Event extends SearchViewBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface SearchView_postlayout_Event extends SearchViewBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface SearchView_singletap_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface SearchView_swipe_Event extends SearchViewBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface SearchView_touchcancel_Event extends SearchViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface SearchView_touchend_Event extends SearchViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface SearchView_touchmove_Event extends SearchViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface SearchView_touchstart_Event extends SearchViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface SearchView_twofingertap_Event extends SearchViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the search view loses focus.
             */
            interface SearchView_blur_Event extends SearchViewBaseEvent {
            }
            /**
             * Fired when the cancel button is pressed.
             */
            interface SearchView_cancel_Event extends SearchViewBaseEvent {
            }
            /**
             * Fired when the value of the search view changes.
             */
            interface SearchView_change_Event extends SearchViewBaseEvent {
            }
            /**
             * If the search query is not empty, fired when the search button is clicked on soft keyboard
             */
            interface SearchView_submit_Event extends SearchViewBaseEvent {
            }
            interface SearchViewEventMap extends ProxyEventMap {
                blur: SearchView_blur_Event;

                cancel: SearchView_cancel_Event;

                change: SearchView_change_Event;

                click: SearchView_click_Event;

                dblclick: SearchView_dblclick_Event;

                doubletap: SearchView_doubletap_Event;

                focus: SearchView_focus_Event;

                keypressed: SearchView_keypressed_Event;

                longclick: SearchView_longclick_Event;

                longpress: SearchView_longpress_Event;

                pinch: SearchView_pinch_Event;

                postlayout: SearchView_postlayout_Event;

                singletap: SearchView_singletap_Event;

                submit: SearchView_submit_Event;

                swipe: SearchView_swipe_Event;

                touchcancel: SearchView_touchcancel_Event;

                touchend: SearchView_touchend_Event;

                touchmove: SearchView_touchmove_Event;

                touchstart: SearchView_touchstart_Event;

                twofingertap: SearchView_twofingertap_Event;

            }
            /**
             * A specialized text field for entering search text.
             */
            class SearchView extends Titanium.UI.View {
                /**
                 * Color of the text in this SearchView, as a color name or hex triplet.
                 */
                color: string;

                /**
                 * Text to show when the search view field is not focused.
                 */
                hintText: string;

                /**
                 * Color of hint text that displays when field is empty.
                 */
                hintTextColor: string;

                /**
                 * Iconifies or expands the search view
                 */
                iconified: boolean;

                /**
                 * Sets the default or resting state of the search view
                 */
                iconifiedByDefault: boolean;

                /**
                 * Whether to display the submit button when necessary or never display.
                 */
                submitEnabled: boolean;

                /**
                 * Value of the search view.
                 */
                value: string;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof SearchViewEventMap>(name: K, callback: (this: Titanium.UI.Android.SearchView, event: SearchViewEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Causes the search view to lose focus.
                 */
                blur(): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof SearchViewEventMap>(name: K, event?: SearchViewEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Causes the search view to gain focus.
                 */
                focus(): void;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.color> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.color> instead.
                 */
                getColor(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.hintText> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.hintText> instead.
                 */
                getHintText(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.hintTextColor> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.hintTextColor> instead.
                 */
                getHintTextColor(): string;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.iconified> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.iconified> instead.
                 */
                getIconified(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.iconifiedByDefault> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.iconifiedByDefault> instead.
                 */
                getIconifiedByDefault(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.submitEnabled> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.submitEnabled> instead.
                 */
                getSubmitEnabled(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.Android.SearchView.value> property.
                 * @deprecated Access <Titanium.UI.Android.SearchView.value> instead.
                 */
                getValue(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof SearchViewEventMap>(name: K, callback: (this: Titanium.UI.Android.SearchView, event: SearchViewEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.color> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.color> instead.
                 */
                setColor(color: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.hintText> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.hintText> instead.
                 */
                setHintText(hintText: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.hintTextColor> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.hintTextColor> instead.
                 */
                setHintTextColor(hintTextColor: string): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.iconified> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.iconified> instead.
                 */
                setIconified(iconified: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.iconifiedByDefault> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.iconifiedByDefault> instead.
                 */
                setIconifiedByDefault(iconifiedByDefault: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.submitEnabled> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.submitEnabled> instead.
                 */
                setSubmitEnabled(submitEnabled: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.Android.SearchView.value> property.
                 * @deprecated Set the value using <Titanium.UI.Android.SearchView.value> instead.
                 */
                setValue(value: string): void;

            }
        }
        /**
         * Apple iOS specific UI capabilities.  All properties, methods and events in this namespace will
         * only work on Apple iOS devices.
         */
        namespace iOS {
            /**
             * Allow the navigation to continue.
             */
            const ACTION_POLICY_ALLOW: number;

            /**
             * Cancel the navigation.
             */
            const ACTION_POLICY_CANCEL: number;

            /**
             * Use with [AdView.adSize](Titanium.UI.iOS.AdView.adSize) to specify a banner ad size
             * appropriate for landscape orientations.
             */
            const AD_SIZE_LANDSCAPE: string;

            /**
             * Use with [AdView.adSize](Titanium.UI.iOS.AdView.adSize) to specify a banner ad size
             * appropriate for portrait orientations.
             */
            const AD_SIZE_PORTRAIT: string;

            /**
             * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
             * slowly and speeds up.
             * @deprecated Use [Titanium.UI.ANIMATION_CURVE_EASE_IN](Titanium.UI.ANIMATION_CURVE_EASE_IN) instead.
             */
            const ANIMATION_CURVE_EASE_IN: never;

            /**
             * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
             * slowly, and speeds up, then slows down at the end of the animation.
             * @deprecated Use [Titanium.UI.ANIMATION_CURVE_EASE_IN_OUT](Titanium.UI.ANIMATION_CURVE_EASE_IN_OUT) instead.
             */
            const ANIMATION_CURVE_EASE_IN_OUT: never;

            /**
             * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that starts
             * quickly, then slows down at the end of the animation.
             * @deprecated Use [Titanium.UI.ANIMATION_CURVE_EASE_OUT](Titanium.UI.ANIMATION_CURVE_EASE_OUT) instead.
             */
            const ANIMATION_CURVE_EASE_OUT: never;

            /**
             * Use with [Animation.curve](Titanium.UI.Animation.curve) to specify an animation that proceeds
             * at a constant rate.
             * @deprecated Use [Titanium.UI.ANIMATION_CURVE_LINEAR](Titanium.UI.ANIMATION_CURVE_LINEAR) instead.
             */
            const ANIMATION_CURVE_LINEAR: never;

            /**
             * Use with <Attribute.type> to specify a background color.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_BACKGROUND_COLOR](Titanium.UI.ATTRIBUTE_BACKGROUND_COLOR) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_BACKGROUND_COLOR: never;

            /**
             * Use with <Attribute.type> to apply a different baseline to the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_BASELINE_OFFSET](Titanium.UI.ATTRIBUTE_BASELINE_OFFSET) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_BASELINE_OFFSET: never;

            /**
             * Use with <Attribute.type> to stretch the text horizontally.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_EXPANSION](Titanium.UI.ATTRIBUTE_EXPANSION) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_EXPANSION: never;

            /**
             * Use with <Attribute.type> to specify a font.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_FONT](Titanium.UI.ATTRIBUTE_FONT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_FONT: never;

            /**
             * Use with <Attribute.type> to specify a font color.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_FOREGROUND_COLOR](Titanium.UI.ATTRIBUTE_FOREGROUND_COLOR) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_FOREGROUND_COLOR: never;

            /**
             * Use with <Attribute.type> to specify kerning (space between characters).
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_KERN](Titanium.UI.ATTRIBUTE_KERN) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_KERN: never;

            /**
             * Use with <Attribute.value> to use a letterpress text effect.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_LETTERPRESS_STYLE](Titanium.UI.ATTRIBUTE_LETTERPRESS_STYLE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_LETTERPRESS_STYLE: never;

            /**
             * Use with <Attribute.type> to enable or disable ligatures.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_LIGATURE](Titanium.UI.ATTRIBUTE_LIGATURE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_LIGATURE: never;

            /**
             * Use with <Attribute.type> to create a link.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_LINK](Titanium.UI.ATTRIBUTE_LINK) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_LINK: never;

            /**
             * Use with <Attribute.type> to skew the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_OBLIQUENESS](Titanium.UI.ATTRIBUTE_OBLIQUENESS) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_OBLIQUENESS: never;

            /**
             * Use with <Attribute.type> to display a shadow behind the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_SHADOW](Titanium.UI.ATTRIBUTE_SHADOW) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_SHADOW: never;

            /**
             * Use with <Attribute.type> to change the color of the horizontal line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_STRIKETHROUGH_COLOR](Titanium.UI.ATTRIBUTE_STRIKETHROUGH_COLOR) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_STRIKETHROUGH_COLOR: never;

            /**
             * Use with <Attribute.type> to place a horizontal line through the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_STRIKETHROUGH_STYLE](Titanium.UI.ATTRIBUTE_STRIKETHROUGH_STYLE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_STRIKETHROUGH_STYLE: never;

            /**
             * Use with <Attribute.type> to specify a color for the stroke text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_STROKE_COLOR](Titanium.UI.ATTRIBUTE_STROKE_COLOR) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_STROKE_COLOR: never;

            /**
             * Use with <Attribute.type> to specify the width of the stroke text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_STROKE_WIDTH](Titanium.UI.ATTRIBUTE_STROKE_WIDTH) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_STROKE_WIDTH: never;

            /**
             * Use with <Attribute.type> to apply a text effect.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_TEXT_EFFECT](Titanium.UI.ATTRIBUTE_TEXT_EFFECT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_TEXT_EFFECT: never;

            /**
             * Use with <Attribute.type> to place a horizontal line under the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINES_STYLE](Titanium.UI.ATTRIBUTE_UNDERLINES_STYLE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINES_STYLE: never;

            /**
             * Use with <Attribute.value> to draw a line only underneath or through words.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_BY_WORD](Titanium.UI.ATTRIBUTE_UNDERLINE_BY_WORD) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_BY_WORD: never;

            /**
             * Use with <Attribute.type> to change the color of the horizontal line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_COLOR](Titanium.UI.ATTRIBUTE_UNDERLINE_COLOR) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_COLOR: never;

            /**
             * Use with <Attribute.value> to draw a dashed line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH](Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_PATTERN_DASH: never;

            /**
             * Use with <Attribute.value> to draw an alternating line of dashes and dots.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT](Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT: never;

            /**
             * Use with <Attribute.value> to draw an alternating line of dashes and two dots.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT_DOT](Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT_DOT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_PATTERN_DASH_DOT_DOT: never;

            /**
             * Use with <Attribute.value> to draw a dotted line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DOT](Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_DOT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_PATTERN_DOT: never;

            /**
             * Use with <Attribute.value> to draw a solid line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_SOLID](Titanium.UI.ATTRIBUTE_UNDERLINE_PATTERN_SOLID) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_PATTERN_SOLID: never;

            /**
             * Use with <Attribute.value> to draw a double line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_DOUBLE](Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_DOUBLE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_STYLE_DOUBLE: never;

            /**
             * Use with <Attribute.value> to not draw a line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_NONE](Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_NONE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_STYLE_NONE: never;

            /**
             * Use with <Attribute.value> to draw a single line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_SINGLE](Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_SINGLE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_STYLE_SINGLE: never;

            /**
             * Use with <Attribute.value> to draw a thick line.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_THICK](Titanium.UI.ATTRIBUTE_UNDERLINE_STYLE_THICK) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_UNDERLINE_STYLE_THICK: never;

            /**
             * Use with <Attribute.type> to control the direction of the text.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION: never;

            /**
             * Use with <Attribute.value> to use the embedded text direction.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_EMBEDDING](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_EMBEDDING) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION_EMBEDDING: never;

            /**
             * Use with <Attribute.value> to write text left to right.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_LEFT_TO_RIGHT](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_LEFT_TO_RIGHT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION_LEFT_TO_RIGHT: never;

            /**
             * Use with <Attribute.value> to use the
             * [Unicode Bidirection Algorithm rules P2 and P3](http://www.unicode.org/reports/tr9/#The_Paragraph_Level)
             * to determine which direction to use.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_NATURAL](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_NATURAL) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION_NATURAL: never;

            /**
             * Use with <Attribute.value> to override the text direction.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_OVERRIDE](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_OVERRIDE) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION_OVERRIDE: never;

            /**
             * Use with <Attribute.value> to write text right to left.
             * @deprecated Use the [Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_RIGHT_TO_LEFT](Titanium.UI.ATTRIBUTE_WRITING_DIRECTION_RIGHT_TO_LEFT) constant instead (without the iOS namespace).
             */
            const ATTRIBUTE_WRITING_DIRECTION_RIGHT_TO_LEFT: never;

            /**
             * All media types require a user gesture to begin playing.
             */
            const AUDIOVISUAL_MEDIA_TYPE_ALL: number;

            /**
             * Media types containing audio require a user gesture to begin playing.
             */
            const AUDIOVISUAL_MEDIA_TYPE_AUDIO: number;

            /**
             * No media types require a user gesture to begin playing.
             */
            const AUDIOVISUAL_MEDIA_TYPE_NONE: number;

            /**
             * Media types containing video require a user gesture to begin playing.
             */
            const AUDIOVISUAL_MEDIA_TYPE_VIDEO: number;

            /**
             * Converts strings formatted as addresses into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_MAP_ADDRESSES](Titanium.UI.AUTOLINK_MAP_ADDRESSES) instead.
             */
            const AUTODETECT_ADDRESS: never;

            /**
             * Converts all detectable types of data into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_ALL](Titanium.UI.AUTOLINK_ALL) instead.
             */
            const AUTODETECT_ALL: never;

            /**
             * Converts strings formatted as calendar events into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_CALENDAR](Titanium.UI.AUTOLINK_CALENDAR) instead.
             */
            const AUTODETECT_CALENDAR: never;

            /**
             * Converts strings formatted as URLs into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_URLS](Titanium.UI.AUTOLINK_URLS) instead.
             */
            const AUTODETECT_LINK: never;

            /**
             * Disables converting strings into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_NONE](Titanium.UI.AUTOLINK_NONE) instead.
             */
            const AUTODETECT_NONE: never;

            /**
             * Converts strings formatted as phone numbers into clickable links.
             * @deprecated Use [Titanium.UI.AUTOLINK_PHONE_NUMBERS](Titanium.UI.AUTOLINK_PHONE_NUMBERS) instead.
             */
            const AUTODETECT_PHONE: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_CLEAR](Titanium.UI.BLEND_MODE_CLEAR) instead.
             */
            const BLEND_MODE_CLEAR: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_COLOR](Titanium.UI.BLEND_MODE_COLOR) instead.
             */
            const BLEND_MODE_COLOR: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_COLOR_BURN](Titanium.UI.BLEND_MODE_COLOR_BURN) instead.
             */
            const BLEND_MODE_COLOR_BURN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_COLOR_DODGE](Titanium.UI.BLEND_MODE_COLOR_DODGE) instead.
             */
            const BLEND_MODE_COLOR_DODGE: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_COPY](Titanium.UI.BLEND_MODE_COPY) instead.
             */
            const BLEND_MODE_COPY: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DARKEN](Titanium.UI.BLEND_MODE_DARKEN) instead.
             */
            const BLEND_MODE_DARKEN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DESTINATION_ATOP](Titanium.UI.BLEND_MODE_DESTINATION_ATOP) instead.
             */
            const BLEND_MODE_DESTINATION_ATOP: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DESTINATION_IN](Titanium.UI.BLEND_MODE_DESTINATION_IN) instead.
             */
            const BLEND_MODE_DESTINATION_IN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DESTINATION_OUT](Titanium.UI.BLEND_MODE_DESTINATION_OUT) instead.
             */
            const BLEND_MODE_DESTINATION_OUT: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DESTINATION_OVER](Titanium.UI.BLEND_MODE_DESTINATION_OVER) instead.
             */
            const BLEND_MODE_DESTINATION_OVER: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_DIFFERENCE](Titanium.UI.BLEND_MODE_DIFFERENCE) instead.
             */
            const BLEND_MODE_DIFFERENCE: never;

            /**
             * Image mode constant. Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_EXCLUSION](Titanium.UI.BLEND_MODE_EXCLUSION) instead.
             */
            const BLEND_MODE_EXCLUSION: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_HARD_LIGHT](Titanium.UI.BLEND_MODE_HARD_LIGHT) instead.
             */
            const BLEND_MODE_HARD_LIGHT: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_HUE](Titanium.UI.BLEND_MODE_HUE) instead.
             */
            const BLEND_MODE_HUE: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_LIGHTEN](Titanium.UI.BLEND_MODE_LIGHTEN) instead.
             */
            const BLEND_MODE_LIGHTEN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_LUMINOSITY](Titanium.UI.BLEND_MODE_LUMINOSITY) instead.
             */
            const BLEND_MODE_LUMINOSITY: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_MULTIPLY](Titanium.UI.BLEND_MODE_MULTIPLY) instead.
             */
            const BLEND_MODE_MULTIPLY: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_NORMAL](Titanium.UI.BLEND_MODE_NORMAL) instead.
             */
            const BLEND_MODE_NORMAL: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_OVERLAY](Titanium.UI.BLEND_MODE_OVERLAY) instead.
             */
            const BLEND_MODE_OVERLAY: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_PLUS_DARKER](Titanium.UI.BLEND_MODE_PLUS_DARKER) instead.
             */
            const BLEND_MODE_PLUS_DARKER: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_PLUS_LIGHTER](Titanium.UI.BLEND_MODE_PLUS_LIGHTER) instead.
             */
            const BLEND_MODE_PLUS_LIGHTER: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SATURATION](Titanium.UI.BLEND_MODE_SATURATION) instead.
             */
            const BLEND_MODE_SATURATION: never;

            /**
             * Image mode constant. Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SCREEN](Titanium.UI.BLEND_MODE_SCREEN) instead.
             */
            const BLEND_MODE_SCREEN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SOFT_LIGHT](Titanium.UI.BLEND_MODE_SOFT_LIGHT) instead.
             */
            const BLEND_MODE_SOFT_LIGHT: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SOURCE_ATOP](Titanium.UI.BLEND_MODE_SOURCE_ATOP) instead.
             */
            const BLEND_MODE_SOURCE_ATOP: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SOURCE_IN](Titanium.UI.BLEND_MODE_SOURCE_IN) instead.
             */
            const BLEND_MODE_SOURCE_IN: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_SOURCE_OUT](Titanium.UI.BLEND_MODE_SOURCE_OUT) instead.
             */
            const BLEND_MODE_SOURCE_OUT: never;

            /**
             * Use with [MaskedImage.mode](Titanium.UI.MaskedImage.mode) to specify a blend mode.
             * @deprecated Use [Titanium.UI.BLEND_MODE_XOR](Titanium.UI.BLEND_MODE_XOR) instead.
             */
            const BLEND_MODE_XOR: never;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_EXTRA_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_PROMINENT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_REGULAR: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_CHROME_MATERIAL: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_CHROME_MATERIAL_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_CHROME_MATERIAL_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_MATERIAL: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_MATERIAL_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_MATERIAL_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THICK_MATERIAL: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THICK_MATERIAL_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THICK_MATERIAL_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THIN_MATERIAL: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THIN_MATERIAL_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_THIN_MATERIAL_LIGHT: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_ULTRA_THIN_MATERIAL: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_ULTRA_THIN_MATERIAL_DARK: number;

            /**
             * Use with [BlurView.effect](Titanium.UI.iOS.BlurView.effect) to specify a blur effect.
             */
            const BLUR_EFFECT_STYLE_SYSTEM_ULTRA_THIN_MATERIAL_LIGHT: number;

            /**
             * Specifies that the data for the URL load should be loaded from the originating source.
             * No existing cache data should be used to satisfy a URL load request.
             */
            const CACHE_POLICY_RELOAD_IGNORING_LOCAL_CACHE_DATA: number;

            /**
             * Specifies that the existing cache data should be used to satisfy a request,
             * regardless of its age or expiration date.
             */
            const CACHE_POLICY_RETURN_CACHE_DATA_DONT_LOAD: number;

            /**
             * Specifies that the existing cached data should be used to satisfy the request,
             * regardless of its age or expiration date.
             */
            const CACHE_POLICY_RETURN_CACHE_DATA_ELSE_LOAD: number;

            /**
             * Specifies that the caching logic defined in the protocol implementation, if any,
             * is used for a particular URL load request.
             */
            const CACHE_POLICY_USE_PROTOCOL_CACHE_POLICY: number;

            /**
             * Use with <Titanium.UI.View.clipMode> to specify clipping behavior.
             */
            const CLIP_MODE_DEFAULT: number;

            /**
             * Use with <Titanium.UI.View.clipMode> to specify clipping behavior.
             */
            const CLIP_MODE_DISABLED: number;

            /**
             * Use with <Titanium.UI.View.clipMode> to specify clipping behavior.
             */
            const CLIP_MODE_ENABLED: number;

            /**
             * Use with <Titanium.UI.iOS.CollisionBehavior.collisionMode> to specify collisions with both items and
             * boundaries.
             */
            const COLLISION_MODE_ALL: number;

            /**
             * Use with <Titanium.UI.iOS.CollisionBehavior.collisionMode> to specify collisions with
             * boundaries only.
             */
            const COLLISION_MODE_BOUNDARY: number;

            /**
             * Use with <Titanium.UI.iOS.CollisionBehavior.collisionMode> to specify collisions with items only.
             */
            const COLLISION_MODE_ITEM: number;

            /**
             * Credential should be stored only for this session.
             */
            const CREDENTIAL_PERSISTENCE_FOR_SESSION: number;

            /**
             * Credential should not be stored.
             */
            const CREDENTIAL_PERSISTENCE_NONE: number;

            /**
             * Credential should be stored in the keychain.
             */
            const CREDENTIAL_PERSISTENCE_PERMANENT: number;

            /**
             * Credential should be stored permanently in the keychain, and in addition should be
             * distributed to other devices based on the owning AppleID.
             */
            const CREDENTIAL_PERSISTENCE_SYNCHRONIZABLE: number;

            /**
             * Use with <Titanium.UI.Picker.datePickerStyle> to automatically pick the best style
             * available for the current platform & mode.
             */
            const DATE_PICKER_STYLE_AUTOMATIC: number;

            /**
             * Use with <Titanium.UI.Picker.datePickerStyle> to show the picker with a compact style. Editing occurs in an overlay.
             */
            const DATE_PICKER_STYLE_COMPACT: number;

            /**
             * Use with <Titanium.UI.Picker.datePickerStyle> to allow editing in place (as a calendar).
             */
            const DATE_PICKER_STYLE_INLINE: number;

            /**
             * Use with <Titanium.UI.Picker.datePickerStyle> to show the picker the wheels. Editing occurs inline.
             */
            const DATE_PICKER_STYLE_WHEELS: number;

            /**
             * The heavy impact style used as the `style` argument when creating a <Titanium.UI.iOS.FeedbackGenerator> with the
             * type <Titanium.UI.iOS.FEEDBACK_GENERATOR_TYPE_IMPACT>.
             */
            const FEEDBACK_GENERATOR_IMPACT_STYLE_HEAVY: number;

            /**
             * The light impact style used as the `style` argument when creating a <Titanium.UI.iOS.FeedbackGenerator> with the
             * type <Titanium.UI.iOS.FEEDBACK_GENERATOR_TYPE_IMPACT>.
             */
            const FEEDBACK_GENERATOR_IMPACT_STYLE_LIGHT: number;

            /**
             * The medium impact style used as the `style` argument when creating a <Titanium.UI.iOS.FeedbackGenerator> with the
             * type <Titanium.UI.iOS.FEEDBACK_GENERATOR_TYPE_IMPACT>.
             */
            const FEEDBACK_GENERATOR_IMPACT_STYLE_MEDIUM: number;

            /**
             * The error notification type used as the argument in <Titanium.UI.iOS.FeedbackGenerator.notificationOccurred>.
             */
            const FEEDBACK_GENERATOR_NOTIFICATION_TYPE_ERROR: number;

            /**
             * The success notification type used as the argument in <Titanium.UI.iOS.FeedbackGenerator.notificationOccurred>.
             */
            const FEEDBACK_GENERATOR_NOTIFICATION_TYPE_SUCCESS: number;

            /**
             * The warning notification type used as the argument in <Titanium.UI.iOS.FeedbackGenerator.notificationOccurred>.
             */
            const FEEDBACK_GENERATOR_NOTIFICATION_TYPE_WARNING: number;

            /**
             * The feedback type to be used when specifying an impact in <Titanium.UI.iOS.FeedbackGenerator>.
             */
            const FEEDBACK_GENERATOR_TYPE_IMPACT: number;

            /**
             * The feedback type to be used when specifying a received notification in <Titanium.UI.iOS.FeedbackGenerator>.
             */
            const FEEDBACK_GENERATOR_TYPE_NOTIFICATION: number;

            /**
             * The feedback type to be used when specifying a selection in <Titanium.UI.iOS.FeedbackGenerator>.
             */
            const FEEDBACK_GENERATOR_TYPE_SELECTION: number;

            /**
             * Inject the script after the document finishes loading, but before other subresources finish loading.
             */
            const INJECTION_TIME_DOCUMENT_END: number;

            /**
             * Inject the script after the document element is created, but before any other content is loaded.
             */
            const INJECTION_TIME_DOCUMENT_START: number;

            /**
             * Use with <Titanium.UI.ScrollView.keyboardDismissMode> to control keyboard dismiss mode.
             */
            const KEYBOARD_DISMISS_MODE_INTERACTIVE: number;

            /**
             * Use with <Titanium.UI.ScrollView.keyboardDismissMode> to control keyboard dismiss mode.
             */
            const KEYBOARD_DISMISS_MODE_NONE: number;

            /**
             * Use with <Titanium.UI.ScrollView.keyboardDismissMode> to control keyboard dismiss mode.
             */
            const KEYBOARD_DISMISS_MODE_ON_DRAG: number;

            /**
             * Always use a larger title when this item is top most.
             */
            const LARGE_TITLE_DISPLAY_MODE_ALWAYS: number;

            /**
             * Automatically use the large out-of-line title based on the state of the p
             * revious item in the navigation bar.
             */
            const LARGE_TITLE_DISPLAY_MODE_AUTOMATIC: number;

            /**
             * Never use a larger title when this item is top most.
             */
            const LARGE_TITLE_DISPLAY_MODE_NEVER: number;

            /**
             * To indicate that the Live Photo aspect is turned off and it will
             * be treated as a still (e.g. for sharing).
             */
            const LIVEPHOTO_BADGE_OPTIONS_LIVE_OFF: number;

            /**
             * Include treatments so this image can be shown directly over the content
             * of the Live Photo.
             */
            const LIVEPHOTO_BADGE_OPTIONS_OVER_CONTENT: number;

            /**
             * Plays back the entire motion and sound content of the Live Photo, including transition
             * effects at the start and end.
             */
            const LIVEPHOTO_PLAYBACK_STYLE_FULL: number;

            /**
             * Plays back only a brief section of the motion content of the Live Photo, without sound.
             */
            const LIVEPHOTO_PLAYBACK_STYLE_HINT: number;

            /**
             * An arrow that is automatically aligned.
             */
            const MENU_POPUP_ARROW_DIRECTION_DEFAULT: number;

            /**
             * An arrow that points downward.
             */
            const MENU_POPUP_ARROW_DIRECTION_DOWN: number;

            /**
             * An arrow that points toward the left.
             */
            const MENU_POPUP_ARROW_DIRECTION_LEFT: number;

            /**
             * An arrow that points toward the right.
             */
            const MENU_POPUP_ARROW_DIRECTION_RIGHT: number;

            /**
             * An arrow that points upward.
             */
            const MENU_POPUP_ARROW_DIRECTION_UP: number;

            /**
             * View presented with the same style as its parent window.
             */
            let MODAL_PRESENTATION_CURRENT_CONTEXT: number;

            /**
             * Window width and height are smaller than those of the screen and the view is centered on
             * the screen.
             */
            const MODAL_PRESENTATION_FORMSHEET: number;

            /**
             * Window covers the screen.
             */
            const MODAL_PRESENTATION_FULLSCREEN: number;

            /**
             * View presented over its parent window.
             */
            let MODAL_PRESENTATION_OVER_CURRENT_CONTEXT: number;

            /**
             * Presented view covers the screen.
             */
            let MODAL_PRESENTATION_OVER_CURRENT_FULL_SCREEN: number;

            /**
             * Window height is the height of the screen and width is equal to screen width in a portrait
             * orientation.
             */
            const MODAL_PRESENTATION_PAGESHEET: number;

            /**
             * When the window is presented, its view slides up from the bottom of the screen. On dismissal,
             * the view slides back down (default.)
             */
            const MODAL_TRANSITION_STYLE_COVER_VERTICAL: number;

            /**
             * When the window is presented, the current view fades out while the new view fades in at the
             * same time. On dismissal, a similar type of cross-fade is used to return to the original view.
             */
            const MODAL_TRANSITION_STYLE_CROSS_DISSOLVE: number;

            /**
             * When the window is presented, the current view initiates a horizontal 3D flip from
             * right-to-left, resulting in the revealing of the new view as if it were on the back of the
             * previous view. On dismissal, the flip occurs from left-to-right, returning to the original
             * view.
             */
            const MODAL_TRANSITION_STYLE_FLIP_HORIZONTAL: number;

            /**
             * When the window is presented, one corner of the current view curls up to reveal the modal
             * view underneath. On dismissal, the curled up page unfurls itself back on top of the modal
             * view.
             */
            const MODAL_TRANSITION_STYLE_PARTIAL_CURL: number;

            /**
             * The normal style for preview actions.
             */
            const PREVIEW_ACTION_STYLE_DEFAULT: number;

            /**
             * The destructive style for preview actions.
             */
            const PREVIEW_ACTION_STYLE_DESTRUCTIVE: number;

            /**
             * The selected style for preview actions.
             */
            const PREVIEW_ACTION_STYLE_SELECTED: number;

            /**
             * Use with <Titanium.UI.iOS.PushBehavior.pushMode> to specifiy a continuous force.
             */
            const PUSH_MODE_CONTINUOUS: number;

            /**
             * Use with <Titanium.UI.iOS.PushBehavior.pushMode> to specifiy an instantaneous force.
             */
            const PUSH_MODE_INSTANTANEOUS: number;

            /**
             * The default style for <RowActionType>.
             */
            const ROW_ACTION_STYLE_DEFAULT: number;

            /**
             * The destructive style for <RowActionType>.
             */
            const ROW_ACTION_STYLE_DESTRUCTIVE: number;

            /**
             * The normal style for <RowActionType>.
             */
            const ROW_ACTION_STYLE_NORMAL: number;

            /**
             * Use with <Titanium.UI.ScrollView.decelerationRate> to control deceleration rate.
             */
            const SCROLL_DECELERATION_RATE_FAST: number;

            /**
             * Use with <Titanium.UI.ScrollView.decelerationRate> to control deceleration rate.
             */
            const SCROLL_DECELERATION_RATE_NORMAL: number;

            /**
             * Use with <Titanium.UI.SearchBar.style> to change the search bar style.
             */
            const SEARCH_BAR_STYLE_MINIMAL: number;

            /**
             * Use with <Titanium.UI.SearchBar.style> to change the search bar style.
             */
            const SEARCH_BAR_STYLE_PROMINENT: number;

            /**
             * Selection endpoints can be placed at any character boundary.
             */
            const SELECTION_GRANULARITY_CHARACTER: number;

            /**
             * Selection granularity varies automatically depending on the selection.
             */
            const SELECTION_GRANULARITY_DYNAMIC: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_ADD: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_ALARM: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_AUDIO: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_BOOKMARK: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_CAPTURE_PHOTO: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_CAPTURE_VIDEO: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_CLOUD: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_COMPOSE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_CONFIRMATION: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_CONTACT: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_DATE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_FAVORITE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_HOME: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_INVITATION: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_LOCATION: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_LOVE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_MAIL: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_MARK_LOCATION: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_MESSAGE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_PAUSE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_PLAY: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_PROHIBIT: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_SEARCH: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_SHARE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_SHUFFLE: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_TASK: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_TASK_COMPLETED: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_TIME: number;

            /**
             * Number that represents the icon used for the application shortcut
             */
            const SHORTCUT_ICON_TYPE_UPDATE: number;

            /**
             * String that represents the magnifying glass on the table view index bar
             */
            const TABLEVIEW_INDEX_SEARCH: string;

            /**
             * User tapped the back or forward button.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_BACK_FORWARD: never;

            /**
             * User resubmitted a form.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_FORM_RESUBMITTED: never;

            /**
             * User submitted a form.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_FORM_SUBMITTED: never;

            /**
             * User tapped a link.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_LINK_CLICKED: never;

            /**
             * Some other action occurred.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_OTHER: never;

            /**
             * User tapped the reload button.
             * @deprecated Not used with Titanium SDK 8.0.0 and later by replacing UIWebView with WKWebView.
             */
            const WEBVIEW_NAVIGATIONTYPE_RELOAD: never;

            /**
             * A set of constants for the style that can be used for the `style` property of
             * <Titanium.UI.AlertDialog>.
             */
            namespace AlertDialogStyle {
                /**
                 * A standard alert dialog. This is the default value.
                 */
                const DEFAULT: number;

                /**
                 * An alert dialog that allows the user to enter login identifier and password.
                 */
                const LOGIN_AND_PASSWORD_INPUT: number;

                /**
                 * An alert dialog that allows the user to enter text.
                 */
                const PLAIN_TEXT_INPUT: number;

                /**
                 * An alert dialog that allows the user to enter text. The text field is obscured.
                 */
                const SECURE_TEXT_INPUT: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the animation styles used for view transitions.
             * One of the group of animation style constants
             *   * [CURL_DOWN](Titanium.UI.iOS.AnimationStyle.CURL_DOWN)
             *   * [CURL_UP](Titanium.UI.iOS.AnimationStyle.CURL_UP)
             *   * [FLIP_FROM_LEFT](Titanium.UI.iOS.AnimationStyle.FLIP_FROM_LEFT)
             *   * [FLIP_FROM_RIGHT](Titanium.UI.iOS.AnimationStyle.FLIP_FROM_RIGHT)
             *   * [FLIP_FROM_TOP](Titanium.UI.iOS.AnimationStyle.FLIP_FROM_TOP)
             *   * [FLIP_FROM_BOTTOM](Titanium.UI.iOS.AnimationStyle.FLIP_FROM_BOTTOM)
             *   * [CROSS_DISSOLVE](Titanium.UI.iOS.AnimationStyle.CROSS_DISSOLVE)
             *   * [NONE](Titanium.UI.iOS.AnimationStyle.NONE)
             */
            namespace AnimationStyle {
                /**
                 * A transition that dissolves from one view to the next.
                 */
                const CROSS_DISSOLVE: number;

                /**
                 * Curl downwards during a transition animation.
                 */
                const CURL_DOWN: number;

                /**
                 * Curl upwards during a transition animation.
                 */
                const CURL_UP: number;

                /**
                 * Flip from bottom to top during a transition animation.
                 */
                const FLIP_FROM_BOTTOM: number;

                /**
                 * Flip from left to right during a transition animation.
                 */
                const FLIP_FROM_LEFT: number;

                /**
                 * Flip from right to left during a transition animation.
                 */
                const FLIP_FROM_RIGHT: number;

                /**
                 * Flip from top to bottom during a transition animation.
                 */
                const FLIP_FROM_TOP: number;

                /**
                 * No animation.
                 */
                const NONE: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the style that can be used for the `selectionStyle` property of a
             * ListItem, which is set in the `properties` dictionary of either the <ListDataItem> or
             * <ItemTemplate>.
             */
            namespace ListViewCellSelectionStyle {
                /**
                 * The cell when selected has a blue background. This is the default value.
                 */
                const BLUE: number;

                /**
                 * The cell when selected has a gray background.
                 */
                const GRAY: number;

                /**
                 * The cell has no distinct style for when it is selected.
                 */
                const NONE: number;

            }
            /**
             * A set of constants for the position value that can be used for the `position` property of
             * <ListViewAnimationProperties> when invoking the ListView's `scrollToItem`, `appendSection`,
             * `deleteSectionAt`, `insertSectionAt` and `replaceSectionAt` methods.
             */
            namespace ListViewScrollPosition {
                /**
                 * The list view scrolls the row of interest to the bottom of the visible list view.
                 */
                const BOTTOM: number;

                /**
                 * The list view scrolls the row of interest to the middle of the list table view.
                 */
                const MIDDLE: number;

                /**
                 * The table view scrolls the row of interest to be fully visible with a minimal movement.
                 * If the row is already fully visible, no scrolling occurs. For example, if the row is above the
                 * visible area, the behavior is identical to that specified by `TOP`. This is the default.
                 */
                const NONE: number;

                /**
                 * The list view scrolls the row of interest to the top of the visible list view.
                 */
                const TOP: number;

            }
            /**
             * A set of constants for the style that can be used for the `style` property of
             * <Titanium.UI.ListView>.
             */
            namespace ListViewStyle {
                /**
                 * A list view whose sections present distinct groups of rows. The section headers and footers
                 * do not float.
                 */
                const GROUPED: number;

                /**
                 * A plain list view. Any section headers or footers are displayed as inline separators and
                 * float when the list view is scrolled.
                 */
                const PLAIN: number;

            }
            /**
             * A set of constants for the bar styles used on the `style` property of <Titanium.UI.ProgressBar>.
             */
            namespace ProgressBarStyle {
                /**
                 * The style of progress view that is used in a toolbar.
                 */
                const BAR: number;

                /**
                 * he standard progress-view style. This is the default.
                 */
                const DEFAULT: number;

                /**
                 * The standard progress-view style. Same as `DEFAULT`.
                 */
                const PLAIN: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the Animation Styles used for transition on table view rows.
             */
            namespace RowAnimationStyle {
                /**
                 * The inserted row or rows slides in from the bottom; the deleted row or rows slides out
                 * toward the bottom.
                 */
                const BOTTOM: number;

                /**
                 * The inserted or deleted row or rows fades into or out of the table view.
                 */
                const FADE: number;

                /**
                 * The inserted row or rows slides in from the left; the deleted row or rows slides out to the
                 * left.
                 */
                const LEFT: number;

                /**
                 * No animation is performed. The new cell value appears as if the cell had just been reloaded.
                 */
                const NONE: number;

                /**
                 * The inserted row or rows slides in from the right; the deleted row or rows slides out to
                 * the right.
                 */
                const RIGHT: number;

                /**
                 * The inserted row or rows slides in from the top; the deleted row or rows slides out toward
                 * the top.
                 */
                const TOP: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the styles available for scrollbars used with <Titanium.UI.ScrollView.scrollIndicatorStyle> and <Titanium.UI.TableView.scrollIndicatorStyle> properties.
             */
            namespace ScrollIndicatorStyle {
                /**
                 * A style of indicator which is black smaller than the default style. This style is good
                 * against a white content background.
                 */
                const BLACK: number;

                /**
                 * The default style of scroll indicator, which is black with a white border. This style is
                 * good against any content background.
                 */
                const DEFAULT: number;

                /**
                 * A style of indicator is white and smaller than the default style. This style is good against
                 * a black content background.
                 */
                const WHITE: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the status bar style.
             */
            namespace StatusBar {
                /**
                 * Fade animation style, when the status bar is hidden or shown.
                 */
                const ANIMATION_STYLE_FADE: number;

                /**
                 * No animation style, when the status bar is hidden or shown.
                 */
                const ANIMATION_STYLE_NONE: number;

                /**
                 * Slide animation style, when the status bar is hidden or shown.
                 */
                const ANIMATION_STYLE_SLIDE: number;

                /**
                 * Status bar style to use with light backgrounds.
                 */
                const DARK_CONTENT: number;

                /**
                 * Default status bar style.
                 */
                const DEFAULT: number;

                /**
                 * Gray-colored status bar style.
                 * @deprecated Use [Titanium.UI.iOS.StatusBar.DEFAULT](Titanium.UI.iOS.StatusBar.DEFAULT) instead.
                 */
                const GRAY: number;

                /**
                 * Gray-colored status bar style.
                 * @deprecated Use [Titanium.UI.iOS.StatusBar.DEFAULT](Titanium.UI.iOS.StatusBar.DEFAULT) instead.
                 */
                const GREY: number;

                /**
                 * Status bar style to use with dark backgrounds.
                 */
                const LIGHT_CONTENT: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for creating standard iOS system buttons.
             */
            namespace SystemButton {
                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify an **Action** button.
                 */
                const ACTION: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to create an activity indicator that
                 * can be used in navigation bars and toolbars.
                 */
                const ACTIVITY: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify an **Add** button.
                 */
                const ADD: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Bookmarks** button.
                 */
                const BOOKMARKS: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Camera** button.
                 */
                const CAMERA: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Cancel** button.
                 */
                const CANCEL: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Compose** button.
                 */
                const COMPOSE: number;

                /**
                 * Use with [Button.style](Titanium.UI.Button.style) to specify a **ContactAdd** button.
                 */
                const CONTACT_ADD: number;

                /**
                 * Use with [Button.style](Titanium.UI.Button.style) to specify a **Disclosure** button.
                 */
                const DISCLOSURE: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Done** button.
                 */
                const DONE: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify an **Edit** button.
                 */
                const EDIT: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Fast Forward** button.
                 */
                const FAST_FORWARD: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to create a fixed-width blank space
                 * for spacing items in toolbars.
                 */
                const FIXED_SPACE: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to create a flexible blank space
                 * for spacing items in toolbars.
                 */
                const FLEXIBLE_SPACE: number;

                /**
                 * Use with [Button.style](Titanium.UI.Button.style) to specify a dark-colored **Info** button.
                 */
                const INFO_DARK: number;

                /**
                 * Use with [Button.style](Titanium.UI.Button.style) to specify a light-colored **Info** button.
                 */
                const INFO_LIGHT: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify an **Organize** button.
                 */
                const ORGANIZE: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Pause** button.
                 */
                const PAUSE: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Play** button.
                 */
                const PLAY: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Refresh** button.
                 */
                const REFRESH: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Reply** button.
                 */
                const REPLY: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Rewind** button.
                 */
                const REWIND: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Save** button.
                 */
                const SAVE: number;

                /**
                 * Identical to [ACTIVITY](Titanium.UI.iOS.SystemButton.ACTIVITY).
                 */
                const SPINNER: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Stop** button.
                 */
                const STOP: number;

                /**
                 * Use with [Button.systemButton](Titanium.UI.Button.systemButton) to specify a **Trash** button.
                 */
                const TRASH: number;

            }
            /**
             * A set of constants for the system button styles that can be used for the button `style` property.
             */
            namespace SystemButtonStyle {
                /**
                 * A simple button style with a border.
                 */
                const BORDERED: number;

                /**
                 * The style for a **Done** button--for example, a button that completes some task and returns
                 * to the previous view.
                 */
                const DONE: number;

                /**
                 * Specifies a borderless button, the default style for toolbars, button bars, and tabbed bars.
                 */
                const PLAIN: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the system icon styles that can be used on a tab group tab.
             */
            namespace SystemIcon {
                /**
                 * Bookmark style icon
                 */
                const BOOKMARKS: number;

                /**
                 * Contacts style icon
                 */
                const CONTACTS: number;

                /**
                 * Downloads style icon
                 */
                const DOWNLOADS: number;

                /**
                 * Favorites style icon
                 */
                const FAVORITES: number;

                /**
                 * Featured style icon
                 */
                const FEATURED: number;

                /**
                 * History style icon
                 */
                const HISTORY: number;

                /**
                 * More style icon
                 */
                const MORE: number;

                /**
                 * Most recent style icon
                 */
                const MOST_RECENT: number;

                /**
                 * Most viewed style icon
                 */
                const MOST_VIEWED: number;

                /**
                 * Recents style icon
                 */
                const RECENTS: number;

                /**
                 * Search style icon
                 */
                const SEARCH: number;

                /**
                 * Top rated style icon
                 */
                const TOP_RATED: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the style that can be used for the `selectionStyle` property of
             * <Titanium.UI.TableViewRow>.
             */
            namespace TableViewCellSelectionStyle {
                /**
                 * The cell when selected has a blue background. This is the default value.
                 */
                const BLUE: number;

                /**
                 * Then cell when selected has a gray background.
                 */
                const GRAY: number;

                /**
                 * The cell has no distinct style for when it is selected.
                 */
                const NONE: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the position value that can be used for the `position` property of
             * <Titanium.UI.TableView> when invoking `scrollToIndex`.
             */
            namespace TableViewScrollPosition {
                /**
                 * The table view scrolls the row of interest to the bottom of the visible table view.
                 */
                const BOTTOM: number;

                /**
                 * The table view scrolls the row of interest to the middle of the visible table view.
                 */
                const MIDDLE: number;

                /**
                 * The table view scrolls the row of interest to be fully visible with a minimum of movement. If the row is already fully visible, no scrolling occurs. For example, if the row is above the visible area, the behavior is identical to that specified by `TOP`. This is the default.
                 */
                const NONE: number;

                /**
                 * The table view scrolls the row of interest to the top of the visible table view.
                 */
                const TOP: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * A set of constants for the style that can be used for the `style` property of
             * <Titanium.UI.TableView> and <Titanium.UI.ListView>.
             */
            namespace TableViewStyle {
                /**
                 * A table view whose sections present distinct groups of rows. The section headers and footers
                 * do not float.
                 */
                const GROUPED: number;

                /**
                 * A table view whose sections present distinct groups of rows  and grouped sections are inset with rounded corners.
                 * The section headers and footers do not float.
                 */
                const INSET_GROUPED: number;

                /**
                 * A plain table view. Any section headers or footers are displayed as inline separators and
                 * float when the table view is scrolled.
                 */
                const PLAIN: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                function addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                function fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                function removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * The AdView is a view for display Apple iAds.
             * @deprecated iAd has been deprecated in iOS 10 and SDK 5.5.0. It was removed as part of the SDK 7.0.0.
             */
            const AdView: never;
            /**
             * Dynamic behavior to support connections between an anchor point and an item.
             */
            class AnchorAttachmentBehavior extends Titanium.Proxy {
                /**
                 * Anchor point for the attachment behavior relative to the animator's coordinate system.
                 */
                anchor: Point;

                /**
                 * Amount of damping to apply to the attachment behavior.
                 */
                damping: number;

                /**
                 * Distance, in points, between the two attachment points.
                 */
                distance: number;

                /**
                 * Frequency of oscillation for the behavior.
                 */
                frequency: number;

                /**
                 * Item to connect to use the attachment behavior.
                 */
                item: Titanium.UI.View;

                /**
                 * Offset from the center point of the item for the attachment.
                 */
                offset: Point;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.anchor> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.anchor> instead.
                 */
                getAnchor(): Point;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.damping> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.damping> instead.
                 */
                getDamping(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.distance> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.distance> instead.
                 */
                getDistance(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.frequency> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.frequency> instead.
                 */
                getFrequency(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.item> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.item> instead.
                 */
                getItem(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.offset> property.
                 * @deprecated Access <Titanium.UI.iOS.AnchorAttachmentBehavior.offset> instead.
                 */
                getOffset(): Point;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.anchor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.anchor> instead.
                 */
                setAnchor(anchor: Point): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.damping> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.damping> instead.
                 */
                setDamping(damping: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.distance> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.distance> instead.
                 */
                setDistance(distance: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.frequency> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.frequency> instead.
                 */
                setFrequency(frequency: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.item> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.item> instead.
                 */
                setItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.AnchorAttachmentBehavior.offset> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.AnchorAttachmentBehavior.offset> instead.
                 */
                setOffset(offset: Point): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.Animator
             */
            interface AnimatorBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.Animator;

            }
            /**
             * Fired when the animator paused its animations.
             */
            interface Animator_pause_Event extends AnimatorBaseEvent {
            }
            /**
             * Fired when the animator resumes its animations.
             */
            interface Animator_resume_Event extends AnimatorBaseEvent {
            }
            interface AnimatorEventMap extends ProxyEventMap {
                pause: Animator_pause_Event;

                resume: Animator_resume_Event;

            }
            /**
             * Provides support for the built-in iOS dynamic animations
             */
            class Animator extends Titanium.Proxy {
                /**
                 * Behaviors associated with this animator.
                 */
                behaviors: Titanium.Proxy[];

                /**
                 * Titanium View object to initialize as the reference view for the animator.
                 */
                referenceView: Titanium.UI.View;

                /**
                 * Returns `true` if the animator is running else `false`.
                 */
                readonly running: boolean;

                /**
                 * Adds a dynamic behavior to the animator.
                 */
                addBehavior(behavior: Titanium.Proxy): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof AnimatorEventMap>(name: K, callback: (this: Titanium.UI.iOS.Animator, event: AnimatorEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof AnimatorEventMap>(name: K, event?: AnimatorEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Animator.behaviors> property.
                 * @deprecated Access <Titanium.UI.iOS.Animator.behaviors> instead.
                 */
                getBehaviors(): Titanium.Proxy[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.Animator.referenceView> property.
                 * @deprecated Access <Titanium.UI.iOS.Animator.referenceView> instead.
                 */
                getReferenceView(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Animator.running> property.
                 * @deprecated Access <Titanium.UI.iOS.Animator.running> instead.
                 */
                getRunning(): boolean;

                /**
                 * Removes all behaviors from this animator.
                 */
                removeAllBehaviors(): void;

                /**
                 * Removes the specified behavior from the animator.
                 */
                removeBehavior(behavior: Titanium.Proxy): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof AnimatorEventMap>(name: K, callback: (this: Titanium.UI.iOS.Animator, event: AnimatorEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Animator.behaviors> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Animator.behaviors> instead.
                 */
                setBehaviors(behaviors: ReadonlyArray<Titanium.Proxy>): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Animator.referenceView> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Animator.referenceView> instead.
                 */
                setReferenceView(referenceView: Titanium.UI.View): void;

                /**
                 * Starts the animation behaviors.
                 */
                startAnimator(): void;

                /**
                 * Stops the animation behaviors.
                 */
                stopAnimator(): void;

                /**
                 * Updates the animator's state information with the current state of the specified item.
                 */
                updateItemUsingCurrentState(item: Titanium.UI.View): void;

            }
            /**
             * The Home screen quick actions API is for adding shortcuts to your app icon that anticipate and accelerate a
             * user's interaction with your app.
             * @deprecated Use [Titanium.UI.Shortcut](Titanium.UI.Shortcut) instead.
             */
            class ApplicationShortcuts extends Titanium.Proxy {
                /**
                 * Creates a new dynamic application shortcut item.
                 */
                addDynamicShortcut(params: ShortcutParams): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Returns true or false depending if the provided shortcut object already exists.
                 */
                dynamicShortcutExists(identifier: string): boolean;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the dynamic application shortcut item identified by the `identifier`.
                 */
                getDynamicShortcut(identifier: string): ShortcutParams;

                /**
                 * Returns an array of the application shortcuts created dynamically.
                 */
                listDynamicShortcuts(): ShortcutParams[];

                /**
                 * Returns an array of the application shortcuts listed in your tiapp.xml file.
                 */
                listStaticShortcuts(): ShortcutParams[];

                /**
                 * Removes all dynamically created application shortcuts.
                 */
                removeAllDynamicShortcuts(): void;

                /**
                 * Removes the dynamic application shortcut item identified by the `identifier`.
                 */
                removeDynamicShortcut(identifier: string): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * An abstract datatype for specifying an attributed string attribute.
             * @deprecated Use [Attribute](Attribute) instead.
             */
            const Attribute: never;
            /**
             * An attributed string proxy manages character strings and associated sets of attributes (for example,
             * font and kerning) that apply to individual characters or ranges of characters in the string.
             * @deprecated Use [Titanium.UI.AttributedString](Titanium.UI.AttributedString) instead.
             */
            const AttributedString: never;
            /**
             * Base event for class Titanium.UI.iOS.BlurView
             */
            interface BlurViewBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.BlurView;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface BlurView_click_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface BlurView_dblclick_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface BlurView_doubletap_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface BlurView_keypressed_Event extends BlurViewBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface BlurView_longpress_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface BlurView_pinch_Event extends BlurViewBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface BlurView_postlayout_Event extends BlurViewBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface BlurView_singletap_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface BlurView_swipe_Event extends BlurViewBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface BlurView_touchcancel_Event extends BlurViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface BlurView_touchend_Event extends BlurViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface BlurView_touchmove_Event extends BlurViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface BlurView_touchstart_Event extends BlurViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface BlurView_twofingertap_Event extends BlurViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            interface BlurViewEventMap extends ProxyEventMap {
                click: BlurView_click_Event;

                dblclick: BlurView_dblclick_Event;

                doubletap: BlurView_doubletap_Event;

                keypressed: BlurView_keypressed_Event;

                longpress: BlurView_longpress_Event;

                pinch: BlurView_pinch_Event;

                postlayout: BlurView_postlayout_Event;

                singletap: BlurView_singletap_Event;

                swipe: BlurView_swipe_Event;

                touchcancel: BlurView_touchcancel_Event;

                touchend: BlurView_touchend_Event;

                touchmove: BlurView_touchmove_Event;

                touchstart: BlurView_touchstart_Event;

                twofingertap: BlurView_twofingertap_Event;

            }
            /**
             * A <Titanium.UI.iOS.BlurView> object gives you an easy way implement some complex visual effects.
             * The blur effect is applied to every view the blur view is added to by default. You can also place the
             * blur view above other views and all visible views layered under the blur view are blurred as well.
             * For more information on BlurView, please refer to the official [Apple documentation](https://developer.apple.com/documentation/uikit/uivisualeffectview).
             * Note: Apple introduced two new constants <Titanium.UI.iOS.BLUR_EFFECT_STYLE_REGULAR> and <Titanium.UI.iOS.BLUR_EFFECT_STYLE_PROMINENT> in
             * iOS 10. These are internally mapped to <Titanium.UI.iOS.BLUR_EFFECT_STYLE_LIGHT> and <Titanium.UI.iOS.BLUR_EFFECT_STYLE_EXTRA_LIGHT>.
             */
            class BlurView extends Titanium.UI.View {
                /**
                 * The effect you provide for the view.
                 */
                effect: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof BlurViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.BlurView, event: BlurViewEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof BlurViewEventMap>(name: K, event?: BlurViewEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.BlurView.effect> property.
                 * @deprecated Access <Titanium.UI.iOS.BlurView.effect> instead.
                 */
                getEffect(): number;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof BlurViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.BlurView, event: BlurViewEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.BlurView.effect> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.BlurView.effect> instead.
                 */
                setEffect(effect: number): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.CollisionBehavior
             */
            interface CollisionBehaviorBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.CollisionBehavior;

            }
            /**
             * Fired when an item collides with a boundary.
             */
            interface CollisionBehavior_boundarycollision_Event extends CollisionBehaviorBaseEvent {
                /**
                 * Identifier of the boundary the item collided with.
                 */
                identifier: string;

                /**
                 * Item that collided with the boundary.
                 */
                item: Titanium.UI.View;

                /**
                 * Point of the collision when it started. Only returned when `start` is `true`.
                 */
                point: Point;

                /**
                 * Returns `true` if the collision started else `false`.
                 */
                start: boolean;

            }
            /**
             * Fired when two items collide.
             */
            interface CollisionBehavior_itemcollision_Event extends CollisionBehaviorBaseEvent {
                /**
                 * Item that collided with `item2`.
                 */
                item1: Titanium.UI.View;

                /**
                 * Item that collided with `item1`.
                 */
                item2: Titanium.UI.View;

                /**
                 * Point of the collision when it started. Only returned when `start` is `true`.
                 */
                point: Point;

                /**
                 * Returns `true` if the collision started else `false`.
                 */
                start: boolean;

            }
            interface CollisionBehaviorEventMap extends ProxyEventMap {
                boundarycollision: CollisionBehavior_boundarycollision_Event;

                itemcollision: CollisionBehavior_itemcollision_Event;

            }
            /**
             * Dynamic behavior to support collisions between items and boundaries.
             */
            class CollisionBehavior extends Titanium.Proxy {
                /**
                 * Boundary identfiers added to this behavior.
                 */
                readonly boundaryIdentifiers: BoundaryIdentifier[];

                /**
                 * Specifies the collision behavior.
                 */
                collisionMode: number;

                /**
                 * Items added to this behavior.
                 */
                readonly items: Titanium.UI.View[];

                /**
                 * Insets to apply when using the animator's reference view as the boundary.
                 */
                referenceInsets: Padding;

                /**
                 * Use the animator's reference view as the boundary.
                 */
                treatReferenceAsBoundary: boolean;

                /**
                 * Adds a boundary to this behavior.
                 */
                addBoundary(boundary: BoundaryIdentifier): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof CollisionBehaviorEventMap>(name: K, callback: (this: Titanium.UI.iOS.CollisionBehavior, event: CollisionBehaviorEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Adds an item to this behavior.
                 */
                addItem(item: Titanium.UI.View): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof CollisionBehaviorEventMap>(name: K, event?: CollisionBehaviorEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.CollisionBehavior.boundaryIdentifiers> property.
                 * @deprecated Access <Titanium.UI.iOS.CollisionBehavior.boundaryIdentifiers> instead.
                 */
                getBoundaryIdentifiers(): BoundaryIdentifier[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.CollisionBehavior.collisionMode> property.
                 * @deprecated Access <Titanium.UI.iOS.CollisionBehavior.collisionMode> instead.
                 */
                getCollisionMode(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.CollisionBehavior.items> property.
                 * @deprecated Access <Titanium.UI.iOS.CollisionBehavior.items> instead.
                 */
                getItems(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.CollisionBehavior.referenceInsets> property.
                 * @deprecated Access <Titanium.UI.iOS.CollisionBehavior.referenceInsets> instead.
                 */
                getReferenceInsets(): Padding;

                /**
                 * Gets the value of the <Titanium.UI.iOS.CollisionBehavior.treatReferenceAsBoundary> property.
                 * @deprecated Access <Titanium.UI.iOS.CollisionBehavior.treatReferenceAsBoundary> instead.
                 */
                getTreatReferenceAsBoundary(): boolean;

                /**
                 * Removes all boundaries from this behavior.
                 */
                removeAllBoundaries(): void;

                /**
                 * Removes the specified boundary from this behavior.
                 */
                removeBoundary(boundary: BoundaryIdentifier): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof CollisionBehaviorEventMap>(name: K, callback: (this: Titanium.UI.iOS.CollisionBehavior, event: CollisionBehaviorEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Removes the specified item from this behavior.
                 */
                removeItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.CollisionBehavior.collisionMode> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.CollisionBehavior.collisionMode> instead.
                 */
                setCollisionMode(collisionMode: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.CollisionBehavior.referenceInsets> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.CollisionBehavior.referenceInsets> instead.
                 */
                setReferenceInsets(referenceInsets: Padding): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.CollisionBehavior.treatReferenceAsBoundary> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.CollisionBehavior.treatReferenceAsBoundary> instead.
                 */
                setTreatReferenceAsBoundary(treatReferenceAsBoundary: boolean): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.CoverFlowView
             */
            interface CoverFlowViewBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.CoverFlowView;

            }
            /**
             * Fired when the user clicks on the view.
             */
            interface CoverFlowView_click_Event extends CoverFlowViewBaseEvent {
                /**
                 * Index of the image that is now visible.
                 */
                index: number;

                /**
                 * Index of the previously-visible image.
                 */
                previous: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface CoverFlowView_dblclick_Event extends CoverFlowViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface CoverFlowView_doubletap_Event extends CoverFlowViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface CoverFlowView_keypressed_Event extends CoverFlowViewBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface CoverFlowView_longpress_Event extends CoverFlowViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface CoverFlowView_pinch_Event extends CoverFlowViewBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface CoverFlowView_postlayout_Event extends CoverFlowViewBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface CoverFlowView_singletap_Event extends CoverFlowViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface CoverFlowView_swipe_Event extends CoverFlowViewBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface CoverFlowView_touchcancel_Event extends CoverFlowViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface CoverFlowView_touchend_Event extends CoverFlowViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface CoverFlowView_touchmove_Event extends CoverFlowViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface CoverFlowView_touchstart_Event extends CoverFlowViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface CoverFlowView_twofingertap_Event extends CoverFlowViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the user changes the image using a gesture.
             */
            interface CoverFlowView_change_Event extends CoverFlowViewBaseEvent {
                /**
                 * Index of the image that is now visible.
                 */
                index: number;

                /**
                 * Index of the previously-visible image.
                 */
                previous: number;

            }
            interface CoverFlowViewEventMap extends ProxyEventMap {
                change: CoverFlowView_change_Event;

                click: CoverFlowView_click_Event;

                dblclick: CoverFlowView_dblclick_Event;

                doubletap: CoverFlowView_doubletap_Event;

                keypressed: CoverFlowView_keypressed_Event;

                longpress: CoverFlowView_longpress_Event;

                pinch: CoverFlowView_pinch_Event;

                postlayout: CoverFlowView_postlayout_Event;

                singletap: CoverFlowView_singletap_Event;

                swipe: CoverFlowView_swipe_Event;

                touchcancel: CoverFlowView_touchcancel_Event;

                touchend: CoverFlowView_touchend_Event;

                touchmove: CoverFlowView_touchmove_Event;

                touchstart: CoverFlowView_touchstart_Event;

                twofingertap: CoverFlowView_twofingertap_Event;

            }
            /**
             * The cover flow view is a container showing animated three-dimensional images in a style
             * consistent with the cover flow presentation style used for iPod, iTunes, and file browsing.
             */
            class CoverFlowView extends Titanium.UI.View {
                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * Images to display in the view.
                 */
                images: string[] | Titanium.Blob[] | Titanium.Filesystem.File[] | CoverFlowImageType[];

                /**
                 * Index to make selected.
                 */
                selected: number;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof CoverFlowViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.CoverFlowView, event: CoverFlowViewEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof CoverFlowViewEventMap>(name: K, event?: CoverFlowViewEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.CoverFlowView.children> property.
                 * @deprecated Access <Titanium.UI.iOS.CoverFlowView.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.CoverFlowView.images> property.
                 * @deprecated Access <Titanium.UI.iOS.CoverFlowView.images> instead.
                 */
                getImages(): string[] | Titanium.Blob[] | Titanium.Filesystem.File[] | CoverFlowImageType[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.CoverFlowView.selected> property.
                 * @deprecated Access <Titanium.UI.iOS.CoverFlowView.selected> instead.
                 */
                getSelected(): number;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof CoverFlowViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.CoverFlowView, event: CoverFlowViewEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
                 */
                replaceAt: never;

                /**
                 * Changes the image for a specified index.
                 */
                setImage(index: number, image: string | Titanium.Blob | Titanium.Filesystem.File | CoverFlowImageType): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.CoverFlowView.images> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.CoverFlowView.images> instead.
                 */
                setImages(images: string[] | Titanium.Blob[] | Titanium.Filesystem.File[] | CoverFlowImageType[]): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.CoverFlowView.selected> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.CoverFlowView.selected> instead.
                 */
                setSelected(selected: number): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.DocumentViewer
             */
            interface DocumentViewerBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.DocumentViewer;

            }
            /**
             * Fires when the document is previewed.
             */
            interface DocumentViewer_load_Event extends DocumentViewerBaseEvent {
            }
            /**
             * Fires when the options menu appears before the document is previewed.
             */
            interface DocumentViewer_menu_Event extends DocumentViewerBaseEvent {
            }
            /**
             * Fires when the document is dismissed.
             */
            interface DocumentViewer_unload_Event extends DocumentViewerBaseEvent {
            }
            interface DocumentViewerEventMap extends ProxyEventMap {
                load: DocumentViewer_load_Event;

                menu: DocumentViewer_menu_Event;

                unload: DocumentViewer_unload_Event;

            }
            /**
             * A DocumentViewer provides in-app support for managing user interactions with files on the
             * local system.
             */
            class DocumentViewer extends Titanium.Proxy {
                /**
                 * Name of the file (without the path).
                 */
                readonly name: string;

                /**
                 * URL of the document being previewed.
                 */
                url: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof DocumentViewerEventMap>(name: K, callback: (this: Titanium.UI.iOS.DocumentViewer, event: DocumentViewerEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof DocumentViewerEventMap>(name: K, event?: DocumentViewerEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DocumentViewer.name> property.
                 * @deprecated Access <Titanium.UI.iOS.DocumentViewer.name> instead.
                 */
                getName(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DocumentViewer.url> property.
                 * @deprecated Access <Titanium.UI.iOS.DocumentViewer.url> instead.
                 */
                getUrl(): string;

                /**
                 * Dismisses the document viewer.
                 */
                hide(options?: DocumentViewerOptions): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof DocumentViewerEventMap>(name: K, callback: (this: Titanium.UI.iOS.DocumentViewer, event: DocumentViewerEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DocumentViewer.url> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DocumentViewer.url> instead.
                 */
                setUrl(url: string): void;

                /**
                 * Displays the document viewer over the current view.
                 */
                show(options?: DocumentViewerOptions): void;

            }
            /**
             * Base dynamic configuration for an item.
             */
            class DynamicItemBehavior extends Titanium.Proxy {
                /**
                 * Specifies if this item can rotate.
                 */
                allowsRotation: boolean;

                /**
                 * Specifies the angular resistance of this item.
                 */
                angularResistance: number;

                /**
                 * Specifies the relative mass density of this item.
                 */
                density: number;

                /**
                 * Specifies the elasticity applied to collisions for this item.
                 */
                elasticity: number;

                /**
                 * Specifies the linear resistance of the item when it slides against another item.
                 */
                friction: number;

                /**
                 * Items added to this behavior.
                 */
                readonly items: Titanium.UI.View[];

                /**
                 * Specifies the linear resistance of this item which reduces linear velocity over time.
                 */
                resistance: number;

                /**
                 * Adds a specified angular velocity for the item.
                 */
                addAngularVelocityForItem(item: Titanium.UI.View, velocity: number): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Adds an item to this behavior.
                 */
                addItem(item: Titanium.UI.View): void;

                /**
                 * Adds a specified linear velocity for the item.
                 */
                addLinearVelocityForItem(item: Titanium.UI.View, velocity: Point): void;

                /**
                 * Returns the angular velocity of the item.
                 */
                angularVelocityForItem(item: Titanium.UI.View): number;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.allowsRotation> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.allowsRotation> instead.
                 */
                getAllowsRotation(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.angularResistance> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.angularResistance> instead.
                 */
                getAngularResistance(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.density> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.density> instead.
                 */
                getDensity(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.elasticity> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.elasticity> instead.
                 */
                getElasticity(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.friction> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.friction> instead.
                 */
                getFriction(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.items> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.items> instead.
                 */
                getItems(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.DynamicItemBehavior.resistance> property.
                 * @deprecated Access <Titanium.UI.iOS.DynamicItemBehavior.resistance> instead.
                 */
                getResistance(): number;

                /**
                 * Returns the linear velocity of the item.
                 */
                linearVelocityForItem(item: Titanium.UI.View): Point;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Removes the specified item from this behavior.
                 */
                removeItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.allowsRotation> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.allowsRotation> instead.
                 */
                setAllowsRotation(allowsRotation: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.angularResistance> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.angularResistance> instead.
                 */
                setAngularResistance(angularResistance: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.density> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.density> instead.
                 */
                setDensity(density: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.elasticity> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.elasticity> instead.
                 */
                setElasticity(elasticity: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.friction> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.friction> instead.
                 */
                setFriction(friction: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.DynamicItemBehavior.resistance> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.DynamicItemBehavior.resistance> instead.
                 */
                setResistance(resistance: number): void;

            }
            /**
             * The feedback generator API is introduced in iOS 10 to handle the haptic feedback when using an iPhone 7 or
             * later devices.
             */
            class FeedbackGenerator extends Titanium.Proxy {
                /**
                 * The style of the feedback generator you want to create. This property is only required when using <Titanium.UI.iOS.FEEDBACK_GENERATOR_TYPE_IMPACT>.
                 */
                style?: number;

                /**
                 * The type of feedback generator you want to create.
                 */
                type: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.FeedbackGenerator.style> property.
                 * @deprecated Access <Titanium.UI.iOS.FeedbackGenerator.style> instead.
                 */
                getStyle(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.FeedbackGenerator.type> property.
                 * @deprecated Access <Titanium.UI.iOS.FeedbackGenerator.type> instead.
                 */
                getType(): number;

                /**
                 * Used to trigger a haptic feedback after an impact occurred.
                 */
                impactOccurred(): void;

                /**
                 * Used to trigger a haptic feedback after a notification has been received.
                 */
                notificationOccurred(notificationType: number): void;

                /**
                 * Used to prepare the haptic sensor for the upcoming interaction with it.
                 */
                prepare(): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Used to trigger a haptic feedback after a selection has been made.
                 */
                selectionChanged(): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.FeedbackGenerator.style> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.FeedbackGenerator.style> instead.
                 */
                setStyle(style: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.FeedbackGenerator.type> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.FeedbackGenerator.type> instead.
                 */
                setType(type: number): void;

            }
            /**
             * Gravitational force to apply to an item.
             */
            class GravityBehavior extends Titanium.Proxy {
                /**
                 * Specifies the angle of the gravity vector in radians.
                 */
                angle: number;

                /**
                 * Specifies the direction of the gravity vector as an x, y pair.
                 */
                gravityDirection: Point;

                /**
                 * Items added to this behavior.
                 */
                readonly items: Titanium.UI.View[];

                /**
                 * Specifies the magnitude of the gravity vector.
                 */
                magnitude: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Adds an item to this behavior.
                 */
                addItem(item: Titanium.UI.View): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.GravityBehavior.angle> property.
                 * @deprecated Access <Titanium.UI.iOS.GravityBehavior.angle> instead.
                 */
                getAngle(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.GravityBehavior.gravityDirection> property.
                 * @deprecated Access <Titanium.UI.iOS.GravityBehavior.gravityDirection> instead.
                 */
                getGravityDirection(): Point;

                /**
                 * Gets the value of the <Titanium.UI.iOS.GravityBehavior.items> property.
                 * @deprecated Access <Titanium.UI.iOS.GravityBehavior.items> instead.
                 */
                getItems(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.GravityBehavior.magnitude> property.
                 * @deprecated Access <Titanium.UI.iOS.GravityBehavior.magnitude> instead.
                 */
                getMagnitude(): number;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Removes the specified item from this behavior.
                 */
                removeItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.GravityBehavior.angle> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.GravityBehavior.angle> instead.
                 */
                setAngle(angle: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.GravityBehavior.gravityDirection> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.GravityBehavior.gravityDirection> instead.
                 */
                setGravityDirection(gravityDirection: Point): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.GravityBehavior.magnitude> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.GravityBehavior.magnitude> instead.
                 */
                setMagnitude(magnitude: number): void;

            }
            /**
             * Abstract object representing a live photo used in <Titanium.UI.iOS.LivePhotoView>.
             */
            class LivePhoto extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.LivePhotoView
             */
            interface LivePhotoViewBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.LivePhotoView;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface LivePhotoView_click_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface LivePhotoView_dblclick_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface LivePhotoView_doubletap_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface LivePhotoView_keypressed_Event extends LivePhotoViewBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface LivePhotoView_longpress_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface LivePhotoView_pinch_Event extends LivePhotoViewBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface LivePhotoView_postlayout_Event extends LivePhotoViewBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface LivePhotoView_singletap_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface LivePhotoView_swipe_Event extends LivePhotoViewBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface LivePhotoView_touchcancel_Event extends LivePhotoViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface LivePhotoView_touchend_Event extends LivePhotoViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface LivePhotoView_touchmove_Event extends LivePhotoViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface LivePhotoView_touchstart_Event extends LivePhotoViewBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface LivePhotoView_twofingertap_Event extends LivePhotoViewBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the Live Photo playback starts.
             */
            interface LivePhotoView_start_Event extends LivePhotoViewBaseEvent {
                /**
                 * Returns the `playbackStyle` that was provided to start the playback.
                 */
                playbackStyle: number;

            }
            /**
             * Fired when the Live Photo playback stops.
             */
            interface LivePhotoView_stop_Event extends LivePhotoViewBaseEvent {
                /**
                 * Returns the `playbackStyle` that was provided to start the playback.
                 */
                playbackStyle: number;

            }
            interface LivePhotoViewEventMap extends ProxyEventMap {
                click: LivePhotoView_click_Event;

                dblclick: LivePhotoView_dblclick_Event;

                doubletap: LivePhotoView_doubletap_Event;

                keypressed: LivePhotoView_keypressed_Event;

                longpress: LivePhotoView_longpress_Event;

                pinch: LivePhotoView_pinch_Event;

                postlayout: LivePhotoView_postlayout_Event;

                singletap: LivePhotoView_singletap_Event;

                start: LivePhotoView_start_Event;

                stop: LivePhotoView_stop_Event;

                swipe: LivePhotoView_swipe_Event;

                touchcancel: LivePhotoView_touchcancel_Event;

                touchend: LivePhotoView_touchend_Event;

                touchmove: LivePhotoView_touchmove_Event;

                touchstart: LivePhotoView_touchstart_Event;

                twofingertap: LivePhotoView_twofingertap_Event;

            }
            /**
             * A view to display a <Titanium.UI.iOS.LivePhoto> object introduced in iOS 9.1.
             */
            class LivePhotoView extends Titanium.UI.View {
                /**
                 * The Live Photo displayed in the view.
                 */
                livePhoto: Titanium.UI.iOS.LivePhoto;

                /**
                 * A Boolean value that determines whether the view plays the audio content of its Live Photo.
                 */
                muted: boolean;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof LivePhotoViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.LivePhotoView, event: LivePhotoViewEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof LivePhotoViewEventMap>(name: K, event?: LivePhotoViewEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.LivePhotoView.livePhoto> property.
                 * @deprecated Access <Titanium.UI.iOS.LivePhotoView.livePhoto> instead.
                 */
                getLivePhoto(): Titanium.UI.iOS.LivePhoto;

                /**
                 * Gets the value of the <Titanium.UI.iOS.LivePhotoView.muted> property.
                 * @deprecated Access <Titanium.UI.iOS.LivePhotoView.muted> instead.
                 */
                getMuted(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof LivePhotoViewEventMap>(name: K, callback: (this: Titanium.UI.iOS.LivePhotoView, event: LivePhotoViewEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.LivePhotoView.livePhoto> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.LivePhotoView.livePhoto> instead.
                 */
                setLivePhoto(livePhoto: Titanium.UI.iOS.LivePhoto): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.LivePhotoView.muted> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.LivePhotoView.muted> instead.
                 */
                setMuted(muted: boolean): void;

                /**
                 * Begins playback of Live Photo content in the view.
                 */
                startPlaybackWithStyle(playbackStyle: number): void;

                /**
                 * Ends playback of Live Photo content in the view.
                 */
                stopPlayback(): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.MenuPopup
             */
            interface MenuPopupBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.MenuPopup;

            }
            /**
             * Fired when the user clicks at one of the menu popup items.
             */
            interface MenuPopup_click_Event extends MenuPopupBaseEvent {
                /**
                 * The index of the clicked item.
                 */
                index: number;

                /**
                 * The title of the clicked item.
                 */
                title: string;

            }
            interface MenuPopupEventMap extends ProxyEventMap {
                click: MenuPopup_click_Event;

            }
            /**
             * A menu popup provides the ability to create custom tooltip options using the `items` property
             * covering the native `UIMenuController` class.
             * See also:
             * * [iOS Developer Library: UIMenuController](https://developer.apple.com/documentation/uikit/uimenucontroller)
             */
            class MenuPopup extends Titanium.Proxy {
                /**
                 * The items of the menu popup.
                 */
                items: string[];

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof MenuPopupEventMap>(name: K, callback: (this: Titanium.UI.iOS.MenuPopup, event: MenuPopupEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof MenuPopupEventMap>(name: K, event?: MenuPopupEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.MenuPopup.items> property.
                 * @deprecated Access <Titanium.UI.iOS.MenuPopup.items> instead.
                 */
                getItems(): string[];

                /**
                 * Hides the menu popup.
                 */
                hide(options?: AnimatedOptions): void;

                /**
                 * Indicates whether the menu popup is currently visible.
                 */
                isVisible(): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof MenuPopupEventMap>(name: K, callback: (this: Titanium.UI.iOS.MenuPopup, event: MenuPopupEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.MenuPopup.items> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.MenuPopup.items> instead.
                 */
                setItems(items: ReadonlyArray<string>): void;

                /**
                 * Shows the menu popup.
                 */
                show(options: MenuPopupShowParams): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.NavigationWindow
             */
            interface NavigationWindowBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.NavigationWindow;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface NavigationWindow_click_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface NavigationWindow_dblclick_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface NavigationWindow_doubletap_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the window gains focus.
             */
            interface NavigationWindow_focus_Event extends NavigationWindowBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface NavigationWindow_keypressed_Event extends NavigationWindowBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface NavigationWindow_longpress_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface NavigationWindow_pinch_Event extends NavigationWindowBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface NavigationWindow_postlayout_Event extends NavigationWindowBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface NavigationWindow_singletap_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface NavigationWindow_swipe_Event extends NavigationWindowBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface NavigationWindow_touchcancel_Event extends NavigationWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface NavigationWindow_touchend_Event extends NavigationWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface NavigationWindow_touchmove_Event extends NavigationWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface NavigationWindow_touchstart_Event extends NavigationWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface NavigationWindow_twofingertap_Event extends NavigationWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the window loses focus.
             */
            interface NavigationWindow_blur_Event extends NavigationWindowBaseEvent {
            }
            /**
             * Fired when the window is closed.
             */
            interface NavigationWindow_close_Event extends NavigationWindowBaseEvent {
            }
            /**
             * Fired when the window is opened.
             */
            interface NavigationWindow_open_Event extends NavigationWindowBaseEvent {
            }
            interface NavigationWindowEventMap extends ProxyEventMap {
                blur: NavigationWindow_blur_Event;

                click: NavigationWindow_click_Event;

                close: NavigationWindow_close_Event;

                dblclick: NavigationWindow_dblclick_Event;

                doubletap: NavigationWindow_doubletap_Event;

                focus: NavigationWindow_focus_Event;

                keypressed: NavigationWindow_keypressed_Event;

                longpress: NavigationWindow_longpress_Event;

                open: NavigationWindow_open_Event;

                pinch: NavigationWindow_pinch_Event;

                postlayout: NavigationWindow_postlayout_Event;

                singletap: NavigationWindow_singletap_Event;

                swipe: NavigationWindow_swipe_Event;

                touchcancel: NavigationWindow_touchcancel_Event;

                touchend: NavigationWindow_touchend_Event;

                touchmove: NavigationWindow_touchmove_Event;

                touchstart: NavigationWindow_touchstart_Event;

                twofingertap: NavigationWindow_twofingertap_Event;

            }
            /**
             * A `NavigationWindow` implements a specialized view that manages the navigation of hierarchical
             * content.
             * @deprecated Use [Titanium.UI.NavigationWindow](Titanium.UI.NavigationWindow) instead.
             */
            class NavigationWindow extends Titanium.UI.Window {
                /**
                 * Title for the back button. This is only valid when the window is a child of a tab.
                 */
                backButtonTitle: never;

                /**
                 * The image to show as the back button. This is only valid when the window is a child of a tab.
                 */
                backButtonTitleImage: never;

                /**
                 * Background color for the nav bar, as a color name or hex triplet.
                 */
                barColor: never;

                /**
                 * Background image for the nav bar, specified as a URL to a local image.
                 */
                barImage: never;

                /**
                 * Set this to true to hide the shadow image of the navigation bar.
                 */
                hideShadow: never;

                /**
                 * View to show in the left nav bar area.
                 */
                leftNavButton: never;

                /**
                 * Hides the navigation bar (`true`) or shows the navigation bar (`false`).
                 */
                navBarHidden: never;

                /**
                 * The tintColor to apply to the navigation bar.
                 */
                navTintColor: never;

                /**
                 * View to show in the right nav bar area.
                 */
                rightNavButton: never;

                /**
                 * Shadow image for the navigation bar, specified as a URL to a local image..
                 */
                shadowImage: never;

                /**
                 * Boolean value indicating if the user should be able to close a window using a swipe gesture.
                 */
                swipeToClose: never;

                /**
                 * Boolean value indicating if the tab bar should be hidden.
                 */
                tabBarHidden: never;

                /**
                 * Title of the window.
                 */
                title: never;

                /**
                 * View to show in the title area of the nav bar.
                 */
                titleControl: never;

                /**
                 * Image to show in the title area of the nav bar, specified as a local file path or URL.
                 */
                titleImage: never;

                /**
                 * Title prompt for the window.
                 */
                titlePrompt: never;

                /**
                 * Key identifying a string from the locale file to use for the window title.
                 */
                titleid: never;

                /**
                 * Key identifying a string from the locale file to use for the window title prompt.
                 */
                titlepromptid: never;

                /**
                 * Array of button objects to show in the window's toolbar.
                 */
                toolbar: never;

                /**
                 * Use a transition animation when opening or closing windows in a
                 * <Titanium.UI.NavigationWindow> or <Titanium.UI.Tab>.
                 */
                transitionAnimation: never;

                /**
                 * Boolean value indicating if the nav bar is translucent.
                 */
                translucent: never;

                /**
                 * Loads a JavaScript file from a local URL.
                 * @deprecated
                 */
                url: never;

                /**
                 * Window to add to this navigation window.
                 */
                window: Titanium.UI.Window;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof NavigationWindowEventMap>(name: K, callback: (this: Titanium.UI.iOS.NavigationWindow, event: NavigationWindowEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Closes a window and removes it from the navigation window.
                 */
                closeWindow(window: Titanium.UI.Window, options: any): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof NavigationWindowEventMap>(name: K, event?: NavigationWindowEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.backButtonTitle> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.backButtonTitle> instead.
                 */
                getBackButtonTitle: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.backButtonTitleImage> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.backButtonTitleImage> instead.
                 */
                getBackButtonTitleImage: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.barColor> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.barColor> instead.
                 */
                getBarColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.barImage> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.barImage> instead.
                 */
                getBarImage: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.hideShadow> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.hideShadow> instead.
                 */
                getHideShadow: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.leftNavButton> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.leftNavButton> instead.
                 */
                getLeftNavButton: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.navBarHidden> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.navBarHidden> instead.
                 */
                getNavBarHidden: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.navTintColor> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.navTintColor> instead.
                 */
                getNavTintColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.rightNavButton> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.rightNavButton> instead.
                 */
                getRightNavButton: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.shadowImage> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.shadowImage> instead.
                 */
                getShadowImage: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.swipeToClose> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.swipeToClose> instead.
                 */
                getSwipeToClose: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.tabBarHidden> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.tabBarHidden> instead.
                 */
                getTabBarHidden: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.title> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.title> instead.
                 */
                getTitle: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.titleControl> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.titleControl> instead.
                 */
                getTitleControl: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.titleImage> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.titleImage> instead.
                 */
                getTitleImage: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.titlePrompt> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.titlePrompt> instead.
                 */
                getTitlePrompt: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.titleid> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.titleid> instead.
                 */
                getTitleid: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.titlepromptid> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.titlepromptid> instead.
                 */
                getTitlepromptid: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.toolbar> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.toolbar> instead.
                 */
                getToolbar: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.transitionAnimation> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.transitionAnimation> instead.
                 */
                getTransitionAnimation: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.translucent> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.translucent> instead.
                 */
                getTranslucent: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.url> property.
                 * @deprecated
                 */
                getUrl: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.NavigationWindow.window> property.
                 * @deprecated Access <Titanium.UI.iOS.NavigationWindow.window> instead.
                 */
                getWindow(): Titanium.UI.Window;

                /**
                 * Hides the tab bar. Must be called before opening the window.
                 */
                hideTabBar: never;

                /**
                 * Opens a window within the navigation window.
                 */
                openWindow(window: Titanium.UI.Window, options: any): void;

                /**
                 * Closes all windows that are currently opened inside the navigation window.
                 */
                popToRootWindow(options: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof NavigationWindowEventMap>(name: K, callback: (this: Titanium.UI.iOS.NavigationWindow, event: NavigationWindowEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.backButtonTitle> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.backButtonTitle> instead.
                 */
                setBackButtonTitle: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.backButtonTitleImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.backButtonTitleImage> instead.
                 */
                setBackButtonTitleImage: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.barColor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.barColor> instead.
                 */
                setBarColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.barImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.barImage> instead.
                 */
                setBarImage: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.hideShadow> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.hideShadow> instead.
                 */
                setHideShadow: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.leftNavButton> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.leftNavButton> instead.
                 */
                setLeftNavButton: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.navBarHidden> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.navBarHidden> instead.
                 */
                setNavBarHidden: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.navTintColor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.navTintColor> instead.
                 */
                setNavTintColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.rightNavButton> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.rightNavButton> instead.
                 */
                setRightNavButton: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.shadowImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.shadowImage> instead.
                 */
                setShadowImage: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.swipeToClose> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.swipeToClose> instead.
                 */
                setSwipeToClose: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.tabBarHidden> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.tabBarHidden> instead.
                 */
                setTabBarHidden: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.title> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.title> instead.
                 */
                setTitle: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.titleControl> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.titleControl> instead.
                 */
                setTitleControl: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.titleImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.titleImage> instead.
                 */
                setTitleImage: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.titlePrompt> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.titlePrompt> instead.
                 */
                setTitlePrompt: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.titleid> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.titleid> instead.
                 */
                setTitleid: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.titlepromptid> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.titlepromptid> instead.
                 */
                setTitlepromptid: never;

                /**
                 * Sets the array of items to show in the window's toolbar.
                 */
                setToolbar: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.transitionAnimation> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.transitionAnimation> instead.
                 */
                setTransitionAnimation: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.translucent> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.translucent> instead.
                 */
                setTranslucent: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.url> property.
                 * @deprecated
                 */
                setUrl: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.NavigationWindow.window> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.NavigationWindow.window> instead.
                 */
                setWindow(window: Titanium.UI.Window): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.PreviewAction
             */
            interface PreviewActionBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.PreviewAction;

            }
            /**
             * Fired when the device detects a click against a preview action.
             */
            interface PreviewAction_click_Event extends PreviewActionBaseEvent {
                /**
                 * The index of the clicked action.
                 */
                index: number;

                /**
                 * The item ID of cell, if the `previewContext` property of the <Titanium.UI.iOS.PreviewContext>
                 * is a <Titanium.UI.ListView>.
                 */
                itemId: string;

                /**
                 * The index of the clicked row, if the `previewContext` property of the <Titanium.UI.iOS.PreviewContext>
                 * is a <Titanium.UI.ListView>.
                 */
                itemIndex: number;

                /**
                 * The index of the clicked section, if the `previewContext` property of the <Titanium.UI.iOS.PreviewContext>
                 * is a <Titanium.UI.ListView>.
                 */
                sectionIndex: number;

            }
            interface PreviewActionEventMap extends ProxyEventMap {
                click: PreviewAction_click_Event;

            }
            /**
             * A PreviewAction provides options to configure actions used by the iOS 9 3D-Touch "Peek and Pop"
             * feature.
             */
            class PreviewAction extends Titanium.Proxy {
                /**
                 * The style of the action.
                 */
                style: number;

                /**
                 * The title of the action.
                 */
                title: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof PreviewActionEventMap>(name: K, callback: (this: Titanium.UI.iOS.PreviewAction, event: PreviewActionEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof PreviewActionEventMap>(name: K, event?: PreviewActionEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewAction.style> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewAction.style> instead.
                 */
                getStyle(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewAction.title> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewAction.title> instead.
                 */
                getTitle(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof PreviewActionEventMap>(name: K, callback: (this: Titanium.UI.iOS.PreviewAction, event: PreviewActionEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewAction.style> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewAction.style> instead.
                 */
                setStyle(style: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewAction.title> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewAction.title> instead.
                 */
                setTitle(title: string): void;

            }
            /**
             * A PreviewActionGroup provides options to configure a group of actions used by the iOS9 3D-Touch
             * feature "Peek and Pop".
             */
            class PreviewActionGroup extends Titanium.Proxy {
                /**
                 * The preview actions assigned to this preview action group.
                 */
                actions: Titanium.UI.iOS.PreviewAction[];

                /**
                 * The style of the action group.
                 */
                style: number;

                /**
                 * The title of the action group.
                 */
                title: string;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewActionGroup.actions> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewActionGroup.actions> instead.
                 */
                getActions(): Titanium.UI.iOS.PreviewAction[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewActionGroup.style> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewActionGroup.style> instead.
                 */
                getStyle(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewActionGroup.title> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewActionGroup.title> instead.
                 */
                getTitle(): string;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewActionGroup.actions> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewActionGroup.actions> instead.
                 */
                setActions(actions: ReadonlyArray<Titanium.UI.iOS.PreviewAction>): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewActionGroup.style> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewActionGroup.style> instead.
                 */
                setStyle(style: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewActionGroup.title> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewActionGroup.title> instead.
                 */
                setTitle(title: string): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.PreviewContext
             */
            interface PreviewContextBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.PreviewContext;

            }
            /**
             * Fired when the user peeks the preview. You can configure the preview
             */
            interface PreviewContext_peek_Event extends PreviewContextBaseEvent {
                /**
                 * The item ID bound to the list item that generated the event.
                 */
                itemId: string;

                /**
                 * The item index of the ListView to identify the selected item.
                 * Note: This property is only available if the preview context is assigned to a <Titanium.UI.ListView>.
                 */
                itemIndex: number;

                /**
                 * The view to be previewed.
                 */
                preview: Titanium.UI.View;

                /**
                 * The section index of the ListView to identify the selected section.
                 * Note: This property is only available if the preview context is assigned to a <Titanium.UI.ListView>.
                 */
                sectionIndex: number;

            }
            /**
             * Fired when the user pop the preview. You will most likely open a fullscreen window here.
             */
            interface PreviewContext_pop_Event extends PreviewContextBaseEvent {
                /**
                 * The item ID bound to the list item that generated the event.
                 */
                itemId: string;

                /**
                 * The item index of the ListView to identify the selected item.
                 * Note: This property is only available if the preview context is assigned to a <Titanium.UI.ListView>.
                 */
                itemIndex: number;

                /**
                 * The view to be previewed.
                 */
                preview: Titanium.UI.View;

                /**
                 * The section index of the ListView to identify the selected section.
                 * Note: This property is only available if the preview context is assigned to a <Titanium.UI.ListView>.
                 */
                sectionIndex: number;

            }
            interface PreviewContextEventMap extends ProxyEventMap {
                peek: PreviewContext_peek_Event;

                pop: PreviewContext_pop_Event;

            }
            /**
             * A PreviewContext provides options to configure the iOS 9 3D-Touch "Peek and Pop" feature.
             */
            class PreviewContext extends Titanium.Proxy {
                /**
                 * The preview actions and preview action groups.
                 */
                actions: Titanium.UI.iOS.PreviewAction[];

                /**
                 * The height of the preview.
                 */
                contentHeight: number;

                /**
                 * The preview view.
                 */
                preview: Titanium.UI.View;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof PreviewContextEventMap>(name: K, callback: (this: Titanium.UI.iOS.PreviewContext, event: PreviewContextEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof PreviewContextEventMap>(name: K, event?: PreviewContextEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewContext.actions> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewContext.actions> instead.
                 */
                getActions(): Titanium.UI.iOS.PreviewAction[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewContext.contentHeight> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewContext.contentHeight> instead.
                 */
                getContentHeight(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PreviewContext.preview> property.
                 * @deprecated Access <Titanium.UI.iOS.PreviewContext.preview> instead.
                 */
                getPreview(): Titanium.UI.View;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof PreviewContextEventMap>(name: K, callback: (this: Titanium.UI.iOS.PreviewContext, event: PreviewContextEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewContext.actions> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewContext.actions> instead.
                 */
                setActions(actions: ReadonlyArray<Titanium.UI.iOS.PreviewAction>): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewContext.contentHeight> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewContext.contentHeight> instead.
                 */
                setContentHeight(contentHeight: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PreviewContext.preview> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PreviewContext.preview> instead.
                 */
                setPreview(preview: Titanium.UI.View): void;

            }
            /**
             * Continuous or instantaneous force to apply to an item.
             */
            class PushBehavior extends Titanium.Proxy {
                /**
                 * State of the push behavior's force.
                 */
                active: boolean;

                /**
                 * Specifies the angle of the force vector in radians.
                 */
                angle: number;

                /**
                 * Items added to this behavior.
                 */
                readonly items: Titanium.UI.View[];

                /**
                 * Specifies the magnitude of the force vector.
                 */
                magnitude: number;

                /**
                 * Specifies the direction of the force vector as an x, y pair.
                 */
                pushDirection: Point;

                /**
                 * Specifies the push mode.
                 */
                pushMode: number;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Adds an item to this behavior.
                 */
                addItem(item: Titanium.UI.View): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.active> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.active> instead.
                 */
                getActive(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.angle> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.angle> instead.
                 */
                getAngle(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.items> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.items> instead.
                 */
                getItems(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.magnitude> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.magnitude> instead.
                 */
                getMagnitude(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.pushDirection> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.pushDirection> instead.
                 */
                getPushDirection(): Point;

                /**
                 * Gets the value of the <Titanium.UI.iOS.PushBehavior.pushMode> property.
                 * @deprecated Access <Titanium.UI.iOS.PushBehavior.pushMode> instead.
                 */
                getPushMode(): number;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Removes the specified item from this behavior.
                 */
                removeItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PushBehavior.active> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PushBehavior.active> instead.
                 */
                setActive(active: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PushBehavior.angle> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PushBehavior.angle> instead.
                 */
                setAngle(angle: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PushBehavior.magnitude> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PushBehavior.magnitude> instead.
                 */
                setMagnitude(magnitude: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PushBehavior.pushDirection> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PushBehavior.pushDirection> instead.
                 */
                setPushDirection(pushDirection: Point): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.PushBehavior.pushMode> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.PushBehavior.pushMode> instead.
                 */
                setPushMode(pushMode: number): void;

            }
            /**
             * Dynamic behavior defining an item's movement to a specific point.
             */
            class SnapBehavior extends Titanium.Proxy {
                /**
                 * Specifies the amount of oscillation during the conclusion of the snap.
                 */
                damping: number;

                /**
                 * Item to add to this behavior.
                 */
                item: Titanium.UI.View;

                /**
                 * Specifies the point to snap to.
                 */
                snapPoint: Point;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SnapBehavior.damping> property.
                 * @deprecated Access <Titanium.UI.iOS.SnapBehavior.damping> instead.
                 */
                getDamping(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SnapBehavior.item> property.
                 * @deprecated Access <Titanium.UI.iOS.SnapBehavior.item> instead.
                 */
                getItem(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SnapBehavior.snapPoint> property.
                 * @deprecated Access <Titanium.UI.iOS.SnapBehavior.snapPoint> instead.
                 */
                getSnapPoint(): Point;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SnapBehavior.damping> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SnapBehavior.damping> instead.
                 */
                setDamping(damping: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SnapBehavior.item> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SnapBehavior.item> instead.
                 */
                setItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SnapBehavior.snapPoint> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SnapBehavior.snapPoint> instead.
                 */
                setSnapPoint(snapPoint: Point): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.SplitWindow
             */
            interface SplitWindowBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.SplitWindow;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface SplitWindow_click_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface SplitWindow_dblclick_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface SplitWindow_doubletap_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the window gains focus.
             */
            interface SplitWindow_focus_Event extends SplitWindowBaseEvent {
            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface SplitWindow_keypressed_Event extends SplitWindowBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface SplitWindow_longpress_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface SplitWindow_pinch_Event extends SplitWindowBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface SplitWindow_postlayout_Event extends SplitWindowBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface SplitWindow_singletap_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface SplitWindow_swipe_Event extends SplitWindowBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface SplitWindow_touchcancel_Event extends SplitWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface SplitWindow_touchend_Event extends SplitWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface SplitWindow_touchmove_Event extends SplitWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface SplitWindow_touchstart_Event extends SplitWindowBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface SplitWindow_twofingertap_Event extends SplitWindowBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the window loses focus.
             */
            interface SplitWindow_blur_Event extends SplitWindowBaseEvent {
            }
            /**
             * Fired when the window is closed.
             */
            interface SplitWindow_close_Event extends SplitWindowBaseEvent {
            }
            /**
             * Fired when the window is opened.
             */
            interface SplitWindow_open_Event extends SplitWindowBaseEvent {
            }
            interface SplitWindowEventMap extends ProxyEventMap {
                blur: SplitWindow_blur_Event;

                click: SplitWindow_click_Event;

                close: SplitWindow_close_Event;

                dblclick: SplitWindow_dblclick_Event;

                doubletap: SplitWindow_doubletap_Event;

                focus: SplitWindow_focus_Event;

                keypressed: SplitWindow_keypressed_Event;

                longpress: SplitWindow_longpress_Event;

                open: SplitWindow_open_Event;

                pinch: SplitWindow_pinch_Event;

                postlayout: SplitWindow_postlayout_Event;

                singletap: SplitWindow_singletap_Event;

                swipe: SplitWindow_swipe_Event;

                touchcancel: SplitWindow_touchcancel_Event;

                touchend: SplitWindow_touchend_Event;

                touchmove: SplitWindow_touchmove_Event;

                touchstart: SplitWindow_touchstart_Event;

                twofingertap: SplitWindow_twofingertap_Event;

            }
            /**
             * A SplitWindow is a window that manages the presentation of two side-by-side view
             * controllers.
             */
            class SplitWindow extends Titanium.UI.Window {
                /**
                 * Window for the detail view section of the SplitWindow.
                 */
                detailView: Titanium.UI.Window;

                /**
                 * Determines the width of the `masterView` in landscape mode.
                 */
                landscapeSplit: number;

                /**
                 * Determines whether to show the master view is overlayed in portrait orientation.
                 */
                masterIsOverlayed: boolean;

                /**
                 * Window for the master view section of the SplitWindow.
                 */
                masterView: Titanium.UI.Window;

                /**
                 * Determines whether to show the master view or hide.
                 */
                masterViewVisible: boolean;

                /**
                 * Determines the width of the `masterView` in portrait mode.
                 */
                portraitSplit: number;

                /**
                 * Determines whether to show the master view in portrait orientation.
                 */
                showMasterInPortrait: boolean;

                /**
                 * Boolean value indicating if the user should be able to close a window using a swipe gesture.
                 */
                swipeToClose: never;

                /**
                 * Use a transition animation when opening or closing windows in a
                 * <Titanium.UI.NavigationWindow> or <Titanium.UI.Tab>.
                 */
                transitionAnimation: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof SplitWindowEventMap>(name: K, callback: (this: Titanium.UI.iOS.SplitWindow, event: SplitWindowEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof SplitWindowEventMap>(name: K, event?: SplitWindowEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.detailView> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.detailView> instead.
                 */
                getDetailView(): Titanium.UI.Window;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.landscapeSplit> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.landscapeSplit> instead.
                 */
                getLandscapeSplit(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.masterIsOverlayed> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.masterIsOverlayed> instead.
                 */
                getMasterIsOverlayed(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.masterView> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.masterView> instead.
                 */
                getMasterView(): Titanium.UI.Window;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.masterViewVisible> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.masterViewVisible> instead.
                 */
                getMasterViewVisible(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.portraitSplit> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.portraitSplit> instead.
                 */
                getPortraitSplit(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.showMasterInPortrait> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.showMasterInPortrait> instead.
                 */
                getShowMasterInPortrait(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.swipeToClose> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.swipeToClose> instead.
                 */
                getSwipeToClose: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.SplitWindow.transitionAnimation> property.
                 * @deprecated Access <Titanium.UI.iOS.SplitWindow.transitionAnimation> instead.
                 */
                getTransitionAnimation: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof SplitWindowEventMap>(name: K, callback: (this: Titanium.UI.iOS.SplitWindow, event: SplitWindowEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.detailView> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.detailView> instead.
                 */
                setDetailView(detailView: Titanium.UI.Window): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.landscapeSplit> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.landscapeSplit> instead.
                 */
                setLandscapeSplit(landscapeSplit: number): void;

                /**
                 * Sets the value of the [masterIsOverlayed](Titanium.UI.iOS.SplitWindow.masterIsOverlayed) property.
                 */
                setMasterIsOverlayed(masterIsOverlayed: boolean, options?: AnimatedOptions): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.masterView> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.masterView> instead.
                 */
                setMasterView(masterView: Titanium.UI.Window): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.masterViewVisible> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.masterViewVisible> instead.
                 */
                setMasterViewVisible(masterViewVisible: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.portraitSplit> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.portraitSplit> instead.
                 */
                setPortraitSplit(portraitSplit: number): void;

                /**
                 * Sets the value of the [showMasterInPortrait](Titanium.UI.iOS.SplitWindow.showMasterInPortrait) property.
                 */
                setShowMasterInPortrait(showMasterInPortrait: boolean, options?: AnimatedOptions): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.swipeToClose> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.swipeToClose> instead.
                 */
                setSwipeToClose: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.SplitWindow.transitionAnimation> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.SplitWindow.transitionAnimation> instead.
                 */
                setTransitionAnimation: never;

            }
            /**
             * Base event for class Titanium.UI.iOS.Stepper
             */
            interface StepperBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.Stepper;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface Stepper_click_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface Stepper_dblclick_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface Stepper_doubletap_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface Stepper_keypressed_Event extends StepperBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface Stepper_longpress_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface Stepper_pinch_Event extends StepperBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface Stepper_postlayout_Event extends StepperBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface Stepper_singletap_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface Stepper_swipe_Event extends StepperBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface Stepper_touchcancel_Event extends StepperBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface Stepper_touchend_Event extends StepperBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface Stepper_touchmove_Event extends StepperBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface Stepper_touchstart_Event extends StepperBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface Stepper_twofingertap_Event extends StepperBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired every time the stepper value changes.
             */
            interface Stepper_change_Event extends StepperBaseEvent {
                /**
                 * The maximum value of the stepper.
                 */
                maximum: number;

                /**
                 * The minimum value of the stepper.
                 */
                minimum: number;

                /**
                 * The current value of the stepper.
                 */
                value: number;

            }
            interface StepperEventMap extends ProxyEventMap {
                change: Stepper_change_Event;

                click: Stepper_click_Event;

                dblclick: Stepper_dblclick_Event;

                doubletap: Stepper_doubletap_Event;

                keypressed: Stepper_keypressed_Event;

                longpress: Stepper_longpress_Event;

                pinch: Stepper_pinch_Event;

                postlayout: Stepper_postlayout_Event;

                singletap: Stepper_singletap_Event;

                swipe: Stepper_swipe_Event;

                touchcancel: Stepper_touchcancel_Event;

                touchend: Stepper_touchend_Event;

                touchmove: Stepper_touchmove_Event;

                touchstart: Stepper_touchstart_Event;

                twofingertap: Stepper_twofingertap_Event;

            }
            /**
             * A widget used to increment and decrement a value.
             */
            class Stepper extends Titanium.UI.View {
                /**
                 * If YES, the user pressing and holding on the stepper repeatedly alters value.
                 * The default value is YES.
                 */
                autorepeat: boolean;

                /**
                 * Background image for the stepper in its normal state, specified as a local file path or URL.
                 */
                backgroundImage: string;

                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * If YES, value change events are sent immediately when the value changes during user interaction.
                 * If NO, a value change event is sent when user interaction ends.
                 * The default value is YES.
                 */
                continuous: boolean;

                /**
                 * Background image for the stepper decrement button in its disabled state, specified as a local
                 * file path or URL. The decrement button enters a disabled state ones the value is equal to the
                 * minimumValue , setting the enabled property to false will have no effect to decrement button state.
                 */
                decrementDisabledImage: string;

                /**
                 * Background image for the stepper decrement button in its normal state, specified as a local
                 * file path or URL.
                 */
                decrementImage: string;

                /**
                 * Determines if the stepper is enabled or disabled.
                 */
                enabled: boolean;

                /**
                 * Background image for the stepper increment button in its disabled state, specified as a local
                 * file path or URL.The increment button enters a disabled state ones the value is equal to the
                 * maximumValue , setting the enabled property to false will have no effect to increment button state.
                 */
                incrementDisabledImage: string;

                /**
                 * Background image for the stepper increment button in its normal state, specified as a local
                 * file path or URL.
                 */
                incrementImage: string;

                /**
                 * The maximum value the stepper will be set to, the value must be greater than the minimum value.
                 * If you attempt to set a value equal to or lower than minimum, the system will default the
                 * value to 100.
                 */
                maximum: number;

                /**
                 * The minimum value the stepper will be set to, the value must be smaller than the maximum value.
                 * If you attempt to set a value equal to or greater than maximum, the system will default the
                 * value to 0.
                 */
                minimum: number;

                /**
                 * The value the stepper will increment and decrement by, default value for this property is 1. When setting
                 * a new value, it must be greater than 1.
                 */
                steps: number;

                /**
                 * Sets the color for the widget, any backgroundImages added will be set to the same color.
                 */
                tintColor: string | Titanium.UI.Color;

                /**
                 * The current value of the stepper.
                 */
                value: number;

                /**
                 * If YES, incrementing beyond <Titanium.UI.iOS.Stepper.maximum> sets value to <Titanium.UI.iOS.Stepper.minimum>. likewise, decrementing below
                 * <Titanium.UI.iOS.Stepper.minimum> sets value to <Titanium.UI.iOS.Stepper.maximum>. If NO, the stepper does not increment beyond <Titanium.UI.iOS.Stepper.maximum> nor
                 * does it decrement below <Titanium.UI.iOS.Stepper.minimum> but rather holds at those values.
                 * The default value is NO.
                 */
                wraps: boolean;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof StepperEventMap>(name: K, callback: (this: Titanium.UI.iOS.Stepper, event: StepperEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof StepperEventMap>(name: K, event?: StepperEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.autorepeat> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.autorepeat> instead.
                 */
                getAutorepeat(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.backgroundImage> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.backgroundImage> instead.
                 */
                getBackgroundImage(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.children> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.continuous> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.continuous> instead.
                 */
                getContinuous(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.decrementDisabledImage> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.decrementDisabledImage> instead.
                 */
                getDecrementDisabledImage(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.decrementImage> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.decrementImage> instead.
                 */
                getDecrementImage(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.enabled> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.enabled> instead.
                 */
                getEnabled(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.incrementDisabledImage> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.incrementDisabledImage> instead.
                 */
                getIncrementDisabledImage(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.incrementImage> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.incrementImage> instead.
                 */
                getIncrementImage(): string;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.maximum> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.maximum> instead.
                 */
                getMaximum(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.minimum> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.minimum> instead.
                 */
                getMinimum(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.steps> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.steps> instead.
                 */
                getSteps(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.tintColor> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.tintColor> instead.
                 */
                getTintColor(): string | Titanium.UI.Color;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.value> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.value> instead.
                 */
                getValue(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Stepper.wraps> property.
                 * @deprecated Access <Titanium.UI.iOS.Stepper.wraps> instead.
                 */
                getWraps(): boolean;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof StepperEventMap>(name: K, callback: (this: Titanium.UI.iOS.Stepper, event: StepperEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
                 */
                replaceAt: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.autorepeat> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.autorepeat> instead.
                 */
                setAutorepeat(autorepeat: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.backgroundImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.backgroundImage> instead.
                 */
                setBackgroundImage(backgroundImage: string): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.continuous> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.continuous> instead.
                 */
                setContinuous(continuous: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.decrementDisabledImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.decrementDisabledImage> instead.
                 */
                setDecrementDisabledImage(decrementDisabledImage: string): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.decrementImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.decrementImage> instead.
                 */
                setDecrementImage(decrementImage: string): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.enabled> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.enabled> instead.
                 */
                setEnabled(enabled: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.incrementDisabledImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.incrementDisabledImage> instead.
                 */
                setIncrementDisabledImage(incrementDisabledImage: string): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.incrementImage> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.incrementImage> instead.
                 */
                setIncrementImage(incrementImage: string): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.maximum> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.maximum> instead.
                 */
                setMaximum(maximum: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.minimum> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.minimum> instead.
                 */
                setMinimum(minimum: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.steps> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.steps> instead.
                 */
                setSteps(steps: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.tintColor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.tintColor> instead.
                 */
                setTintColor(tintColor: string | Titanium.UI.Color): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.value> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.value> instead.
                 */
                setValue(value: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Stepper.wraps> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Stepper.wraps> instead.
                 */
                setWraps(wraps: boolean): void;

            }
            /**
             * A set of constants for creating standard iOS system buttons.
             */
            class SystemButton extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.TabbedBar
             */
            interface TabbedBarBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.TabbedBar;

            }
            /**
             * Fired when a button is clicked.
             */
            interface TabbedBar_click_Event extends TabbedBarBaseEvent {
                /**
                 * Index of the clicked button.
                 */
                index: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface TabbedBar_dblclick_Event extends TabbedBarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface TabbedBar_doubletap_Event extends TabbedBarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface TabbedBar_keypressed_Event extends TabbedBarBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface TabbedBar_longpress_Event extends TabbedBarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface TabbedBar_pinch_Event extends TabbedBarBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface TabbedBar_postlayout_Event extends TabbedBarBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface TabbedBar_singletap_Event extends TabbedBarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface TabbedBar_swipe_Event extends TabbedBarBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface TabbedBar_touchcancel_Event extends TabbedBarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface TabbedBar_touchend_Event extends TabbedBarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface TabbedBar_touchmove_Event extends TabbedBarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface TabbedBar_touchstart_Event extends TabbedBarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface TabbedBar_twofingertap_Event extends TabbedBarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            interface TabbedBarEventMap extends ProxyEventMap {
                click: TabbedBar_click_Event;

                dblclick: TabbedBar_dblclick_Event;

                doubletap: TabbedBar_doubletap_Event;

                keypressed: TabbedBar_keypressed_Event;

                longpress: TabbedBar_longpress_Event;

                pinch: TabbedBar_pinch_Event;

                postlayout: TabbedBar_postlayout_Event;

                singletap: TabbedBar_singletap_Event;

                swipe: TabbedBar_swipe_Event;

                touchcancel: TabbedBar_touchcancel_Event;

                touchend: TabbedBar_touchend_Event;

                touchmove: TabbedBar_touchmove_Event;

                touchstart: TabbedBar_touchstart_Event;

                twofingertap: TabbedBar_twofingertap_Event;

            }
            /**
             * A button bar that maintains a selected state.
             * @deprecated Use [Titanium.UI.TabbedBar](Titanium.UI.TabbedBar) instead.
             */
            class TabbedBar extends Titanium.UI.View {
                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * Index of the currently selected button.
                 */
                index: number;

                /**
                 * Array of labels for the tabbed bar.
                 */
                labels: string[] | BarItemType[];

                /**
                 * Style of the tabbed bar.
                 */
                style: number;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof TabbedBarEventMap>(name: K, callback: (this: Titanium.UI.iOS.TabbedBar, event: TabbedBarEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof TabbedBarEventMap>(name: K, event?: TabbedBarEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TabbedBar.children> property.
                 * @deprecated Access <Titanium.UI.iOS.TabbedBar.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TabbedBar.index> property.
                 * @deprecated Access <Titanium.UI.iOS.TabbedBar.index> instead.
                 */
                getIndex(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TabbedBar.labels> property.
                 * @deprecated Access <Titanium.UI.iOS.TabbedBar.labels> instead.
                 */
                getLabels(): string[] | BarItemType[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.TabbedBar.style> property.
                 * @deprecated Access <Titanium.UI.iOS.TabbedBar.style> instead.
                 */
                getStyle(): number;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof TabbedBarEventMap>(name: K, callback: (this: Titanium.UI.iOS.TabbedBar, event: TabbedBarEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
                 */
                replaceAt: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TabbedBar.index> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TabbedBar.index> instead.
                 */
                setIndex(index: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TabbedBar.labels> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TabbedBar.labels> instead.
                 */
                setLabels(labels: string[] | BarItemType[]): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TabbedBar.style> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TabbedBar.style> instead.
                 */
                setStyle(style: number): void;

            }
            /**
             * Base event for class Titanium.UI.iOS.Toolbar
             */
            interface ToolbarBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iOS.Toolbar;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface Toolbar_click_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface Toolbar_dblclick_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface Toolbar_doubletap_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface Toolbar_keypressed_Event extends ToolbarBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface Toolbar_longpress_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface Toolbar_pinch_Event extends ToolbarBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface Toolbar_postlayout_Event extends ToolbarBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface Toolbar_singletap_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface Toolbar_swipe_Event extends ToolbarBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface Toolbar_touchcancel_Event extends ToolbarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface Toolbar_touchend_Event extends ToolbarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface Toolbar_touchmove_Event extends ToolbarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface Toolbar_touchstart_Event extends ToolbarBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface Toolbar_twofingertap_Event extends ToolbarBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            interface ToolbarEventMap extends ProxyEventMap {
                click: Toolbar_click_Event;

                dblclick: Toolbar_dblclick_Event;

                doubletap: Toolbar_doubletap_Event;

                keypressed: Toolbar_keypressed_Event;

                longpress: Toolbar_longpress_Event;

                pinch: Toolbar_pinch_Event;

                postlayout: Toolbar_postlayout_Event;

                singletap: Toolbar_singletap_Event;

                swipe: Toolbar_swipe_Event;

                touchcancel: Toolbar_touchcancel_Event;

                touchend: Toolbar_touchend_Event;

                touchmove: Toolbar_touchmove_Event;

                touchstart: Toolbar_touchstart_Event;

                twofingertap: Toolbar_twofingertap_Event;

            }
            /**
             * An iOS toolbar, which can contain buttons and certain other controls.
             * @deprecated Use the cross-platform [Titanium.UI.Toolbar](Titanium.UI.Toolbar) instead.
             */
            class Toolbar extends Titanium.UI.View {
                /**
                 * Background color of the view, as a color name or hex triplet.
                 */
                backgroundColor: never;

                /**
                 * Size of the left end cap.
                 */
                backgroundLeftCap: never;

                /**
                 * Determines whether to tile a background across a view.
                 */
                backgroundRepeat: never;

                /**
                 * Size of the top end cap.
                 */
                backgroundTopCap: never;

                /**
                 * Background color for the toolbar, as a color name or hex triplet.
                 */
                barColor: string | Titanium.UI.Color;

                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * If `true`, the background of the toolbar extends upwards.
                 */
                extendBackground: boolean;

                /**
                 * An array of buttons (or other widgets) contained in the toolbar.
                 */
                items: Titanium.UI.View[];

                /**
                 * Specifies how the view positions its children.
                 * One of: 'composite', 'vertical', or 'horizontal'.
                 */
                layout: never;

                /**
                 * If `true`, a translucent background color is used for the toolbar.
                 */
                translucent: boolean;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof ToolbarEventMap>(name: K, callback: (this: Titanium.UI.iOS.Toolbar, event: ToolbarEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof ToolbarEventMap>(name: K, event?: ToolbarEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.backgroundColor> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.backgroundColor> instead.
                 */
                getBackgroundColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.backgroundLeftCap> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.backgroundLeftCap> instead.
                 */
                getBackgroundLeftCap: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.backgroundRepeat> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.backgroundRepeat> instead.
                 */
                getBackgroundRepeat: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.backgroundTopCap> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.backgroundTopCap> instead.
                 */
                getBackgroundTopCap: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.barColor> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.barColor> instead.
                 */
                getBarColor(): string | Titanium.UI.Color;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.children> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.extendBackground> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.extendBackground> instead.
                 */
                getExtendBackground(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.items> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.items> instead.
                 */
                getItems(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.layout> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.layout> instead.
                 */
                getLayout: never;

                /**
                 * Gets the value of the <Titanium.UI.iOS.Toolbar.translucent> property.
                 * @deprecated Access <Titanium.UI.iOS.Toolbar.translucent> instead.
                 */
                getTranslucent(): boolean;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof ToolbarEventMap>(name: K, callback: (this: Titanium.UI.iOS.Toolbar, event: ToolbarEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
                 */
                replaceAt: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.backgroundColor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.backgroundColor> instead.
                 */
                setBackgroundColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.backgroundLeftCap> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.backgroundLeftCap> instead.
                 */
                setBackgroundLeftCap: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.backgroundRepeat> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.backgroundRepeat> instead.
                 */
                setBackgroundRepeat: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.backgroundTopCap> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.backgroundTopCap> instead.
                 */
                setBackgroundTopCap: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.barColor> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.barColor> instead.
                 */
                setBarColor(barColor: string | Titanium.UI.Color): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.extendBackground> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.extendBackground> instead.
                 */
                setExtendBackground(extendBackground: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.items> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.items> instead.
                 */
                setItems(items: ReadonlyArray<Titanium.UI.View>): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.layout> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.layout> instead.
                 */
                setLayout: never;

                /**
                 * Sets the value of the <Titanium.UI.iOS.Toolbar.translucent> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.Toolbar.translucent> instead.
                 */
                setTranslucent(translucent: boolean): void;

            }
            /**
             * A transition animation when opening or closing windows in a
             * <Titanium.UI.NavigationWindow> or <Titanium.UI.Tab>.
             * Use this proxy with the Window's
             * [transitionAnimation](Titanium.UI.Window.transitionAnimation) property.
             */
            class TransitionAnimation extends Titanium.Proxy {
                /**
                 * Length of the transition in milliseconds.
                 */
                duration: number;

                /**
                 * Animation to hide the current window.
                 */
                transitionFrom: Titanium.UI.Animation;

                /**
                 * Animation to show the new window.
                 */
                transitionTo: Titanium.UI.Animation;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TransitionAnimation.duration> property.
                 * @deprecated Access <Titanium.UI.iOS.TransitionAnimation.duration> instead.
                 */
                getDuration(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TransitionAnimation.transitionFrom> property.
                 * @deprecated Access <Titanium.UI.iOS.TransitionAnimation.transitionFrom> instead.
                 */
                getTransitionFrom(): Titanium.UI.Animation;

                /**
                 * Gets the value of the <Titanium.UI.iOS.TransitionAnimation.transitionTo> property.
                 * @deprecated Access <Titanium.UI.iOS.TransitionAnimation.transitionTo> instead.
                 */
                getTransitionTo(): Titanium.UI.Animation;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TransitionAnimation.duration> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TransitionAnimation.duration> instead.
                 */
                setDuration(duration: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TransitionAnimation.transitionFrom> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TransitionAnimation.transitionFrom> instead.
                 */
                setTransitionFrom(transitionFrom: Titanium.UI.Animation): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.TransitionAnimation.transitionTo> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.TransitionAnimation.transitionTo> instead.
                 */
                setTransitionTo(transitionTo: Titanium.UI.Animation): void;

            }
            /**
             * Dynamic behavior to support connections between two items.
             */
            class ViewAttachmentBehavior extends Titanium.Proxy {
                /**
                 * Item to use as the anchor in this behavior.
                 */
                anchorItem: Titanium.UI.View;

                /**
                 * Offset from the center point of the anchor item for the attachment.
                 */
                anchorOffset: Point;

                /**
                 * Amount of damping to apply to the attachment behavior.
                 */
                damping: number;

                /**
                 * Distance, in points, between the two attachment points.
                 */
                distance: number;

                /**
                 * Frequency of oscillation for the behavior.
                 */
                frequency: number;

                /**
                 * Item to connect to use the attachment behavior.
                 */
                item: Titanium.UI.View;

                /**
                 * Offset from the center point of the item for the attachment.
                 */
                itemOffset: Point;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.anchorItem> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.anchorItem> instead.
                 */
                getAnchorItem(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.anchorOffset> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.anchorOffset> instead.
                 */
                getAnchorOffset(): Point;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.damping> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.damping> instead.
                 */
                getDamping(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.distance> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.distance> instead.
                 */
                getDistance(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.frequency> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.frequency> instead.
                 */
                getFrequency(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.item> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.item> instead.
                 */
                getItem(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.itemOffset> property.
                 * @deprecated Access <Titanium.UI.iOS.ViewAttachmentBehavior.itemOffset> instead.
                 */
                getItemOffset(): Point;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.anchorItem> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.anchorItem> instead.
                 */
                setAnchorItem(anchorItem: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.anchorOffset> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.anchorOffset> instead.
                 */
                setAnchorOffset(anchorOffset: Point): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.damping> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.damping> instead.
                 */
                setDamping(damping: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.distance> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.distance> instead.
                 */
                setDistance(distance: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.frequency> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.frequency> instead.
                 */
                setFrequency(frequency: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.item> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.item> instead.
                 */
                setItem(item: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.ViewAttachmentBehavior.itemOffset> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.ViewAttachmentBehavior.itemOffset> instead.
                 */
                setItemOffset(itemOffset: Point): void;

            }
            /**
             * A collection of properties used to initialize a web view.
             */
            class WebViewConfiguration extends Titanium.Proxy {
                /**
                 * A Boolean value indicating whether AirPlay is allowed.
                 */
                allowsAirPlayMediaPlayback: boolean;

                /**
                 * A Boolean value indicating whether HTML5 videos play inline or use the native full-screen controller.
                 */
                allowsInlineMediaPlayback: boolean;

                /**
                 * A Boolean value indicating whether HTML5 videos can play picture-in-picture.
                 */
                allowsPictureInPictureMediaPlayback: boolean;

                /**
                 * Determines which media types require a user gesture to begin playing.
                 */
                mediaTypesRequiringUserActionForPlayback: number;

                /**
                 * The preference settings to be used by the web view.
                 */
                preferences: WebViewPreferencesObject;

                /**
                 * The process pool from which to obtain the  Web Content process of view.
                 */
                processPool: Titanium.UI.iOS.WebViewProcessPool;

                /**
                 * The level of granularity with which the user can interactively select content in the web view.
                 */
                selectionGranularity: number;

                /**
                 * A Boolean value indicating whether the web view suppresses content rendering until it is fully
                 * loaded into memory.
                 */
                suppressesIncrementalRendering: boolean;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsAirPlayMediaPlayback> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.allowsAirPlayMediaPlayback> instead.
                 */
                getAllowsAirPlayMediaPlayback(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsInlineMediaPlayback> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.allowsInlineMediaPlayback> instead.
                 */
                getAllowsInlineMediaPlayback(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsPictureInPictureMediaPlayback> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.allowsPictureInPictureMediaPlayback> instead.
                 */
                getAllowsPictureInPictureMediaPlayback(): boolean;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.mediaTypesRequiringUserActionForPlayback> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.mediaTypesRequiringUserActionForPlayback> instead.
                 */
                getMediaTypesRequiringUserActionForPlayback(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.preferences> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.preferences> instead.
                 */
                getPreferences(): WebViewPreferencesObject;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.processPool> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.processPool> instead.
                 */
                getProcessPool(): Titanium.UI.iOS.WebViewProcessPool;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.selectionGranularity> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.selectionGranularity> instead.
                 */
                getSelectionGranularity(): number;

                /**
                 * Gets the value of the <Titanium.UI.iOS.WebViewConfiguration.suppressesIncrementalRendering> property.
                 * @deprecated Access <Titanium.UI.iOS.WebViewConfiguration.suppressesIncrementalRendering> instead.
                 */
                getSuppressesIncrementalRendering(): boolean;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsAirPlayMediaPlayback> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.allowsAirPlayMediaPlayback> instead.
                 */
                setAllowsAirPlayMediaPlayback(allowsAirPlayMediaPlayback: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsInlineMediaPlayback> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.allowsInlineMediaPlayback> instead.
                 */
                setAllowsInlineMediaPlayback(allowsInlineMediaPlayback: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.allowsPictureInPictureMediaPlayback> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.allowsPictureInPictureMediaPlayback> instead.
                 */
                setAllowsPictureInPictureMediaPlayback(allowsPictureInPictureMediaPlayback: boolean): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.mediaTypesRequiringUserActionForPlayback> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.mediaTypesRequiringUserActionForPlayback> instead.
                 */
                setMediaTypesRequiringUserActionForPlayback(mediaTypesRequiringUserActionForPlayback: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.preferences> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.preferences> instead.
                 */
                setPreferences(preferences: WebViewPreferencesObject): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.processPool> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.processPool> instead.
                 */
                setProcessPool(processPool: Titanium.UI.iOS.WebViewProcessPool): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.selectionGranularity> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.selectionGranularity> instead.
                 */
                setSelectionGranularity(selectionGranularity: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iOS.WebViewConfiguration.suppressesIncrementalRendering> property.
                 * @deprecated Set the value using <Titanium.UI.iOS.WebViewConfiguration.suppressesIncrementalRendering> instead.
                 */
                setSuppressesIncrementalRendering(suppressesIncrementalRendering: boolean): void;

            }
            /**
             * It represents the decision handler to tell to webview, whether allow or cancel the navigation.
             */
            class WebViewDecisionHandler extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * It calls the decision handler with given action policy.
                 */
                invoke(value: number): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
            /**
             * It represents a pool of Web Content processes.
             */
            class WebViewProcessPool extends Titanium.Proxy {
                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            }
        }
        /**
         * iPad specific UI capabilities.
         */
        namespace iPad {
            /**
             * An arrow that points in any direction.
             */
            const POPOVER_ARROW_DIRECTION_ANY: number;

            /**
             * An arrow that points downward.
             */
            const POPOVER_ARROW_DIRECTION_DOWN: number;

            /**
             * An arrow that points toward the left.
             */
            const POPOVER_ARROW_DIRECTION_LEFT: number;

            /**
             * An arrow that points toward the right.
             */
            const POPOVER_ARROW_DIRECTION_RIGHT: number;

            /**
             * The status of the arrow is currently unknown.
             */
            const POPOVER_ARROW_DIRECTION_UNKNOWN: number;

            /**
             * An arrow that points upward.
             */
            const POPOVER_ARROW_DIRECTION_UP: number;

            /**
             * A DocumentViewer provides in-app support for managing user interactions with files on the
             * local system.
             * @deprecated Use [Titanium.UI.iOS.DocumentViewer](Titanium.UI.iOS.DocumentViewer) instead.
             */
            const DocumentViewer: never;
            /**
             * Base event for class Titanium.UI.iPad.Popover
             */
            interface PopoverBaseEvent extends Ti.Event {
                /**
                 * Source object that fired the event.
                 */
                source: Titanium.UI.iPad.Popover;

            }
            /**
             * Fired when the device detects a click against the view.
             */
            interface Popover_click_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double click against the view.
             */
            interface Popover_dblclick_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a double tap against the view.
             */
            interface Popover_doubletap_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a hardware key is pressed in the view.
             */
            interface Popover_keypressed_Event extends PopoverBaseEvent {
                /**
                 * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
                 */
                keyCode: number;

            }
            /**
             * Fired when the device detects a long press.
             */
            interface Popover_longpress_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a pinch gesture.
             */
            interface Popover_pinch_Event extends PopoverBaseEvent {
                /**
                 * The average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpan: number;

                /**
                 * The average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanX: number;

                /**
                 * The average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                currentSpanY: number;

                /**
                 * The X coordinate of the current gesture's focal point.
                 */
                focusX: number;

                /**
                 * The Y coordinate of the current gesture's focal point.
                 */
                focusY: number;

                /**
                 * Returns `true` if a scale gesture is in progress, `false` otherwise.
                 */
                inProgress: boolean;

                /**
                 * The previous average distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpan: number;

                /**
                 * The previous average X distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanX: number;

                /**
                 * The previous average Y distance between each of the pointers forming the gesture in progress through
                 * the focal point.
                 */
                previousSpanY: number;

                /**
                 * The scale factor relative to the points of the two touches in screen coordinates.
                 */
                scale: number;

                /**
                 * The event time of the current event being processed.
                 */
                time: number;

                /**
                 * The time difference in milliseconds between the previous accepted scaling event and the
                 * current scaling event.
                 */
                timeDelta: number;

                /**
                 * The velocity of the pinch in scale factor per second.
                 */
                velocity: number;

            }
            /**
             * Fired when a layout cycle is finished.
             */
            interface Popover_postlayout_Event extends PopoverBaseEvent {
            }
            /**
             * Fired when the device detects a single tap against the view.
             */
            interface Popover_singletap_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a swipe gesture against the view.
             */
            interface Popover_swipe_Event extends PopoverBaseEvent {
                /**
                 * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
                 */
                direction: string;

                /**
                 * X coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event's endpoint from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is interrupted by the device.
             */
            interface Popover_touchcancel_Event extends PopoverBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when a touch event is completed.
             */
            interface Popover_touchend_Event extends PopoverBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects movement of a touch.
             */
            interface Popover_touchmove_Event extends PopoverBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired as soon as the device detects a touch gesture.
             */
            interface Popover_touchstart_Event extends PopoverBaseEvent {
                /**
                 * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
                 * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
                 * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
                 */
                altitudeAngle: number;

                /**
                 * The x value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewX: number;

                /**
                 * The y value of the unit vector that points in the direction of the azimuth of the stylus.
                 * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
                 */
                azimuthUnitVectorInViewY: number;

                /**
                 * The current force value of the touch event.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
                 */
                force: number;

                /**
                 * Maximum possible value of the force property.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                maximumPossibleForce: number;

                /**
                 * The current size of the touch area. Note: This property is only available on some Android devices.
                 */
                size: number;

                /**
                 * The time (in seconds) when the touch was used in correlation with the system start up.
                 * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
                 */
                timestamp: number;

                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the device detects a two-finger tap against the view.
             */
            interface Popover_twofingertap_Event extends PopoverBaseEvent {
                /**
                 * X coordinate of the event from the `source` view's coordinate system.
                 */
                x: number;

                /**
                 * Y coordinate of the event from the `source` view's coordinate system.
                 */
                y: number;

            }
            /**
             * Fired when the popover is hidden.
             */
            interface Popover_hide_Event extends PopoverBaseEvent {
            }
            interface PopoverEventMap extends ProxyEventMap {
                click: Popover_click_Event;

                dblclick: Popover_dblclick_Event;

                doubletap: Popover_doubletap_Event;

                hide: Popover_hide_Event;

                keypressed: Popover_keypressed_Event;

                longpress: Popover_longpress_Event;

                pinch: Popover_pinch_Event;

                postlayout: Popover_postlayout_Event;

                singletap: Popover_singletap_Event;

                swipe: Popover_swipe_Event;

                touchcancel: Popover_touchcancel_Event;

                touchend: Popover_touchend_Event;

                touchmove: Popover_touchmove_Event;

                touchstart: Popover_touchstart_Event;

                twofingertap: Popover_twofingertap_Event;

            }
            /**
             * A Popover is used to manage the presentation of content in a popover.
             */
            class Popover extends Titanium.UI.View {
                /**
                 * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
                 */
                accessibilityHidden: never;

                /**
                 * Briefly describes what performing an action (such as a click) on the view will do.
                 */
                accessibilityHint: never;

                /**
                 * A succint label identifying the view for the device's accessibility service.
                 */
                accessibilityLabel: never;

                /**
                 * A string describing the value (if any) of the view for the device's accessibility service.
                 */
                accessibilityValue: never;

                /**
                 * Coordinate of the view about which to pivot an animation.
                 */
                anchorPoint: never;

                /**
                 * Current position of the view during an animation.
                 */
                readonly animatedCenter: never;

                /**
                 * Indicates the arrow direction of the popover.
                 */
                arrowDirection: number;

                /**
                 * Sets the background color of the popover.
                 */
                backgroundColor: string | Titanium.UI.Color;

                /**
                 * A background gradient for the view.
                 */
                backgroundGradient: never;

                /**
                 * Background image for the view, specified as a local file path or URL.
                 */
                backgroundImage: never;

                /**
                 * Size of the left end cap.
                 */
                backgroundLeftCap: never;

                /**
                 * Determines whether to tile a background across a view.
                 */
                backgroundRepeat: never;

                /**
                 * Size of the top end cap.
                 */
                backgroundTopCap: never;

                /**
                 * Border color of the view, as a color name or hex triplet.
                 */
                borderColor: never;

                /**
                 * Radius for the rounded corners of the view's border.
                 */
                borderRadius: never;

                /**
                 * Border width of the view.
                 */
                borderWidth: never;

                /**
                 * View's bottom position, in platform-specific units.
                 */
                bottom: never;

                /**
                 * View's center position, in the parent view's coordinates.
                 */
                center: never;

                /**
                 * Array of this view's child views.
                 */
                readonly children: never;

                /**
                 * View's clipping behavior.
                 */
                clipMode: never;

                /**
                 * View to use for the popover content. Must be set before calling the `show()` method.
                 */
                contentView: Titanium.UI.View;

                /**
                 * Height of the popover.
                 * @deprecated This property is deprecated. Set the height on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                height: never;

                /**
                 * Determines whether the layout has wrapping behavior.
                 */
                horizontalWrap: never;

                /**
                 * Specifies how the view positions its children.
                 * One of: 'composite', 'vertical', or 'horizontal'.
                 */
                layout: never;

                /**
                 * View's left position, in platform-specific units.
                 */
                left: never;

                /**
                 * Left button in the navigation area of the popover.
                 * @deprecated This property is no longer supported.
                 */
                leftNavButton: never;

                /**
                 * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
                 */
                opacity: never;

                /**
                 * Passthrough views to use when the popover is shown.
                 */
                passthroughViews: Titanium.UI.View[];

                /**
                 * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
                 * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
                 */
                pullBackgroundColor: never;

                /**
                 * The bounding box of the view relative to its parent, in system units.
                 */
                readonly rect: never;

                /**
                 * View's right position, in platform-specific units.
                 */
                right: never;

                /**
                 * Right button in the navigation area of the popover.
                 * @deprecated This property is no longer supported.
                 */
                rightNavButton: never;

                /**
                 * The size of the view in system units.
                 */
                readonly size: never;

                /**
                 * The view's tintColor
                 */
                tintColor: never;

                /**
                 * Title of the navigation area of the popover.
                 * @deprecated This property is no longer supported.
                 */
                title: never;

                /**
                 * The view's top position.
                 */
                top: never;

                /**
                 * Determines whether view should receive touch events.
                 */
                touchEnabled: never;

                /**
                 * Transformation matrix to apply to the view.
                 */
                transform: never;

                /**
                 * Determines the color of the shadow.
                 */
                viewShadowColor: never;

                /**
                 * Determines the offset for the shadow of the view.
                 */
                viewShadowOffset: never;

                /**
                 * Determines the blur radius used to create the shadow.
                 */
                viewShadowRadius: never;

                /**
                 * Determines whether the view is visible.
                 */
                visible: never;

                /**
                 * Width of the popover.
                 * @deprecated This property is deprecated. Set the width on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                width: never;

                /**
                 * Z-index stack order position, relative to other sibling views.
                 */
                zIndex: never;

                /**
                 * Adds a child to this view's hierarchy.
                 */
                add: never;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener<K extends keyof PopoverEventMap>(name: K, callback: (this: Titanium.UI.iPad.Popover, event: PopoverEventMap[K]) => void): void;

                /**
                 * Adds the specified callback as an event listener for the named event.
                 */
                addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Animates this view.
                 */
                animate: never;

                /**
                 * Translates a point from this view's coordinate system to another view's coordinate system.
                 */
                convertPointToView: never;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent<K extends keyof PopoverEventMap>(name: K, event?: PopoverEventMap[K]): void;

                /**
                 * Fires a synthesized event to any registered listeners.
                 */
                fireEvent(name: string, event?: any): void;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.accessibilityHidden> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.accessibilityHidden> instead.
                 */
                getAccessibilityHidden: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.accessibilityHint> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.accessibilityHint> instead.
                 */
                getAccessibilityHint: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.accessibilityLabel> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.accessibilityLabel> instead.
                 */
                getAccessibilityLabel: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.accessibilityValue> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.accessibilityValue> instead.
                 */
                getAccessibilityValue: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.anchorPoint> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.anchorPoint> instead.
                 */
                getAnchorPoint: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.animatedCenter> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.animatedCenter> instead.
                 */
                getAnimatedCenter: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.arrowDirection> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.arrowDirection> instead.
                 */
                getArrowDirection(): number;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundColor> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundColor> instead.
                 */
                getBackgroundColor(): string | Titanium.UI.Color;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundGradient> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundGradient> instead.
                 */
                getBackgroundGradient: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundImage> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundImage> instead.
                 */
                getBackgroundImage: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundLeftCap> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundLeftCap> instead.
                 */
                getBackgroundLeftCap: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundRepeat> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundRepeat> instead.
                 */
                getBackgroundRepeat: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.backgroundTopCap> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.backgroundTopCap> instead.
                 */
                getBackgroundTopCap: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.borderColor> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.borderColor> instead.
                 */
                getBorderColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.borderRadius> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.borderRadius> instead.
                 */
                getBorderRadius: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.borderWidth> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.borderWidth> instead.
                 */
                getBorderWidth: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.bottom> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.bottom> instead.
                 */
                getBottom: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.center> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.center> instead.
                 */
                getCenter: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.children> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.children> instead.
                 */
                getChildren: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.clipMode> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.clipMode> instead.
                 */
                getClipMode: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.contentView> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.contentView> instead.
                 */
                getContentView(): Titanium.UI.View;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.height> property.
                 * @deprecated This property is deprecated. Set the height on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                getHeight: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.horizontalWrap> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.horizontalWrap> instead.
                 */
                getHorizontalWrap: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.layout> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.layout> instead.
                 */
                getLayout: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.left> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.left> instead.
                 */
                getLeft: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.leftNavButton> property.
                 * @deprecated This property is no longer supported.
                 */
                getLeftNavButton: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.opacity> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.opacity> instead.
                 */
                getOpacity: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.passthroughViews> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.passthroughViews> instead.
                 */
                getPassthroughViews(): Titanium.UI.View[];

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.pullBackgroundColor> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.pullBackgroundColor> instead.
                 */
                getPullBackgroundColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.rect> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.rect> instead.
                 */
                getRect: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.right> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.right> instead.
                 */
                getRight: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.rightNavButton> property.
                 * @deprecated This property is no longer supported.
                 */
                getRightNavButton: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.size> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.size> instead.
                 */
                getSize: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.tintColor> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.tintColor> instead.
                 */
                getTintColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.title> property.
                 * @deprecated This property is no longer supported.
                 */
                getTitle: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.top> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.top> instead.
                 */
                getTop: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.touchEnabled> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.touchEnabled> instead.
                 */
                getTouchEnabled: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.transform> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.transform> instead.
                 */
                getTransform: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.viewShadowColor> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.viewShadowColor> instead.
                 */
                getViewShadowColor: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.viewShadowOffset> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.viewShadowOffset> instead.
                 */
                getViewShadowOffset: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.viewShadowRadius> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.viewShadowRadius> instead.
                 */
                getViewShadowRadius: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.visible> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.visible> instead.
                 */
                getVisible: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.width> property.
                 * @deprecated This property is deprecated. Set the width on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                getWidth: never;

                /**
                 * Gets the value of the <Titanium.UI.iPad.Popover.zIndex> property.
                 * @deprecated Access <Titanium.UI.iPad.Popover.zIndex> instead.
                 */
                getZIndex: never;

                /**
                 * Hides the popover.
                 */
                hide(options?: AnimatedOptions): void;

                /**
                 * Removes a child view from this view's hierarchy.
                 */
                remove: never;

                /**
                 * Removes all child views from this view's hierarchy.
                 */
                removeAllChildren: never;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener<K extends keyof PopoverEventMap>(name: K, callback: (this: Titanium.UI.iPad.Popover, event: PopoverEventMap[K]) => void): void;

                /**
                 * Removes the specified callback as an event listener for the named event.
                 */
                removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

                /**
                 * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
                 */
                replaceAt: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.accessibilityHidden> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.accessibilityHidden> instead.
                 */
                setAccessibilityHidden: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.accessibilityHint> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.accessibilityHint> instead.
                 */
                setAccessibilityHint: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.accessibilityLabel> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.accessibilityLabel> instead.
                 */
                setAccessibilityLabel: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.accessibilityValue> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.accessibilityValue> instead.
                 */
                setAccessibilityValue: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.anchorPoint> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.anchorPoint> instead.
                 */
                setAnchorPoint: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.arrowDirection> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.arrowDirection> instead.
                 */
                setArrowDirection(arrowDirection: number): void;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundColor> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundColor> instead.
                 */
                setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundGradient> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundGradient> instead.
                 */
                setBackgroundGradient: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundImage> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundImage> instead.
                 */
                setBackgroundImage: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundLeftCap> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundLeftCap> instead.
                 */
                setBackgroundLeftCap: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundRepeat> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundRepeat> instead.
                 */
                setBackgroundRepeat: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.backgroundTopCap> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.backgroundTopCap> instead.
                 */
                setBackgroundTopCap: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.borderColor> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.borderColor> instead.
                 */
                setBorderColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.borderRadius> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.borderRadius> instead.
                 */
                setBorderRadius: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.borderWidth> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.borderWidth> instead.
                 */
                setBorderWidth: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.bottom> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.bottom> instead.
                 */
                setBottom: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.center> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.center> instead.
                 */
                setCenter: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.clipMode> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.clipMode> instead.
                 */
                setClipMode: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.contentView> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.contentView> instead.
                 */
                setContentView(contentView: Titanium.UI.View): void;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.height> property.
                 * @deprecated This property is deprecated. Set the height on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                setHeight: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.horizontalWrap> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.horizontalWrap> instead.
                 */
                setHorizontalWrap: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.layout> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.layout> instead.
                 */
                setLayout: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.left> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.left> instead.
                 */
                setLeft: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.leftNavButton> property.
                 * @deprecated This property is no longer supported.
                 */
                setLeftNavButton: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.opacity> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.opacity> instead.
                 */
                setOpacity: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.passthroughViews> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.passthroughViews> instead.
                 */
                setPassthroughViews(passthroughViews: ReadonlyArray<Titanium.UI.View>): void;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.pullBackgroundColor> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.pullBackgroundColor> instead.
                 */
                setPullBackgroundColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.right> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.right> instead.
                 */
                setRight: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.rightNavButton> property.
                 * @deprecated This property is no longer supported.
                 */
                setRightNavButton: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.tintColor> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.tintColor> instead.
                 */
                setTintColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.title> property.
                 * @deprecated This property is no longer supported.
                 */
                setTitle: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.top> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.top> instead.
                 */
                setTop: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.touchEnabled> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.touchEnabled> instead.
                 */
                setTouchEnabled: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.transform> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.transform> instead.
                 */
                setTransform: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.viewShadowColor> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.viewShadowColor> instead.
                 */
                setViewShadowColor: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.viewShadowOffset> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.viewShadowOffset> instead.
                 */
                setViewShadowOffset: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.viewShadowRadius> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.viewShadowRadius> instead.
                 */
                setViewShadowRadius: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.visible> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.visible> instead.
                 */
                setVisible: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.width> property.
                 * @deprecated This property is deprecated. Set the width on the [Titanium.UI.iPad.Popover.contentView](Titanium.UI.iPad.Popover.contentView) property instead.
                 */
                setWidth: never;

                /**
                 * Sets the value of the <Titanium.UI.iPad.Popover.zIndex> property.
                 * @deprecated Set the value using <Titanium.UI.iPad.Popover.zIndex> instead.
                 */
                setZIndex: never;

                /**
                 * Displays the popover.
                 */
                show(options: ShowPopoverParams): void;

                /**
                 * Returns an image of the rendered view, as a Blob.
                 */
                toImage: never;

            }
            /**
             * A SplitWindow is a window that manages the presentation of two side-by-side view
             * controllers.
             * @deprecated Use [Titanium.UI.iOS.SplitWindow](Titanium.UI.iOS.SplitWindow) instead.
             */
            const SplitWindow: never;
        }
        /**
         * Base event for class Titanium.UI.ActivityIndicator
         */
        interface ActivityIndicatorBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ActivityIndicator;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ActivityIndicator_click_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ActivityIndicator_dblclick_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ActivityIndicator_doubletap_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ActivityIndicator_focus_Event extends ActivityIndicatorBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ActivityIndicator_keypressed_Event extends ActivityIndicatorBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ActivityIndicator_longclick_Event extends ActivityIndicatorBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface ActivityIndicator_longpress_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ActivityIndicator_pinch_Event extends ActivityIndicatorBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ActivityIndicator_postlayout_Event extends ActivityIndicatorBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ActivityIndicator_singletap_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ActivityIndicator_swipe_Event extends ActivityIndicatorBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ActivityIndicator_touchcancel_Event extends ActivityIndicatorBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ActivityIndicator_touchend_Event extends ActivityIndicatorBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ActivityIndicator_touchmove_Event extends ActivityIndicatorBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ActivityIndicator_touchstart_Event extends ActivityIndicatorBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ActivityIndicator_twofingertap_Event extends ActivityIndicatorBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ActivityIndicatorEventMap extends ProxyEventMap {
            click: ActivityIndicator_click_Event;

            dblclick: ActivityIndicator_dblclick_Event;

            doubletap: ActivityIndicator_doubletap_Event;

            focus: ActivityIndicator_focus_Event;

            keypressed: ActivityIndicator_keypressed_Event;

            longclick: ActivityIndicator_longclick_Event;

            longpress: ActivityIndicator_longpress_Event;

            pinch: ActivityIndicator_pinch_Event;

            postlayout: ActivityIndicator_postlayout_Event;

            singletap: ActivityIndicator_singletap_Event;

            swipe: ActivityIndicator_swipe_Event;

            touchcancel: ActivityIndicator_touchcancel_Event;

            touchend: ActivityIndicator_touchend_Event;

            touchmove: ActivityIndicator_touchmove_Event;

            touchstart: ActivityIndicator_touchstart_Event;

            twofingertap: ActivityIndicator_twofingertap_Event;

        }
        /**
         * An activity indicator that lets the user know an action is taking place.
         */
        class ActivityIndicator extends Titanium.UI.View {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * Bottom position of the view.
             */
            bottom: number | string;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * View's clipping behavior.
             */
            clipMode: never;

            /**
             * Color of the message text, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * Font used for the message text.
             */
            font: Font;

            /**
             * Width of the view. Only accepts value of <Titanium.UI.SIZE>, which must be explicitly set in order to
             * display the message and to position the view correctly.
             */
            height: string;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Color of the animated indicator.
             */
            indicatorColor: string | Titanium.UI.Color;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * Left position of the view.
             */
            left: number | string;

            /**
             * Message text.
             */
            message: string;

            /**
             * Key identifying a string in the locale file to use for the message text.
             */
            messageid: string;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: never;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * Right position of the view.
             */
            right: number | string;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * The style for the activity indicator.
             */
            style: number;

            /**
             * The view's tintColor
             */
            tintColor: never;

            /**
             * Top position of the view.
             */
            top: number | string;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: never;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: never;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * Width of the view. Only accepts value of <Titanium.UI.SIZE>, which must be explicitly set in order to
             * display the message and to position the view correctly.
             */
            width: string;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ActivityIndicatorEventMap>(name: K, callback: (this: Titanium.UI.ActivityIndicator, event: ActivityIndicatorEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ActivityIndicatorEventMap>(name: K, event?: ActivityIndicatorEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.anchorPoint> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.animatedCenter> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundImage> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.borderColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.borderRadius> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.borderWidth> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.bottom> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.bottom> instead.
             */
            getBottom(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.center> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.children> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.clipMode> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.clipMode> instead.
             */
            getClipMode: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.color> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.focusable> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.font> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.height> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.height> instead.
             */
            getHeight(): string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.indicatorColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.indicatorColor> instead.
             */
            getIndicatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.layout> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.left> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.left> instead.
             */
            getLeft(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.message> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.message> instead.
             */
            getMessage(): string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.messageid> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.messageid> instead.
             */
            getMessageid(): string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.opacity> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.pullBackgroundColor> instead.
             */
            getPullBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.rect> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.right> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.right> instead.
             */
            getRight(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.size> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.style> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.tintColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.tintColor> instead.
             */
            getTintColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.top> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.top> instead.
             */
            getTop(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.touchEnabled> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.touchEnabled> instead.
             */
            getTouchEnabled: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.transform> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.viewShadowColor> instead.
             */
            getViewShadowColor: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.viewShadowOffset> instead.
             */
            getViewShadowOffset: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.viewShadowRadius> instead.
             */
            getViewShadowRadius: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.visible> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.width> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.width> instead.
             */
            getWidth(): string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicator.zIndex> property.
             * @deprecated Access <Titanium.UI.ActivityIndicator.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Hides the activity indicator and stops the animation.
             */
            hide(options?: AnimatedOptions): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ActivityIndicatorEventMap>(name: K, callback: (this: Titanium.UI.ActivityIndicator, event: ActivityIndicatorEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.bottom> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.bottom> instead.
             */
            setBottom(bottom: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.center> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.clipMode> instead.
             */
            setClipMode: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.color> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.focusable> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.font> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.height> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.height> instead.
             */
            setHeight(height: string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.indicatorColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.indicatorColor> instead.
             */
            setIndicatorColor(indicatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.layout> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.left> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.left> instead.
             */
            setLeft(left: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.message> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.message> instead.
             */
            setMessage(message: string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.messageid> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.messageid> instead.
             */
            setMessageid(messageid: string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.opacity> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.pullBackgroundColor> instead.
             */
            setPullBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.right> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.right> instead.
             */
            setRight(right: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.style> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.tintColor> instead.
             */
            setTintColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.top> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.top> instead.
             */
            setTop(top: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.touchEnabled> instead.
             */
            setTouchEnabled: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.transform> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.viewShadowColor> instead.
             */
            setViewShadowColor: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.viewShadowOffset> instead.
             */
            setViewShadowOffset: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.viewShadowRadius> instead.
             */
            setViewShadowRadius: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.visible> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.width> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.width> instead.
             */
            setWidth(width: string): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicator.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicator.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Shows the activity indicator and starts the animation.
             */
            show(options?: AnimatedOptions): void;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage: never;

        }
        /**
         * A set of constants for the styles available for <Titanium.UI.ActivityIndicator> objects.
         */
        class ActivityIndicatorStyle extends Titanium.Module {
            /**
             * Large white spinning indicator.
             */
            static readonly BIG: number;

            /**
             * Large gray spinning indicator.
             */
            static readonly BIG_DARK: number;

            /**
             * Small gray spinning indicator.
             */
            static readonly DARK: number;

            /**
             * Small white spinning indicator (default).
             */
            static readonly PLAIN: number;

            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicatorStyle.apiName> property.
             * @deprecated Access <Titanium.UI.ActivityIndicatorStyle.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicatorStyle.bubbleParent> property.
             * @deprecated Access <Titanium.UI.ActivityIndicatorStyle.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ActivityIndicatorStyle.lifecycleContainer> property.
             * @deprecated Access <Titanium.UI.ActivityIndicatorStyle.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicatorStyle.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicatorStyle.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ActivityIndicatorStyle.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.UI.ActivityIndicatorStyle.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * Base event for class Titanium.UI.AlertDialog
         */
        interface AlertDialogBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.AlertDialog;

        }
        /**
         * Fired when a button in the dialog is clicked.
         */
        interface AlertDialog_click_Event extends AlertDialogBaseEvent {
            /**
             * Boolean type on Android; Number on iOS.
             * On Android, indicates whether the cancel button was clicked, in which
             * case returns `true`.
             * On iOS, the value of the [cancel](Titanium.UI.AlertDialog.cancel) property is
             * returned, if defined, or `-1` otherwise. Also note that the cancel button may not be
             * used on the iPad, because iOS will internally decide whether or not to show it in
             * the current context (e.g. in a popover).
             * See the `Three-button Alert Dialog` example for a cross-platform workaround for this
             * parity issue.
             */
            cancel: boolean | number;

            /**
             * Index of the button that was clicked.
             */
            index: number;

            /**
             * Value of login field if dialog `style` property is defined as
             * <Titanium.UI.iOS.AlertDialogStyle.LOGIN_AND_PASSWORD_INPUT>.
             */
            login: string;

            /**
             * Value of password field if dialog `style` property is defined as
             * <Titanium.UI.iOS.AlertDialogStyle.LOGIN_AND_PASSWORD_INPUT>.
             */
            password: string;

            /**
             * Value of text field if dialog `style` property is defined as
             * <Titanium.UI.iOS.AlertDialogStyle.PLAIN_TEXT_INPUT> or
             * <Titanium.UI.iOS.AlertDialogStyle.SECURE_TEXT_INPUT>.
             */
            text: string;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface AlertDialog_dblclick_Event extends AlertDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface AlertDialog_doubletap_Event extends AlertDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface AlertDialog_focus_Event extends AlertDialogBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface AlertDialog_keypressed_Event extends AlertDialogBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface AlertDialog_longclick_Event extends AlertDialogBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface AlertDialog_longpress_Event extends AlertDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface AlertDialog_pinch_Event extends AlertDialogBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface AlertDialog_postlayout_Event extends AlertDialogBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface AlertDialog_singletap_Event extends AlertDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface AlertDialog_swipe_Event extends AlertDialogBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface AlertDialog_touchcancel_Event extends AlertDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface AlertDialog_touchend_Event extends AlertDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface AlertDialog_touchmove_Event extends AlertDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface AlertDialog_touchstart_Event extends AlertDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface AlertDialog_twofingertap_Event extends AlertDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface AlertDialogEventMap extends ProxyEventMap {
            click: AlertDialog_click_Event;

            dblclick: AlertDialog_dblclick_Event;

            doubletap: AlertDialog_doubletap_Event;

            focus: AlertDialog_focus_Event;

            keypressed: AlertDialog_keypressed_Event;

            longclick: AlertDialog_longclick_Event;

            longpress: AlertDialog_longpress_Event;

            pinch: AlertDialog_pinch_Event;

            postlayout: AlertDialog_postlayout_Event;

            singletap: AlertDialog_singletap_Event;

            swipe: AlertDialog_swipe_Event;

            touchcancel: AlertDialog_touchcancel_Event;

            touchend: AlertDialog_touchend_Event;

            touchmove: AlertDialog_touchmove_Event;

            touchstart: AlertDialog_touchstart_Event;

            twofingertap: AlertDialog_twofingertap_Event;

        }
        /**
         * An alert dialog is a modal view that includes an optional title, a message and buttons,
         * positioned in the middle of the display.
         */
        class AlertDialog extends Titanium.UI.View {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * View to load inside the message area, to create a custom layout.
             */
            androidView: Titanium.UI.View;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * Setting this to true requires the end-user to click a dialog button to close the dialog.
             */
            buttonClickRequired: boolean;

            /**
             * Name of each button to create.
             */
            buttonNames: string[];

            /**
             * Index to define the cancel button.
             */
            cancel: number;

            /**
             * When this is set to `true`, the dialog is canceled when touched outside the window's bounds.
             */
            canceledOnTouchOutside: boolean;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * View's clipping behavior.
             */
            clipMode: never;

            /**
             * Index to define the destructive button.
             */
            destructive: number;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Hint text of the text field inside the dialog.
             */
            hintText: string;

            /**
             * Key identifying a string from the locale file to use for the
             * [hintText](Titanium.UI.AlertDialog.hintText) property.
             */
            hinttextid: string;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Keyboard appearance to be displayed when the text field inside the dialog is focused.
             */
            keyboardAppearance: number;

            /**
             * Keyboard type to display when this text field inside the dialog is focused.
             */
            keyboardType: number;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * View's left position, in platform-specific units.
             */
            left: never;

            /**
             * Hint text of the login text field inside the dialog.
             */
            loginHintText: string;

            /**
             * Keyboard type to display when this text field inside the dialog is focused.
             */
            loginKeyboardType: number;

            /**
             * Placeholder of the login text field inside the dialog.
             * @deprecated Use [Titanium.UI.AlertDialog.loginHintText](Titanium.UI.AlertDialog.loginHintText) instead.
             */
            loginPlaceholder: string;

            /**
             * Specifies the text to display on the keyboard `Return` key when this field is focused.
             */
            loginReturnKeyType: number;

            /**
             * Value of the login text field inside the dialog.
             */
            loginValue: string;

            /**
             * Key identifying a string from the locale file to use for the
             * [loginHintText](Titanium.UI.AlertDialog.loginHintText) property.
             */
            loginhinttextid: string;

            /**
             * Dialog message.
             */
            message: string;

            /**
             * Key identifying a string in the locale file to use for the message text.
             */
            messageid: string;

            /**
             * Text for the `OK` button.
             */
            ok: string;

            /**
             * Key identifying a string in the locale file to use for the `ok` text.
             */
            okid: string;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: never;

            /**
             * Hint text of the password text field inside the dialog.
             */
            passwordHintText: string;

            /**
             * Keyboard type to display when this text field inside the dialog is focused.
             */
            passwordKeyboardType: number;

            /**
             * Placeholder of the password text field inside the dialog.
             * @deprecated Use [Titanium.UI.AlertDialog.passwordHintText](Titanium.UI.AlertDialog.passwordHintText) instead.
             */
            passwordPlaceholder: string;

            /**
             * Specifies the text to display on the keyboard `Return` key when this field is focused.
             */
            passwordReturnKeyType: number;

            /**
             * Value of the password text field inside the dialog.
             */
            passwordValue: string;

            /**
             * Key identifying a string from the locale file to use for the
             * [passwordHintText](Titanium.UI.AlertDialog.passwordHintText) property.
             */
            passwordhinttextid: string;

            /**
             * Boolean value indicating if the alert dialog should only be cancelled by user gesture or by hide method.
             */
            persistent: boolean;

            /**
             * Placeholder of the text field inside the dialog.
             * @deprecated Use [Titanium.UI.AlertDialog.hintText](Titanium.UI.AlertDialog.hintText) instead.
             */
            placeholder: string;

            /**
             * Index to define the preferred button.
             */
            preferred: number;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * Specifies the text to display on the keyboard `Return` key when this field is focused.
             */
            returnKeyType: number;

            /**
             * View's right position, in platform-specific units.
             */
            right: never;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * The style for the alert dialog.
             */
            style: number;

            /**
             * The tint-color of the dialog.
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * Title of the dialog.
             */
            title: string;

            /**
             * Key identifying a string in the locale file to use for the title text.
             */
            titleid: string;

            /**
             * The view's top position.
             */
            top: never;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Value of the text field inside the dialog.
             */
            value: string;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: never;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: never;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof AlertDialogEventMap>(name: K, callback: (this: Titanium.UI.AlertDialog, event: AlertDialogEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof AlertDialogEventMap>(name: K, event?: AlertDialogEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.AlertDialog.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.AlertDialog.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.AlertDialog.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.AlertDialog.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.anchorPoint> property.
             * @deprecated Access <Titanium.UI.AlertDialog.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.animatedCenter> property.
             * @deprecated Access <Titanium.UI.AlertDialog.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundImage> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.AlertDialog.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.borderColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.borderRadius> property.
             * @deprecated Access <Titanium.UI.AlertDialog.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.borderWidth> property.
             * @deprecated Access <Titanium.UI.AlertDialog.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.bottom> property.
             * @deprecated Access <Titanium.UI.AlertDialog.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.buttonClickRequired> property.
             * @deprecated Access <Titanium.UI.AlertDialog.buttonClickRequired> instead.
             */
            getButtonClickRequired(): boolean;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.buttonNames> property.
             * @deprecated Access <Titanium.UI.AlertDialog.buttonNames> instead.
             */
            getButtonNames(): string[];

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.cancel> property.
             * @deprecated Access <Titanium.UI.AlertDialog.cancel> instead.
             */
            getCancel(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.canceledOnTouchOutside> property.
             * @deprecated Access <Titanium.UI.AlertDialog.canceledOnTouchOutside> instead.
             */
            getCanceledOnTouchOutside(): boolean;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.center> property.
             * @deprecated Access <Titanium.UI.AlertDialog.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.children> property.
             * @deprecated Access <Titanium.UI.AlertDialog.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.clipMode> property.
             * @deprecated Access <Titanium.UI.AlertDialog.clipMode> instead.
             */
            getClipMode: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.destructive> property.
             * @deprecated Access <Titanium.UI.AlertDialog.destructive> instead.
             */
            getDestructive(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.focusable> property.
             * @deprecated Access <Titanium.UI.AlertDialog.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.height> property.
             * @deprecated Access <Titanium.UI.AlertDialog.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.hintText> property.
             * @deprecated Access <Titanium.UI.AlertDialog.hintText> instead.
             */
            getHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.hinttextid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.hinttextid> instead.
             */
            getHinttextid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.AlertDialog.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.AlertDialog.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.keyboardAppearance> property.
             * @deprecated Access <Titanium.UI.AlertDialog.keyboardAppearance> instead.
             */
            getKeyboardAppearance(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.keyboardType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.keyboardType> instead.
             */
            getKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.layout> property.
             * @deprecated Access <Titanium.UI.AlertDialog.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.left> property.
             * @deprecated Access <Titanium.UI.AlertDialog.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginHintText> property.
             * @deprecated Access <Titanium.UI.AlertDialog.loginHintText> instead.
             */
            getLoginHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginKeyboardType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.loginKeyboardType> instead.
             */
            getLoginKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginPlaceholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.loginHintText](Titanium.UI.AlertDialog.loginHintText) instead.
             */
            getLoginPlaceholder(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginReturnKeyType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.loginReturnKeyType> instead.
             */
            getLoginReturnKeyType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginValue> property.
             * @deprecated Access <Titanium.UI.AlertDialog.loginValue> instead.
             */
            getLoginValue(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.loginhinttextid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.loginhinttextid> instead.
             */
            getLoginhinttextid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.message> property.
             * @deprecated Access <Titanium.UI.AlertDialog.message> instead.
             */
            getMessage(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.messageid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.messageid> instead.
             */
            getMessageid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.ok> property.
             * @deprecated Access <Titanium.UI.AlertDialog.ok> instead.
             */
            getOk(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.okid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.okid> instead.
             */
            getOkid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.opacity> property.
             * @deprecated Access <Titanium.UI.AlertDialog.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.AlertDialog.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordHintText> property.
             * @deprecated Access <Titanium.UI.AlertDialog.passwordHintText> instead.
             */
            getPasswordHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordKeyboardType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.passwordKeyboardType> instead.
             */
            getPasswordKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordPlaceholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.passwordHintText](Titanium.UI.AlertDialog.passwordHintText) instead.
             */
            getPasswordPlaceholder(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordReturnKeyType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.passwordReturnKeyType> instead.
             */
            getPasswordReturnKeyType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordValue> property.
             * @deprecated Access <Titanium.UI.AlertDialog.passwordValue> instead.
             */
            getPasswordValue(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.passwordhinttextid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.passwordhinttextid> instead.
             */
            getPasswordhinttextid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.persistent> property.
             * @deprecated Access <Titanium.UI.AlertDialog.persistent> instead.
             */
            getPersistent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.placeholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.hintText](Titanium.UI.AlertDialog.hintText) instead.
             */
            getPlaceholder(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.preferred> property.
             * @deprecated Access <Titanium.UI.AlertDialog.preferred> instead.
             */
            getPreferred(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.pullBackgroundColor> instead.
             */
            getPullBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.rect> property.
             * @deprecated Access <Titanium.UI.AlertDialog.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.returnKeyType> property.
             * @deprecated Access <Titanium.UI.AlertDialog.returnKeyType> instead.
             */
            getReturnKeyType(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.right> property.
             * @deprecated Access <Titanium.UI.AlertDialog.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.size> property.
             * @deprecated Access <Titanium.UI.AlertDialog.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.AlertDialog.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.style> property.
             * @deprecated Access <Titanium.UI.AlertDialog.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.tintColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.title> property.
             * @deprecated Access <Titanium.UI.AlertDialog.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.titleid> property.
             * @deprecated Access <Titanium.UI.AlertDialog.titleid> instead.
             */
            getTitleid(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.top> property.
             * @deprecated Access <Titanium.UI.AlertDialog.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.touchEnabled> property.
             * @deprecated Access <Titanium.UI.AlertDialog.touchEnabled> instead.
             */
            getTouchEnabled: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.transform> property.
             * @deprecated Access <Titanium.UI.AlertDialog.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.value> property.
             * @deprecated Access <Titanium.UI.AlertDialog.value> instead.
             */
            getValue(): string;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.AlertDialog.viewShadowColor> instead.
             */
            getViewShadowColor: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.AlertDialog.viewShadowOffset> instead.
             */
            getViewShadowOffset: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.AlertDialog.viewShadowRadius> instead.
             */
            getViewShadowRadius: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.visible> property.
             * @deprecated Access <Titanium.UI.AlertDialog.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.width> property.
             * @deprecated Access <Titanium.UI.AlertDialog.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.AlertDialog.zIndex> property.
             * @deprecated Access <Titanium.UI.AlertDialog.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Hides this dialog.
             */
            hide(options?: AnimatedOptions): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof AlertDialogEventMap>(name: K, callback: (this: Titanium.UI.AlertDialog, event: AlertDialogEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.bottom> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.buttonClickRequired> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.buttonClickRequired> instead.
             */
            setButtonClickRequired(buttonClickRequired: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.buttonNames> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.buttonNames> instead.
             */
            setButtonNames(buttonNames: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.cancel> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.cancel> instead.
             */
            setCancel(cancel: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.canceledOnTouchOutside> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.canceledOnTouchOutside> instead.
             */
            setCanceledOnTouchOutside(canceledOnTouchOutside: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.center> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.clipMode> instead.
             */
            setClipMode: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.destructive> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.destructive> instead.
             */
            setDestructive(destructive: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.focusable> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.height> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.hintText> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.hintText> instead.
             */
            setHintText(hintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.hinttextid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.hinttextid> instead.
             */
            setHinttextid(hinttextid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.keyboardAppearance> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.keyboardAppearance> instead.
             */
            setKeyboardAppearance(keyboardAppearance: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.keyboardType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.keyboardType> instead.
             */
            setKeyboardType(keyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.layout> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.left> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginHintText> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.loginHintText> instead.
             */
            setLoginHintText(loginHintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginKeyboardType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.loginKeyboardType> instead.
             */
            setLoginKeyboardType(loginKeyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginPlaceholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.loginHintText](Titanium.UI.AlertDialog.loginHintText) instead.
             */
            setLoginPlaceholder(loginPlaceholder: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginReturnKeyType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.loginReturnKeyType> instead.
             */
            setLoginReturnKeyType(loginReturnKeyType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginValue> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.loginValue> instead.
             */
            setLoginValue(loginValue: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.loginhinttextid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.loginhinttextid> instead.
             */
            setLoginhinttextid(loginhinttextid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.message> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.message> instead.
             */
            setMessage(message: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.messageid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.messageid> instead.
             */
            setMessageid(messageid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.ok> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.ok> instead.
             */
            setOk(ok: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.okid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.okid> instead.
             */
            setOkid(okid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.opacity> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordHintText> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.passwordHintText> instead.
             */
            setPasswordHintText(passwordHintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordKeyboardType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.passwordKeyboardType> instead.
             */
            setPasswordKeyboardType(passwordKeyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordPlaceholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.passwordHintText](Titanium.UI.AlertDialog.passwordHintText) instead.
             */
            setPasswordPlaceholder(passwordPlaceholder: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordReturnKeyType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.passwordReturnKeyType> instead.
             */
            setPasswordReturnKeyType(passwordReturnKeyType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordValue> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.passwordValue> instead.
             */
            setPasswordValue(passwordValue: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.passwordhinttextid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.passwordhinttextid> instead.
             */
            setPasswordhinttextid(passwordhinttextid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.persistent> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.persistent> instead.
             */
            setPersistent(persistent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.placeholder> property.
             * @deprecated Use [Titanium.UI.AlertDialog.hintText](Titanium.UI.AlertDialog.hintText) instead.
             */
            setPlaceholder(placeholder: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.preferred> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.preferred> instead.
             */
            setPreferred(preferred: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.pullBackgroundColor> instead.
             */
            setPullBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.returnKeyType> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.returnKeyType> instead.
             */
            setReturnKeyType(returnKeyType: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.right> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.style> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.title> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.titleid> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.titleid> instead.
             */
            setTitleid(titleid: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.top> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.touchEnabled> instead.
             */
            setTouchEnabled: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.transform> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.value> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.value> instead.
             */
            setValue(value: string): void;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.viewShadowColor> instead.
             */
            setViewShadowColor: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.viewShadowOffset> instead.
             */
            setViewShadowOffset: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.viewShadowRadius> instead.
             */
            setViewShadowRadius: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.visible> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.width> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.width> instead.
             */
            setWidth: never;

            /**
             * Sets the value of the <Titanium.UI.AlertDialog.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.AlertDialog.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Shows this dialog.
             */
            show(options?: AnimatedOptions): void;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage: never;

        }
        /**
         * The Android-specific UI capabilities. All properties, methods and events in this namespace will
         * only work on Android systems.
         */
        class Android extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
             */
            static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Creates and returns an instance of <Titanium.UI.Android.CardView>.
             */
            static createCardView(parameters?: Dictionary<Titanium.UI.Android.CardView>): Titanium.UI.Android.CardView;

            /**
             * Creates and returns an instance of <Titanium.UI.Android.DrawerLayout>.
             */
            static createDrawerLayout(parameters?: Dictionary<Titanium.UI.Android.DrawerLayout>): Titanium.UI.Android.DrawerLayout;

            /**
             * Creates and returns an instance of <Titanium.UI.Android.ProgressIndicator>.
             */
            static createProgressIndicator(parameters?: Dictionary<Titanium.UI.Android.ProgressIndicator>): Titanium.UI.Android.ProgressIndicator;

            /**
             * Creates and returns an instance of <Titanium.UI.Android.SearchView>.
             */
            static createSearchView(parameters?: Dictionary<Titanium.UI.Android.SearchView>): Titanium.UI.Android.SearchView;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Android.apiName> property.
             * @deprecated Access <Titanium.UI.Android.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.UI.Android.bubbleParent> property.
             * @deprecated Access <Titanium.UI.Android.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Returns a <Ti.Color> instance for a color defined by the system or user resources (colors.xml)
             */
            static getColorResource(resourceIdOrColorName: number | string): Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Android.lifecycleContainer> property.
             * @deprecated Access <Titanium.UI.Android.lifecycleContainer> instead.
             */
            static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

            /**
             * Hides the soft keyboard.
             */
            static hideSoftKeyboard(): void;

            /**
             * Opens an application preferences dialog, using the native Android system settings interface,
             * defined by the platform-specific `preferences.xml` and `array.xml` files.
             */
            static openPreferences(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.Android.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.Android.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Android.lifecycleContainer> property.
             * @deprecated Set the value using <Titanium.UI.Android.lifecycleContainer> instead.
             */
            static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        }
        /**
         * Base event for class Titanium.UI.Animation
         */
        interface AnimationBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Animation;

        }
        /**
         * Fired when the animation completes.
         */
        interface Animation_complete_Event extends AnimationBaseEvent {
        }
        /**
         * Fired when the animation starts.
         */
        interface Animation_start_Event extends AnimationBaseEvent {
        }
        interface AnimationEventMap extends ProxyEventMap {
            complete: Animation_complete_Event;

            start: Animation_start_Event;

        }
        /**
         * The `Animation` object defines an animation that can be applied to a view.
         */
        class Animation extends Titanium.Proxy {
            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: Point;

            /**
             * Specifies if the animation should be replayed in reverse upon completion.
             */
            autoreverse: boolean;

            /**
             * Value of the `backgroundColor` property at the end of the animation, as a color name
             * or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Value of the `bottom` property at the end of the animation.
             */
            bottom: number;

            /**
             * Value of the `center` property at the end of the animation.
             */
            center: Point;

            /**
             * Value of the `color` property at the end of the animation, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Animation curve or easing function to apply to the animation.
             */
            curve: number;

            /**
             * The damping ratio for the spring animation as it approaches its quiescent state.
             */
            dampingRatio: number;

            /**
             * Delay, in milliseconds before starting the animation.
             */
            delay: number;

            /**
             * Duration of the animation, in milliseconds.
             */
            duration: number;

            /**
             * Value of the `elevation` property at the end of the animation.
             */
            elevation: number;

            /**
             * Value of the `height` property at the end of the animation.
             */
            height: number;

            /**
             * Value of the `left` property at the end of the animation.
             */
            left: number;

            /**
             * Value of the `opacity` property at the end of the animation.
             */
            opacity: number;

            /**
             * Value of the `opaque` property at the end of the animation.
             */
            opaque: boolean;

            /**
             * Number of times the animation should be performed.
             */
            repeat: number;

            /**
             * Value of the `right` property at the end of the animation.
             */
            right: number;

            /**
             * The initial spring velocity.
             */
            springVelocity: number;

            /**
             * Value of the `top` property at the end of the animation.
             */
            top: number;

            /**
             * Animate the view from its current tranform to the specified transform.
             */
            transform: Titanium.UI.Matrix2D | Titanium.UI.Matrix3D;

            /**
             * Transition type to use during a transition animation.
             */
            transition: number;

            /**
             * New view to transition to.
             */
            view: Titanium.UI.View;

            /**
             * Value of the `visible` property at the end of the animation.
             */
            visible: boolean;

            /**
             * Value of the `width` property at the end of the animation.
             */
            width: number;

            /**
             * Value of the `zIndex` property at the end of the animation.
             */
            zIndex: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof AnimationEventMap>(name: K, callback: (this: Titanium.UI.Animation, event: AnimationEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof AnimationEventMap>(name: K, event?: AnimationEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Animation.anchorPoint> property.
             * @deprecated Access <Titanium.UI.Animation.anchorPoint> instead.
             */
            getAnchorPoint(): Point;

            /**
             * Gets the value of the <Titanium.UI.Animation.autoreverse> property.
             * @deprecated Access <Titanium.UI.Animation.autoreverse> instead.
             */
            getAutoreverse(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Animation.backgroundColor> property.
             * @deprecated Access <Titanium.UI.Animation.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Animation.bottom> property.
             * @deprecated Access <Titanium.UI.Animation.bottom> instead.
             */
            getBottom(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.center> property.
             * @deprecated Access <Titanium.UI.Animation.center> instead.
             */
            getCenter(): Point;

            /**
             * Gets the value of the <Titanium.UI.Animation.color> property.
             * @deprecated Access <Titanium.UI.Animation.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Animation.curve> property.
             * @deprecated Access <Titanium.UI.Animation.curve> instead.
             */
            getCurve(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.dampingRatio> property.
             * @deprecated Access <Titanium.UI.Animation.dampingRatio> instead.
             */
            getDampingRatio(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.delay> property.
             * @deprecated Access <Titanium.UI.Animation.delay> instead.
             */
            getDelay(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.duration> property.
             * @deprecated Access <Titanium.UI.Animation.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.elevation> property.
             * @deprecated Access <Titanium.UI.Animation.elevation> instead.
             */
            getElevation(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.height> property.
             * @deprecated Access <Titanium.UI.Animation.height> instead.
             */
            getHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.left> property.
             * @deprecated Access <Titanium.UI.Animation.left> instead.
             */
            getLeft(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.opacity> property.
             * @deprecated Access <Titanium.UI.Animation.opacity> instead.
             */
            getOpacity(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.opaque> property.
             * @deprecated Access <Titanium.UI.Animation.opaque> instead.
             */
            getOpaque(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Animation.repeat> property.
             * @deprecated Access <Titanium.UI.Animation.repeat> instead.
             */
            getRepeat(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.right> property.
             * @deprecated Access <Titanium.UI.Animation.right> instead.
             */
            getRight(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.springVelocity> property.
             * @deprecated Access <Titanium.UI.Animation.springVelocity> instead.
             */
            getSpringVelocity(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.top> property.
             * @deprecated Access <Titanium.UI.Animation.top> instead.
             */
            getTop(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.transform> property.
             * @deprecated Access <Titanium.UI.Animation.transform> instead.
             */
            getTransform(): Titanium.UI.Matrix2D | Titanium.UI.Matrix3D;

            /**
             * Gets the value of the <Titanium.UI.Animation.transition> property.
             * @deprecated Access <Titanium.UI.Animation.transition> instead.
             */
            getTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.view> property.
             * @deprecated Access <Titanium.UI.Animation.view> instead.
             */
            getView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.Animation.visible> property.
             * @deprecated Access <Titanium.UI.Animation.visible> instead.
             */
            getVisible(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Animation.width> property.
             * @deprecated Access <Titanium.UI.Animation.width> instead.
             */
            getWidth(): number;

            /**
             * Gets the value of the <Titanium.UI.Animation.zIndex> property.
             * @deprecated Access <Titanium.UI.Animation.zIndex> instead.
             */
            getZIndex(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof AnimationEventMap>(name: K, callback: (this: Titanium.UI.Animation, event: AnimationEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.Animation.anchorPoint> instead.
             */
            setAnchorPoint(anchorPoint: Point): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.autoreverse> property.
             * @deprecated Set the value using <Titanium.UI.Animation.autoreverse> instead.
             */
            setAutoreverse(autoreverse: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.Animation.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.bottom> property.
             * @deprecated Set the value using <Titanium.UI.Animation.bottom> instead.
             */
            setBottom(bottom: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.center> property.
             * @deprecated Set the value using <Titanium.UI.Animation.center> instead.
             */
            setCenter(center: Point): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.color> property.
             * @deprecated Set the value using <Titanium.UI.Animation.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.curve> property.
             * @deprecated Set the value using <Titanium.UI.Animation.curve> instead.
             */
            setCurve(curve: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.dampingRatio> property.
             * @deprecated Set the value using <Titanium.UI.Animation.dampingRatio> instead.
             */
            setDampingRatio(dampingRatio: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.delay> property.
             * @deprecated Set the value using <Titanium.UI.Animation.delay> instead.
             */
            setDelay(delay: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.duration> property.
             * @deprecated Set the value using <Titanium.UI.Animation.duration> instead.
             */
            setDuration(duration: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.elevation> property.
             * @deprecated Set the value using <Titanium.UI.Animation.elevation> instead.
             */
            setElevation(elevation: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.height> property.
             * @deprecated Set the value using <Titanium.UI.Animation.height> instead.
             */
            setHeight(height: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.left> property.
             * @deprecated Set the value using <Titanium.UI.Animation.left> instead.
             */
            setLeft(left: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.opacity> property.
             * @deprecated Set the value using <Titanium.UI.Animation.opacity> instead.
             */
            setOpacity(opacity: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.opaque> property.
             * @deprecated Set the value using <Titanium.UI.Animation.opaque> instead.
             */
            setOpaque(opaque: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.repeat> property.
             * @deprecated Set the value using <Titanium.UI.Animation.repeat> instead.
             */
            setRepeat(repeat: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.right> property.
             * @deprecated Set the value using <Titanium.UI.Animation.right> instead.
             */
            setRight(right: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.springVelocity> property.
             * @deprecated Set the value using <Titanium.UI.Animation.springVelocity> instead.
             */
            setSpringVelocity(springVelocity: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.top> property.
             * @deprecated Set the value using <Titanium.UI.Animation.top> instead.
             */
            setTop(top: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.transform> property.
             * @deprecated Set the value using <Titanium.UI.Animation.transform> instead.
             */
            setTransform(transform: Titanium.UI.Matrix2D | Titanium.UI.Matrix3D): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.transition> property.
             * @deprecated Set the value using <Titanium.UI.Animation.transition> instead.
             */
            setTransition(transition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.view> property.
             * @deprecated Set the value using <Titanium.UI.Animation.view> instead.
             */
            setView(view: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.visible> property.
             * @deprecated Set the value using <Titanium.UI.Animation.visible> instead.
             */
            setVisible(visible: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.width> property.
             * @deprecated Set the value using <Titanium.UI.Animation.width> instead.
             */
            setWidth(width: number): void;

            /**
             * Sets the value of the <Titanium.UI.Animation.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.Animation.zIndex> instead.
             */
            setZIndex(zIndex: number): void;

        }
        /**
         * An attributed string proxy manages character strings and associated sets of attributes (for example,
         * font and foregroundcolor) that apply to individual characters or ranges of characters in the string.
         */
        class AttributedString extends Titanium.Proxy {
            /**
             * An array of attributes to add.
             */
            attributes: Attribute[];

            /**
             * The text applied to the attributed string.
             */
            text: string;

            /**
             * Adds an [attribute](Attribute) with the given name and value to the characters in the specified range.
             */
            addAttribute(attribute: Attribute): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.AttributedString.attributes> property.
             * @deprecated Access <Titanium.UI.AttributedString.attributes> instead.
             */
            getAttributes(): Attribute[];

            /**
             * Gets the value of the <Titanium.UI.AttributedString.text> property.
             * @deprecated Access <Titanium.UI.AttributedString.text> instead.
             */
            getText(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.AttributedString.attributes> property.
             * @deprecated Set the value using <Titanium.UI.AttributedString.attributes> instead.
             */
            setAttributes(attributes: ReadonlyArray<Attribute>): void;

            /**
             * Sets the value of the <Titanium.UI.AttributedString.text> property.
             * @deprecated Set the value using <Titanium.UI.AttributedString.text> instead.
             */
            setText(text: string): void;

        }
        /**
         * Base event for class Titanium.UI.Button
         */
        interface ButtonBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Button;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Button_click_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Button_dblclick_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Button_doubletap_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Button_focus_Event extends ButtonBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Button_keypressed_Event extends ButtonBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Button_longclick_Event extends ButtonBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Button_longpress_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Button_pinch_Event extends ButtonBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Button_postlayout_Event extends ButtonBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Button_singletap_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Button_swipe_Event extends ButtonBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Button_touchcancel_Event extends ButtonBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Button_touchend_Event extends ButtonBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Button_touchmove_Event extends ButtonBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Button_touchstart_Event extends ButtonBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Button_twofingertap_Event extends ButtonBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ButtonEventMap extends ProxyEventMap {
            click: Button_click_Event;

            dblclick: Button_dblclick_Event;

            doubletap: Button_doubletap_Event;

            focus: Button_focus_Event;

            keypressed: Button_keypressed_Event;

            longclick: Button_longclick_Event;

            longpress: Button_longpress_Event;

            pinch: Button_pinch_Event;

            postlayout: Button_postlayout_Event;

            singletap: Button_singletap_Event;

            swipe: Button_swipe_Event;

            touchcancel: Button_touchcancel_Event;

            touchend: Button_touchend_Event;

            touchmove: Button_touchmove_Event;

            touchstart: Button_touchstart_Event;

            twofingertap: Button_twofingertap_Event;

        }
        /**
         * A button widget that has four states: normal, disabled, focused and selected.
         */
        class Button extends Titanium.UI.View {
            /**
             * Specify an attributed string for the label.
             */
            attributedString: Titanium.UI.AttributedString;

            /**
             * Background image for the button in its disabled state, specified as a local file path
             * or URL.
             */
            backgroundDisabledImage: string;

            /**
             * Background image for the button in its focused state, specified as a local file path
             * or URL.
             */
            backgroundFocusedImage: string;

            /**
             * Background image for the button in its normal state, specified as a local file path or URL.
             */
            backgroundImage: string;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: string | Titanium.UI.Color;

            /**
             * Background image for the button in its selected state, specified as a local file
             * path or URL.
             */
            backgroundSelectedImage: string;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Default button text color, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Text color of the button in its disabled state, as a color name or hex triplet.
             */
            disabledColor: string | Titanium.UI.Color;

            /**
             * Set to `true` to enable the button, `false` to disable the button.
             */
            enabled: boolean;

            /**
             * Font to use for the button text.
             */
            font: Font;

            /**
             * Image to display on the button, specified as a local path, URL or a `Blob`.
             */
            image: string | Titanium.Blob;

            /**
             * Button text color used to indicate the selected state, as a color name or hex triplet.
             */
            selectedColor: string | Titanium.UI.Color;

            /**
             * Shadow color of the [title](Titanium.UI.Button.title), as a color name or hex triplet.
             */
            shadowColor: string | Titanium.UI.Color;

            /**
             * Shadow offset of the [title](Titanium.UI.Button.title), as a dictionary with the properties `x` and `y`.
             */
            shadowOffset: Point;

            /**
             * Shadow radius of the [title](Titanium.UI.Button.title).
             */
            shadowRadius: number;

            /**
             * Style constant for the button, as defined in <Titanium.UI.iOS.SystemButtonStyle>.
             */
            style: number;

            /**
             * Specifies an iOS system button appearance, as defined in <Titanium.UI.iOS.SystemButton>.
             */
            systemButton: number;

            /**
             * Text alignment, specified using one of the <Titanium.UI> text alignment constants.
             */
            textAlign: string | number;

            /**
             * Button tint color.
             */
            tintColor: string;

            /**
             * Button title.
             */
            title: string;

            /**
             * Key identifying a string from the locale file to use for the button title.
             */
            titleid: string;

            /**
             * Vertical alignment for the text field, specified using one of the
             * vertical alignment constants from <Titanium.UI>.
             */
            verticalAlign: number | string;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ButtonEventMap>(name: K, callback: (this: Titanium.UI.Button, event: ButtonEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ButtonEventMap>(name: K, event?: ButtonEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Button.attributedString> property.
             * @deprecated Access <Titanium.UI.Button.attributedString> instead.
             */
            getAttributedString(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.Button.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.Button.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.Button.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.backgroundImage> property.
             * @deprecated Access <Titanium.UI.Button.backgroundImage> instead.
             */
            getBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.Button.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Button.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.Button.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.children> property.
             * @deprecated Access <Titanium.UI.Button.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Button.color> property.
             * @deprecated Access <Titanium.UI.Button.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Button.disabledColor> property.
             * @deprecated Access <Titanium.UI.Button.disabledColor> instead.
             */
            getDisabledColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Button.enabled> property.
             * @deprecated Access <Titanium.UI.Button.enabled> instead.
             */
            getEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Button.font> property.
             * @deprecated Access <Titanium.UI.Button.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.Button.image> property.
             * @deprecated Access <Titanium.UI.Button.image> instead.
             */
            getImage(): string | Titanium.Blob;

            /**
             * Gets the value of the <Titanium.UI.Button.selectedColor> property.
             * @deprecated Access <Titanium.UI.Button.selectedColor> instead.
             */
            getSelectedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Button.shadowColor> property.
             * @deprecated Access <Titanium.UI.Button.shadowColor> instead.
             */
            getShadowColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Button.shadowOffset> property.
             * @deprecated Access <Titanium.UI.Button.shadowOffset> instead.
             */
            getShadowOffset(): Point;

            /**
             * Gets the value of the <Titanium.UI.Button.shadowRadius> property.
             * @deprecated Access <Titanium.UI.Button.shadowRadius> instead.
             */
            getShadowRadius(): number;

            /**
             * Gets the value of the <Titanium.UI.Button.style> property.
             * @deprecated Access <Titanium.UI.Button.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.Button.systemButton> property.
             * @deprecated Access <Titanium.UI.Button.systemButton> instead.
             */
            getSystemButton(): number;

            /**
             * Gets the value of the <Titanium.UI.Button.textAlign> property.
             * @deprecated Access <Titanium.UI.Button.textAlign> instead.
             */
            getTextAlign(): string | number;

            /**
             * Gets the value of the <Titanium.UI.Button.tintColor> property.
             * @deprecated Access <Titanium.UI.Button.tintColor> instead.
             */
            getTintColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.title> property.
             * @deprecated Access <Titanium.UI.Button.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.titleid> property.
             * @deprecated Access <Titanium.UI.Button.titleid> instead.
             */
            getTitleid(): string;

            /**
             * Gets the value of the <Titanium.UI.Button.verticalAlign> property.
             * @deprecated Access <Titanium.UI.Button.verticalAlign> instead.
             */
            getVerticalAlign(): number | string;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ButtonEventMap>(name: K, callback: (this: Titanium.UI.Button, event: ButtonEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Button.attributedString> property.
             * @deprecated Set the value using <Titanium.UI.Button.attributedString> instead.
             */
            setAttributedString(attributedString: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.Button.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.Button.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage(backgroundDisabledImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.Button.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage(backgroundFocusedImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.Button.backgroundImage> instead.
             */
            setBackgroundImage(backgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.Button.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor(backgroundSelectedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Button.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.Button.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage(backgroundSelectedImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.color> property.
             * @deprecated Set the value using <Titanium.UI.Button.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Button.disabledColor> property.
             * @deprecated Set the value using <Titanium.UI.Button.disabledColor> instead.
             */
            setDisabledColor(disabledColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Button.enabled> property.
             * @deprecated Set the value using <Titanium.UI.Button.enabled> instead.
             */
            setEnabled(enabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Button.font> property.
             * @deprecated Set the value using <Titanium.UI.Button.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.Button.image> property.
             * @deprecated Set the value using <Titanium.UI.Button.image> instead.
             */
            setImage(image: string | Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.UI.Button.selectedColor> property.
             * @deprecated Set the value using <Titanium.UI.Button.selectedColor> instead.
             */
            setSelectedColor(selectedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Button.shadowColor> property.
             * @deprecated Set the value using <Titanium.UI.Button.shadowColor> instead.
             */
            setShadowColor(shadowColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Button.shadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.Button.shadowOffset> instead.
             */
            setShadowOffset(shadowOffset: Point): void;

            /**
             * Sets the value of the <Titanium.UI.Button.shadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.Button.shadowRadius> instead.
             */
            setShadowRadius(shadowRadius: number): void;

            /**
             * Sets the value of the <Titanium.UI.Button.style> property.
             * @deprecated Set the value using <Titanium.UI.Button.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.Button.systemButton> property.
             * @deprecated Set the value using <Titanium.UI.Button.systemButton> instead.
             */
            setSystemButton(systemButton: number): void;

            /**
             * Sets the value of the <Titanium.UI.Button.textAlign> property.
             * @deprecated Set the value using <Titanium.UI.Button.textAlign> instead.
             */
            setTextAlign(textAlign: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.Button.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.Button.tintColor> instead.
             */
            setTintColor(tintColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.title> property.
             * @deprecated Set the value using <Titanium.UI.Button.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.titleid> property.
             * @deprecated Set the value using <Titanium.UI.Button.titleid> instead.
             */
            setTitleid(titleid: string): void;

            /**
             * Sets the value of the <Titanium.UI.Button.verticalAlign> property.
             * @deprecated Set the value using <Titanium.UI.Button.verticalAlign> instead.
             */
            setVerticalAlign(verticalAlign: number | string): void;

        }
        /**
         * Base event for class Titanium.UI.ButtonBar
         */
        interface ButtonBarBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ButtonBar;

        }
        /**
         * Fired when a button is clicked.
         */
        interface ButtonBar_click_Event extends ButtonBarBaseEvent {
            /**
             * Index of the clicked button.
             */
            index: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ButtonBar_dblclick_Event extends ButtonBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ButtonBar_doubletap_Event extends ButtonBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ButtonBar_keypressed_Event extends ButtonBarBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long press.
         */
        interface ButtonBar_longpress_Event extends ButtonBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ButtonBar_pinch_Event extends ButtonBarBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ButtonBar_postlayout_Event extends ButtonBarBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ButtonBar_singletap_Event extends ButtonBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ButtonBar_swipe_Event extends ButtonBarBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ButtonBar_touchcancel_Event extends ButtonBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ButtonBar_touchend_Event extends ButtonBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ButtonBar_touchmove_Event extends ButtonBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ButtonBar_touchstart_Event extends ButtonBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ButtonBar_twofingertap_Event extends ButtonBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ButtonBarEventMap extends ProxyEventMap {
            click: ButtonBar_click_Event;

            dblclick: ButtonBar_dblclick_Event;

            doubletap: ButtonBar_doubletap_Event;

            keypressed: ButtonBar_keypressed_Event;

            longpress: ButtonBar_longpress_Event;

            pinch: ButtonBar_pinch_Event;

            postlayout: ButtonBar_postlayout_Event;

            singletap: ButtonBar_singletap_Event;

            swipe: ButtonBar_swipe_Event;

            touchcancel: ButtonBar_touchcancel_Event;

            touchend: ButtonBar_touchend_Event;

            touchmove: ButtonBar_touchmove_Event;

            touchstart: ButtonBar_touchstart_Event;

            twofingertap: ButtonBar_twofingertap_Event;

        }
        /**
         * An iOS button bar component.
         */
        class ButtonBar extends Titanium.UI.View {
            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Index of the currently selected button.
             * @deprecated This property has been deprecated in Titanium SDK 8.0.0 as this property has no effect
             * and will be removed in SDK 9.0.0.
             *
             */
            index: number;

            /**
             * Array of labels for the button bar.
             */
            labels: string[] | BarItemType[];

            /**
             * Color of selected button, as a color name or hex triplet.
             */
            selectedButtonColor: string | Titanium.UI.Color;

            /**
             * Color of title of button when it is selected, as a color name or hex triplet.
             */
            selectedTextColor: string | Titanium.UI.Color;

            /**
             * Color of title of button, as a color name or hex triplet.
             */
            textColor: string | Titanium.UI.Color;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ButtonBarEventMap>(name: K, callback: (this: Titanium.UI.ButtonBar, event: ButtonBarEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ButtonBarEventMap>(name: K, event?: ButtonBarEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.children> property.
             * @deprecated Access <Titanium.UI.ButtonBar.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.index> property.
             * @deprecated This property has been deprecated in Titanium SDK 8.0.0 as this property has no effect
             * and will be removed in SDK 9.0.0.
             *
             */
            getIndex(): number;

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.labels> property.
             * @deprecated Access <Titanium.UI.ButtonBar.labels> instead.
             */
            getLabels(): string[] | BarItemType[];

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.selectedButtonColor> property.
             * @deprecated Access <Titanium.UI.ButtonBar.selectedButtonColor> instead.
             */
            getSelectedButtonColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.selectedTextColor> property.
             * @deprecated Access <Titanium.UI.ButtonBar.selectedTextColor> instead.
             */
            getSelectedTextColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ButtonBar.textColor> property.
             * @deprecated Access <Titanium.UI.ButtonBar.textColor> instead.
             */
            getTextColor(): string | Titanium.UI.Color;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ButtonBarEventMap>(name: K, callback: (this: Titanium.UI.ButtonBar, event: ButtonBarEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.ButtonBar.index> property.
             * @deprecated This property has been deprecated in Titanium SDK 8.0.0 as this property has no effect
             * and will be removed in SDK 9.0.0.
             *
             */
            setIndex(index: number): void;

            /**
             * Sets the value of the <Titanium.UI.ButtonBar.labels> property.
             * @deprecated Set the value using <Titanium.UI.ButtonBar.labels> instead.
             */
            setLabels(labels: string[] | BarItemType[]): void;

            /**
             * Sets the value of the <Titanium.UI.ButtonBar.selectedButtonColor> property.
             * @deprecated Set the value using <Titanium.UI.ButtonBar.selectedButtonColor> instead.
             */
            setSelectedButtonColor(selectedButtonColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ButtonBar.selectedTextColor> property.
             * @deprecated Set the value using <Titanium.UI.ButtonBar.selectedTextColor> instead.
             */
            setSelectedTextColor(selectedTextColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ButtonBar.textColor> property.
             * @deprecated Set the value using <Titanium.UI.ButtonBar.textColor> instead.
             */
            setTextColor(textColor: string | Titanium.UI.Color): void;

        }
        /**
         * A module used for accessing clipboard data.
         */
        class Clipboard extends Titanium.Module {
            /**
             * Create a clipboard identified by name if it doesn't exist.
             */
            static allowCreation: boolean;

            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * Create a new named clipboard.
             */
            static name: string;

            /**
             * Create a new clipboard identified by a unique system-generated name.
             */
            static unique: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Deletes data of the specified MIME type stored in the clipboard. If MIME type omitted, all
             * data is deleted.
             */
            static clearData(type?: string): void;

            /**
             * Deletes all text data stored in the clipboard.
             */
            static clearText(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Clipboard.allowCreation> property.
             * @deprecated Access <Titanium.UI.Clipboard.allowCreation> instead.
             */
            static getAllowCreation(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Clipboard.apiName> property.
             * @deprecated Access <Titanium.UI.Clipboard.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.UI.Clipboard.bubbleParent> property.
             * @deprecated Access <Titanium.UI.Clipboard.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets data of the specified MIME type stored in the clipboard. Returns null if non-text mimetype on Android.
             */
            static getData(type: string): string | Titanium.Blob;

            /**
             * Gets the items that have been specified earlier using <Titanium.UI.Clipboard.setItems>.
             */
            static getItems(): any[];

            /**
             * Gets the value of the <Titanium.UI.Clipboard.name> property.
             * @deprecated Access <Titanium.UI.Clipboard.name> instead.
             */
            static getName(): string;

            /**
             * Gets text data stored in the clipboard.
             */
            static getText(): string;

            /**
             * Gets the value of the <Titanium.UI.Clipboard.unique> property.
             * @deprecated Access <Titanium.UI.Clipboard.unique> instead.
             */
            static getUnique(): boolean;

            /**
             * Indicates whether any colors are stored in the clipboard.
             */
            static hasColors(): boolean;

            /**
             * Indicates whether any data of the specified MIME type is stored in the clipboard.
             */
            static hasData(type?: string): boolean;

            /**
             * Indicates whether any images are stored in the clipboard.
             */
            static hasImages(): boolean;

            /**
             * Indicates whether any text data is stored in the clipboard.
             */
            static hasText(): boolean;

            /**
             * Indicates whether any URLs are stored in the clipboard.
             */
            static hasURLs(): boolean;

            /**
             * Removes the clipboard.
             */
            static remove(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.Clipboard.allowCreation> property.
             * @deprecated Set the value using <Titanium.UI.Clipboard.allowCreation> instead.
             */
            static setAllowCreation(allowCreation: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Clipboard.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.Clipboard.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Stores data of the specified MIME type in the clipboard.
             */
            static setData(type: string, data: any): void;

            /**
             * Adds an array of items to a clipboard, and sets privacy options for all included items.
             */
            static setItems(items: ClipboardItemsType): void;

            /**
             * Sets the value of the <Titanium.UI.Clipboard.name> property.
             * @deprecated Set the value using <Titanium.UI.Clipboard.name> instead.
             */
            static setName(name: string): void;

            /**
             * Stores text data in the clipboard.
             */
            static setText(text: string): void;

            /**
             * Sets the value of the <Titanium.UI.Clipboard.unique> property.
             * @deprecated Set the value using <Titanium.UI.Clipboard.unique> instead.
             */
            static setUnique(unique: boolean): void;

        }
        /**
         * Represents a color used for UI components.
         */
        class Color extends Titanium.Proxy {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Returns a hex string representation of the color (in the RRGGBB or AARRGGBB formats)
             */
            toHex(): string;

        }
        /**
         * The cover flow view is a container showing animated three-dimensional images in a style
         * consistent with the cover flow presentation used for iPod, iTunes, and file browsing.
         * @deprecated Use [Titanium.UI.iOS.CoverFlowView](Titanium.UI.iOS.CoverFlowView) instead.
         */
        const CoverFlowView: never;
        /**
         * Base event for class Titanium.UI.DashboardItem
         */
        interface DashboardItemBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.DashboardItem;

        }
        /**
         * Fired when a click is detected against the view.
         */
        interface DashboardItem_click_Event extends DashboardItemBaseEvent {
            /**
             * Item that was clicked.
             */
            item: Titanium.UI.DashboardItem;

            /**
             * Coordinates `x` and `y` of the event from the parent view's coordinate system.
             */
            location: Point;

        }
        /**
         * Fired when an item is deleted during editing mode.
         */
        interface DashboardItem_delete_Event extends DashboardItemBaseEvent {
            /**
             * Item that was deleted.
             */
            item: Titanium.UI.DashboardItem;

        }
        /**
         * Fired when an item is moved during editing mode.
         */
        interface DashboardItem_move_Event extends DashboardItemBaseEvent {
            /**
             * Item that was moved.
             */
            item: Titanium.UI.DashboardItem;

            /**
             * List of items to be committed, possibly in new order, when edit mode ends.
             */
            items: Titanium.UI.DashboardItem[];

        }
        interface DashboardItemEventMap extends ProxyEventMap {
            click: DashboardItem_click_Event;

            delete: DashboardItem_delete_Event;

            move: DashboardItem_move_Event;

        }
        /**
         * A dashboard item is a view that is displayed as an icon in a <Titanium.UI.DashboardView>.
         */
        class DashboardItem extends Titanium.Proxy {
            /**
             * Integer value displayed in a badge.
             */
            badge: number;

            /**
             * Determines whether this item can be deleted when it edit mode.
             */
            canDelete: boolean;

            /**
             * Image or path to image to display in the item by default.
             */
            image: string | Titanium.Blob;

            /**
             * Image or path to image to display in the item as it is selected.
             */
            selectedImage: string | Titanium.Blob;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof DashboardItemEventMap>(name: K, callback: (this: Titanium.UI.DashboardItem, event: DashboardItemEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof DashboardItemEventMap>(name: K, event?: DashboardItemEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.DashboardItem.badge> property.
             * @deprecated Access <Titanium.UI.DashboardItem.badge> instead.
             */
            getBadge(): number;

            /**
             * Gets the value of the <Titanium.UI.DashboardItem.canDelete> property.
             * @deprecated Access <Titanium.UI.DashboardItem.canDelete> instead.
             */
            getCanDelete(): boolean;

            /**
             * Gets the value of the <Titanium.UI.DashboardItem.image> property.
             * @deprecated Access <Titanium.UI.DashboardItem.image> instead.
             */
            getImage(): string | Titanium.Blob;

            /**
             * Gets the value of the <Titanium.UI.DashboardItem.selectedImage> property.
             * @deprecated Access <Titanium.UI.DashboardItem.selectedImage> instead.
             */
            getSelectedImage(): string | Titanium.Blob;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof DashboardItemEventMap>(name: K, callback: (this: Titanium.UI.DashboardItem, event: DashboardItemEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardItem.badge> property.
             * @deprecated Set the value using <Titanium.UI.DashboardItem.badge> instead.
             */
            setBadge(badge: number): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardItem.canDelete> property.
             * @deprecated Set the value using <Titanium.UI.DashboardItem.canDelete> instead.
             */
            setCanDelete(canDelete: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardItem.image> property.
             * @deprecated Set the value using <Titanium.UI.DashboardItem.image> instead.
             */
            setImage(image: string | Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardItem.selectedImage> property.
             * @deprecated Set the value using <Titanium.UI.DashboardItem.selectedImage> instead.
             */
            setSelectedImage(selectedImage: string | Titanium.Blob): void;

        }
        /**
         * Base event for class Titanium.UI.DashboardView
         */
        interface DashboardViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.DashboardView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface DashboardView_click_Event extends DashboardViewBaseEvent {
            /**
             * Item that was clicked.
             */
            item: any;

            /**
             * Coordinates x and y of the event from the parent view's coordinate system.
             */
            location: Point;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface DashboardView_dblclick_Event extends DashboardViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface DashboardView_doubletap_Event extends DashboardViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface DashboardView_keypressed_Event extends DashboardViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long press.
         */
        interface DashboardView_longpress_Event extends DashboardViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface DashboardView_pinch_Event extends DashboardViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface DashboardView_postlayout_Event extends DashboardViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface DashboardView_singletap_Event extends DashboardViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface DashboardView_swipe_Event extends DashboardViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface DashboardView_touchcancel_Event extends DashboardViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface DashboardView_touchend_Event extends DashboardViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface DashboardView_touchmove_Event extends DashboardViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface DashboardView_touchstart_Event extends DashboardViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface DashboardView_twofingertap_Event extends DashboardViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when edit mode ends.
         */
        interface DashboardView_commit_Event extends DashboardViewBaseEvent {
        }
        /**
         * Fired when an item is deleted in edit mode.
         */
        interface DashboardView_delete_Event extends DashboardViewBaseEvent {
            /**
             * Item that was deleted.
             */
            item: Titanium.UI.DashboardItem;

        }
        /**
         * Fired when an item finishes being dragged in edit mode.
         */
        interface DashboardView_dragend_Event extends DashboardViewBaseEvent {
            /**
             * Item that was dragged.
             */
            item: Titanium.UI.DashboardItem;

        }
        /**
         * Fired when an item starts being dragged in edit mode.
         */
        interface DashboardView_dragstart_Event extends DashboardViewBaseEvent {
            /**
             * Item that was dragged.
             */
            item: Titanium.UI.DashboardItem;

        }
        /**
         * Fired when edit mode starts.
         */
        interface DashboardView_edit_Event extends DashboardViewBaseEvent {
        }
        /**
         * Fired when an item is moved in edit mode.
         */
        interface DashboardView_move_Event extends DashboardViewBaseEvent {
            /**
             * Item that was moved.
             */
            item: Titanium.UI.DashboardItem;

            /**
             * List of items to be committed, possibly in new order, when edit mode ends.
             */
            items: Titanium.UI.DashboardItem[];

        }
        /**
         * Fired when the current page of the dashboard view changes.
         */
        interface DashboardView_pagechanged_Event extends DashboardViewBaseEvent {
            /**
             * The current page number.
             */
            pageNo: number;

        }
        interface DashboardViewEventMap extends ProxyEventMap {
            click: DashboardView_click_Event;

            commit: DashboardView_commit_Event;

            dblclick: DashboardView_dblclick_Event;

            delete: DashboardView_delete_Event;

            doubletap: DashboardView_doubletap_Event;

            dragend: DashboardView_dragend_Event;

            dragstart: DashboardView_dragstart_Event;

            edit: DashboardView_edit_Event;

            keypressed: DashboardView_keypressed_Event;

            longpress: DashboardView_longpress_Event;

            move: DashboardView_move_Event;

            pagechanged: DashboardView_pagechanged_Event;

            pinch: DashboardView_pinch_Event;

            postlayout: DashboardView_postlayout_Event;

            singletap: DashboardView_singletap_Event;

            swipe: DashboardView_swipe_Event;

            touchcancel: DashboardView_touchcancel_Event;

            touchend: DashboardView_touchend_Event;

            touchmove: DashboardView_touchmove_Event;

            touchstart: DashboardView_touchstart_Event;

            twofingertap: DashboardView_twofingertap_Event;

        }
        /**
         * A dashboard view is an iOS Springboard-like view of <Titanium.UI.DashboardItem> items that may
         * be deleted and reordered by the user using its built-in edit mode.
         */
        class DashboardView extends Titanium.UI.View {
            /**
             * The number of columns of items in the view.
             */
            columnCount: number;

            /**
             * Items to display in this view.
             */
            data: Titanium.UI.DashboardItem[];

            /**
             * Determines whether edit mode is activated by a longpress of an item.
             */
            editable: boolean;

            /**
             * The number of rows of items in the view.
             */
            rowCount: number;

            /**
             * Determines whether the wobble visual editing cue is enabled in edit mode.
             */
            wobble: boolean;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof DashboardViewEventMap>(name: K, callback: (this: Titanium.UI.DashboardView, event: DashboardViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof DashboardViewEventMap>(name: K, event?: DashboardViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.DashboardView.columnCount> property.
             * @deprecated Access <Titanium.UI.DashboardView.columnCount> instead.
             */
            getColumnCount(): number;

            /**
             * Gets the value of the <Titanium.UI.DashboardView.data> property.
             * @deprecated Access <Titanium.UI.DashboardView.data> instead.
             */
            getData(): Titanium.UI.DashboardItem[];

            /**
             * Gets the value of the <Titanium.UI.DashboardView.editable> property.
             * @deprecated Access <Titanium.UI.DashboardView.editable> instead.
             */
            getEditable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.DashboardView.rowCount> property.
             * @deprecated Access <Titanium.UI.DashboardView.rowCount> instead.
             */
            getRowCount(): number;

            /**
             * Gets the value of the <Titanium.UI.DashboardView.wobble> property.
             * @deprecated Access <Titanium.UI.DashboardView.wobble> instead.
             */
            getWobble(): boolean;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof DashboardViewEventMap>(name: K, callback: (this: Titanium.UI.DashboardView, event: DashboardViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.DashboardView.columnCount> property.
             * @deprecated Set the value using <Titanium.UI.DashboardView.columnCount> instead.
             */
            setColumnCount(columnCount: number): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardView.data> property.
             * @deprecated Set the value using <Titanium.UI.DashboardView.data> instead.
             */
            setData(data: ReadonlyArray<Titanium.UI.DashboardItem>): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardView.editable> property.
             * @deprecated Set the value using <Titanium.UI.DashboardView.editable> instead.
             */
            setEditable(editable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardView.rowCount> property.
             * @deprecated Set the value using <Titanium.UI.DashboardView.rowCount> instead.
             */
            setRowCount(rowCount: number): void;

            /**
             * Sets the value of the <Titanium.UI.DashboardView.wobble> property.
             * @deprecated Set the value using <Titanium.UI.DashboardView.wobble> instead.
             */
            setWobble(wobble: boolean): void;

            /**
             * Enable edit mode.
             */
            startEditing(): void;

            /**
             * Disable edit mode.
             */
            stopEditing(): void;

        }
        /**
         * Base event for class Titanium.UI.EmailDialog
         */
        interface EmailDialogBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.EmailDialog;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface EmailDialog_click_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface EmailDialog_dblclick_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface EmailDialog_doubletap_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface EmailDialog_focus_Event extends EmailDialogBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface EmailDialog_keypressed_Event extends EmailDialogBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface EmailDialog_longclick_Event extends EmailDialogBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface EmailDialog_longpress_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface EmailDialog_pinch_Event extends EmailDialogBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface EmailDialog_postlayout_Event extends EmailDialogBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface EmailDialog_singletap_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface EmailDialog_swipe_Event extends EmailDialogBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface EmailDialog_touchcancel_Event extends EmailDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface EmailDialog_touchend_Event extends EmailDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface EmailDialog_touchmove_Event extends EmailDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface EmailDialog_touchstart_Event extends EmailDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface EmailDialog_twofingertap_Event extends EmailDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when this email dialog has completed sending an email.
         */
        interface EmailDialog_complete_Event extends EmailDialogBaseEvent {
            /**
             * Error code.
             * Error code will be 0 if `success` is `true`, nonzero otherwise. If the error
             * was generated by the operating system, that system's error value is used.
             * Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. Will be undefined if `success` is `true`.
             */
            error: string;

            /**
             * Status of the email send process.
             * The `SAVED` and `CANCELLED` constants are iOS only.
             * On Android, this property will return `SENT` when the user discards or saves
             * a message.
             */
            result: number;

            /**
             * Indicates if the email was handled successfully.
             * Returns `true` if request succeeded, `false` otherwise. Note that emails being
             * deleted or saved for later do count as success.
             */
            success: boolean;

        }
        interface EmailDialogEventMap extends ProxyEventMap {
            click: EmailDialog_click_Event;

            complete: EmailDialog_complete_Event;

            dblclick: EmailDialog_dblclick_Event;

            doubletap: EmailDialog_doubletap_Event;

            focus: EmailDialog_focus_Event;

            keypressed: EmailDialog_keypressed_Event;

            longclick: EmailDialog_longclick_Event;

            longpress: EmailDialog_longpress_Event;

            pinch: EmailDialog_pinch_Event;

            postlayout: EmailDialog_postlayout_Event;

            singletap: EmailDialog_singletap_Event;

            swipe: EmailDialog_swipe_Event;

            touchcancel: EmailDialog_touchcancel_Event;

            touchend: EmailDialog_touchend_Event;

            touchmove: EmailDialog_touchmove_Event;

            touchstart: EmailDialog_touchstart_Event;

            twofingertap: EmailDialog_twofingertap_Event;

        }
        /**
         * An email dialog is a modal window that allows users to compose and send an email.
         */
        class EmailDialog extends Titanium.UI.View {
            /**
             * Constant for the `CANCELLED` status result. On Android, this property exists but is not used.
             */
            readonly CANCELLED: number;

            /**
             * Constant for the `FAILED` status result.
             */
            readonly FAILED: number;

            /**
             * Constant for the `SAVED` status result. On Android, this property exists but is not used.
             */
            readonly SAVED: number;

            /**
             * Constant for the `SENT` status result.
             */
            readonly SENT: number;

            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Bar color of the email dialog window, as a color name or hex triplet.
             */
            barColor: string | Titanium.UI.Color;

            /**
             * Recipients of the email included via the `BCC` (Blind Carbon Copy) field.
             */
            bccRecipients: string[];

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * Recipients of the email included via the `CC` (Carbon Copy) field.
             */
            ccRecipients: string[];

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * View's clipping behavior.
             */
            clipMode: never;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Determines whether the email message, specifically the contents of
             * [messageBody](Titanium.UI.EmailDialog.messageBody), should be sent as HTML content type
             * rather than plain text.
             */
            html: boolean;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * View's left position, in platform-specific units.
             */
            left: never;

            /**
             * Email message body.
             */
            messageBody: string;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: never;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * View's right position, in platform-specific units.
             */
            right: never;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * Subject line for the email.
             */
            subject: string;

            /**
             * The view's tintColor
             */
            tintColor: never;

            /**
             * Recipients of the email included via the main `TO` field.
             */
            toRecipients: string[];

            /**
             * The view's top position.
             */
            top: never;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: never;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: never;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds an attachment.
             */
            addAttachment(attachment: Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof EmailDialogEventMap>(name: K, callback: (this: Titanium.UI.EmailDialog, event: EmailDialogEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof EmailDialogEventMap>(name: K, event?: EmailDialogEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.EmailDialog.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.EmailDialog.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.EmailDialog.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.EmailDialog.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.anchorPoint> property.
             * @deprecated Access <Titanium.UI.EmailDialog.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.animatedCenter> property.
             * @deprecated Access <Titanium.UI.EmailDialog.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundImage> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.EmailDialog.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.barColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.barColor> instead.
             */
            getBarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.bccRecipients> property.
             * @deprecated Access <Titanium.UI.EmailDialog.bccRecipients> instead.
             */
            getBccRecipients(): string[];

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.borderColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.borderRadius> property.
             * @deprecated Access <Titanium.UI.EmailDialog.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.borderWidth> property.
             * @deprecated Access <Titanium.UI.EmailDialog.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.bottom> property.
             * @deprecated Access <Titanium.UI.EmailDialog.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.ccRecipients> property.
             * @deprecated Access <Titanium.UI.EmailDialog.ccRecipients> instead.
             */
            getCcRecipients(): string[];

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.center> property.
             * @deprecated Access <Titanium.UI.EmailDialog.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.children> property.
             * @deprecated Access <Titanium.UI.EmailDialog.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.clipMode> property.
             * @deprecated Access <Titanium.UI.EmailDialog.clipMode> instead.
             */
            getClipMode: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.focusable> property.
             * @deprecated Access <Titanium.UI.EmailDialog.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.height> property.
             * @deprecated Access <Titanium.UI.EmailDialog.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.EmailDialog.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.html> property.
             * @deprecated Access <Titanium.UI.EmailDialog.html> instead.
             */
            getHtml(): boolean;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.EmailDialog.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.layout> property.
             * @deprecated Access <Titanium.UI.EmailDialog.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.left> property.
             * @deprecated Access <Titanium.UI.EmailDialog.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.messageBody> property.
             * @deprecated Access <Titanium.UI.EmailDialog.messageBody> instead.
             */
            getMessageBody(): string;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.opacity> property.
             * @deprecated Access <Titanium.UI.EmailDialog.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.EmailDialog.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.pullBackgroundColor> instead.
             */
            getPullBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.rect> property.
             * @deprecated Access <Titanium.UI.EmailDialog.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.right> property.
             * @deprecated Access <Titanium.UI.EmailDialog.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.size> property.
             * @deprecated Access <Titanium.UI.EmailDialog.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.EmailDialog.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.subject> property.
             * @deprecated Access <Titanium.UI.EmailDialog.subject> instead.
             */
            getSubject(): string;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.tintColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.tintColor> instead.
             */
            getTintColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.toRecipients> property.
             * @deprecated Access <Titanium.UI.EmailDialog.toRecipients> instead.
             */
            getToRecipients(): string[];

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.top> property.
             * @deprecated Access <Titanium.UI.EmailDialog.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.touchEnabled> property.
             * @deprecated Access <Titanium.UI.EmailDialog.touchEnabled> instead.
             */
            getTouchEnabled: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.transform> property.
             * @deprecated Access <Titanium.UI.EmailDialog.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.EmailDialog.viewShadowColor> instead.
             */
            getViewShadowColor: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.EmailDialog.viewShadowOffset> instead.
             */
            getViewShadowOffset: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.EmailDialog.viewShadowRadius> instead.
             */
            getViewShadowRadius: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.visible> property.
             * @deprecated Access <Titanium.UI.EmailDialog.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.width> property.
             * @deprecated Access <Titanium.UI.EmailDialog.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.EmailDialog.zIndex> property.
             * @deprecated Access <Titanium.UI.EmailDialog.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Indicates whether sending email is supported by the system.
             */
            isSupported(): boolean;

            /**
             * Opens this email dialog.
             */
            open(options?: AnimatedOptions): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof EmailDialogEventMap>(name: K, callback: (this: Titanium.UI.EmailDialog, event: EmailDialogEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.barColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.barColor> instead.
             */
            setBarColor(barColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.bccRecipients> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.bccRecipients> instead.
             */
            setBccRecipients(bccRecipients: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.bottom> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.ccRecipients> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.ccRecipients> instead.
             */
            setCcRecipients(ccRecipients: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.center> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.clipMode> instead.
             */
            setClipMode: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.focusable> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.height> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.html> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.html> instead.
             */
            setHtml(html: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.layout> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.left> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.messageBody> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.messageBody> instead.
             */
            setMessageBody(messageBody: string): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.opacity> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.pullBackgroundColor> instead.
             */
            setPullBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.right> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.subject> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.subject> instead.
             */
            setSubject(subject: string): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.tintColor> instead.
             */
            setTintColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.toRecipients> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.toRecipients> instead.
             */
            setToRecipients(toRecipients: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.top> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.touchEnabled> instead.
             */
            setTouchEnabled: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.transform> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.viewShadowColor> instead.
             */
            setViewShadowColor: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.viewShadowOffset> instead.
             */
            setViewShadowOffset: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.viewShadowRadius> instead.
             */
            setViewShadowRadius: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.visible> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.width> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.width> instead.
             */
            setWidth: never;

            /**
             * Sets the value of the <Titanium.UI.EmailDialog.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.EmailDialog.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage: never;

        }
        /**
         * Base event for class Titanium.UI.ImageView
         */
        interface ImageViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ImageView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ImageView_click_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ImageView_dblclick_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ImageView_doubletap_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ImageView_focus_Event extends ImageViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ImageView_keypressed_Event extends ImageViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ImageView_longclick_Event extends ImageViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface ImageView_longpress_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ImageView_pinch_Event extends ImageViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ImageView_postlayout_Event extends ImageViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ImageView_singletap_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ImageView_swipe_Event extends ImageViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ImageView_touchcancel_Event extends ImageViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ImageView_touchend_Event extends ImageViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ImageView_touchmove_Event extends ImageViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ImageView_touchstart_Event extends ImageViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ImageView_twofingertap_Event extends ImageViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired for each frame change during an animation.
         */
        interface ImageView_change_Event extends ImageViewBaseEvent {
            /**
             * Index of the image frame being displayed.
             */
            index: number;

        }
        /**
         * Fired when either the initial image and/or all of the images in an animation are loaded.
         */
        interface ImageView_load_Event extends ImageViewBaseEvent {
            /**
             * Set to `image` when the image defined in the [image](Titanium.UI.ImageView.image)
             * property is loaded. Set to `images`, when the series of images defined in the
             * [images](Titanium.UI.ImageView.images) property are loaded.
             */
            state: string;

        }
        /**
         * Fired when the animation starts.
         */
        interface ImageView_start_Event extends ImageViewBaseEvent {
        }
        /**
         * Fired when the animation stops.
         */
        interface ImageView_stop_Event extends ImageViewBaseEvent {
        }
        /**
         * Fired when an image fails to load.
         */
        interface ImageView_error_Event extends ImageViewBaseEvent {
            /**
             * Error code.
             * If the error was generated by the operating system, that system's error value
             * is used. Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. May be undefined.
             */
            error: string;

            /**
             * URL of the image that failed to load.
             */
            image: string;

            /**
             * Indicates a successful operation. Returns `false`.
             */
            success: boolean;

        }
        /**
         * Fired when the animation pauses.
         */
        interface ImageView_pause_Event extends ImageViewBaseEvent {
        }
        interface ImageViewEventMap extends ProxyEventMap {
            change: ImageView_change_Event;

            click: ImageView_click_Event;

            dblclick: ImageView_dblclick_Event;

            doubletap: ImageView_doubletap_Event;

            error: ImageView_error_Event;

            focus: ImageView_focus_Event;

            keypressed: ImageView_keypressed_Event;

            load: ImageView_load_Event;

            longclick: ImageView_longclick_Event;

            longpress: ImageView_longpress_Event;

            pause: ImageView_pause_Event;

            pinch: ImageView_pinch_Event;

            postlayout: ImageView_postlayout_Event;

            singletap: ImageView_singletap_Event;

            start: ImageView_start_Event;

            stop: ImageView_stop_Event;

            swipe: ImageView_swipe_Event;

            touchcancel: ImageView_touchcancel_Event;

            touchend: ImageView_touchend_Event;

            touchmove: ImageView_touchmove_Event;

            touchstart: ImageView_touchstart_Event;

            twofingertap: ImageView_twofingertap_Event;

        }
        /**
         * A view to display a single image or series of animated images.
         */
        class ImageView extends Titanium.UI.View {
            /**
             * Indicates whether animation is running.
             */
            readonly animating: boolean;

            /**
             * Indicates whether the image should be rotated based on exif orientation data.
             * By default, this is false on android and true on iOS.
             */
            autorotate: boolean;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Number of times to retry decoding the bitmap at a URL.
             */
            decodeRetries: number;

            /**
             * Local path to the default image to display while loading a remote image.
             */
            defaultImage: string;

            /**
             * Amount of time in milliseconds to animate one cycle.
             */
            duration: number;

            /**
             * Show zoom controls when the user touches the image view.
             */
            enableZoomControls: boolean;

            /**
             * Set to `true` to prevent scaling of 2x/3x-resolution remote images for retina
             * displays.
             */
            hires: boolean;

            /**
             * Image to display.
             */
            image: string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Array of images to animate, defined using local filesystem paths, `File` objects,
             * remote URLs (Android only), or `Blob` objects containing image data.
             * When using this property, an initial `start()` needs to be called upon the ImageView before any image will show in this imageview.
             * Related properties/methods to look at: `start`, `stop`, `pause`, `reverse`, `resume` and `repeatCount`
             */
            images: string[] | Titanium.Blob[] | Titanium.Filesystem.File[];

            /**
             * Indicates whether the animation is paused.
             */
            readonly paused: boolean;

            /**
             * Prevent the default image from being displayed while loading a remote image. This property
             * is ignored when the `defaultImage` property is set.
             */
            preventDefaultImage: boolean;

            /**
             * Number of times to repeat the image animation.
             */
            repeatCount: number;

            /**
             * Run the animation in reverse.
             */
            reverse: boolean;

            /**
             * The view's tintColor. Android does not support setting instances of <Titanium.UI.Color>
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * URL to the image to display.
             * @deprecated Use [Titanium.UI.ImageView.image](Titanium.UI.ImageView.image) instead.
             */
            url: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ImageViewEventMap>(name: K, callback: (this: Titanium.UI.ImageView, event: ImageViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ImageViewEventMap>(name: K, event?: ImageViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ImageView.animating> property.
             * @deprecated Access <Titanium.UI.ImageView.animating> instead.
             */
            getAnimating(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.autorotate> property.
             * @deprecated Access <Titanium.UI.ImageView.autorotate> instead.
             */
            getAutorotate(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.children> property.
             * @deprecated Access <Titanium.UI.ImageView.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ImageView.decodeRetries> property.
             * @deprecated Access <Titanium.UI.ImageView.decodeRetries> instead.
             */
            getDecodeRetries(): number;

            /**
             * Gets the value of the <Titanium.UI.ImageView.defaultImage> property.
             * @deprecated Access <Titanium.UI.ImageView.defaultImage> instead.
             */
            getDefaultImage(): string;

            /**
             * Gets the value of the <Titanium.UI.ImageView.duration> property.
             * @deprecated Access <Titanium.UI.ImageView.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.UI.ImageView.enableZoomControls> property.
             * @deprecated Access <Titanium.UI.ImageView.enableZoomControls> instead.
             */
            getEnableZoomControls(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.hires> property.
             * @deprecated Access <Titanium.UI.ImageView.hires> instead.
             */
            getHires(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.image> property.
             * @deprecated Access <Titanium.UI.ImageView.image> instead.
             */
            getImage(): string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.UI.ImageView.images> property.
             * @deprecated Access <Titanium.UI.ImageView.images> instead.
             */
            getImages(): string[] | Titanium.Blob[] | Titanium.Filesystem.File[];

            /**
             * Gets the value of the <Titanium.UI.ImageView.paused> property.
             * @deprecated Access <Titanium.UI.ImageView.paused> instead.
             */
            getPaused(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.preventDefaultImage> property.
             * @deprecated Access <Titanium.UI.ImageView.preventDefaultImage> instead.
             */
            getPreventDefaultImage(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.repeatCount> property.
             * @deprecated Access <Titanium.UI.ImageView.repeatCount> instead.
             */
            getRepeatCount(): number;

            /**
             * Gets the value of the <Titanium.UI.ImageView.reverse> property.
             * @deprecated Access <Titanium.UI.ImageView.reverse> instead.
             */
            getReverse(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ImageView.tintColor> property.
             * @deprecated Access <Titanium.UI.ImageView.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ImageView.url> property.
             * @deprecated Use [Titanium.UI.ImageView.image](Titanium.UI.ImageView.image) instead.
             */
            getUrl: never;

            /**
             * Pauses a running animation. Use `resume` method to continue.
             */
            pause(): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ImageViewEventMap>(name: K, callback: (this: Titanium.UI.ImageView, event: ImageViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Resumes an animation from a `pause` state.
             */
            resume(): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.autorotate> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.autorotate> instead.
             */
            setAutorotate(autorotate: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.decodeRetries> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.decodeRetries> instead.
             */
            setDecodeRetries(decodeRetries: number): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.defaultImage> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.defaultImage> instead.
             */
            setDefaultImage(defaultImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.duration> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.duration> instead.
             */
            setDuration(duration: number): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.enableZoomControls> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.enableZoomControls> instead.
             */
            setEnableZoomControls(enableZoomControls: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.hires> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.hires> instead.
             */
            setHires(hires: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.image> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.image> instead.
             */
            setImage(image: string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.images> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.images> instead.
             */
            setImages(images: string[] | Titanium.Blob[] | Titanium.Filesystem.File[]): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.preventDefaultImage> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.preventDefaultImage> instead.
             */
            setPreventDefaultImage(preventDefaultImage: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.repeatCount> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.repeatCount> instead.
             */
            setRepeatCount(repeatCount: number): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.reverse> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.reverse> instead.
             */
            setReverse(reverse: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.ImageView.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ImageView.url> property.
             * @deprecated Use [Titanium.UI.ImageView.image](Titanium.UI.ImageView.image) instead.
             */
            setUrl: never;

            /**
             * Starts the image animation. On Android, also resets `index` to the first image.
             */
            start(): void;

            /**
             * Stops a running animation. On iOS, also resets `index` to the first image.
             */
            stop(): void;

            /**
             * Returns the image as a Blob object.
             */
            toBlob(): Titanium.Blob;

        }
        /**
         * Base event for class Titanium.UI.Label
         */
        interface LabelBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Label;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Label_click_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Label_dblclick_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Label_doubletap_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Label_focus_Event extends LabelBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Label_keypressed_Event extends LabelBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Label_longclick_Event extends LabelBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Label_longpress_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Label_pinch_Event extends LabelBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Label_postlayout_Event extends LabelBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Label_singletap_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Label_swipe_Event extends LabelBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Label_touchcancel_Event extends LabelBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Label_touchend_Event extends LabelBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Label_touchmove_Event extends LabelBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Label_touchstart_Event extends LabelBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Label_twofingertap_Event extends LabelBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when user interacts with a URL in the Label.
         */
        interface Label_link_Event extends LabelBaseEvent {
            /**
             * This is false. This event does not bubble
             */
            bubbles: boolean;

            /**
             * An array of two numbers [location, length] describing the character range of the text associated with this URL.
             */
            range: any[];

            /**
             * The URL that is associated with this event.
             */
            url: string;

        }
        interface LabelEventMap extends ProxyEventMap {
            click: Label_click_Event;

            dblclick: Label_dblclick_Event;

            doubletap: Label_doubletap_Event;

            focus: Label_focus_Event;

            keypressed: Label_keypressed_Event;

            link: Label_link_Event;

            longclick: Label_longclick_Event;

            longpress: Label_longpress_Event;

            pinch: Label_pinch_Event;

            postlayout: Label_postlayout_Event;

            singletap: Label_singletap_Event;

            swipe: Label_swipe_Event;

            touchcancel: Label_touchcancel_Event;

            touchend: Label_touchend_Event;

            touchmove: Label_touchmove_Event;

            touchstart: Label_touchstart_Event;

            twofingertap: Label_twofingertap_Event;

        }
        /**
         * A text label, with an optional background image.
         */
        class Label extends Titanium.UI.View {
            /**
             * Specify an attributed string for the label.
             */
            attributedString: Titanium.UI.AttributedString;

            /**
             * Automatically convert certain text items in the label to clickable links.
             */
            autoLink: number;

            /**
             * Number of pixels to extend the background image past the label on the bottom.
             */
            backgroundPaddingBottom: number;

            /**
             * Number of pixels to extend the background image past the label on the left.
             */
            backgroundPaddingLeft: number;

            /**
             * Number of pixels to extend the background image past the label on the right.
             */
            backgroundPaddingRight: number;

            /**
             * Number of pixels to extend the background image past the label on the top.
             */
            backgroundPaddingTop: number;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Color of the label text, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Causes words in the text that are longer than the view is wide to be ellipsized instead of broken in the middle.
             */
            ellipsize: number;

            /**
             * Font to use for the label text.
             */
            font: Font;

            /**
             * Color of the label when in the highlighted state, as a color name or hex triplet.
             */
            highlightedColor: string | Titanium.UI.Color;

            /**
             * Simple HTML formatting.
             */
            html: string;

            /**
             * Includes extra top and bottom padding to make room for accents that go above normal ascent and descent.
             */
            includeFontPadding: boolean;

            /**
             * Line spacing of the [text](Titanium.UI.Label.text), as a dictionary with the properties `add` and `multiply`.
             */
            lineSpacing: LabelLineSpacing;

            /**
             * Makes the label be exactly this many lines tall.
             */
            lines: number;

            /**
             * Makes the label at most this many lines tall.
             */
            maxLines: number;

            /**
             * Minimum font size when the font is sized based on the contents.
             */
            minimumFontSize: number;

            /**
             * Shadow color of the [text](Titanium.UI.Label.text), as a color name or hex triplet.
             */
            shadowColor: string | Titanium.UI.Color;

            /**
             * Shadow offset of the [text](Titanium.UI.Label.text), as a dictionary with the properties `x` and `y`.
             */
            shadowOffset: Point;

            /**
             * Shadow radius of the [text](Titanium.UI.Label.text).
             */
            shadowRadius: number;

            /**
             * Label text.
             */
            text: string;

            /**
             * Text alignment.
             */
            textAlign: string | number;

            /**
             * Key identifying a string from the locale file to use for the label text.
             */
            textid: string;

            /**
             * Vertical text alignment, specified using one of the  vertical alignment constants
             * from <Titanium.UI>.
             */
            verticalAlign: number | string;

            /**
             * Enable or disable word wrapping in the label.
             * @deprecated If you want to disable wrapping, then set [Titanium.UI.Label.maxLines](Titanium.UI.Label.maxLines) to 1 instead.
             */
            wordWrap: boolean;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof LabelEventMap>(name: K, callback: (this: Titanium.UI.Label, event: LabelEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof LabelEventMap>(name: K, event?: LabelEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Label.attributedString> property.
             * @deprecated Access <Titanium.UI.Label.attributedString> instead.
             */
            getAttributedString(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.Label.autoLink> property.
             * @deprecated Access <Titanium.UI.Label.autoLink> instead.
             */
            getAutoLink(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.backgroundPaddingBottom> property.
             * @deprecated Access <Titanium.UI.Label.backgroundPaddingBottom> instead.
             */
            getBackgroundPaddingBottom(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.backgroundPaddingLeft> property.
             * @deprecated Access <Titanium.UI.Label.backgroundPaddingLeft> instead.
             */
            getBackgroundPaddingLeft(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.backgroundPaddingRight> property.
             * @deprecated Access <Titanium.UI.Label.backgroundPaddingRight> instead.
             */
            getBackgroundPaddingRight(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.backgroundPaddingTop> property.
             * @deprecated Access <Titanium.UI.Label.backgroundPaddingTop> instead.
             */
            getBackgroundPaddingTop(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.children> property.
             * @deprecated Access <Titanium.UI.Label.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Label.color> property.
             * @deprecated Access <Titanium.UI.Label.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Label.ellipsize> property.
             * @deprecated Access <Titanium.UI.Label.ellipsize> instead.
             */
            getEllipsize(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.font> property.
             * @deprecated Access <Titanium.UI.Label.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.Label.highlightedColor> property.
             * @deprecated Access <Titanium.UI.Label.highlightedColor> instead.
             */
            getHighlightedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Label.html> property.
             * @deprecated Access <Titanium.UI.Label.html> instead.
             */
            getHtml(): string;

            /**
             * Gets the value of the <Titanium.UI.Label.includeFontPadding> property.
             * @deprecated Access <Titanium.UI.Label.includeFontPadding> instead.
             */
            getIncludeFontPadding(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Label.lineSpacing> property.
             * @deprecated Access <Titanium.UI.Label.lineSpacing> instead.
             */
            getLineSpacing(): LabelLineSpacing;

            /**
             * Gets the value of the <Titanium.UI.Label.lines> property.
             * @deprecated Access <Titanium.UI.Label.lines> instead.
             */
            getLines(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.maxLines> property.
             * @deprecated Access <Titanium.UI.Label.maxLines> instead.
             */
            getMaxLines(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.minimumFontSize> property.
             * @deprecated Access <Titanium.UI.Label.minimumFontSize> instead.
             */
            getMinimumFontSize(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.shadowColor> property.
             * @deprecated Access <Titanium.UI.Label.shadowColor> instead.
             */
            getShadowColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Label.shadowOffset> property.
             * @deprecated Access <Titanium.UI.Label.shadowOffset> instead.
             */
            getShadowOffset(): Point;

            /**
             * Gets the value of the <Titanium.UI.Label.shadowRadius> property.
             * @deprecated Access <Titanium.UI.Label.shadowRadius> instead.
             */
            getShadowRadius(): number;

            /**
             * Gets the value of the <Titanium.UI.Label.text> property.
             * @deprecated Access <Titanium.UI.Label.text> instead.
             */
            getText(): string;

            /**
             * Gets the value of the <Titanium.UI.Label.textAlign> property.
             * @deprecated Access <Titanium.UI.Label.textAlign> instead.
             */
            getTextAlign(): string | number;

            /**
             * Gets the value of the <Titanium.UI.Label.textid> property.
             * @deprecated Access <Titanium.UI.Label.textid> instead.
             */
            getTextid(): string;

            /**
             * Gets the value of the <Titanium.UI.Label.verticalAlign> property.
             * @deprecated Access <Titanium.UI.Label.verticalAlign> instead.
             */
            getVerticalAlign(): number | string;

            /**
             * Gets the value of the <Titanium.UI.Label.wordWrap> property.
             * @deprecated If you want to disable wrapping, then set [Titanium.UI.Label.maxLines](Titanium.UI.Label.maxLines) to 1 instead.
             */
            getWordWrap(): boolean;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof LabelEventMap>(name: K, callback: (this: Titanium.UI.Label, event: LabelEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Label.attributedString> property.
             * @deprecated Set the value using <Titanium.UI.Label.attributedString> instead.
             */
            setAttributedString(attributedString: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.Label.autoLink> property.
             * @deprecated Set the value using <Titanium.UI.Label.autoLink> instead.
             */
            setAutoLink(autoLink: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.backgroundPaddingBottom> property.
             * @deprecated Set the value using <Titanium.UI.Label.backgroundPaddingBottom> instead.
             */
            setBackgroundPaddingBottom(backgroundPaddingBottom: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.backgroundPaddingLeft> property.
             * @deprecated Set the value using <Titanium.UI.Label.backgroundPaddingLeft> instead.
             */
            setBackgroundPaddingLeft(backgroundPaddingLeft: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.backgroundPaddingRight> property.
             * @deprecated Set the value using <Titanium.UI.Label.backgroundPaddingRight> instead.
             */
            setBackgroundPaddingRight(backgroundPaddingRight: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.backgroundPaddingTop> property.
             * @deprecated Set the value using <Titanium.UI.Label.backgroundPaddingTop> instead.
             */
            setBackgroundPaddingTop(backgroundPaddingTop: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.color> property.
             * @deprecated Set the value using <Titanium.UI.Label.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Label.ellipsize> property.
             * @deprecated Set the value using <Titanium.UI.Label.ellipsize> instead.
             */
            setEllipsize(ellipsize: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.font> property.
             * @deprecated Set the value using <Titanium.UI.Label.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.Label.highlightedColor> property.
             * @deprecated Set the value using <Titanium.UI.Label.highlightedColor> instead.
             */
            setHighlightedColor(highlightedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Label.html> property.
             * @deprecated Set the value using <Titanium.UI.Label.html> instead.
             */
            setHtml(html: string): void;

            /**
             * Sets the value of the <Titanium.UI.Label.includeFontPadding> property.
             * @deprecated Set the value using <Titanium.UI.Label.includeFontPadding> instead.
             */
            setIncludeFontPadding(includeFontPadding: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Label.lineSpacing> property.
             * @deprecated Set the value using <Titanium.UI.Label.lineSpacing> instead.
             */
            setLineSpacing(lineSpacing: LabelLineSpacing): void;

            /**
             * Sets the value of the <Titanium.UI.Label.lines> property.
             * @deprecated Set the value using <Titanium.UI.Label.lines> instead.
             */
            setLines(lines: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.maxLines> property.
             * @deprecated Set the value using <Titanium.UI.Label.maxLines> instead.
             */
            setMaxLines(maxLines: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.minimumFontSize> property.
             * @deprecated Set the value using <Titanium.UI.Label.minimumFontSize> instead.
             */
            setMinimumFontSize(minimumFontSize: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.shadowColor> property.
             * @deprecated Set the value using <Titanium.UI.Label.shadowColor> instead.
             */
            setShadowColor(shadowColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Label.shadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.Label.shadowOffset> instead.
             */
            setShadowOffset(shadowOffset: Point): void;

            /**
             * Sets the value of the <Titanium.UI.Label.shadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.Label.shadowRadius> instead.
             */
            setShadowRadius(shadowRadius: number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.text> property.
             * @deprecated Set the value using <Titanium.UI.Label.text> instead.
             */
            setText(text: string): void;

            /**
             * Sets the value of the <Titanium.UI.Label.textAlign> property.
             * @deprecated Set the value using <Titanium.UI.Label.textAlign> instead.
             */
            setTextAlign(textAlign: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.Label.textid> property.
             * @deprecated Set the value using <Titanium.UI.Label.textid> instead.
             */
            setTextid(textid: string): void;

            /**
             * Sets the value of the <Titanium.UI.Label.verticalAlign> property.
             * @deprecated Set the value using <Titanium.UI.Label.verticalAlign> instead.
             */
            setVerticalAlign(verticalAlign: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.Label.wordWrap> property.
             * @deprecated If you want to disable wrapping, then set [Titanium.UI.Label.maxLines](Titanium.UI.Label.maxLines) to 1 instead.
             */
            setWordWrap(wordWrap: boolean): void;

        }
        /**
         * A list item is an individual item in a list section.
         */
        class ListItem extends Titanium.Proxy {
            /**
             * Sets an accessory on the right side of an item.
             */
            accessoryType: number;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Background gradient to render when the item is not selected.
             */
            backgroundGradient: Gradient;

            /**
             * Background image to render when the item is not selected.
             */
            backgroundImage: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            bubbleParent: never;

            /**
             * Specifies if the item can be deleted by a user initiated action.
             */
            canEdit: boolean;

            /**
             * Specifies if the item can be inserted by a user initiated action.
             */
            canInsert: boolean;

            /**
             * Specifies if the item can be reordered within the list view by a user initiated action.
             */
            canMove: boolean;

            /**
             * Default text color of the item when not selected, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Specifies custom action items to be shown when when a list item is edited.
             */
            editActions: RowActionType[];

            /**
             * Font to use for the item title.
             */
            font: Font;

            /**
             * Row height in platform-specific units.
             */
            height: number | string;

            /**
             * Image to render in the image area of the item, specified as a local path or URL.
             */
            image: string;

            /**
             * A user defined string that gets passed to events.
             */
            itemId: string;

            /**
             * The text to match against when the [ListView](Titanium.UI.ListView) is performing a search.
             */
            searchableText: string;

            /**
             * Background color of the view, as a color name or hex triplet when item is selected.
             */
            selectedBackgroundColor: string | Titanium.UI.Color;

            /**
             * Background gradient to render when the item is selected.
             */
            selectedBackgroundGradient: Gradient;

            /**
             * Background image to render when the item is selected.
             */
            selectedBackgroundImage: string;

            /**
             * Color to use for the item title when the item is selected, as a color name or hex triplet.
             */
            selectedColor: string | Titanium.UI.Color;

            /**
             * Color to use for the item subtitle when the item is selected, as a color name or hex triplet.
             */
            selectedSubtitleColor: string | Titanium.UI.Color;

            /**
             * Selection style constant to control the selection color.
             */
            selectionStyle: number;

            /**
             * Subtitle to set in the text area of the item.
             */
            subtitle: string;

            /**
             * Default text color of the subtitle, as a color name or hex triplet.
             */
            subtitleColor: string | Titanium.UI.Color;

            /**
             * Title to set in the text area of the item.
             */
            title: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener: never;

            /**
             * Applies the properties to the proxy.
             */
            applyProperties: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent: never;

            /**
             * Gets the value of the <Titanium.UI.ListItem.bubbleParent> property.
             * @deprecated Access <Titanium.UI.ListItem.bubbleParent> instead.
             */
            getBubbleParent: never;

            /**
             * Gets the value of the <Titanium.UI.ListItem.editActions> property.
             * @deprecated Access <Titanium.UI.ListItem.editActions> instead.
             */
            getEditActions(): RowActionType[];

            /**
             * Gets the value of the <Titanium.UI.ListItem.selectedColor> property.
             * @deprecated Access <Titanium.UI.ListItem.selectedColor> instead.
             */
            getSelectedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ListItem.selectedSubtitleColor> property.
             * @deprecated Access <Titanium.UI.ListItem.selectedSubtitleColor> instead.
             */
            getSelectedSubtitleColor(): string | Titanium.UI.Color;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener: never;

            /**
             * Sets the value of the <Titanium.UI.ListItem.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.ListItem.bubbleParent> instead.
             */
            setBubbleParent: never;

            /**
             * Sets the value of the <Titanium.UI.ListItem.editActions> property.
             * @deprecated Set the value using <Titanium.UI.ListItem.editActions> instead.
             */
            setEditActions(editActions: ReadonlyArray<RowActionType>): void;

            /**
             * Sets the value of the <Titanium.UI.ListItem.selectedColor> property.
             * @deprecated Set the value using <Titanium.UI.ListItem.selectedColor> instead.
             */
            setSelectedColor(selectedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ListItem.selectedSubtitleColor> property.
             * @deprecated Set the value using <Titanium.UI.ListItem.selectedSubtitleColor> instead.
             */
            setSelectedSubtitleColor(selectedSubtitleColor: string | Titanium.UI.Color): void;

        }
        /**
         * A list section is a container within a list view used to organize list items.
         */
        class ListSection extends Titanium.Proxy {
            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            bubbleParent: never;

            /**
             * Title of this section footer.
             */
            footerTitle: string;

            /**
             * View to use for this section footer.
             */
            footerView: Titanium.UI.View;

            /**
             * Title of this section header.
             */
            headerTitle: string;

            /**
             * View to use for this section header.
             */
            headerView: Titanium.UI.View;

            /**
             * Items of this list section.
             */
            items: ListDataItem[];

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener: never;

            /**
             * Appends the data entries to the end of the list section.
             */
            appendItems(dataItems: ReadonlyArray<ListDataItem>, animation?: ListViewAnimationProperties): void;

            /**
             * Removes count entries from the list section at the specified index.
             */
            deleteItemsAt(itemIndex: number, count: number, animation?: ListViewAnimationProperties): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent: never;

            /**
             * Gets the value of the <Titanium.UI.ListSection.bubbleParent> property.
             * @deprecated Access <Titanium.UI.ListSection.bubbleParent> instead.
             */
            getBubbleParent: never;

            /**
             * Gets the value of the <Titanium.UI.ListSection.footerTitle> property.
             * @deprecated Access <Titanium.UI.ListSection.footerTitle> instead.
             */
            getFooterTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.ListSection.footerView> property.
             * @deprecated Access <Titanium.UI.ListSection.footerView> instead.
             */
            getFooterView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.ListSection.headerTitle> property.
             * @deprecated Access <Titanium.UI.ListSection.headerTitle> instead.
             */
            getHeaderTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.ListSection.headerView> property.
             * @deprecated Access <Titanium.UI.ListSection.headerView> instead.
             */
            getHeaderView(): Titanium.UI.View;

            /**
             * Returns the item entry from the list view at the specified index.
             */
            getItemAt(itemIndex: number): ListDataItem;

            /**
             * Gets the value of the <Titanium.UI.ListSection.items> property.
             * @deprecated Access <Titanium.UI.ListSection.items> instead.
             */
            getItems(): ListDataItem[];

            /**
             * Inserts data entries to the list section at the specified index.
             */
            insertItemsAt(itemIndex: number, dataItems: ReadonlyArray<ListDataItem>, animation?: ListViewAnimationProperties): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener: never;

            /**
             * Removes count entries from the list section at the specified index,
             * then inserts data entries to the list section at the same index.
             */
            replaceItemsAt(index: number, count: number, dataItems: ReadonlyArray<ListDataItem>, animation?: ListViewAnimationProperties): void;

            /**
             * Sets the value of the <Titanium.UI.ListSection.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.ListSection.bubbleParent> instead.
             */
            setBubbleParent: never;

            /**
             * Sets the value of the <Titanium.UI.ListSection.footerTitle> property.
             * @deprecated Set the value using <Titanium.UI.ListSection.footerTitle> instead.
             */
            setFooterTitle(footerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.ListSection.footerView> property.
             * @deprecated Set the value using <Titanium.UI.ListSection.footerView> instead.
             */
            setFooterView(footerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.ListSection.headerTitle> property.
             * @deprecated Set the value using <Titanium.UI.ListSection.headerTitle> instead.
             */
            setHeaderTitle(headerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.ListSection.headerView> property.
             * @deprecated Set the value using <Titanium.UI.ListSection.headerView> instead.
             */
            setHeaderView(headerView: Titanium.UI.View): void;

            /**
             * Sets the data entries in the list section.
             */
            setItems(dataItems: ReadonlyArray<ListDataItem>, animation?: ListViewAnimationProperties): void;

            /**
             * Updates an item at the specified index.
             */
            updateItemAt(index: number, dataItem: ListDataItem, animation?: ListViewAnimationProperties): void;

        }
        /**
         * Base event for class Titanium.UI.ListView
         */
        interface ListViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ListView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ListView_click_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ListView_dblclick_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ListView_doubletap_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ListView_focus_Event extends ListViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ListView_keypressed_Event extends ListViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ListView_longclick_Event extends ListViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface ListView_longpress_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ListView_pinch_Event extends ListViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ListView_postlayout_Event extends ListViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ListView_singletap_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ListView_swipe_Event extends ListViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ListView_touchcancel_Event extends ListViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ListView_touchend_Event extends ListViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ListView_touchmove_Event extends ListViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ListView_touchstart_Event extends ListViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ListView_twofingertap_Event extends ListViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the index bar is clicked by the user.
         */
        interface ListView_indexclick_Event extends ListViewBaseEvent {
            /**
             * The index number clicked.
             */
            index: number;

            /**
             * The title of the index clicked.
             */
            title: string;

        }
        /**
         * Fired when a list row is clicked by the user.
         */
        interface ListView_itemclick_Event extends ListViewBaseEvent {
            /**
             * Returns `true` if the detail button is clicked else returns `false`.
             * Only returns `true` if the `accessoryType` property is set to
             * <Titanium.UI.LIST_ACCESSORY_TYPE_DETAIL>.  All other accessories return `false` if
             * clicked.
             */
            accessoryClicked: boolean;

            /**
             * The bind ID of the control that generated this event, if one exists.
             */
            bindId: string;

            /**
             * The item ID bound to the list item that generated the event.
             */
            itemId: string;

            /**
             * Item index.
             */
            itemIndex: number;

            /**
             * List section if the item is contained in a list section.
             */
            section: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            sectionIndex: number;

        }
        /**
         * Fired when user stops two-pan gesture interaction for selecting multiple items.
         * It is used with <Titanium.UI.ListView.allowsMultipleSelectionInteraction>.
         */
        interface ListView_itemsselected_Event extends ListViewBaseEvent {
            /**
             * List of items selected by user.
             */
            selectedItems: SelectedItem[];

            /**
             * First item selected when user started interaction.
             */
            startingItem: SelectedItem;

        }
        /**
         * Fired when a list row is deleted by the user.
         */
        interface ListView_delete_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The item ID bound to the list item that generated the event.
             */
            itemId: string;

            /**
             * Item index.
             */
            itemIndex: number;

            /**
             * List section from which the item is deleted.
             */
            section: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            sectionIndex: number;

        }
        /**
         * Fired when a list row is inserted by the user.
         */
        interface ListView_insert_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The item ID bound to the list item that generated the event.
             */
            itemId: string;

            /**
             * Item index.
             */
            itemIndex: number;

            /**
             * List section from which the item is deleted.
             */
            section: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            sectionIndex: number;

        }
        /**
         * Fired when the user starts dragging the list view.
         */
        interface ListView_dragstart_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

        }
        /**
         * Fired when the user stops dragging the list view.
         */
        interface ListView_dragend_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

        }
        /**
         * Fired when the list view displays the reference item.
         */
        interface ListView_marker_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * section item index of the reference item.
             */
            itemIndex: number;

            /**
             * section index of the reference item.
             */
            sectionIndex: number;

        }
        /**
         * Fired when a list row is moved to a different location by the user.
         */
        interface ListView_move_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The item ID bound to the list item that generated the event.
             */
            itemId: string;

            /**
             * Item index.
             */
            itemIndex: number;

            /**
             * List section from which the item is moved.
             */
            section: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            sectionIndex: number;

            /**
             * Position within the `targetSection`.
             */
            targetItemIndex: number;

            /**
             * List section to which the item is moved. Might be the same as `section` property.
             */
            targetSection: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            targetSectionIndex: number;

        }
        /**
         * Fired when the search using either [searchView](Titanium.UI.ListView.searchView) or [searchText](Titanium.UI.ListView.searchText) has no results.
         */
        interface ListView_noresults_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

        }
        /**
         * Fired when the user drags the list view past the top edge of the [pullView](Titanium.UI.ListView.pullView).
         */
        interface ListView_pull_Event extends ListViewBaseEvent {
            /**
             * Determines if the `pullView` is completely visible (true) or partially hidden (false).
             */
            active: boolean;

            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

        }
        /**
         * Fired when new list items are prefetched. The items are ordered ascending by geometric distance
         * from the list view. Note that this event is only available on iOS 10 and later.
         */
        interface ListView_prefetch_Event extends ListViewBaseEvent {
            /**
             * An array of prefetched items.
             */
            prefetchedItems: ListItemEventType[];

        }
        /**
         * Fired when list items that previously were considered as candidates for pre-fetching were not
         * actually used. Note that this event is only available on iOS 10 and later
         */
        interface ListView_cancelprefetch_Event extends ListViewBaseEvent {
            /**
             * An array of prefetched items.
             */
            prefetchedItems: ListItemEventType[];

        }
        /**
         * Fired when the user stops dragging the list view and the [pullView](Titanium.UI.ListView.pullView) is completely visible.
         */
        interface ListView_pullend_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

        }
        /**
         * Fired when the user interacts with one of the custom edit actions defined by <Titanium.UI.ListItem.editActions>.
         */
        interface ListView_editaction_Event extends ListViewBaseEvent {
            /**
             * The [title](RowActionType.title) as defined in the row action object.
             */
            action: string;

            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The [identifier](RowActionType. identifier) of the row action. Only included in the event
             * if previously defined. Available in Titanium 6.0.0 and later.
             */
            identifier: string;

            /**
             * The item ID bound to the list item that generated the event.
             */
            itemId: string;

            /**
             * Item index.
             */
            itemIndex: number;

            /**
             * List section from which the event was generated.
             */
            section: Titanium.UI.ListSection;

            /**
             * Section index.
             */
            sectionIndex: number;

        }
        /**
         * Fires when the list view starts scrolling by user interaction. Calling the `scrollTo` methods will not fire this event
         */
        interface ListView_scrollstart_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The first visible item in the list view when the event fires; this item might not be fully visible. May be -1 on iOS.
             */
            firstVisibleItem: any;

            /**
             * The index of the first visible item in the list view when the event fires; this item might not be fully visible.
             * Note: The index is `-1` when there are no items in the <Titanium.UI.ListView>.
             */
            firstVisibleItemIndex: number;

            /**
             * The first visible section in the list view when the event fires.
             */
            firstVisibleSection: Titanium.UI.ListSection;

            /**
             * The index of the first visible section in the list view when the event fires.
             * Note: The index is `-1` when there are no items in the <Titanium.UI.ListView>.
             */
            firstVisibleSectionIndex: number;

            /**
             * The number of visible items in the list view when the event fires.
             */
            visibleItemCount: number;

        }
        /**
         * Fires when the list view ends scrolling. Calling the `scrollTo` methods will not fire this event
         */
        interface ListView_scrollend_Event extends ListViewBaseEvent {
            /**
             * false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * The first visible item in the list view when the event fires; this item might not be fully visible. May be -1 on iOS.
             */
            firstVisibleItem: any;

            /**
             * The index of the first visible item in the list view when the event fires; this item might not be fully visible.
             */
            firstVisibleItemIndex: number;

            /**
             * The first visible section in the list view when the event fires.
             */
            firstVisibleSection: Titanium.UI.ListSection;

            /**
             * The index of the first visible section in the list view when the event fires.
             */
            firstVisibleSectionIndex: number;

            /**
             * The number of visible items in the list view when the event fires.
             */
            visibleItemCount: number;

        }
        /**
         * Fires when the list view is scrolling. Calling the `scrollTo` methods will not fire this event
         */
        interface ListView_scrolling_Event extends ListViewBaseEvent {
            /**
             * Direction of the scroll either 'up', or 'down'.
             */
            direction: string;

            /**
             * The expected y axis offset when the scrolling action decelerates to a stop.
             */
            targetContentOffset: number;

            /**
             * The velocity of the scroll in scale factor per second
             */
            velocity: number;

        }
        interface ListViewEventMap extends ProxyEventMap {
            cancelprefetch: ListView_cancelprefetch_Event;

            click: ListView_click_Event;

            dblclick: ListView_dblclick_Event;

            delete: ListView_delete_Event;

            doubletap: ListView_doubletap_Event;

            dragend: ListView_dragend_Event;

            dragstart: ListView_dragstart_Event;

            editaction: ListView_editaction_Event;

            focus: ListView_focus_Event;

            indexclick: ListView_indexclick_Event;

            insert: ListView_insert_Event;

            itemclick: ListView_itemclick_Event;

            itemsselected: ListView_itemsselected_Event;

            keypressed: ListView_keypressed_Event;

            longclick: ListView_longclick_Event;

            longpress: ListView_longpress_Event;

            marker: ListView_marker_Event;

            move: ListView_move_Event;

            noresults: ListView_noresults_Event;

            pinch: ListView_pinch_Event;

            postlayout: ListView_postlayout_Event;

            prefetch: ListView_prefetch_Event;

            pull: ListView_pull_Event;

            pullend: ListView_pullend_Event;

            scrollend: ListView_scrollend_Event;

            scrolling: ListView_scrolling_Event;

            scrollstart: ListView_scrollstart_Event;

            singletap: ListView_singletap_Event;

            swipe: ListView_swipe_Event;

            touchcancel: ListView_touchcancel_Event;

            touchend: ListView_touchend_Event;

            touchmove: ListView_touchmove_Event;

            touchstart: ListView_touchstart_Event;

            twofingertap: ListView_twofingertap_Event;

        }
        /**
         * A list view is used to present information, organized in to sections and items,
         * in a vertically-scrolling view.
         */
        class ListView extends Titanium.UI.View {
            /**
             * Determines whether multiple items of this list view can be selected at the same time while editing the table.
             */
            allowsMultipleSelectionDuringEditing: boolean;

            /**
             * Allows a two-finger pan gesture to automatically transition the table view into editing mode and start selecting rows.
             */
            allowsMultipleSelectionInteraction: boolean;

            /**
             * Determines whether this item can be selected.
             */
            allowsSelection: boolean;

            /**
             * Determines whether this list view items can be selected while editing the table.
             */
            allowsSelectionDuringEditing: boolean;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Determines if the list view can scroll in response to user actions.
             */
            canScroll: boolean;

            /**
             * Determines if the search performed is case insensitive.
             */
            caseInsensitiveSearch: boolean;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Sets the default template for list data items that do not specify the `template` property.
             */
            defaultItemTemplate: string | number;

            /**
             * A Boolean indicating whether the underlying content is dimmed during a search.
             */
            dimBackgroundForSearch: boolean;

            /**
             * Determines whether the scroll-bounce of the list view should be disabled.
             */
            disableBounce: boolean;

            /**
             * Determines if the list view is currently in editing mode.
             */
            editing: boolean;

            /**
             * Sets the fastScroll mode on Android ListViews.
             */
            fastScroll: boolean;

            /**
             * When set to false, the ListView will not draw the divider before the footer view.
             */
            footerDividersEnabled: boolean;

            /**
             * List view footer title.
             */
            footerTitle: string;

            /**
             * List view footer as a view that will be rendered instead of a label.
             */
            footerView: Titanium.UI.View;

            /**
             * When set to false, the ListView will not draw the divider after the header view.
             */
            headerDividersEnabled: boolean;

            /**
             * List view header title.
             */
            headerTitle: string;

            /**
             * List view header as a view that will be rendered instead of a label.
             */
            headerView: Titanium.UI.View;

            /**
             * Determines if the section information is displayed in the search results when using the `searchText` property.
             */
            keepSectionsInSearch: boolean;

            /**
             * The manner in which the keyboard is dismissed when a drag begins in the list view.
             */
            keyboardDismissMode: number;

            /**
             * Determines if the list view should use lazy loading to load remote images.
             */
            lazyLoadingEnabled: boolean;

            /**
             * The insets for the list view header and footer.
             */
            listSeparatorInsets: HorizontalInsets;

            /**
             * Determines if empty sections are retained when the user completes editing the list view.
             */
            pruneSectionsOnEdit: boolean;

            /**
             * View positioned above the first row that is only revealed when the user drags the list view contents down.
             */
            pullView: Titanium.UI.View;

            /**
             * View positioned above the first row that is only revealed when the user drags the list view contents down.
             */
            refreshControl: Titanium.UI.RefreshControl;

            /**
             * The background color of the search results (iOS-only).
             */
            resultsBackgroundColor: string | Titanium.UI.Color;

            /**
             * Separator line color between rows inside search results,
             * as a color name or hex triplet (iOS-only).
             */
            resultsSeparatorColor: string | Titanium.UI.Color;

            /**
             * The insets for search results separators (applies to all cells & iOS-only).
             */
            resultsSeparatorInsets: HorizontalInsets;

            /**
             * The separator style of the search results (iOS-only).
             */
            resultsSeparatorStyle: number;

            /**
             * The insets for list view cells (applies to all cells).
             */
            rowSeparatorInsets: HorizontalInsets;

            /**
             * Style of the scrollbar.
             */
            scrollIndicatorStyle: number;

            /**
             * The string to use as the search parameter.
             */
            searchText: string;

            /**
             * Search field to use for the list view.
             */
            searchView: Titanium.UI.SearchBar | Titanium.UI.Android.SearchView;

            /**
             * Number of sections in this list view.
             */
            readonly sectionCount: number;

            /**
             * Array of objects (with `title` and `index` properties) to control the list view index.
             */
            sectionIndexTitles: ListViewIndexEntry[];

            /**
             * Sections of this list.
             */
            sections: Titanium.UI.ListSection[];

            /**
             * Returns the selected list view items.
             */
            selectedItems: ListItemEventType[];

            /**
             * Separator line color between items, as a color name or hex triplet.
             */
            separatorColor: string | Titanium.UI.Color;

            /**
             * height of the ListView separator.
             */
            separatorHeight: string | number;

            /**
             * The insets for list view separators (applies to all cells).
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            separatorInsets: HorizontalInsets;

            /**
             * Separator style constant.
             */
            separatorStyle: number;

            /**
             * A Boolean indicating whether search bar will be in navigation bar.
             */
            showSearchBarInNavBar: boolean;

            /**
             * Determines whether this list view displays a vertical scroll indicator.
             */
            showVerticalScrollIndicator: boolean;

            /**
             * Style of the list view.
             */
            style: number;

            /**
             * The insets for the table view header and footer.
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            tableSeparatorInsets: HorizontalInsets;

            /**
             * Contain key-value pairs mapping a style name (key) to an <ItemTemplate> (value).
             */
            templates: any;

            /**
             * Controls the scroll-to-top gesture.
             */
            willScrollOnStatusTap: boolean;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ListViewEventMap>(name: K, callback: (this: Titanium.UI.ListView, event: ListViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a reference item in the list view.
             */
            addMarker(markerProps: ListViewMarkerProps): void;

            /**
             * Appends a single section or an array of sections to the end of the list.
             */
            appendSection(section: Titanium.UI.ListSection | Titanium.UI.ListSection[], animation?: ListViewAnimationProperties): void;

            /**
             * Deletes an existing section.
             */
            deleteSectionAt(sectionIndex: number, animation?: ListViewAnimationProperties): void;

            /**
             * Deselects a specific item.
             */
            deselectItem(sectionIndex: number, itemIndex: number): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ListViewEventMap>(name: K, event?: ListViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ListView.allowsMultipleSelectionDuringEditing> property.
             * @deprecated Access <Titanium.UI.ListView.allowsMultipleSelectionDuringEditing> instead.
             */
            getAllowsMultipleSelectionDuringEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.allowsMultipleSelectionInteraction> property.
             * @deprecated Access <Titanium.UI.ListView.allowsMultipleSelectionInteraction> instead.
             */
            getAllowsMultipleSelectionInteraction(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.allowsSelection> property.
             * @deprecated Access <Titanium.UI.ListView.allowsSelection> instead.
             */
            getAllowsSelection(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.allowsSelectionDuringEditing> property.
             * @deprecated Access <Titanium.UI.ListView.allowsSelectionDuringEditing> instead.
             */
            getAllowsSelectionDuringEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.ListView.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.ListView.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.ListView.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.ListView.canScroll> property.
             * @deprecated Access <Titanium.UI.ListView.canScroll> instead.
             */
            getCanScroll(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.caseInsensitiveSearch> property.
             * @deprecated Access <Titanium.UI.ListView.caseInsensitiveSearch> instead.
             */
            getCaseInsensitiveSearch(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.children> property.
             * @deprecated Access <Titanium.UI.ListView.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ListView.defaultItemTemplate> property.
             * @deprecated Access <Titanium.UI.ListView.defaultItemTemplate> instead.
             */
            getDefaultItemTemplate(): string | number;

            /**
             * Gets the value of the <Titanium.UI.ListView.dimBackgroundForSearch> property.
             * @deprecated Access <Titanium.UI.ListView.dimBackgroundForSearch> instead.
             */
            getDimBackgroundForSearch(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.disableBounce> property.
             * @deprecated Access <Titanium.UI.ListView.disableBounce> instead.
             */
            getDisableBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.editing> property.
             * @deprecated Access <Titanium.UI.ListView.editing> instead.
             */
            getEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.fastScroll> property.
             * @deprecated Access <Titanium.UI.ListView.fastScroll> instead.
             */
            getFastScroll(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.footerDividersEnabled> property.
             * @deprecated Access <Titanium.UI.ListView.footerDividersEnabled> instead.
             */
            getFooterDividersEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.footerTitle> property.
             * @deprecated Access <Titanium.UI.ListView.footerTitle> instead.
             */
            getFooterTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.ListView.footerView> property.
             * @deprecated Access <Titanium.UI.ListView.footerView> instead.
             */
            getFooterView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.ListView.headerDividersEnabled> property.
             * @deprecated Access <Titanium.UI.ListView.headerDividersEnabled> instead.
             */
            getHeaderDividersEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.headerTitle> property.
             * @deprecated Access <Titanium.UI.ListView.headerTitle> instead.
             */
            getHeaderTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.ListView.headerView> property.
             * @deprecated Access <Titanium.UI.ListView.headerView> instead.
             */
            getHeaderView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.ListView.keepSectionsInSearch> property.
             * @deprecated Access <Titanium.UI.ListView.keepSectionsInSearch> instead.
             */
            getKeepSectionsInSearch(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.keyboardDismissMode> property.
             * @deprecated Access <Titanium.UI.ListView.keyboardDismissMode> instead.
             */
            getKeyboardDismissMode(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.lazyLoadingEnabled> property.
             * @deprecated Access <Titanium.UI.ListView.lazyLoadingEnabled> instead.
             */
            getLazyLoadingEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.listSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.ListView.listSeparatorInsets> instead.
             */
            getListSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.ListView.pruneSectionsOnEdit> property.
             * @deprecated Access <Titanium.UI.ListView.pruneSectionsOnEdit> instead.
             */
            getPruneSectionsOnEdit(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.pullView> property.
             * @deprecated Access <Titanium.UI.ListView.pullView> instead.
             */
            getPullView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.ListView.refreshControl> property.
             * @deprecated Access <Titanium.UI.ListView.refreshControl> instead.
             */
            getRefreshControl(): Titanium.UI.RefreshControl;

            /**
             * Gets the value of the <Titanium.UI.ListView.resultsBackgroundColor> property.
             * @deprecated Access <Titanium.UI.ListView.resultsBackgroundColor> instead.
             */
            getResultsBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ListView.resultsSeparatorColor> property.
             * @deprecated Access <Titanium.UI.ListView.resultsSeparatorColor> instead.
             */
            getResultsSeparatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ListView.resultsSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.ListView.resultsSeparatorInsets> instead.
             */
            getResultsSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.ListView.resultsSeparatorStyle> property.
             * @deprecated Access <Titanium.UI.ListView.resultsSeparatorStyle> instead.
             */
            getResultsSeparatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.rowSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.ListView.rowSeparatorInsets> instead.
             */
            getRowSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.ListView.scrollIndicatorStyle> property.
             * @deprecated Access <Titanium.UI.ListView.scrollIndicatorStyle> instead.
             */
            getScrollIndicatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.searchText> property.
             * @deprecated Access <Titanium.UI.ListView.searchText> instead.
             */
            getSearchText(): string;

            /**
             * Gets the value of the <Titanium.UI.ListView.searchView> property.
             * @deprecated Access <Titanium.UI.ListView.searchView> instead.
             */
            getSearchView(): Titanium.UI.SearchBar | Titanium.UI.Android.SearchView;

            /**
             * Gets the value of the <Titanium.UI.ListView.sectionCount> property.
             * @deprecated Access <Titanium.UI.ListView.sectionCount> instead.
             */
            getSectionCount(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.sectionIndexTitles> property.
             * @deprecated Access <Titanium.UI.ListView.sectionIndexTitles> instead.
             */
            getSectionIndexTitles(): ListViewIndexEntry[];

            /**
             * Gets the value of the <Titanium.UI.ListView.sections> property.
             * @deprecated Access <Titanium.UI.ListView.sections> instead.
             */
            getSections(): Titanium.UI.ListSection[];

            /**
             * Gets the value of the <Titanium.UI.ListView.selectedItems> property.
             * @deprecated Access <Titanium.UI.ListView.selectedItems> instead.
             */
            getSelectedItems(): ListItemEventType[];

            /**
             * Gets the value of the <Titanium.UI.ListView.separatorColor> property.
             * @deprecated Access <Titanium.UI.ListView.separatorColor> instead.
             */
            getSeparatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ListView.separatorHeight> property.
             * @deprecated Access <Titanium.UI.ListView.separatorHeight> instead.
             */
            getSeparatorHeight(): string | number;

            /**
             * Gets the value of the <Titanium.UI.ListView.separatorInsets> property.
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            getSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.ListView.separatorStyle> property.
             * @deprecated Access <Titanium.UI.ListView.separatorStyle> instead.
             */
            getSeparatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.showSearchBarInNavBar> property.
             * @deprecated Access <Titanium.UI.ListView.showSearchBarInNavBar> instead.
             */
            getShowSearchBarInNavBar(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.showVerticalScrollIndicator> property.
             * @deprecated Access <Titanium.UI.ListView.showVerticalScrollIndicator> instead.
             */
            getShowVerticalScrollIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ListView.style> property.
             * @deprecated Access <Titanium.UI.ListView.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ListView.tableSeparatorInsets> property.
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            getTableSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.ListView.templates> property.
             * @deprecated Access <Titanium.UI.ListView.templates> instead.
             */
            getTemplates(): any;

            /**
             * Gets the value of the <Titanium.UI.ListView.willScrollOnStatusTap> property.
             * @deprecated Access <Titanium.UI.ListView.willScrollOnStatusTap> instead.
             */
            getWillScrollOnStatusTap(): boolean;

            /**
             * Inserts a section or an array of sections at a specific index.
             */
            insertSectionAt(sectionIndex: number, section: Titanium.UI.ListSection | Titanium.UI.ListSection[], animation?: ListViewAnimationProperties): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ListViewEventMap>(name: K, callback: (this: Titanium.UI.ListView, event: ListViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Replaces an existing section.
             */
            replaceSectionAt(sectionIndex: number, section: Titanium.UI.ListSection, animation?: ListViewAnimationProperties): void;

            /**
             * Scrolls to a specific item.
             */
            scrollToItem(sectionIndex: number, itemIndex: number, animation?: ListViewAnimationProperties): void;

            /**
             * Selects an item in the list using the specified item and section indices.
             */
            selectItem(sectionIndex: number, itemIndex: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.allowsMultipleSelectionDuringEditing> property.
             * @deprecated Set the value using <Titanium.UI.ListView.allowsMultipleSelectionDuringEditing> instead.
             */
            setAllowsMultipleSelectionDuringEditing(allowsMultipleSelectionDuringEditing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.allowsMultipleSelectionInteraction> property.
             * @deprecated Set the value using <Titanium.UI.ListView.allowsMultipleSelectionInteraction> instead.
             */
            setAllowsMultipleSelectionInteraction(allowsMultipleSelectionInteraction: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.allowsSelection> property.
             * @deprecated Set the value using <Titanium.UI.ListView.allowsSelection> instead.
             */
            setAllowsSelection(allowsSelection: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.allowsSelectionDuringEditing> property.
             * @deprecated Set the value using <Titanium.UI.ListView.allowsSelectionDuringEditing> instead.
             */
            setAllowsSelectionDuringEditing(allowsSelectionDuringEditing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.ListView.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.ListView.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.ListView.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.ListView.canScroll> property.
             * @deprecated Set the value using <Titanium.UI.ListView.canScroll> instead.
             */
            setCanScroll(canScroll: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.caseInsensitiveSearch> property.
             * @deprecated Set the value using <Titanium.UI.ListView.caseInsensitiveSearch> instead.
             */
            setCaseInsensitiveSearch(caseInsensitiveSearch: boolean): void;

            /**
             * Sets this list view's content insets.
             */
            setContentInsets(edgeInsets: Padding, options?: AnimatedWithDurationOptions): void;

            /**
             * Sets the value of the content offset of the list view without animation by default.
             */
            setContentOffset(contentOffset: Point, options?: AnimatedOptions): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.defaultItemTemplate> property.
             * @deprecated Set the value using <Titanium.UI.ListView.defaultItemTemplate> instead.
             */
            setDefaultItemTemplate(defaultItemTemplate: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.dimBackgroundForSearch> property.
             * @deprecated Set the value using <Titanium.UI.ListView.dimBackgroundForSearch> instead.
             */
            setDimBackgroundForSearch(dimBackgroundForSearch: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.disableBounce> property.
             * @deprecated Set the value using <Titanium.UI.ListView.disableBounce> instead.
             */
            setDisableBounce(disableBounce: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.editing> property.
             * @deprecated Set the value using <Titanium.UI.ListView.editing> instead.
             */
            setEditing(editing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.fastScroll> property.
             * @deprecated Set the value using <Titanium.UI.ListView.fastScroll> instead.
             */
            setFastScroll(fastScroll: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.footerDividersEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ListView.footerDividersEnabled> instead.
             */
            setFooterDividersEnabled(footerDividersEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.footerTitle> property.
             * @deprecated Set the value using <Titanium.UI.ListView.footerTitle> instead.
             */
            setFooterTitle(footerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.footerView> property.
             * @deprecated Set the value using <Titanium.UI.ListView.footerView> instead.
             */
            setFooterView(footerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.headerDividersEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ListView.headerDividersEnabled> instead.
             */
            setHeaderDividersEnabled(headerDividersEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.headerTitle> property.
             * @deprecated Set the value using <Titanium.UI.ListView.headerTitle> instead.
             */
            setHeaderTitle(headerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.headerView> property.
             * @deprecated Set the value using <Titanium.UI.ListView.headerView> instead.
             */
            setHeaderView(headerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.keepSectionsInSearch> property.
             * @deprecated Set the value using <Titanium.UI.ListView.keepSectionsInSearch> instead.
             */
            setKeepSectionsInSearch(keepSectionsInSearch: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.keyboardDismissMode> property.
             * @deprecated Set the value using <Titanium.UI.ListView.keyboardDismissMode> instead.
             */
            setKeyboardDismissMode(keyboardDismissMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.lazyLoadingEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ListView.lazyLoadingEnabled> instead.
             */
            setLazyLoadingEnabled(lazyLoadingEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.listSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.ListView.listSeparatorInsets> instead.
             */
            setListSeparatorInsets(listSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets a reference item in the list view.
             */
            setMarker(markerProps: ListViewMarkerProps): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.pruneSectionsOnEdit> property.
             * @deprecated Set the value using <Titanium.UI.ListView.pruneSectionsOnEdit> instead.
             */
            setPruneSectionsOnEdit(pruneSectionsOnEdit: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.pullView> property.
             * @deprecated Set the value using <Titanium.UI.ListView.pullView> instead.
             */
            setPullView(pullView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.refreshControl> property.
             * @deprecated Set the value using <Titanium.UI.ListView.refreshControl> instead.
             */
            setRefreshControl(refreshControl: Titanium.UI.RefreshControl): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.resultsBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.ListView.resultsBackgroundColor> instead.
             */
            setResultsBackgroundColor(resultsBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.resultsSeparatorColor> property.
             * @deprecated Set the value using <Titanium.UI.ListView.resultsSeparatorColor> instead.
             */
            setResultsSeparatorColor(resultsSeparatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.resultsSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.ListView.resultsSeparatorInsets> instead.
             */
            setResultsSeparatorInsets(resultsSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.resultsSeparatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.ListView.resultsSeparatorStyle> instead.
             */
            setResultsSeparatorStyle(resultsSeparatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.rowSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.ListView.rowSeparatorInsets> instead.
             */
            setRowSeparatorInsets(rowSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.scrollIndicatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.ListView.scrollIndicatorStyle> instead.
             */
            setScrollIndicatorStyle(scrollIndicatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.searchText> property.
             * @deprecated Set the value using <Titanium.UI.ListView.searchText> instead.
             */
            setSearchText(searchText: string): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.searchView> property.
             * @deprecated Set the value using <Titanium.UI.ListView.searchView> instead.
             */
            setSearchView(searchView: Titanium.UI.SearchBar | Titanium.UI.Android.SearchView): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.sectionIndexTitles> property.
             * @deprecated Set the value using <Titanium.UI.ListView.sectionIndexTitles> instead.
             */
            setSectionIndexTitles(sectionIndexTitles: ReadonlyArray<ListViewIndexEntry>): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.sections> property.
             * @deprecated Set the value using <Titanium.UI.ListView.sections> instead.
             */
            setSections(sections: ReadonlyArray<Titanium.UI.ListSection>): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.selectedItems> property.
             * @deprecated Set the value using <Titanium.UI.ListView.selectedItems> instead.
             */
            setSelectedItems(selectedItems: ReadonlyArray<ListItemEventType>): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.separatorColor> property.
             * @deprecated Set the value using <Titanium.UI.ListView.separatorColor> instead.
             */
            setSeparatorColor(separatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.separatorHeight> property.
             * @deprecated Set the value using <Titanium.UI.ListView.separatorHeight> instead.
             */
            setSeparatorHeight(separatorHeight: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.separatorInsets> property.
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            setSeparatorInsets(separatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.separatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.ListView.separatorStyle> instead.
             */
            setSeparatorStyle(separatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.showSearchBarInNavBar> property.
             * @deprecated Set the value using <Titanium.UI.ListView.showSearchBarInNavBar> instead.
             */
            setShowSearchBarInNavBar(showSearchBarInNavBar: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.showVerticalScrollIndicator> property.
             * @deprecated Set the value using <Titanium.UI.ListView.showVerticalScrollIndicator> instead.
             */
            setShowVerticalScrollIndicator(showVerticalScrollIndicator: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.style> property.
             * @deprecated Set the value using <Titanium.UI.ListView.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.tableSeparatorInsets> property.
             * @deprecated Use [Titanium.UI.ListView.listSeparatorInsets](Titanium.UI.ListView.listSeparatorInsets) instead.
             */
            setTableSeparatorInsets(tableSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.templates> property.
             * @deprecated Set the value using <Titanium.UI.ListView.templates> instead.
             */
            setTemplates(templates: any): void;

            /**
             * Sets the value of the <Titanium.UI.ListView.willScrollOnStatusTap> property.
             * @deprecated Set the value using <Titanium.UI.ListView.willScrollOnStatusTap> instead.
             */
            setWillScrollOnStatusTap(willScrollOnStatusTap: boolean): void;

        }
        /**
         * Base event for class Titanium.UI.MaskedImage
         */
        interface MaskedImageBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.MaskedImage;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface MaskedImage_click_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface MaskedImage_dblclick_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface MaskedImage_doubletap_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface MaskedImage_focus_Event extends MaskedImageBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface MaskedImage_keypressed_Event extends MaskedImageBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface MaskedImage_longclick_Event extends MaskedImageBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface MaskedImage_longpress_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface MaskedImage_pinch_Event extends MaskedImageBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface MaskedImage_postlayout_Event extends MaskedImageBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface MaskedImage_singletap_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface MaskedImage_swipe_Event extends MaskedImageBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface MaskedImage_touchcancel_Event extends MaskedImageBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface MaskedImage_touchend_Event extends MaskedImageBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface MaskedImage_touchmove_Event extends MaskedImageBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface MaskedImage_touchstart_Event extends MaskedImageBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface MaskedImage_twofingertap_Event extends MaskedImageBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface MaskedImageEventMap extends ProxyEventMap {
            click: MaskedImage_click_Event;

            dblclick: MaskedImage_dblclick_Event;

            doubletap: MaskedImage_doubletap_Event;

            focus: MaskedImage_focus_Event;

            keypressed: MaskedImage_keypressed_Event;

            longclick: MaskedImage_longclick_Event;

            longpress: MaskedImage_longpress_Event;

            pinch: MaskedImage_pinch_Event;

            postlayout: MaskedImage_postlayout_Event;

            singletap: MaskedImage_singletap_Event;

            swipe: MaskedImage_swipe_Event;

            touchcancel: MaskedImage_touchcancel_Event;

            touchend: MaskedImage_touchend_Event;

            touchmove: MaskedImage_touchmove_Event;

            touchstart: MaskedImage_touchstart_Event;

            twofingertap: MaskedImage_twofingertap_Event;

        }
        /**
         * A control that displays an image composited with a background image or color.
         */
        class MaskedImage extends Titanium.UI.View {
            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Image drawn as the Foreground image.
             */
            image: string;

            /**
             * Image drawn as the background image.
             */
            mask: string;

            /**
             * Blend mode to use to combine layers.
             */
            mode: number;

            /**
             * Color to combine with the image, as a color name or hex triplet.
             */
            tint: string | Titanium.UI.Color;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof MaskedImageEventMap>(name: K, callback: (this: Titanium.UI.MaskedImage, event: MaskedImageEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof MaskedImageEventMap>(name: K, event?: MaskedImageEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.MaskedImage.children> property.
             * @deprecated Access <Titanium.UI.MaskedImage.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.MaskedImage.image> property.
             * @deprecated Access <Titanium.UI.MaskedImage.image> instead.
             */
            getImage(): string;

            /**
             * Gets the value of the <Titanium.UI.MaskedImage.mask> property.
             * @deprecated Access <Titanium.UI.MaskedImage.mask> instead.
             */
            getMask(): string;

            /**
             * Gets the value of the <Titanium.UI.MaskedImage.mode> property.
             * @deprecated Access <Titanium.UI.MaskedImage.mode> instead.
             */
            getMode(): number;

            /**
             * Gets the value of the <Titanium.UI.MaskedImage.tint> property.
             * @deprecated Access <Titanium.UI.MaskedImage.tint> instead.
             */
            getTint(): string | Titanium.UI.Color;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof MaskedImageEventMap>(name: K, callback: (this: Titanium.UI.MaskedImage, event: MaskedImageEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.MaskedImage.image> property.
             * @deprecated Set the value using <Titanium.UI.MaskedImage.image> instead.
             */
            setImage(image: string): void;

            /**
             * Sets the value of the <Titanium.UI.MaskedImage.mask> property.
             * @deprecated Set the value using <Titanium.UI.MaskedImage.mask> instead.
             */
            setMask(mask: string): void;

            /**
             * Sets the value of the <Titanium.UI.MaskedImage.mode> property.
             * @deprecated Set the value using <Titanium.UI.MaskedImage.mode> instead.
             */
            setMode(mode: number): void;

            /**
             * Sets the value of the <Titanium.UI.MaskedImage.tint> property.
             * @deprecated Set the value using <Titanium.UI.MaskedImage.tint> instead.
             */
            setTint(tint: string | Titanium.UI.Color): void;

        }
        /**
         * The 2D Matrix is an object for holding values for an affine transformation matrix.
         */
        class Matrix2D extends Titanium.Proxy {
            /**
             * The entry at position [1,1] in the matrix.
             */
            a: number;

            /**
             * The entry at position [1,2] in the matrix.
             */
            b: number;

            /**
             * The entry at position [2,1] in the matrix.
             */
            c: number;

            /**
             * The entry at position [2,2] in the matrix.
             */
            d: number;

            /**
             * The entry at position [3,1] in the matrix.
             */
            tx: number;

            /**
             * The entry at position [3,2] in the matrix.
             */
            ty: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.a> property.
             * @deprecated Access <Titanium.UI.Matrix2D.a> instead.
             */
            getA(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.b> property.
             * @deprecated Access <Titanium.UI.Matrix2D.b> instead.
             */
            getB(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.c> property.
             * @deprecated Access <Titanium.UI.Matrix2D.c> instead.
             */
            getC(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.d> property.
             * @deprecated Access <Titanium.UI.Matrix2D.d> instead.
             */
            getD(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.tx> property.
             * @deprecated Access <Titanium.UI.Matrix2D.tx> instead.
             */
            getTx(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix2D.ty> property.
             * @deprecated Access <Titanium.UI.Matrix2D.ty> instead.
             */
            getTy(): number;

            /**
             * Returns a matrix constructed by inverting this matrix.
             */
            invert(): Titanium.UI.Matrix2D;

            /**
             * Returns a matrix constructed by combining two existing matrices.
             */
            multiply(t2: Titanium.UI.Matrix2D): Titanium.UI.Matrix2D;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Returns a matrix constructed by rotating this matrix.
             */
            rotate(angle: number, toAngle?: number): Titanium.UI.Matrix2D;

            /**
             * Returns a `Matrix2D` object that specifies a scaling animation from one scale to another.
             */
            scale(sx: number, sy: number, toSx?: number, toSy?: number): Titanium.UI.Matrix2D;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.a> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.a> instead.
             */
            setA(a: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.b> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.b> instead.
             */
            setB(b: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.c> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.c> instead.
             */
            setC(c: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.d> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.d> instead.
             */
            setD(d: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.tx> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.tx> instead.
             */
            setTx(tx: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix2D.ty> property.
             * @deprecated Set the value using <Titanium.UI.Matrix2D.ty> instead.
             */
            setTy(ty: number): void;

            /**
             * Returns a matrix constructed by applying a translation transform to this matrix.
             */
            translate(tx: number, ty: number): Titanium.UI.Matrix2D;

        }
        /**
         * The 3D Matrix is an object for holding values for a 3D affine transform.
         */
        class Matrix3D extends Titanium.Proxy {
            /**
             * The entry at position [1,1] in the matrix.
             */
            m11: number;

            /**
             * The entry at position [1,2] in the matrix.
             */
            m12: number;

            /**
             * The entry at position [1,3] in the matrix.
             */
            m13: number;

            /**
             * The entry at position [1,4] in the matrix.
             */
            m14: number;

            /**
             * The entry at position [2,1] in the matrix.
             */
            m21: number;

            /**
             * The entry at position [2,2] in the matrix.
             */
            m22: number;

            /**
             * The entry at position [2,3] in the matrix.
             */
            m23: number;

            /**
             * The entry at position [2,4] in the matrix.
             */
            m24: number;

            /**
             * The entry at position [3,1] in the matrix.
             */
            m31: number;

            /**
             * The entry at position [3,2] in the matrix.
             */
            m32: number;

            /**
             * The entry at position [3,3] in the matrix.
             */
            m33: number;

            /**
             * The entry at position [3,4] in the matrix.
             */
            m34: number;

            /**
             * The entry at position [4,1] in the matrix.
             */
            m41: number;

            /**
             * The entry at position [4,2] in the matrix.
             */
            m42: number;

            /**
             * The entry at position [4,3] in the matrix.
             */
            m43: number;

            /**
             * The entry at position [4,4] in the matrix.
             */
            m44: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m11> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m11> instead.
             */
            getM11(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m12> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m12> instead.
             */
            getM12(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m13> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m13> instead.
             */
            getM13(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m14> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m14> instead.
             */
            getM14(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m21> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m21> instead.
             */
            getM21(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m22> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m22> instead.
             */
            getM22(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m23> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m23> instead.
             */
            getM23(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m24> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m24> instead.
             */
            getM24(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m31> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m31> instead.
             */
            getM31(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m32> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m32> instead.
             */
            getM32(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m33> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m33> instead.
             */
            getM33(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m34> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m34> instead.
             */
            getM34(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m41> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m41> instead.
             */
            getM41(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m42> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m42> instead.
             */
            getM42(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m43> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m43> instead.
             */
            getM43(): number;

            /**
             * Gets the value of the <Titanium.UI.Matrix3D.m44> property.
             * @deprecated Access <Titanium.UI.Matrix3D.m44> instead.
             */
            getM44(): number;

            /**
             * Returns a matrix constructed by inverting this matrix.
             */
            invert(): Titanium.UI.Matrix3D;

            /**
             * Returns a matrix constructed by combining two existing matrix.
             */
            multiply(t2: Titanium.UI.Matrix3D): Titanium.UI.Matrix3D;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Returns a matrix constructed by rotating this matrix.
             */
            rotate(angle: number, x: number, y: number, z: number): Titanium.UI.Matrix3D;

            /**
             * Returns a matrix constructed by scaling this matrix.
             */
            scale(sx: number, sy: number, sz: number): Titanium.UI.Matrix3D;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m11> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m11> instead.
             */
            setM11(m11: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m12> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m12> instead.
             */
            setM12(m12: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m13> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m13> instead.
             */
            setM13(m13: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m14> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m14> instead.
             */
            setM14(m14: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m21> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m21> instead.
             */
            setM21(m21: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m22> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m22> instead.
             */
            setM22(m22: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m23> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m23> instead.
             */
            setM23(m23: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m24> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m24> instead.
             */
            setM24(m24: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m31> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m31> instead.
             */
            setM31(m31: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m32> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m32> instead.
             */
            setM32(m32: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m33> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m33> instead.
             */
            setM33(m33: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m34> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m34> instead.
             */
            setM34(m34: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m41> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m41> instead.
             */
            setM41(m41: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m42> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m42> instead.
             */
            setM42(m42: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m43> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m43> instead.
             */
            setM43(m43: number): void;

            /**
             * Sets the value of the <Titanium.UI.Matrix3D.m44> property.
             * @deprecated Set the value using <Titanium.UI.Matrix3D.m44> instead.
             */
            setM44(m44: number): void;

            /**
             * Returns a matrix constructed by translating an existing matrix.
             */
            translate(tx: number, ty: number, tz: number): Titanium.UI.Matrix3D;

        }
        /**
         * Base event for class Titanium.UI.NavigationWindow
         */
        interface NavigationWindowBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.NavigationWindow;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface NavigationWindow_click_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface NavigationWindow_dblclick_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface NavigationWindow_doubletap_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the window gains focus.
         */
        interface NavigationWindow_focus_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface NavigationWindow_keypressed_Event extends NavigationWindowBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface NavigationWindow_longclick_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface NavigationWindow_longpress_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface NavigationWindow_pinch_Event extends NavigationWindowBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface NavigationWindow_postlayout_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface NavigationWindow_singletap_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface NavigationWindow_swipe_Event extends NavigationWindowBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface NavigationWindow_touchcancel_Event extends NavigationWindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface NavigationWindow_touchend_Event extends NavigationWindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface NavigationWindow_touchmove_Event extends NavigationWindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface NavigationWindow_touchstart_Event extends NavigationWindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface NavigationWindow_twofingertap_Event extends NavigationWindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the back button is pressed by the user.
         */
        interface NavigationWindow_androidback_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the Camera button is released.
         */
        interface NavigationWindow_androidcamera_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the Camera button is half-pressed then released.
         */
        interface NavigationWindow_androidfocus_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the Search button is released.
         */
        interface NavigationWindow_androidsearch_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the volume down button is released.
         */
        interface NavigationWindow_androidvoldown_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the volume up button is released.
         */
        interface NavigationWindow_androidvolup_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the window loses focus.
         */
        interface NavigationWindow_blur_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the window is closed.
         */
        interface NavigationWindow_close_Event extends NavigationWindowBaseEvent {
        }
        /**
         * Fired when the window is opened.
         */
        interface NavigationWindow_open_Event extends NavigationWindowBaseEvent {
        }
        interface NavigationWindowEventMap extends ProxyEventMap {
            androidback: NavigationWindow_androidback_Event;

            androidcamera: NavigationWindow_androidcamera_Event;

            androidfocus: NavigationWindow_androidfocus_Event;

            androidsearch: NavigationWindow_androidsearch_Event;

            androidvoldown: NavigationWindow_androidvoldown_Event;

            androidvolup: NavigationWindow_androidvolup_Event;

            blur: NavigationWindow_blur_Event;

            click: NavigationWindow_click_Event;

            close: NavigationWindow_close_Event;

            dblclick: NavigationWindow_dblclick_Event;

            doubletap: NavigationWindow_doubletap_Event;

            focus: NavigationWindow_focus_Event;

            keypressed: NavigationWindow_keypressed_Event;

            longclick: NavigationWindow_longclick_Event;

            longpress: NavigationWindow_longpress_Event;

            open: NavigationWindow_open_Event;

            pinch: NavigationWindow_pinch_Event;

            postlayout: NavigationWindow_postlayout_Event;

            singletap: NavigationWindow_singletap_Event;

            swipe: NavigationWindow_swipe_Event;

            touchcancel: NavigationWindow_touchcancel_Event;

            touchend: NavigationWindow_touchend_Event;

            touchmove: NavigationWindow_touchmove_Event;

            touchstart: NavigationWindow_touchstart_Event;

            twofingertap: NavigationWindow_twofingertap_Event;

        }
        /**
         * A `NavigationWindow` implements a specialized view that manages the navigation of hierarchical
         * content.
         */
        class NavigationWindow extends Titanium.UI.Window {
            /**
             * Title for the back button. This is only valid when the window is a child of a tab.
             */
            backButtonTitle: never;

            /**
             * The image to show as the back button. This is only valid when the window is a child of a tab.
             */
            backButtonTitleImage: never;

            /**
             * Background color for the nav bar, as a color name or hex triplet.
             */
            barColor: never;

            /**
             * Background image for the nav bar, specified as a URL to a local image.
             */
            barImage: never;

            /**
             * Set this to true to hide the shadow image of the navigation bar.
             */
            hideShadow: never;

            /**
             * View to show in the left nav bar area.
             */
            leftNavButton: never;

            /**
             * Hides the navigation bar (`true`) or shows the navigation bar (`false`).
             */
            navBarHidden: never;

            /**
             * The tintColor to apply to the navigation bar.
             */
            navTintColor: never;

            /**
             * View to show in the right nav bar area.
             */
            rightNavButton: never;

            /**
             * Shadow image for the navigation bar, specified as a URL to a local image..
             */
            shadowImage: never;

            /**
             * Boolean value indicating if the user should be able to close a window using a swipe gesture.
             */
            swipeToClose: never;

            /**
             * Boolean value indicating if the tab bar should be hidden.
             */
            tabBarHidden: never;

            /**
             * Title of the window.
             */
            title: never;

            /**
             * View to show in the title area of the nav bar.
             */
            titleControl: never;

            /**
             * Image to show in the title area of the nav bar, specified as a local file path or URL.
             */
            titleImage: never;

            /**
             * Title prompt for the window.
             */
            titlePrompt: never;

            /**
             * Key identifying a string from the locale file to use for the window title.
             */
            titleid: never;

            /**
             * Key identifying a string from the locale file to use for the window title prompt.
             */
            titlepromptid: never;

            /**
             * Array of button objects to show in the window's toolbar.
             */
            toolbar: never;

            /**
             * Use a transition animation when opening or closing windows in a
             * <Titanium.UI.NavigationWindow> or <Titanium.UI.Tab>.
             */
            transitionAnimation: never;

            /**
             * Boolean value indicating if the nav bar is translucent.
             */
            translucent: never;

            /**
             * Loads a JavaScript file from a local URL.
             * @deprecated
             */
            url: never;

            /**
             * Window to add to this navigation window.
             */
            window: Titanium.UI.Window;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof NavigationWindowEventMap>(name: K, callback: (this: Titanium.UI.NavigationWindow, event: NavigationWindowEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Closes a window and removes it from the navigation window.
             */
            closeWindow(window: Titanium.UI.Window, options: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof NavigationWindowEventMap>(name: K, event?: NavigationWindowEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.backButtonTitle> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.backButtonTitle> instead.
             */
            getBackButtonTitle: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.backButtonTitleImage> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.backButtonTitleImage> instead.
             */
            getBackButtonTitleImage: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.barColor> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.barColor> instead.
             */
            getBarColor: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.barImage> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.barImage> instead.
             */
            getBarImage: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.hideShadow> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.hideShadow> instead.
             */
            getHideShadow: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.leftNavButton> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.leftNavButton> instead.
             */
            getLeftNavButton: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.navBarHidden> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.navBarHidden> instead.
             */
            getNavBarHidden: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.navTintColor> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.navTintColor> instead.
             */
            getNavTintColor: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.rightNavButton> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.rightNavButton> instead.
             */
            getRightNavButton: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.shadowImage> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.shadowImage> instead.
             */
            getShadowImage: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.swipeToClose> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.swipeToClose> instead.
             */
            getSwipeToClose: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.tabBarHidden> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.tabBarHidden> instead.
             */
            getTabBarHidden: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.title> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.title> instead.
             */
            getTitle: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.titleControl> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.titleControl> instead.
             */
            getTitleControl: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.titleImage> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.titleImage> instead.
             */
            getTitleImage: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.titlePrompt> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.titlePrompt> instead.
             */
            getTitlePrompt: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.titleid> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.titleid> instead.
             */
            getTitleid: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.titlepromptid> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.titlepromptid> instead.
             */
            getTitlepromptid: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.toolbar> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.toolbar> instead.
             */
            getToolbar: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.transitionAnimation> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.transitionAnimation> instead.
             */
            getTransitionAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.translucent> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.translucent> instead.
             */
            getTranslucent: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.url> property.
             * @deprecated
             */
            getUrl: never;

            /**
             * Gets the value of the <Titanium.UI.NavigationWindow.window> property.
             * @deprecated Access <Titanium.UI.NavigationWindow.window> instead.
             */
            getWindow(): Titanium.UI.Window;

            /**
             * Hides the tab bar. Must be called before opening the window.
             */
            hideTabBar: never;

            /**
             * Opens a window within the navigation window.
             */
            openWindow(window: Titanium.UI.Window, options?: AnimatedOptions): void;

            /**
             * Closes all windows that are currently opened inside the navigation window.
             */
            popToRootWindow(options?: AnimatedOptions): void;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof NavigationWindowEventMap>(name: K, callback: (this: Titanium.UI.NavigationWindow, event: NavigationWindowEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.backButtonTitle> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.backButtonTitle> instead.
             */
            setBackButtonTitle: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.backButtonTitleImage> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.backButtonTitleImage> instead.
             */
            setBackButtonTitleImage: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.barColor> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.barColor> instead.
             */
            setBarColor: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.barImage> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.barImage> instead.
             */
            setBarImage: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.hideShadow> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.hideShadow> instead.
             */
            setHideShadow: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.leftNavButton> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.leftNavButton> instead.
             */
            setLeftNavButton: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.navBarHidden> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.navBarHidden> instead.
             */
            setNavBarHidden: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.navTintColor> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.navTintColor> instead.
             */
            setNavTintColor: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.rightNavButton> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.rightNavButton> instead.
             */
            setRightNavButton: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.shadowImage> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.shadowImage> instead.
             */
            setShadowImage: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.swipeToClose> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.swipeToClose> instead.
             */
            setSwipeToClose: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.tabBarHidden> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.tabBarHidden> instead.
             */
            setTabBarHidden: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.title> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.title> instead.
             */
            setTitle: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.titleControl> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.titleControl> instead.
             */
            setTitleControl: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.titleImage> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.titleImage> instead.
             */
            setTitleImage: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.titlePrompt> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.titlePrompt> instead.
             */
            setTitlePrompt: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.titleid> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.titleid> instead.
             */
            setTitleid: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.titlepromptid> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.titlepromptid> instead.
             */
            setTitlepromptid: never;

            /**
             * Sets the array of items to show in the window's toolbar.
             */
            setToolbar: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.transitionAnimation> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.transitionAnimation> instead.
             */
            setTransitionAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.translucent> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.translucent> instead.
             */
            setTranslucent: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.url> property.
             * @deprecated
             */
            setUrl: never;

            /**
             * Sets the value of the <Titanium.UI.NavigationWindow.window> property.
             * @deprecated Set the value using <Titanium.UI.NavigationWindow.window> instead.
             */
            setWindow(window: Titanium.UI.Window): void;

        }
        /**
         * A toast notification.
         */
        class Notification extends Titanium.Proxy {
            /**
             * Determines how long the notification stays on screen.
             */
            duration: number;

            /**
             * Determines the location at which the notification should appear on the screen.
             */
            gravity: number;

            /**
             * Horizontal placement of the notification, *as a fraction of the screen width*.
             */
            horizontalMargin: number;

            /**
             * Notification text to display.
             */
            message: string;

            /**
             * Vertical placement of the notifcation, *as a fraction of the screen height*.
             */
            verticalMargin: number;

            /**
             * X offset from the default position, in pixels.
             */
            xOffset: number;

            /**
             * Y offset from the default position, in pixels.
             */
            yOffset: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Notification.duration> property.
             * @deprecated Access <Titanium.UI.Notification.duration> instead.
             */
            getDuration(): number;

            /**
             * Gets the value of the <Titanium.UI.Notification.gravity> property.
             * @deprecated Access <Titanium.UI.Notification.gravity> instead.
             */
            getGravity(): number;

            /**
             * Gets the value of the <Titanium.UI.Notification.horizontalMargin> property.
             * @deprecated Access <Titanium.UI.Notification.horizontalMargin> instead.
             */
            getHorizontalMargin(): number;

            /**
             * Gets the value of the <Titanium.UI.Notification.message> property.
             * @deprecated Access <Titanium.UI.Notification.message> instead.
             */
            getMessage(): string;

            /**
             * Gets the value of the <Titanium.UI.Notification.verticalMargin> property.
             * @deprecated Access <Titanium.UI.Notification.verticalMargin> instead.
             */
            getVerticalMargin(): number;

            /**
             * Gets the value of the <Titanium.UI.Notification.xOffset> property.
             * @deprecated Access <Titanium.UI.Notification.xOffset> instead.
             */
            getXOffset(): number;

            /**
             * Gets the value of the <Titanium.UI.Notification.yOffset> property.
             * @deprecated Access <Titanium.UI.Notification.yOffset> instead.
             */
            getYOffset(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.duration> property.
             * @deprecated Set the value using <Titanium.UI.Notification.duration> instead.
             */
            setDuration(duration: number): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.gravity> property.
             * @deprecated Set the value using <Titanium.UI.Notification.gravity> instead.
             */
            setGravity(gravity: number): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.horizontalMargin> property.
             * @deprecated Set the value using <Titanium.UI.Notification.horizontalMargin> instead.
             */
            setHorizontalMargin(horizontalMargin: number): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.message> property.
             * @deprecated Set the value using <Titanium.UI.Notification.message> instead.
             */
            setMessage(message: string): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.verticalMargin> property.
             * @deprecated Set the value using <Titanium.UI.Notification.verticalMargin> instead.
             */
            setVerticalMargin(verticalMargin: number): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.xOffset> property.
             * @deprecated Set the value using <Titanium.UI.Notification.xOffset> instead.
             */
            setXOffset(xOffset: number): void;

            /**
             * Sets the value of the <Titanium.UI.Notification.yOffset> property.
             * @deprecated Set the value using <Titanium.UI.Notification.yOffset> instead.
             */
            setYOffset(yOffset: number): void;

            /**
             * Show the notification.
             */
            show(): void;

        }
        /**
         * Base event for class Titanium.UI.OptionDialog
         */
        interface OptionDialogBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.OptionDialog;

        }
        /**
         * Fired when an option of this dialog is clicked or, under certain circumstances, when this
         * dialog is dismissed.
         */
        interface OptionDialog_click_Event extends OptionDialogBaseEvent {
            /**
             * Indicates whether the index returned by the `index` property relates to a button rather
             * than an option item.
             */
            button: boolean;

            /**
             * Boolean type on Android; Number on iOS.
             * On Android, indicates whether the cancel button was clicked, in which
             * case returns `true`.
             * On iOS, the value of the [cancel](Titanium.UI.OptionDialog.cancel)
             * property is returned, if defined, or `-1` otherwise.
             */
            cancel: boolean | number;

            /**
             * Index of the destructive option if defined or `-1` otherwise.
             */
            destructive: number;

            /**
             * Index of the option that was pressed. See description for result of the dialog being
             * dismissed in some other way.
             */
            index: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface OptionDialog_dblclick_Event extends OptionDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface OptionDialog_doubletap_Event extends OptionDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface OptionDialog_focus_Event extends OptionDialogBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface OptionDialog_keypressed_Event extends OptionDialogBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface OptionDialog_longclick_Event extends OptionDialogBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface OptionDialog_longpress_Event extends OptionDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface OptionDialog_pinch_Event extends OptionDialogBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface OptionDialog_postlayout_Event extends OptionDialogBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface OptionDialog_singletap_Event extends OptionDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface OptionDialog_swipe_Event extends OptionDialogBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface OptionDialog_touchcancel_Event extends OptionDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface OptionDialog_touchend_Event extends OptionDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface OptionDialog_touchmove_Event extends OptionDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface OptionDialog_touchstart_Event extends OptionDialogBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface OptionDialog_twofingertap_Event extends OptionDialogBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface OptionDialogEventMap extends ProxyEventMap {
            click: OptionDialog_click_Event;

            dblclick: OptionDialog_dblclick_Event;

            doubletap: OptionDialog_doubletap_Event;

            focus: OptionDialog_focus_Event;

            keypressed: OptionDialog_keypressed_Event;

            longclick: OptionDialog_longclick_Event;

            longpress: OptionDialog_longpress_Event;

            pinch: OptionDialog_pinch_Event;

            postlayout: OptionDialog_postlayout_Event;

            singletap: OptionDialog_singletap_Event;

            swipe: OptionDialog_swipe_Event;

            touchcancel: OptionDialog_touchcancel_Event;

            touchend: OptionDialog_touchend_Event;

            touchmove: OptionDialog_touchmove_Event;

            touchstart: OptionDialog_touchstart_Event;

            twofingertap: OptionDialog_twofingertap_Event;

        }
        /**
         * An option dialog is a modal view that includes a message and one or more option items positioned
         * in the middle of the display on Android and at the bottom edge on iOS. On Android, buttons may
         * be added below the options.
         */
        class OptionDialog extends Titanium.UI.View {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * View to load inside the message area, to create a custom layout.
             */
            androidView: Titanium.UI.View;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * List of button names.
             */
            buttonNames: string[];

            /**
             * Index to define the cancel option.
             */
            cancel: number;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * View's clipping behavior.
             */
            clipMode: never;

            /**
             * Index to define the destructive option, indicated by a visual cue when rendered.
             */
            destructive: number;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * View's left position, in platform-specific units.
             */
            left: never;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * Boolean value indicating if the option dialog should have an opaque background.
             */
            opaquebackground: boolean;

            /**
             * List of option names to display in the dialog.
             */
            options: string[];

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: never;

            /**
             * Boolean value indicating if the option dialog should only be cancelled by user gesture or by hide method.
             */
            persistent: boolean;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * View's right position, in platform-specific units.
             */
            right: never;

            /**
             * Defines the default selected option. Since `8.1.0`, if not defined or -1 it will show a normal list instead of radio buttons.
             */
            selectedIndex: number;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * Title of the dialog.
             */
            title: string;

            /**
             * Key identifying a string in the locale file to use for the title text.
             */
            titleid: string;

            /**
             * The view's top position.
             */
            top: never;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: never;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: never;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof OptionDialogEventMap>(name: K, callback: (this: Titanium.UI.OptionDialog, event: OptionDialogEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof OptionDialogEventMap>(name: K, event?: OptionDialogEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.OptionDialog.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.OptionDialog.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.OptionDialog.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.OptionDialog.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.anchorPoint> property.
             * @deprecated Access <Titanium.UI.OptionDialog.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.androidView> property.
             * @deprecated Access <Titanium.UI.OptionDialog.androidView> instead.
             */
            getAndroidView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.animatedCenter> property.
             * @deprecated Access <Titanium.UI.OptionDialog.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundImage> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.OptionDialog.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.borderColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.borderRadius> property.
             * @deprecated Access <Titanium.UI.OptionDialog.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.borderWidth> property.
             * @deprecated Access <Titanium.UI.OptionDialog.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.bottom> property.
             * @deprecated Access <Titanium.UI.OptionDialog.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.buttonNames> property.
             * @deprecated Access <Titanium.UI.OptionDialog.buttonNames> instead.
             */
            getButtonNames(): string[];

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.cancel> property.
             * @deprecated Access <Titanium.UI.OptionDialog.cancel> instead.
             */
            getCancel(): number;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.center> property.
             * @deprecated Access <Titanium.UI.OptionDialog.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.children> property.
             * @deprecated Access <Titanium.UI.OptionDialog.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.clipMode> property.
             * @deprecated Access <Titanium.UI.OptionDialog.clipMode> instead.
             */
            getClipMode: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.destructive> property.
             * @deprecated Access <Titanium.UI.OptionDialog.destructive> instead.
             */
            getDestructive(): number;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.focusable> property.
             * @deprecated Access <Titanium.UI.OptionDialog.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.height> property.
             * @deprecated Access <Titanium.UI.OptionDialog.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.OptionDialog.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.OptionDialog.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.layout> property.
             * @deprecated Access <Titanium.UI.OptionDialog.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.left> property.
             * @deprecated Access <Titanium.UI.OptionDialog.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.opacity> property.
             * @deprecated Access <Titanium.UI.OptionDialog.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.opaquebackground> property.
             * @deprecated Access <Titanium.UI.OptionDialog.opaquebackground> instead.
             */
            getOpaquebackground(): boolean;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.options> property.
             * @deprecated Access <Titanium.UI.OptionDialog.options> instead.
             */
            getOptions(): string[];

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.OptionDialog.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.persistent> property.
             * @deprecated Access <Titanium.UI.OptionDialog.persistent> instead.
             */
            getPersistent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.pullBackgroundColor> instead.
             */
            getPullBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.rect> property.
             * @deprecated Access <Titanium.UI.OptionDialog.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.right> property.
             * @deprecated Access <Titanium.UI.OptionDialog.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.selectedIndex> property.
             * @deprecated Access <Titanium.UI.OptionDialog.selectedIndex> instead.
             */
            getSelectedIndex(): number;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.size> property.
             * @deprecated Access <Titanium.UI.OptionDialog.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.OptionDialog.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.title> property.
             * @deprecated Access <Titanium.UI.OptionDialog.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.titleid> property.
             * @deprecated Access <Titanium.UI.OptionDialog.titleid> instead.
             */
            getTitleid(): string;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.top> property.
             * @deprecated Access <Titanium.UI.OptionDialog.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.touchEnabled> property.
             * @deprecated Access <Titanium.UI.OptionDialog.touchEnabled> instead.
             */
            getTouchEnabled: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.transform> property.
             * @deprecated Access <Titanium.UI.OptionDialog.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.OptionDialog.viewShadowColor> instead.
             */
            getViewShadowColor: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.OptionDialog.viewShadowOffset> instead.
             */
            getViewShadowOffset: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.OptionDialog.viewShadowRadius> instead.
             */
            getViewShadowRadius: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.visible> property.
             * @deprecated Access <Titanium.UI.OptionDialog.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.width> property.
             * @deprecated Access <Titanium.UI.OptionDialog.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.OptionDialog.zIndex> property.
             * @deprecated Access <Titanium.UI.OptionDialog.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Hides this dialog.
             */
            hide(params?: hideParams): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof OptionDialogEventMap>(name: K, callback: (this: Titanium.UI.OptionDialog, event: OptionDialogEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.androidView> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.androidView> instead.
             */
            setAndroidView(androidView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.bottom> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.buttonNames> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.buttonNames> instead.
             */
            setButtonNames(buttonNames: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.cancel> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.cancel> instead.
             */
            setCancel(cancel: number): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.center> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.clipMode> instead.
             */
            setClipMode: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.destructive> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.destructive> instead.
             */
            setDestructive(destructive: number): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.focusable> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.height> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.layout> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.left> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.opacity> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.opaquebackground> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.opaquebackground> instead.
             */
            setOpaquebackground(opaquebackground: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.options> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.options> instead.
             */
            setOptions(options: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.persistent> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.persistent> instead.
             */
            setPersistent(persistent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.pullBackgroundColor> instead.
             */
            setPullBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.right> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.selectedIndex> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.selectedIndex> instead.
             */
            setSelectedIndex(selectedIndex: number): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.title> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.titleid> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.titleid> instead.
             */
            setTitleid(titleid: string): void;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.top> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.touchEnabled> instead.
             */
            setTouchEnabled: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.transform> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.viewShadowColor> instead.
             */
            setViewShadowColor: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.viewShadowOffset> instead.
             */
            setViewShadowOffset: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.viewShadowRadius> instead.
             */
            setViewShadowRadius: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.visible> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.width> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.width> instead.
             */
            setWidth: never;

            /**
             * Sets the value of the <Titanium.UI.OptionDialog.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.OptionDialog.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Shows this dialog.
             */
            show(params?: showParams): void;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage: never;

        }
        /**
         * Base event for class Titanium.UI.Picker
         */
        interface PickerBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Picker;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Picker_click_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Picker_dblclick_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Picker_doubletap_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Picker_focus_Event extends PickerBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Picker_keypressed_Event extends PickerBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Picker_longclick_Event extends PickerBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Picker_longpress_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Picker_pinch_Event extends PickerBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Picker_postlayout_Event extends PickerBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Picker_singletap_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Picker_swipe_Event extends PickerBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Picker_touchcancel_Event extends PickerBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Picker_touchend_Event extends PickerBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Picker_touchmove_Event extends PickerBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Picker_touchstart_Event extends PickerBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Picker_twofingertap_Event extends PickerBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the value of any column's row is changed.
         */
        interface Picker_change_Event extends PickerBaseEvent {
            /**
             * The column object. On iOS, only applicable to <Titanium.UI.PICKER_TYPE_PLAIN>
             * picker types.
             */
            column: Titanium.UI.PickerColumn;

            /**
             * Selected column index. On iOS, only applicable to <Titanium.UI.PICKER_TYPE_PLAIN>
             * picker types.
             */
            columnIndex: number;

            /**
             * The selected duration in milliseconds. Applicable to <Titanium.UI.PICKER_TYPE_COUNT_DOWN_TIMER> picker types.
             */
            countDownDuration: number;

            /**
             * The row object. On iOS, only applicable to <Titanium.UI.PICKER_TYPE_PLAIN> picker types.
             */
            row: Titanium.UI.PickerRow;

            /**
             * Selected row index. On iOS, only applicable to <Titanium.UI.PICKER_TYPE_PLAIN>
             * picker types.
             */
            rowIndex: number;

            /**
             * Array of selected values, one element per column in the picker. Applicable to
             * <Titanium.UI.PICKER_TYPE_PLAIN> picker types.
             */
            selectedValue: string[];

            /**
             * The selected value. Applicable to date/time pickers only. This property is read-only
             * on Android.
             */
            value: string;

        }
        interface PickerEventMap extends ProxyEventMap {
            change: Picker_change_Event;

            click: Picker_click_Event;

            dblclick: Picker_dblclick_Event;

            doubletap: Picker_doubletap_Event;

            focus: Picker_focus_Event;

            keypressed: Picker_keypressed_Event;

            longclick: Picker_longclick_Event;

            longpress: Picker_longpress_Event;

            pinch: Picker_pinch_Event;

            postlayout: Picker_postlayout_Event;

            singletap: Picker_singletap_Event;

            swipe: Picker_swipe_Event;

            touchcancel: Picker_touchcancel_Event;

            touchend: Picker_touchend_Event;

            touchmove: Picker_touchmove_Event;

            touchstart: Picker_touchstart_Event;

            twofingertap: Picker_twofingertap_Event;

        }
        /**
         * A control used to select one or more fixed values.
         */
        class Picker extends Titanium.UI.View {
            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Background color of the picker, as a color name or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Determines whether the calenderView is visible.
             */
            calendarViewShown: boolean;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Columns used for this picker, as an array of <Titanium.UI.PickerColumn> objects.
             */
            columns: Titanium.UI.PickerColumn[];

            /**
             * Duration in milliseconds used for a Countdown Timer picker.
             */
            countDownDuration: number;

            /**
             * Request a style if the picker is a date picker (`PICKER_TYPE_DATE`).
             */
            datePickerStyle: number;

            /**
             * Sets the text color of date- and time-pickers.
             */
            dateTimeColor: string | Titanium.UI.Color;

            /**
             * Font to use for text.
             */
            font: Font;

            /**
             * Determines whether the Time pickers display in 24-hour or 12-hour clock format.
             */
            format24: boolean;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * Locale used when displaying Date and Time picker values.
             */
            locale: string;

            /**
             * Maximum date displayed when a Date picker is in use.
             */
            maxDate: Date;

            /**
             * Minimum date displayed when a Date picker is in use.
             */
            minDate: Date;

            /**
             * Interval in minutes displayed when one of the Time types of pickers is in use.
             */
            minuteInterval: number;

            /**
             * Creates a native Android control for creating a Time Spinner with Type `Ti.UI.PICKER_TYPE_TIME`.
             * This is invoked rather than the default native "dropdown" style.
             */
            nativeSpinner: boolean;

            /**
             * Determines whether the visual selection indicator is shown.
             */
            selectionIndicator: boolean;

            /**
             * Determines whether calling the method `setSelectedRow` opens when called
             */
            selectionOpens: boolean;

            /**
             * The view's tintColor
             */
            tintColor: never;

            /**
             * Determines the type of picker displayed
             */
            type: number;

            /**
             * Determines whether the non-native Android control, with a spinning wheel that looks and
             * behaves like the iOS picker, is invoked rather than the default native "dropdown" style.
             * @deprecated This property is deprecated. Please use the default native "dropdown" style.
             */
            useSpinner: boolean;

            /**
             * Date and time value for Date and Time pickers.
             */
            value: Date;

            /**
             * Number of visible rows to display. This is only applicable to a plain picker and when the
             * `useSpinner` is `true`.
             */
            visibleItems: number;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds rows or columns to the picker.
             */
            add(data: Titanium.UI.PickerRow[] | Titanium.UI.PickerRow | Titanium.UI.PickerColumn[] | Titanium.UI.PickerColumn): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof PickerEventMap>(name: K, callback: (this: Titanium.UI.Picker, event: PickerEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof PickerEventMap>(name: K, event?: PickerEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Picker.anchorPoint> property.
             * @deprecated Access <Titanium.UI.Picker.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundColor> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundImage> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.Picker.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.calendarViewShown> property.
             * @deprecated Access <Titanium.UI.Picker.calendarViewShown> instead.
             */
            getCalendarViewShown(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Picker.center> property.
             * @deprecated Access <Titanium.UI.Picker.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.children> property.
             * @deprecated Access <Titanium.UI.Picker.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.columns> property.
             * @deprecated Access <Titanium.UI.Picker.columns> instead.
             */
            getColumns(): Titanium.UI.PickerColumn[];

            /**
             * Gets the value of the <Titanium.UI.Picker.countDownDuration> property.
             * @deprecated Access <Titanium.UI.Picker.countDownDuration> instead.
             */
            getCountDownDuration(): number;

            /**
             * Gets the value of the <Titanium.UI.Picker.datePickerStyle> property.
             * @deprecated Access <Titanium.UI.Picker.datePickerStyle> instead.
             */
            getDatePickerStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.Picker.dateTimeColor> property.
             * @deprecated Access <Titanium.UI.Picker.dateTimeColor> instead.
             */
            getDateTimeColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Picker.font> property.
             * @deprecated Access <Titanium.UI.Picker.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.Picker.format24> property.
             * @deprecated Access <Titanium.UI.Picker.format24> instead.
             */
            getFormat24(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Picker.layout> property.
             * @deprecated Access <Titanium.UI.Picker.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.locale> property.
             * @deprecated Access <Titanium.UI.Picker.locale> instead.
             */
            getLocale(): string;

            /**
             * Gets the value of the <Titanium.UI.Picker.maxDate> property.
             * @deprecated Access <Titanium.UI.Picker.maxDate> instead.
             */
            getMaxDate(): Date;

            /**
             * Gets the value of the <Titanium.UI.Picker.minDate> property.
             * @deprecated Access <Titanium.UI.Picker.minDate> instead.
             */
            getMinDate(): Date;

            /**
             * Gets the value of the <Titanium.UI.Picker.minuteInterval> property.
             * @deprecated Access <Titanium.UI.Picker.minuteInterval> instead.
             */
            getMinuteInterval(): number;

            /**
             * Gets the value of the <Titanium.UI.Picker.nativeSpinner> property.
             * @deprecated Access <Titanium.UI.Picker.nativeSpinner> instead.
             */
            getNativeSpinner(): boolean;

            /**
             * Gets the selected row for a column, or `null` if none exists.
             */
            getSelectedRow(index: number): Titanium.UI.PickerRow;

            /**
             * Gets the value of the <Titanium.UI.Picker.selectionIndicator> property.
             * @deprecated Access <Titanium.UI.Picker.selectionIndicator> instead.
             */
            getSelectionIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Picker.selectionOpens> property.
             * @deprecated Access <Titanium.UI.Picker.selectionOpens> instead.
             */
            getSelectionOpens(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Picker.tintColor> property.
             * @deprecated Access <Titanium.UI.Picker.tintColor> instead.
             */
            getTintColor: never;

            /**
             * Gets the value of the <Titanium.UI.Picker.type> property.
             * @deprecated Access <Titanium.UI.Picker.type> instead.
             */
            getType(): number;

            /**
             * Gets the value of the <Titanium.UI.Picker.useSpinner> property.
             * @deprecated This property is deprecated. Please use the default native "dropdown" style.
             */
            getUseSpinner(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Picker.value> property.
             * @deprecated Access <Titanium.UI.Picker.value> instead.
             */
            getValue(): Date;

            /**
             * Gets the value of the <Titanium.UI.Picker.visibleItems> property.
             * @deprecated Access <Titanium.UI.Picker.visibleItems> instead.
             */
            getVisibleItems(): number;

            /**
             * Gets the value of the <Titanium.UI.Picker.zIndex> property.
             * @deprecated Access <Titanium.UI.Picker.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Repopulates values for a column.
             */
            reloadColumn(column: Titanium.UI.PickerColumn): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof PickerEventMap>(name: K, callback: (this: Titanium.UI.Picker, event: PickerEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.Picker.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.Picker.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.calendarViewShown> property.
             * @deprecated Set the value using <Titanium.UI.Picker.calendarViewShown> instead.
             */
            setCalendarViewShown(calendarViewShown: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.center> property.
             * @deprecated Set the value using <Titanium.UI.Picker.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.columns> property.
             * @deprecated Set the value using <Titanium.UI.Picker.columns> instead.
             */
            setColumns(columns: ReadonlyArray<Titanium.UI.PickerColumn>): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.countDownDuration> property.
             * @deprecated Set the value using <Titanium.UI.Picker.countDownDuration> instead.
             */
            setCountDownDuration(countDownDuration: number): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.datePickerStyle> property.
             * @deprecated Set the value using <Titanium.UI.Picker.datePickerStyle> instead.
             */
            setDatePickerStyle(datePickerStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.dateTimeColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.dateTimeColor> instead.
             */
            setDateTimeColor(dateTimeColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.font> property.
             * @deprecated Set the value using <Titanium.UI.Picker.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.format24> property.
             * @deprecated Set the value using <Titanium.UI.Picker.format24> instead.
             */
            setFormat24(format24: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.layout> property.
             * @deprecated Set the value using <Titanium.UI.Picker.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.locale> property.
             * @deprecated Set the value using <Titanium.UI.Picker.locale> instead.
             */
            setLocale(locale: string): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.maxDate> property.
             * @deprecated Set the value using <Titanium.UI.Picker.maxDate> instead.
             */
            setMaxDate(maxDate: Date): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.minDate> property.
             * @deprecated Set the value using <Titanium.UI.Picker.minDate> instead.
             */
            setMinDate(minDate: Date): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.minuteInterval> property.
             * @deprecated Set the value using <Titanium.UI.Picker.minuteInterval> instead.
             */
            setMinuteInterval(minuteInterval: number): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.nativeSpinner> property.
             * @deprecated Set the value using <Titanium.UI.Picker.nativeSpinner> instead.
             */
            setNativeSpinner(nativeSpinner: boolean): void;

            /**
             * Selects a column's row.
             */
            setSelectedRow(column: number, row: number, animated?: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.selectionIndicator> property.
             * @deprecated Set the value using <Titanium.UI.Picker.selectionIndicator> instead.
             */
            setSelectionIndicator(selectionIndicator: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.selectionOpens> property.
             * @deprecated Set the value using <Titanium.UI.Picker.selectionOpens> instead.
             */
            setSelectionOpens(selectionOpens: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.Picker.tintColor> instead.
             */
            setTintColor: never;

            /**
             * Sets the value of the <Titanium.UI.Picker.type> property.
             * @deprecated Set the value using <Titanium.UI.Picker.type> instead.
             */
            setType(type: number): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.useSpinner> property.
             * @deprecated This property is deprecated. Please use the default native "dropdown" style.
             */
            setUseSpinner(useSpinner: boolean): void;

            /**
             * Sets the date and time value property for Date pickers.
             */
            setValue(date: any, suppressEvent: boolean): Titanium.UI.PickerRow;

            /**
             * Sets the value of the <Titanium.UI.Picker.visibleItems> property.
             * @deprecated Set the value using <Titanium.UI.Picker.visibleItems> instead.
             */
            setVisibleItems(visibleItems: number): void;

            /**
             * Sets the value of the <Titanium.UI.Picker.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.Picker.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Shows Date picker as a modal dialog.
             */
            showDatePickerDialog(dictObj: any): void;

            /**
             * Shows Time picker as a modal dialog.
             */
            showTimePickerDialog(dictObj: any): void;

        }
        /**
         * Base event for class Titanium.UI.PickerColumn
         */
        interface PickerColumnBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.PickerColumn;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface PickerColumn_click_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface PickerColumn_dblclick_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface PickerColumn_doubletap_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface PickerColumn_focus_Event extends PickerColumnBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface PickerColumn_keypressed_Event extends PickerColumnBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface PickerColumn_longclick_Event extends PickerColumnBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface PickerColumn_longpress_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface PickerColumn_pinch_Event extends PickerColumnBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface PickerColumn_postlayout_Event extends PickerColumnBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface PickerColumn_singletap_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface PickerColumn_swipe_Event extends PickerColumnBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface PickerColumn_touchcancel_Event extends PickerColumnBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface PickerColumn_touchend_Event extends PickerColumnBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface PickerColumn_touchmove_Event extends PickerColumnBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface PickerColumn_touchstart_Event extends PickerColumnBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface PickerColumn_twofingertap_Event extends PickerColumnBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface PickerColumnEventMap extends ProxyEventMap {
            click: PickerColumn_click_Event;

            dblclick: PickerColumn_dblclick_Event;

            doubletap: PickerColumn_doubletap_Event;

            focus: PickerColumn_focus_Event;

            keypressed: PickerColumn_keypressed_Event;

            longclick: PickerColumn_longclick_Event;

            longpress: PickerColumn_longpress_Event;

            pinch: PickerColumn_pinch_Event;

            postlayout: PickerColumn_postlayout_Event;

            singletap: PickerColumn_singletap_Event;

            swipe: PickerColumn_swipe_Event;

            touchcancel: PickerColumn_touchcancel_Event;

            touchend: PickerColumn_touchend_Event;

            touchmove: PickerColumn_touchmove_Event;

            touchstart: PickerColumn_touchstart_Event;

            twofingertap: PickerColumn_twofingertap_Event;

        }
        /**
         * A picker column, representing a selectable group of items in a <Titanium.UI.Picker>.
         */
        class PickerColumn extends Titanium.UI.View {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * View's clipping behavior.
             */
            clipMode: never;

            /**
             * Base elevation of the view relative to its parent in pixels.
             */
            elevation: never;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * Font to use for text.
             */
            font: Font;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Sets the behavior when hiding an object to release or keep the free space
             */
            hiddenBehavior: never;

            /**
             * Adds a horizontal parallax effect to the view
             */
            horizontalMotionEffect: never;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * View's left position, in platform-specific units.
             */
            left: never;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: never;

            /**
             * The preview context used in the 3D-Touch feature "Peek and Pop".
             */
            previewContext: never;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * View's right position, in platform-specific units.
             */
            right: never;

            /**
             * Clockwise 2D rotation of the view in degrees.
             */
            rotation: never;

            /**
             * Clockwise rotation of the view in degrees (x-axis).
             */
            rotationX: never;

            /**
             * Clockwise rotation of the view in degrees (y-axis).
             */
            rotationY: never;

            /**
             * Number of rows in this column.
             */
            readonly rowCount: number;

            /**
             * Rows of this column.
             */
            readonly rows: Titanium.UI.PickerRow[];

            /**
             * Scaling of the view in x-axis in pixels.
             */
            scaleX: never;

            /**
             * Scaling of the view in y-axis in pixels.
             */
            scaleY: never;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * The view's tintColor
             */
            tintColor: never;

            /**
             * The view's top position.
             */
            top: never;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: never;

            /**
             * A material design visual construct that provides an instantaneous visual confirmation of touch point.
             */
            touchFeedback: never;

            /**
             * Optional touch feedback ripple color. This has no effect unless `touchFeedback` is true.
             */
            touchFeedbackColor: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * A name to identify this view in activity transition.
             */
            transitionName: never;

            /**
             * Horizontal location of the view relative to its left position in pixels.
             */
            translationX: never;

            /**
             * Vertical location of the view relative to its top position in pixels.
             */
            translationY: never;

            /**
             * Depth of the view relative to its elevation in pixels.
             */
            translationZ: never;

            /**
             * Adds a vertical parallax effect to the view
             */
            verticalMotionEffect: never;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: never;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: never;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof PickerColumnEventMap>(name: K, callback: (this: Titanium.UI.PickerColumn, event: PickerColumnEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a row to this column.
             */
            addRow(row: Titanium.UI.PickerRow): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Removes all previously added motion effects.
             */
            clearMotionEffects: never;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView: never;

            /**
             * Finishes a batch update of the View's layout properties and schedules a layout pass of the
             * view tree.
             * @deprecated Use the [applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            finishLayout: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof PickerColumnEventMap>(name: K, event?: PickerColumnEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.PickerColumn.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.PickerColumn.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.PickerColumn.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.PickerColumn.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.anchorPoint> property.
             * @deprecated Access <Titanium.UI.PickerColumn.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.animatedCenter> property.
             * @deprecated Access <Titanium.UI.PickerColumn.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundImage> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.PickerColumn.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.borderColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.borderRadius> property.
             * @deprecated Access <Titanium.UI.PickerColumn.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.borderWidth> property.
             * @deprecated Access <Titanium.UI.PickerColumn.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.bottom> property.
             * @deprecated Access <Titanium.UI.PickerColumn.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.center> property.
             * @deprecated Access <Titanium.UI.PickerColumn.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.children> property.
             * @deprecated Access <Titanium.UI.PickerColumn.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.clipMode> property.
             * @deprecated Access <Titanium.UI.PickerColumn.clipMode> instead.
             */
            getClipMode: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.elevation> property.
             * @deprecated Access <Titanium.UI.PickerColumn.elevation> instead.
             */
            getElevation: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.focusable> property.
             * @deprecated Access <Titanium.UI.PickerColumn.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.font> property.
             * @deprecated Access <Titanium.UI.PickerColumn.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.height> property.
             * @deprecated Access <Titanium.UI.PickerColumn.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.hiddenBehavior> property.
             * @deprecated Access <Titanium.UI.PickerColumn.hiddenBehavior> instead.
             */
            getHiddenBehavior: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.horizontalMotionEffect> property.
             * @deprecated Access <Titanium.UI.PickerColumn.horizontalMotionEffect> instead.
             */
            getHorizontalMotionEffect: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.PickerColumn.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.PickerColumn.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.layout> property.
             * @deprecated Access <Titanium.UI.PickerColumn.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.left> property.
             * @deprecated Access <Titanium.UI.PickerColumn.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.opacity> property.
             * @deprecated Access <Titanium.UI.PickerColumn.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.PickerColumn.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.previewContext> property.
             * @deprecated Access <Titanium.UI.PickerColumn.previewContext> instead.
             */
            getPreviewContext: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.pullBackgroundColor> instead.
             */
            getPullBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rect> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.right> property.
             * @deprecated Access <Titanium.UI.PickerColumn.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rotation> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rotation> instead.
             */
            getRotation: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rotationX> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rotationX> instead.
             */
            getRotationX: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rotationY> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rotationY> instead.
             */
            getRotationY: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rowCount> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rowCount> instead.
             */
            getRowCount(): number;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.rows> property.
             * @deprecated Access <Titanium.UI.PickerColumn.rows> instead.
             */
            getRows(): Titanium.UI.PickerRow[];

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.scaleX> property.
             * @deprecated Access <Titanium.UI.PickerColumn.scaleX> instead.
             */
            getScaleX: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.scaleY> property.
             * @deprecated Access <Titanium.UI.PickerColumn.scaleY> instead.
             */
            getScaleY: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.size> property.
             * @deprecated Access <Titanium.UI.PickerColumn.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.PickerColumn.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.tintColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.tintColor> instead.
             */
            getTintColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.top> property.
             * @deprecated Access <Titanium.UI.PickerColumn.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.touchEnabled> property.
             * @deprecated Access <Titanium.UI.PickerColumn.touchEnabled> instead.
             */
            getTouchEnabled: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.touchFeedback> property.
             * @deprecated Access <Titanium.UI.PickerColumn.touchFeedback> instead.
             */
            getTouchFeedback: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.touchFeedbackColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.touchFeedbackColor> instead.
             */
            getTouchFeedbackColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.transform> property.
             * @deprecated Access <Titanium.UI.PickerColumn.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.transitionName> property.
             * @deprecated Access <Titanium.UI.PickerColumn.transitionName> instead.
             */
            getTransitionName: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.translationX> property.
             * @deprecated Access <Titanium.UI.PickerColumn.translationX> instead.
             */
            getTranslationX: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.translationY> property.
             * @deprecated Access <Titanium.UI.PickerColumn.translationY> instead.
             */
            getTranslationY: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.translationZ> property.
             * @deprecated Access <Titanium.UI.PickerColumn.translationZ> instead.
             */
            getTranslationZ: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.verticalMotionEffect> property.
             * @deprecated Access <Titanium.UI.PickerColumn.verticalMotionEffect> instead.
             */
            getVerticalMotionEffect: never;

            /**
             * Returns the matching view of a given view ID.
             */
            getViewById: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.PickerColumn.viewShadowColor> instead.
             */
            getViewShadowColor: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.PickerColumn.viewShadowOffset> instead.
             */
            getViewShadowOffset: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.PickerColumn.viewShadowRadius> instead.
             */
            getViewShadowRadius: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.visible> property.
             * @deprecated Access <Titanium.UI.PickerColumn.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.width> property.
             * @deprecated Access <Titanium.UI.PickerColumn.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.PickerColumn.zIndex> property.
             * @deprecated Access <Titanium.UI.PickerColumn.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Hides this view.
             */
            hide: never;

            /**
             * Inserts a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            insertAt: never;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof PickerColumnEventMap>(name: K, callback: (this: Titanium.UI.PickerColumn, event: PickerColumnEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a row from this column.
             */
            removeRow(row: Titanium.UI.PickerRow): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.bottom> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.center> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.clipMode> instead.
             */
            setClipMode: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.elevation> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.elevation> instead.
             */
            setElevation: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.focusable> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.font> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.height> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.hiddenBehavior> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.hiddenBehavior> instead.
             */
            setHiddenBehavior: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.horizontalMotionEffect> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.horizontalMotionEffect> instead.
             */
            setHorizontalMotionEffect: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.layout> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.left> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.opacity> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.previewContext> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.previewContext> instead.
             */
            setPreviewContext: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.pullBackgroundColor> instead.
             */
            setPullBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.right> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.rotation> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.rotation> instead.
             */
            setRotation: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.rotationX> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.rotationX> instead.
             */
            setRotationX: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.rotationY> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.rotationY> instead.
             */
            setRotationY: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.scaleX> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.scaleX> instead.
             */
            setScaleX: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.scaleY> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.scaleY> instead.
             */
            setScaleY: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.tintColor> instead.
             */
            setTintColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.top> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.touchEnabled> instead.
             */
            setTouchEnabled: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.touchFeedback> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.touchFeedback> instead.
             */
            setTouchFeedback: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.touchFeedbackColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.touchFeedbackColor> instead.
             */
            setTouchFeedbackColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.transform> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.transitionName> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.transitionName> instead.
             */
            setTransitionName: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.translationX> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.translationX> instead.
             */
            setTranslationX: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.translationY> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.translationY> instead.
             */
            setTranslationY: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.translationZ> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.translationZ> instead.
             */
            setTranslationZ: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.verticalMotionEffect> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.verticalMotionEffect> instead.
             */
            setVerticalMotionEffect: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.viewShadowColor> instead.
             */
            setViewShadowColor: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.viewShadowOffset> instead.
             */
            setViewShadowOffset: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.viewShadowRadius> instead.
             */
            setViewShadowRadius: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.visible> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.width> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.width> instead.
             */
            setWidth: never;

            /**
             * Sets the value of the <Titanium.UI.PickerColumn.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.PickerColumn.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Makes this view visible.
             */
            show: never;

            /**
             * Starts a batch update of this view's layout properties.
             * @deprecated Use the [Titanium.Proxy.applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            startLayout: never;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage: never;

            /**
             * Performs a batch update of all supplied layout properties and schedules a layout pass after
             * they have been updated.
             * @deprecated Use the [Titanium.Proxy.applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            updateLayout: never;

        }
        /**
         * Base event for class Titanium.UI.PickerRow
         */
        interface PickerRowBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.PickerRow;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface PickerRow_click_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface PickerRow_dblclick_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface PickerRow_doubletap_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface PickerRow_focus_Event extends PickerRowBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface PickerRow_keypressed_Event extends PickerRowBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface PickerRow_longclick_Event extends PickerRowBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface PickerRow_longpress_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface PickerRow_pinch_Event extends PickerRowBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface PickerRow_postlayout_Event extends PickerRowBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface PickerRow_singletap_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface PickerRow_swipe_Event extends PickerRowBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface PickerRow_touchcancel_Event extends PickerRowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface PickerRow_touchend_Event extends PickerRowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface PickerRow_touchmove_Event extends PickerRowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface PickerRow_touchstart_Event extends PickerRowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface PickerRow_twofingertap_Event extends PickerRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface PickerRowEventMap extends ProxyEventMap {
            click: PickerRow_click_Event;

            dblclick: PickerRow_dblclick_Event;

            doubletap: PickerRow_doubletap_Event;

            focus: PickerRow_focus_Event;

            keypressed: PickerRow_keypressed_Event;

            longclick: PickerRow_longclick_Event;

            longpress: PickerRow_longpress_Event;

            pinch: PickerRow_pinch_Event;

            postlayout: PickerRow_postlayout_Event;

            singletap: PickerRow_singletap_Event;

            swipe: PickerRow_swipe_Event;

            touchcancel: PickerRow_touchcancel_Event;

            touchend: PickerRow_touchend_Event;

            touchmove: PickerRow_touchmove_Event;

            touchstart: PickerRow_touchstart_Event;

            twofingertap: PickerRow_twofingertap_Event;

        }
        /**
         * A picker row, representing a selectable item in a <Titanium.UI.Picker>.
         */
        class PickerRow extends Titanium.UI.View {
            /**
             * Color of the item text, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Font to use for the item text.
             */
            font: Font;

            /**
             * Item text.
             */
            title: string;

            /**
             * Adds a child view to this picker row, to provide a custom row.
             */
            add(view: Titanium.UI.View): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof PickerRowEventMap>(name: K, callback: (this: Titanium.UI.PickerRow, event: PickerRowEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof PickerRowEventMap>(name: K, event?: PickerRowEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.PickerRow.color> property.
             * @deprecated Access <Titanium.UI.PickerRow.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.PickerRow.font> property.
             * @deprecated Access <Titanium.UI.PickerRow.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.PickerRow.title> property.
             * @deprecated Access <Titanium.UI.PickerRow.title> instead.
             */
            getTitle(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof PickerRowEventMap>(name: K, callback: (this: Titanium.UI.PickerRow, event: PickerRowEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.PickerRow.color> property.
             * @deprecated Set the value using <Titanium.UI.PickerRow.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.PickerRow.font> property.
             * @deprecated Set the value using <Titanium.UI.PickerRow.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.PickerRow.title> property.
             * @deprecated Set the value using <Titanium.UI.PickerRow.title> instead.
             */
            setTitle(title: string): void;

        }
        /**
         * Base event for class Titanium.UI.ProgressBar
         */
        interface ProgressBarBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ProgressBar;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ProgressBar_click_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ProgressBar_dblclick_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ProgressBar_doubletap_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ProgressBar_focus_Event extends ProgressBarBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ProgressBar_keypressed_Event extends ProgressBarBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ProgressBar_longclick_Event extends ProgressBarBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface ProgressBar_longpress_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ProgressBar_pinch_Event extends ProgressBarBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ProgressBar_postlayout_Event extends ProgressBarBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ProgressBar_singletap_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ProgressBar_swipe_Event extends ProgressBarBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ProgressBar_touchcancel_Event extends ProgressBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ProgressBar_touchend_Event extends ProgressBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ProgressBar_touchmove_Event extends ProgressBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ProgressBar_touchstart_Event extends ProgressBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ProgressBar_twofingertap_Event extends ProgressBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ProgressBarEventMap extends ProxyEventMap {
            click: ProgressBar_click_Event;

            dblclick: ProgressBar_dblclick_Event;

            doubletap: ProgressBar_doubletap_Event;

            focus: ProgressBar_focus_Event;

            keypressed: ProgressBar_keypressed_Event;

            longclick: ProgressBar_longclick_Event;

            longpress: ProgressBar_longpress_Event;

            pinch: ProgressBar_pinch_Event;

            postlayout: ProgressBar_postlayout_Event;

            singletap: ProgressBar_singletap_Event;

            swipe: ProgressBar_swipe_Event;

            touchcancel: ProgressBar_touchcancel_Event;

            touchend: ProgressBar_touchend_Event;

            touchmove: ProgressBar_touchmove_Event;

            touchstart: ProgressBar_touchstart_Event;

            twofingertap: ProgressBar_twofingertap_Event;

        }
        /**
         * A progress bar.
         */
        class ProgressBar extends Titanium.UI.View {
            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Color of the progress bar message, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Font for the progress bar text.
             */
            font: Font;

            /**
             * Maximum value of the progress bar.
             */
            max: number;

            /**
             * Progress bar text.
             */
            message: string;

            /**
             * Minimum value of the progress bar.
             */
            min: number;

            /**
             * Style of the progress bar.
             */
            style: number;

            /**
             * The color shown for the portion of the progress bar that is filled.
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * The color shown for the portion of the progress bar that is not filled.
             */
            trackTintColor: string | Titanium.UI.Color;

            /**
             * Current value of the progress bar.
             */
            value: number;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ProgressBarEventMap>(name: K, callback: (this: Titanium.UI.ProgressBar, event: ProgressBarEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ProgressBarEventMap>(name: K, event?: ProgressBarEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.children> property.
             * @deprecated Access <Titanium.UI.ProgressBar.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.color> property.
             * @deprecated Access <Titanium.UI.ProgressBar.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.font> property.
             * @deprecated Access <Titanium.UI.ProgressBar.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.max> property.
             * @deprecated Access <Titanium.UI.ProgressBar.max> instead.
             */
            getMax(): number;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.message> property.
             * @deprecated Access <Titanium.UI.ProgressBar.message> instead.
             */
            getMessage(): string;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.min> property.
             * @deprecated Access <Titanium.UI.ProgressBar.min> instead.
             */
            getMin(): number;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.style> property.
             * @deprecated Access <Titanium.UI.ProgressBar.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.tintColor> property.
             * @deprecated Access <Titanium.UI.ProgressBar.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.trackTintColor> property.
             * @deprecated Access <Titanium.UI.ProgressBar.trackTintColor> instead.
             */
            getTrackTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ProgressBar.value> property.
             * @deprecated Access <Titanium.UI.ProgressBar.value> instead.
             */
            getValue(): number;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ProgressBarEventMap>(name: K, callback: (this: Titanium.UI.ProgressBar, event: ProgressBarEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.color> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.font> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.max> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.max> instead.
             */
            setMax(max: number): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.message> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.message> instead.
             */
            setMessage(message: string): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.min> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.min> instead.
             */
            setMin(min: number): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.style> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.trackTintColor> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.trackTintColor> instead.
             */
            setTrackTintColor(trackTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ProgressBar.value> property.
             * @deprecated Set the value using <Titanium.UI.ProgressBar.value> instead.
             */
            setValue(value: number): void;

        }
        /**
         * Base event for class Titanium.UI.RefreshControl
         */
        interface RefreshControlBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.RefreshControl;

        }
        /**
         * Fired in response to a user initiated an action to refresh the contents of the
         * table view, list view or scroll view.
         */
        interface RefreshControl_refreshstart_Event extends RefreshControlBaseEvent {
            /**
             * This is false. This event does not bubble
             */
            bubbles: boolean;

        }
        /**
         * Fired in response to a user finished action to refresh the contents of the
         * table view, list view or scroll view.
         */
        interface RefreshControl_refreshend_Event extends RefreshControlBaseEvent {
            /**
             * This is false. This event does not bubble
             */
            bubbles: boolean;

        }
        interface RefreshControlEventMap extends ProxyEventMap {
            refreshend: RefreshControl_refreshend_Event;

            refreshstart: RefreshControl_refreshstart_Event;

        }
        /**
         * The RefreshControl is a representation of the native iOS
         * [UIRefreshControl](https://developer.apple.com/documentation/uikit/uirefreshcontrol)
         * and Android [SwipeRefreshLayout](https://developer.android.com/reference/android/support/v4/widget/SwipeRefreshLayout.html).
         */
        class RefreshControl extends Titanium.Proxy {
            /**
             * The tint color for the refresh control, as a color name or hex triplet.
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * The attributed title of the control.
             */
            title: Titanium.UI.AttributedString;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof RefreshControlEventMap>(name: K, callback: (this: Titanium.UI.RefreshControl, event: RefreshControlEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Tells the control that a refresh operation was started programmatically.
             */
            beginRefreshing(): void;

            /**
             * Tells the control that a refresh operation has ended.
             */
            endRefreshing(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof RefreshControlEventMap>(name: K, event?: RefreshControlEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.RefreshControl.tintColor> property.
             * @deprecated Access <Titanium.UI.RefreshControl.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.RefreshControl.title> property.
             * @deprecated Access <Titanium.UI.RefreshControl.title> instead.
             */
            getTitle(): Titanium.UI.AttributedString;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof RefreshControlEventMap>(name: K, callback: (this: Titanium.UI.RefreshControl, event: RefreshControlEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.RefreshControl.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.RefreshControl.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.RefreshControl.title> property.
             * @deprecated Set the value using <Titanium.UI.RefreshControl.title> instead.
             */
            setTitle(title: Titanium.UI.AttributedString): void;

        }
        /**
         * Base event for class Titanium.UI.ScrollView
         */
        interface ScrollViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ScrollView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ScrollView_click_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ScrollView_dblclick_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface ScrollView_doubletap_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ScrollView_focus_Event extends ScrollViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ScrollView_keypressed_Event extends ScrollViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ScrollView_longclick_Event extends ScrollViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface ScrollView_longpress_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ScrollView_pinch_Event extends ScrollViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ScrollView_postlayout_Event extends ScrollViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface ScrollView_singletap_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ScrollView_swipe_Event extends ScrollViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface ScrollView_touchcancel_Event extends ScrollViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ScrollView_touchend_Event extends ScrollViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ScrollView_touchmove_Event extends ScrollViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface ScrollView_touchstart_Event extends ScrollViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ScrollView_twofingertap_Event extends ScrollViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the zoom scale factor changes.
         */
        interface ScrollView_scale_Event extends ScrollViewBaseEvent {
            /**
             * New scaling factor as a float.
             */
            scale: number;

        }
        /**
         * Fired when the scrollable region is scrolled.
         */
        interface ScrollView_scroll_Event extends ScrollViewBaseEvent {
            /**
             * The current content size of the scroll view defined by its `width` and `height` properties.
             */
            contentSize: Size;

            /**
             * The current scaling factor of the scroll view content. This might not be equal to
             * the `zoomScale` property or be within the range specified by `minZoomScale` and `maxZoomScale`.
             * This is only available from Release 3.2.3 of the Titanium Mobile SDK.
             */
            curZoomScale: number;

            /**
             * Indicates whether the scroll is decelerating.
             */
            decelerating: boolean;

            /**
             * Indicates whether the event was fired during a dragging gesture, where the touch
             * remained in contact with the display to physically drag the view, as opposed to it being
             * the result of scrolling momentum.
             */
            dragging: boolean;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

            /**
             * Indicates whether the event was fired during a zooming operation. This is only available
             * from Release 3.2.3 of the Titanium Mobile SDK.
             */
            zooming: boolean;

        }
        /**
         * Fired when the scrollable region starts being dragged.
         */
        interface ScrollView_dragStart_Event extends ScrollViewBaseEvent {
        }
        /**
         * Fired when the scrollable region stops being dragged.
         */
        interface ScrollView_dragEnd_Event extends ScrollViewBaseEvent {
            /**
             * Indicates whether scrolling will continue but decelerate, now that the drag gesture has
             * been released by the touch. If `false`, scrolling will stop immediately.
             */
            decelerate: boolean;

        }
        /**
         * Fired when the scrollable region starts being dragged.
         */
        interface ScrollView_dragstart_Event extends ScrollViewBaseEvent {
        }
        /**
         * Fired when the scrollable region stops being dragged.
         */
        interface ScrollView_dragend_Event extends ScrollViewBaseEvent {
            /**
             * Indicates whether scrolling will continue but decelerate, now that the drag gesture has
             * been released by the touch. If `false`, scrolling will stop immediately.
             * Is always `true` on Android.
             */
            decelerate: boolean;

        }
        interface ScrollViewEventMap extends ProxyEventMap {
            click: ScrollView_click_Event;

            dblclick: ScrollView_dblclick_Event;

            doubletap: ScrollView_doubletap_Event;

            dragEnd: ScrollView_dragEnd_Event;

            dragStart: ScrollView_dragStart_Event;

            dragend: ScrollView_dragend_Event;

            dragstart: ScrollView_dragstart_Event;

            focus: ScrollView_focus_Event;

            keypressed: ScrollView_keypressed_Event;

            longclick: ScrollView_longclick_Event;

            longpress: ScrollView_longpress_Event;

            pinch: ScrollView_pinch_Event;

            postlayout: ScrollView_postlayout_Event;

            scale: ScrollView_scale_Event;

            scroll: ScrollView_scroll_Event;

            singletap: ScrollView_singletap_Event;

            swipe: ScrollView_swipe_Event;

            touchcancel: ScrollView_touchcancel_Event;

            touchend: ScrollView_touchend_Event;

            touchmove: ScrollView_touchmove_Event;

            touchstart: ScrollView_touchstart_Event;

            twofingertap: ScrollView_twofingertap_Event;

        }
        /**
         * A view that contains a horizontally and/or vertically-scrollable region of content.
         */
        class ScrollView extends Titanium.UI.View {
            /**
             * Determines whether this scroll view can cancel subview touches in order to scroll instead.
             */
            canCancelEvents: boolean;

            /**
             * Height of the scrollable region.
             */
            contentHeight: number | string;

            /**
             * X and Y coordinates to which to reposition the top-left point of the scrollable region.
             */
            contentOffset: Point;

            /**
             * Width of the scrollable region.
             */
            contentWidth: number | string;

            /**
             * The deceleration rate of the ScrollView.
             */
            decelerationRate: number;

            /**
             * Determines whether scroll bounce of the scrollable region is enabled.
             */
            disableBounce: boolean;

            /**
             * Determines whether horizontal scroll bounce of the scrollable region is enabled.
             */
            horizontalBounce: boolean;

            /**
             * The manner in which the keyboard is dismissed when a drag begins in the scroll view.
             */
            keyboardDismissMode: number;

            /**
             * Maximum scaling factor of the scrollable region and its content.
             */
            maxZoomScale: number;

            /**
             * Minimum scaling factor of the scrollable region and its content.
             */
            minZoomScale: number;

            /**
             * Determines the behavior when the user overscolls the view.
             */
            overScrollMode: number;

            /**
             * View positioned above the first row that is only revealed when the user drags the scroll view contents down.
             */
            refreshControl: Titanium.UI.RefreshControl;

            /**
             * Style of the scrollbar.
             */
            scrollIndicatorStyle: number;

            /**
             * Limits the direction of the scrollable region, overriding the deduced setting. Set to
             * `horizontal` or `vertical`.
             */
            scrollType: string;

            /**
             * Determines whether scrolling is enabled for the view.
             */
            scrollingEnabled: boolean;

            /**
             * Controls whether the scroll-to-top gesture is effective.
             */
            scrollsToTop: boolean;

            /**
             * Determines whether the horizontal scroll indicator is visible.
             */
            showHorizontalScrollIndicator: boolean;

            /**
             * Determines whether the vertical scroll indicator is visible.
             */
            showVerticalScrollIndicator: boolean;

            /**
             * Determines whether vertical scroll bounce of the scrollable region is enabled.
             */
            verticalBounce: boolean;

            /**
             * Scaling factor of the scroll view's content.
             */
            zoomScale: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ScrollViewEventMap>(name: K, callback: (this: Titanium.UI.ScrollView, event: ScrollViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ScrollViewEventMap>(name: K, event?: ScrollViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.canCancelEvents> property.
             * @deprecated Access <Titanium.UI.ScrollView.canCancelEvents> instead.
             */
            getCanCancelEvents(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.contentHeight> property.
             * @deprecated Access <Titanium.UI.ScrollView.contentHeight> instead.
             */
            getContentHeight(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.contentOffset> property.
             * @deprecated Access <Titanium.UI.ScrollView.contentOffset> instead.
             */
            getContentOffset(): Point;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.contentWidth> property.
             * @deprecated Access <Titanium.UI.ScrollView.contentWidth> instead.
             */
            getContentWidth(): number | string;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.decelerationRate> property.
             * @deprecated Access <Titanium.UI.ScrollView.decelerationRate> instead.
             */
            getDecelerationRate(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.disableBounce> property.
             * @deprecated Access <Titanium.UI.ScrollView.disableBounce> instead.
             */
            getDisableBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.horizontalBounce> property.
             * @deprecated Access <Titanium.UI.ScrollView.horizontalBounce> instead.
             */
            getHorizontalBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.keyboardDismissMode> property.
             * @deprecated Access <Titanium.UI.ScrollView.keyboardDismissMode> instead.
             */
            getKeyboardDismissMode(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.maxZoomScale> property.
             * @deprecated Access <Titanium.UI.ScrollView.maxZoomScale> instead.
             */
            getMaxZoomScale(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.minZoomScale> property.
             * @deprecated Access <Titanium.UI.ScrollView.minZoomScale> instead.
             */
            getMinZoomScale(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.overScrollMode> property.
             * @deprecated Access <Titanium.UI.ScrollView.overScrollMode> instead.
             */
            getOverScrollMode(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.refreshControl> property.
             * @deprecated Access <Titanium.UI.ScrollView.refreshControl> instead.
             */
            getRefreshControl(): Titanium.UI.RefreshControl;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.scrollIndicatorStyle> property.
             * @deprecated Access <Titanium.UI.ScrollView.scrollIndicatorStyle> instead.
             */
            getScrollIndicatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.scrollType> property.
             * @deprecated Access <Titanium.UI.ScrollView.scrollType> instead.
             */
            getScrollType(): string;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.scrollingEnabled> property.
             * @deprecated Access <Titanium.UI.ScrollView.scrollingEnabled> instead.
             */
            getScrollingEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.scrollsToTop> property.
             * @deprecated Access <Titanium.UI.ScrollView.scrollsToTop> instead.
             */
            getScrollsToTop(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.showHorizontalScrollIndicator> property.
             * @deprecated Access <Titanium.UI.ScrollView.showHorizontalScrollIndicator> instead.
             */
            getShowHorizontalScrollIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.showVerticalScrollIndicator> property.
             * @deprecated Access <Titanium.UI.ScrollView.showVerticalScrollIndicator> instead.
             */
            getShowVerticalScrollIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.verticalBounce> property.
             * @deprecated Access <Titanium.UI.ScrollView.verticalBounce> instead.
             */
            getVerticalBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollView.zoomScale> property.
             * @deprecated Access <Titanium.UI.ScrollView.zoomScale> instead.
             */
            getZoomScale(): number;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ScrollViewEventMap>(name: K, callback: (this: Titanium.UI.ScrollView, event: ScrollViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Moves the specified coordinate of the scrollable region into the viewable area.
             */
            scrollTo(x: number, y: number, options?: AnimatedOptions): void;

            /**
             * Moves the end of the scrollable region into the viewable area.
             */
            scrollToBottom(): void;

            /**
             * Moves the top of the scrollable region into the viewable area.
             */
            scrollToTop(): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.canCancelEvents> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.canCancelEvents> instead.
             */
            setCanCancelEvents(canCancelEvents: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.contentHeight> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.contentHeight> instead.
             */
            setContentHeight(contentHeight: number | string): void;

            /**
             * Sets the value of the [contentOffset](Titanium.UI.ScrollView.contentOffset) property.
             */
            setContentOffset(contentOffsetXY: Point, animated?: AnimatedOptions): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.contentWidth> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.contentWidth> instead.
             */
            setContentWidth(contentWidth: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.decelerationRate> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.decelerationRate> instead.
             */
            setDecelerationRate(decelerationRate: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.disableBounce> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.disableBounce> instead.
             */
            setDisableBounce(disableBounce: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.horizontalBounce> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.horizontalBounce> instead.
             */
            setHorizontalBounce(horizontalBounce: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.keyboardDismissMode> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.keyboardDismissMode> instead.
             */
            setKeyboardDismissMode(keyboardDismissMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.maxZoomScale> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.maxZoomScale> instead.
             */
            setMaxZoomScale(maxZoomScale: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.minZoomScale> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.minZoomScale> instead.
             */
            setMinZoomScale(minZoomScale: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.overScrollMode> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.overScrollMode> instead.
             */
            setOverScrollMode(overScrollMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.refreshControl> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.refreshControl> instead.
             */
            setRefreshControl(refreshControl: Titanium.UI.RefreshControl): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.scrollIndicatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.scrollIndicatorStyle> instead.
             */
            setScrollIndicatorStyle(scrollIndicatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.scrollType> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.scrollType> instead.
             */
            setScrollType(scrollType: string): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.scrollingEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.scrollingEnabled> instead.
             */
            setScrollingEnabled(scrollingEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.scrollsToTop> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.scrollsToTop> instead.
             */
            setScrollsToTop(scrollsToTop: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.showHorizontalScrollIndicator> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.showHorizontalScrollIndicator> instead.
             */
            setShowHorizontalScrollIndicator(showHorizontalScrollIndicator: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.showVerticalScrollIndicator> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.showVerticalScrollIndicator> instead.
             */
            setShowVerticalScrollIndicator(showVerticalScrollIndicator: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollView.verticalBounce> property.
             * @deprecated Set the value using <Titanium.UI.ScrollView.verticalBounce> instead.
             */
            setVerticalBounce(verticalBounce: boolean): void;

            /**
             * Sets the value of the [zoomScale](Titanium.UI.ScrollView.zoomScale) property.
             */
            setZoomScale(zoomScale: number, options?: AnimatedOptions): void;

        }
        /**
         * Base event for class Titanium.UI.ScrollableView
         */
        interface ScrollableViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.ScrollableView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface ScrollableView_click_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface ScrollableView_dblclick_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against this page.
         */
        interface ScrollableView_doubletap_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface ScrollableView_focus_Event extends ScrollableViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface ScrollableView_keypressed_Event extends ScrollableViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface ScrollableView_longclick_Event extends ScrollableViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press against this view.
         */
        interface ScrollableView_longpress_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface ScrollableView_pinch_Event extends ScrollableViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface ScrollableView_postlayout_Event extends ScrollableViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against this view.
         */
        interface ScrollableView_singletap_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface ScrollableView_swipe_Event extends ScrollableViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch gesture is interrupted by the device.
         */
        interface ScrollableView_touchcancel_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface ScrollableView_touchend_Event extends ScrollableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface ScrollableView_touchmove_Event extends ScrollableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture against this view.
         */
        interface ScrollableView_touchstart_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface ScrollableView_twofingertap_Event extends ScrollableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired repeatedly as the view is being scrolled.
         */
        interface ScrollableView_scroll_Event extends ScrollableViewBaseEvent {
            /**
             * Index of the currently visible view of <Titanium.UI.ScrollableView.views>.
             */
            currentPage: number;

            /**
             * Current page index that the view is scrolled to as a float. For
             * example, if the user is holding the `ScrollableView` in between
             * the first and second page, this will have a value of 0.5.
             */
            currentPageAsFloat: number;

            /**
             * The currently visible view.
             */
            view: Titanium.UI.View;

        }
        /**
         * Fired when the view has stopped moving completely.
         */
        interface ScrollableView_scrollend_Event extends ScrollableViewBaseEvent {
            /**
             * Index of the currently visible view of <Titanium.UI.ScrollableView.views>.
             */
            currentPage: number;

            /**
             * The currently visible view.
             */
            view: Titanium.UI.View;

        }
        /**
         * Fired when the scrolling drag gesture on the view has been completed.
         */
        interface ScrollableView_dragend_Event extends ScrollableViewBaseEvent {
            /**
             * Index of the currently visible view of <Titanium.UI.ScrollableView.views>.
             */
            currentPage: number;

            /**
             * The currently visible view.
             */
            view: Titanium.UI.View;

        }
        interface ScrollableViewEventMap extends ProxyEventMap {
            click: ScrollableView_click_Event;

            dblclick: ScrollableView_dblclick_Event;

            doubletap: ScrollableView_doubletap_Event;

            dragend: ScrollableView_dragend_Event;

            focus: ScrollableView_focus_Event;

            keypressed: ScrollableView_keypressed_Event;

            longclick: ScrollableView_longclick_Event;

            longpress: ScrollableView_longpress_Event;

            pinch: ScrollableView_pinch_Event;

            postlayout: ScrollableView_postlayout_Event;

            scroll: ScrollableView_scroll_Event;

            scrollend: ScrollableView_scrollend_Event;

            singletap: ScrollableView_singletap_Event;

            swipe: ScrollableView_swipe_Event;

            touchcancel: ScrollableView_touchcancel_Event;

            touchend: ScrollableView_touchend_Event;

            touchmove: ScrollableView_touchmove_Event;

            touchstart: ScrollableView_touchstart_Event;

            twofingertap: ScrollableView_twofingertap_Event;

        }
        /**
         * A view that encapsulates a horizontally-scrolling set of child views, known as pages, navigable
         * using its built-in horizontal swipe gestures.
         */
        class ScrollableView extends Titanium.UI.View {
            /**
             * Number of pages to cache (pre-render).
             */
            cacheSize: number;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Determines whether the previous and next pages are clipped, so that they are not visible
             * adjacent to the current page.
             */
            clipViews: boolean;

            /**
             * Index of the active page.
             */
            currentPage: number;

            /**
             * Color for the current page of the paging control, as a color name or hex triplet.
             */
            currentPageIndicatorColor: string | Titanium.UI.Color;

            /**
             * Determines whether page bouncing effect is disabled.
             */
            disableBounce: boolean;

            /**
             * Sets the region where this view responds to gestures.
             */
            hitRect: Dimension;

            /**
             * Determines the behavior when the user overscolls the view.
             */
            overScrollMode: number;

            /**
             * Determines whether the paging control is added as an overlay to the view.
             */
            overlayEnabled: boolean;

            /**
             * The padding applied to the scrollable view.
             */
            padding: Padding;

            /**
             * Color of the paging control, as a color name or hex triplet.
             */
            pageIndicatorColor: string | Titanium.UI.Color;

            /**
             * Alpha value of the paging control.
             */
            pagingControlAlpha: number;

            /**
             * Color of the paging control, as a color name or hex triplet.
             */
            pagingControlColor: string | Titanium.UI.Color;

            /**
             * Height of the paging control, in pixels.
             */
            pagingControlHeight: number;

            /**
             * Determines whether the paging control is displayed at the top or bottom of the view.
             */
            pagingControlOnTop: boolean;

            /**
             * Number of milliseconds to wait before hiding the paging control.
             */
            pagingControlTimeout: number;

            /**
             * The preferred image for indicators, defined using a local filesystem path, or a `Blob` object containing image data.
             */
            preferredIndicatorImage: string | Titanium.Blob;

            /**
             * Determines whether scrolling is enabled for the view.
             */
            scrollingEnabled: boolean;

            /**
             * Determines whether the paging control is visible.
             */
            showPagingControl: boolean;

            /**
             * Sets the pages within this Scrollable View.
             */
            views: Titanium.UI.View[];

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ScrollableViewEventMap>(name: K, callback: (this: Titanium.UI.ScrollableView, event: ScrollableViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a new page to this Scrollable View.
             */
            addView(view: Titanium.UI.View): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ScrollableViewEventMap>(name: K, event?: ScrollableViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.cacheSize> property.
             * @deprecated Access <Titanium.UI.ScrollableView.cacheSize> instead.
             */
            getCacheSize(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.children> property.
             * @deprecated Access <Titanium.UI.ScrollableView.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.clipViews> property.
             * @deprecated Access <Titanium.UI.ScrollableView.clipViews> instead.
             */
            getClipViews(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.currentPage> property.
             * @deprecated Access <Titanium.UI.ScrollableView.currentPage> instead.
             */
            getCurrentPage(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.currentPageIndicatorColor> property.
             * @deprecated Access <Titanium.UI.ScrollableView.currentPageIndicatorColor> instead.
             */
            getCurrentPageIndicatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.disableBounce> property.
             * @deprecated Access <Titanium.UI.ScrollableView.disableBounce> instead.
             */
            getDisableBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.hitRect> property.
             * @deprecated Access <Titanium.UI.ScrollableView.hitRect> instead.
             */
            getHitRect(): Dimension;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.overScrollMode> property.
             * @deprecated Access <Titanium.UI.ScrollableView.overScrollMode> instead.
             */
            getOverScrollMode(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.overlayEnabled> property.
             * @deprecated Access <Titanium.UI.ScrollableView.overlayEnabled> instead.
             */
            getOverlayEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.padding> property.
             * @deprecated Access <Titanium.UI.ScrollableView.padding> instead.
             */
            getPadding(): Padding;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pageIndicatorColor> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pageIndicatorColor> instead.
             */
            getPageIndicatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pagingControlAlpha> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pagingControlAlpha> instead.
             */
            getPagingControlAlpha(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pagingControlColor> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pagingControlColor> instead.
             */
            getPagingControlColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pagingControlHeight> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pagingControlHeight> instead.
             */
            getPagingControlHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pagingControlOnTop> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pagingControlOnTop> instead.
             */
            getPagingControlOnTop(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.pagingControlTimeout> property.
             * @deprecated Access <Titanium.UI.ScrollableView.pagingControlTimeout> instead.
             */
            getPagingControlTimeout(): number;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.preferredIndicatorImage> property.
             * @deprecated Access <Titanium.UI.ScrollableView.preferredIndicatorImage> instead.
             */
            getPreferredIndicatorImage(): string | Titanium.Blob;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.scrollingEnabled> property.
             * @deprecated Access <Titanium.UI.ScrollableView.scrollingEnabled> instead.
             */
            getScrollingEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.showPagingControl> property.
             * @deprecated Access <Titanium.UI.ScrollableView.showPagingControl> instead.
             */
            getShowPagingControl(): boolean;

            /**
             * Gets the value of the <Titanium.UI.ScrollableView.views> property.
             * @deprecated Access <Titanium.UI.ScrollableView.views> instead.
             */
            getViews(): Titanium.UI.View[];

            /**
             * Inserts views at the specified position in the [views](Titanium.UI.ScrollableView.views) array.
             */
            insertViewsAt(position: number, views: ReadonlyArray<Titanium.UI.View>): void;

            /**
             * Sets the current page to the next consecutive page in <Titanium.UI.ScrollableView.views>.
             */
            moveNext(): void;

            /**
             * Sets the current page to the previous consecutive page in <Titanium.UI.ScrollableView.views>.
             */
            movePrevious(): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ScrollableViewEventMap>(name: K, callback: (this: Titanium.UI.ScrollableView, event: ScrollableViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes an existing page from this Scrollable View.
             */
            removeView(view: number | Titanium.UI.View): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Scrolls to the specified page in <Titanium.UI.ScrollableView.views>.
             */
            scrollToView(view: number | Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.cacheSize> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.cacheSize> instead.
             */
            setCacheSize(cacheSize: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.clipViews> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.clipViews> instead.
             */
            setClipViews(clipViews: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.currentPage> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.currentPage> instead.
             */
            setCurrentPage(currentPage: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.currentPageIndicatorColor> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.currentPageIndicatorColor> instead.
             */
            setCurrentPageIndicatorColor(currentPageIndicatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.disableBounce> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.disableBounce> instead.
             */
            setDisableBounce(disableBounce: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.hitRect> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.hitRect> instead.
             */
            setHitRect(hitRect: Dimension): void;

            /**
             * Sets the indicator image for the specified page.
             */
            setIndicatorImageForPage(image: string | Titanium.Blob, pageNo: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.overScrollMode> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.overScrollMode> instead.
             */
            setOverScrollMode(overScrollMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.overlayEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.overlayEnabled> instead.
             */
            setOverlayEnabled(overlayEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.padding> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.padding> instead.
             */
            setPadding(padding: Padding): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pageIndicatorColor> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pageIndicatorColor> instead.
             */
            setPageIndicatorColor(pageIndicatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pagingControlAlpha> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pagingControlAlpha> instead.
             */
            setPagingControlAlpha(pagingControlAlpha: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pagingControlColor> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pagingControlColor> instead.
             */
            setPagingControlColor(pagingControlColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pagingControlHeight> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pagingControlHeight> instead.
             */
            setPagingControlHeight(pagingControlHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pagingControlOnTop> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pagingControlOnTop> instead.
             */
            setPagingControlOnTop(pagingControlOnTop: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.pagingControlTimeout> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.pagingControlTimeout> instead.
             */
            setPagingControlTimeout(pagingControlTimeout: number): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.preferredIndicatorImage> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.preferredIndicatorImage> instead.
             */
            setPreferredIndicatorImage(preferredIndicatorImage: string | Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.scrollingEnabled> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.scrollingEnabled> instead.
             */
            setScrollingEnabled(scrollingEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.showPagingControl> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.showPagingControl> instead.
             */
            setShowPagingControl(showPagingControl: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.ScrollableView.views> property.
             * @deprecated Set the value using <Titanium.UI.ScrollableView.views> instead.
             */
            setViews(views: ReadonlyArray<Titanium.UI.View>): void;

        }
        /**
         * Base event for class Titanium.UI.SearchBar
         */
        interface SearchBarBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.SearchBar;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface SearchBar_click_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface SearchBar_dblclick_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface SearchBar_doubletap_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the search bar gains focus.
         */
        interface SearchBar_focus_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface SearchBar_keypressed_Event extends SearchBarBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface SearchBar_longclick_Event extends SearchBarBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface SearchBar_longpress_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface SearchBar_pinch_Event extends SearchBarBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface SearchBar_postlayout_Event extends SearchBarBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface SearchBar_singletap_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface SearchBar_swipe_Event extends SearchBarBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface SearchBar_touchcancel_Event extends SearchBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface SearchBar_touchend_Event extends SearchBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface SearchBar_touchmove_Event extends SearchBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface SearchBar_touchstart_Event extends SearchBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface SearchBar_twofingertap_Event extends SearchBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the search bar loses focus.
         */
        interface SearchBar_blur_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        /**
         * Fired when the bookmark button is pressed.
         */
        interface SearchBar_bookmark_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        /**
         * Fired when the cancel button is pressed.
         */
        interface SearchBar_cancel_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        /**
         * Fired when the value of the search bar changes.
         */
        interface SearchBar_change_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        /**
         * Fired when keyboard search button is pressed.
         */
        interface SearchBar_return_Event extends SearchBarBaseEvent {
            /**
             * Value of the search bar.
             */
            value: string;

        }
        interface SearchBarEventMap extends ProxyEventMap {
            blur: SearchBar_blur_Event;

            bookmark: SearchBar_bookmark_Event;

            cancel: SearchBar_cancel_Event;

            change: SearchBar_change_Event;

            click: SearchBar_click_Event;

            dblclick: SearchBar_dblclick_Event;

            doubletap: SearchBar_doubletap_Event;

            focus: SearchBar_focus_Event;

            keypressed: SearchBar_keypressed_Event;

            longclick: SearchBar_longclick_Event;

            longpress: SearchBar_longpress_Event;

            pinch: SearchBar_pinch_Event;

            postlayout: SearchBar_postlayout_Event;

            return: SearchBar_return_Event;

            singletap: SearchBar_singletap_Event;

            swipe: SearchBar_swipe_Event;

            touchcancel: SearchBar_touchcancel_Event;

            touchend: SearchBar_touchend_Event;

            touchmove: SearchBar_touchmove_Event;

            touchstart: SearchBar_touchstart_Event;

            twofingertap: SearchBar_twofingertap_Event;

        }
        /**
         * A specialized text field for entering search text.
         */
        class SearchBar extends Titanium.UI.View {
            /**
             * Determines how text is capitalized during typing.
             */
            autocapitalization: number;

            /**
             * Determines whether the text in the search bar is autocorrected during typing.
             */
            autocorrect: boolean;

            /**
             * Bar color of the search bar view, as a color name or hex triplet.
             */
            barColor: string | Titanium.UI.Color;

            /**
             * The title of the cancel button when the search bar field is focused.
             */
            cancelButtonTitle: string;

            /**
             * Color of the text in this text field, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Background image of the text field in disabled state, specified as a local file path or URL.
             */
            fieldBackgroundDisabledImage: string;

            /**
             * Background image of the text field, specified as a local file path or URL.
             */
            fieldBackgroundImage: string;

            /**
             * Determines whether this SearchBar has focus.
             */
            readonly focused: boolean;

            /**
             * Text to show when the search bar field is not focused.
             */
            hintText: string;

            /**
             * Hint text color to display when the field is empty.
             */
            hintTextColor: string | Titanium.UI.Color;

            /**
             * Key identifying a string from the locale file to use for the
             * [hintText](Titanium.UI.SearchBar.hintText) property.
             */
            hinttextid: string;

            /**
             * Determines the appearance of the keyboard to be displayed the field is focused.
             */
            keyboardAppearance: number;

            /**
             * Keyboard type constant to use when the field is focused.
             */
            keyboardType: number;

            /**
             * Single line of text displayed at the top of the search bar.
             */
            prompt: string;

            /**
             * Key identifying a string from the locale file to use for the
             * [prompt](Titanium.UI.SearchBar.prompt) property.
             */
            promptid: string;

            /**
             * Determines whether the bookmark button is displayed.
             */
            showBookmark: boolean;

            /**
             * Determines whether the cancel button is displayed.
             */
            showCancel: boolean;

            /**
             * Determines the style of the search bar.
             */
            style: number;

            /**
             * The token of a search text field
             */
            tokens: string[];

            /**
             * Value of the search bar.
             */
            value: string;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof SearchBarEventMap>(name: K, callback: (this: Titanium.UI.SearchBar, event: SearchBarEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Causes the search bar to lose focus.
             */
            blur(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof SearchBarEventMap>(name: K, event?: SearchBarEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Causes the search bar to gain focus.
             */
            focus(): void;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.autocapitalization> property.
             * @deprecated Access <Titanium.UI.SearchBar.autocapitalization> instead.
             */
            getAutocapitalization(): number;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.autocorrect> property.
             * @deprecated Access <Titanium.UI.SearchBar.autocorrect> instead.
             */
            getAutocorrect(): boolean;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.barColor> property.
             * @deprecated Access <Titanium.UI.SearchBar.barColor> instead.
             */
            getBarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.cancelButtonTitle> property.
             * @deprecated Access <Titanium.UI.SearchBar.cancelButtonTitle> instead.
             */
            getCancelButtonTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.color> property.
             * @deprecated Access <Titanium.UI.SearchBar.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.fieldBackgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.SearchBar.fieldBackgroundDisabledImage> instead.
             */
            getFieldBackgroundDisabledImage(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.fieldBackgroundImage> property.
             * @deprecated Access <Titanium.UI.SearchBar.fieldBackgroundImage> instead.
             */
            getFieldBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.focused> property.
             * @deprecated Access <Titanium.UI.SearchBar.focused> instead.
             */
            getFocused(): boolean;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.hintText> property.
             * @deprecated Access <Titanium.UI.SearchBar.hintText> instead.
             */
            getHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.hintTextColor> property.
             * @deprecated Access <Titanium.UI.SearchBar.hintTextColor> instead.
             */
            getHintTextColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.hinttextid> property.
             * @deprecated Access <Titanium.UI.SearchBar.hinttextid> instead.
             */
            getHinttextid(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.keyboardAppearance> property.
             * @deprecated Access <Titanium.UI.SearchBar.keyboardAppearance> instead.
             */
            getKeyboardAppearance(): number;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.keyboardType> property.
             * @deprecated Access <Titanium.UI.SearchBar.keyboardType> instead.
             */
            getKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.prompt> property.
             * @deprecated Access <Titanium.UI.SearchBar.prompt> instead.
             */
            getPrompt(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.promptid> property.
             * @deprecated Access <Titanium.UI.SearchBar.promptid> instead.
             */
            getPromptid(): string;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.showBookmark> property.
             * @deprecated Access <Titanium.UI.SearchBar.showBookmark> instead.
             */
            getShowBookmark(): boolean;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.showCancel> property.
             * @deprecated Access <Titanium.UI.SearchBar.showCancel> instead.
             */
            getShowCancel(): boolean;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.style> property.
             * @deprecated Access <Titanium.UI.SearchBar.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.SearchBar.tokens> property.
             * @deprecated Access <Titanium.UI.SearchBar.tokens> instead.
             */
            getTokens(): string[];

            /**
             * Gets the value of the <Titanium.UI.SearchBar.value> property.
             * @deprecated Access <Titanium.UI.SearchBar.value> instead.
             */
            getValue(): string;

            /**
             * Inserts a new search token at the specified index.
             */
            insertTokenAtIndex(token: SearchBarToken, index: number): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof SearchBarEventMap>(name: K, callback: (this: Titanium.UI.SearchBar, event: SearchBarEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes an existing token at the specified index.
             */
            removeTokenAtIndex(index: number): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.autocapitalization> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.autocapitalization> instead.
             */
            setAutocapitalization(autocapitalization: number): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.autocorrect> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.autocorrect> instead.
             */
            setAutocorrect(autocorrect: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.barColor> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.barColor> instead.
             */
            setBarColor(barColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.cancelButtonTitle> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.cancelButtonTitle> instead.
             */
            setCancelButtonTitle(cancelButtonTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.color> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.fieldBackgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.fieldBackgroundDisabledImage> instead.
             */
            setFieldBackgroundDisabledImage(fieldBackgroundDisabledImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.fieldBackgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.fieldBackgroundImage> instead.
             */
            setFieldBackgroundImage(fieldBackgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.hintText> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.hintText> instead.
             */
            setHintText(hintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.hintTextColor> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.hintTextColor> instead.
             */
            setHintTextColor(hintTextColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.hinttextid> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.hinttextid> instead.
             */
            setHinttextid(hinttextid: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.keyboardAppearance> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.keyboardAppearance> instead.
             */
            setKeyboardAppearance(keyboardAppearance: number): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.keyboardType> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.keyboardType> instead.
             */
            setKeyboardType(keyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.prompt> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.prompt> instead.
             */
            setPrompt(prompt: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.promptid> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.promptid> instead.
             */
            setPromptid(promptid: string): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.showBookmark> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.showBookmark> instead.
             */
            setShowBookmark(showBookmark: boolean): void;

            /**
             * Shows or hides the cancel button.
             */
            setShowCancel(showCancel: boolean, options?: AnimatedOptions): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.style> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.tokens> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.tokens> instead.
             */
            setTokens(tokens: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.SearchBar.value> property.
             * @deprecated Set the value using <Titanium.UI.SearchBar.value> instead.
             */
            setValue(value: string): void;

        }
        /**
         * Base event for class Titanium.UI.Shortcut
         */
        interface ShortcutBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Shortcut;

        }
        /**
         * Fired when a <Titanium.UI.ShortcutItem> was clicked on.
         */
        interface Shortcut_click_Event extends ShortcutBaseEvent {
            /**
             * The shortcut item clicked.
             */
            item: Titanium.UI.ShortcutItem;

        }
        interface ShortcutEventMap extends ProxyEventMap {
            click: Shortcut_click_Event;

        }
        /**
         * Manage application shortcuts.
         */
        class Shortcut extends Titanium.Proxy {
            /**
             * List dynamic shortcuts.
             */
            readonly items: Titanium.UI.ShortcutItem[];

            /**
             * List current pinned/static shortcuts.
             */
            readonly staticItems: Titanium.UI.ShortcutItem[];

            /**
             * Adds a shortcut item to the application.
             */
            add(item: Titanium.UI.ShortcutItem): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ShortcutEventMap>(name: K, callback: (this: Titanium.UI.Shortcut, event: ShortcutEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ShortcutEventMap>(name: K, event?: ShortcutEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Fetches a shortcut item by its unique string identifier.
             */
            getById(id: string): Titanium.UI.ShortcutItem;

            /**
             * Gets the value of the <Titanium.UI.Shortcut.items> property.
             * @deprecated Access <Titanium.UI.Shortcut.items> instead.
             */
            getItems(): Titanium.UI.ShortcutItem[];

            /**
             * Gets the value of the <Titanium.UI.Shortcut.staticItems> property.
             * @deprecated Access <Titanium.UI.Shortcut.staticItems> instead.
             */
            getStaticItems(): Titanium.UI.ShortcutItem[];

            /**
             * Removes the given shortcut item from the application.
             */
            remove(item: Titanium.UI.ShortcutItem): void;

            /**
             * Removes all shortcut items from the application.
             */
            removeAll(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ShortcutEventMap>(name: K, callback: (this: Titanium.UI.Shortcut, event: ShortcutEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * An application shortcut item.
         */
        class ShortcutItem extends Titanium.Proxy {
            /**
             * Shortcut data.
             */
            data: any;

            /**
             * Description of the shortcut.
             */
            description: string;

            /**
             * Shortcut icon.
             */
            icon: string | number;

            /**
             * Determines shortcut id.
             */
            id: string;

            /**
             * Title of the shortcut.
             */
            title: string;

            /**
             * Shortcut visibility.
             * @deprecated Use [Titanium.UI.Shortcut.items](Titanium.UI.Shortcut.items) to determine if shortcut is active.
             */
            visible: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.data> property.
             * @deprecated Access <Titanium.UI.ShortcutItem.data> instead.
             */
            getData(): any;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.description> property.
             * @deprecated Access <Titanium.UI.ShortcutItem.description> instead.
             */
            getDescription(): string;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.icon> property.
             * @deprecated Access <Titanium.UI.ShortcutItem.icon> instead.
             */
            getIcon(): string | number;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.id> property.
             * @deprecated Access <Titanium.UI.ShortcutItem.id> instead.
             */
            getId(): string;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.title> property.
             * @deprecated Access <Titanium.UI.ShortcutItem.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.ShortcutItem.visible> property.
             * @deprecated Use [Titanium.UI.Shortcut.items](Titanium.UI.Shortcut.items) to determine if shortcut is active.
             */
            getVisible(): boolean;

            /**
             * Hide the shortcut.
             * @deprecated Use [Titanium.UI.Shortcut.remove](Titanium.UI.Shortcut.remove) instead.
             */
            hide(): void;

            /**
             * Pin shortcut to launcher.
             */
            pin(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.data> property.
             * @deprecated Set the value using <Titanium.UI.ShortcutItem.data> instead.
             */
            setData(data: any): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.description> property.
             * @deprecated Set the value using <Titanium.UI.ShortcutItem.description> instead.
             */
            setDescription(description: string): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.icon> property.
             * @deprecated Set the value using <Titanium.UI.ShortcutItem.icon> instead.
             */
            setIcon(icon: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.id> property.
             * @deprecated Set the value using <Titanium.UI.ShortcutItem.id> instead.
             */
            setId(id: string): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.title> property.
             * @deprecated Set the value using <Titanium.UI.ShortcutItem.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.ShortcutItem.visible> property.
             * @deprecated Use [Titanium.UI.Shortcut.items](Titanium.UI.Shortcut.items) to determine if shortcut is active.
             */
            setVisible(visible: boolean): void;

            /**
             * Allow the shortcut to show.
             * @deprecated Use [Titanium.UI.Shortcut.add](Titanium.UI.Shortcut.add) instead.
             */
            show(): void;

        }
        /**
         * Base event for class Titanium.UI.Slider
         */
        interface SliderBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Slider;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Slider_click_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Slider_dblclick_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Slider_doubletap_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Slider_focus_Event extends SliderBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Slider_keypressed_Event extends SliderBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Slider_longclick_Event extends SliderBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Slider_longpress_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Slider_pinch_Event extends SliderBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Slider_postlayout_Event extends SliderBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Slider_singletap_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Slider_swipe_Event extends SliderBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Slider_touchcancel_Event extends SliderBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Slider_touchend_Event extends SliderBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Slider_touchmove_Event extends SliderBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Slider_touchstart_Event extends SliderBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Slider_twofingertap_Event extends SliderBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the value of the slider changes.
         */
        interface Slider_change_Event extends SliderBaseEvent {
            /**
             * True if change was made by the user. False if change was made programmatically.
             */
            isTrusted: boolean;

            /**
             * Dictionary with properties `x` and `y` of the thumb's left-top corner in
             * the control. Available with custom thumb image.
             */
            thumbOffset: Point;

            /**
             * Dictionary with properties `width` and `height` of the size of the thumb.
             * Available with custom thumb image.
             */
            thumbSize: Size;

            /**
             * New value of the slider.
             */
            value: number;

        }
        /**
         * Fired when the user starts tracking the slider.
         */
        interface Slider_start_Event extends SliderBaseEvent {
            /**
             * False. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * Current value of the slider.
             */
            value: number;

        }
        /**
         * Fired when the user stops tracking the slider.
         */
        interface Slider_stop_Event extends SliderBaseEvent {
            /**
             * False. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * Current value of the slider.
             */
            value: number;

        }
        interface SliderEventMap extends ProxyEventMap {
            change: Slider_change_Event;

            click: Slider_click_Event;

            dblclick: Slider_dblclick_Event;

            doubletap: Slider_doubletap_Event;

            focus: Slider_focus_Event;

            keypressed: Slider_keypressed_Event;

            longclick: Slider_longclick_Event;

            longpress: Slider_longpress_Event;

            pinch: Slider_pinch_Event;

            postlayout: Slider_postlayout_Event;

            singletap: Slider_singletap_Event;

            start: Slider_start_Event;

            stop: Slider_stop_Event;

            swipe: Slider_swipe_Event;

            touchcancel: Slider_touchcancel_Event;

            touchend: Slider_touchend_Event;

            touchmove: Slider_touchmove_Event;

            touchstart: Slider_touchstart_Event;

            twofingertap: Slider_twofingertap_Event;

        }
        /**
         * A slider component with a draggable thumb.
         */
        class Slider extends Titanium.UI.View {
            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Image URL of the slider left track when in the disabled state.
             */
            disabledLeftTrackImage: string;

            /**
             * Image URL of the slider right track when in the disabled state.
             */
            disabledRightTrackImage: string;

            /**
             * Image URL of the slider thumb when in the disabled state.
             */
            disabledThumbImage: string;

            /**
             * Boolean to indicate the enabled state of the slider.
             */
            enabled: boolean;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Image URL of the slider left track when in the highlighted state.
             */
            highlightedLeftTrackImage: string;

            /**
             * Image URL of the slider right track when in the highlighted state.
             */
            highlightedRightTrackImage: string;

            /**
             * Image URL of the slider thumb when in the highlighted state.
             */
            highlightedThumbImage: string;

            /**
             * Image URL of the slider left track.
             */
            leftTrackImage: string;

            /**
             * Size of the left end cap for the leftTrackImage, disabledLeftTrackImage, highlightedLeftTrackImage and selectedLeftTrackImage properties.
             */
            leftTrackLeftCap: number;

            /**
             * Size of the top end cap for the leftTrackImage, disabledLeftTrackImage, highlightedLeftTrackImage and selectedLeftTrackImage properties.
             */
            leftTrackTopCap: number;

            /**
             * Maximum value of the slider.
             */
            max: number;

            /**
             * Upper limit on the slider value that can be selected.
             */
            maxRange: number;

            /**
             * Minimum value of the slider.
             */
            min: number;

            /**
             * Lower limit on the slider value that can be selected.
             */
            minRange: number;

            /**
             * Image URL of the slider right track.
             */
            rightTrackImage: string;

            /**
             * Size of the left end cap for the rightTrackImage, disabledRightTrackImage, highlightedRightTrackImage and selectedRightTrackImage properties.
             */
            rightTrackLeftCap: number;

            /**
             * Size of the top end cap for the rightTrackImage, disabledRightTrackImage, highlightedRightTrackImage and selectedRightTrackImage properties.
             */
            rightTrackTopCap: number;

            /**
             * Image URL of the slider left track when in the selected state.
             */
            selectedLeftTrackImage: string;

            /**
             * Image URL of the slider right track when in the selected state.
             */
            selectedRightTrackImage: string;

            /**
             * Image URL of the slider thumb when in the selected state.
             */
            selectedThumbImage: string;

            /**
             * Separates the thumbImage from the slider track.
             */
            splitTrack: boolean;

            /**
             * Image for the slider thumb.
             */
            thumbImage: string | Titanium.Blob;

            /**
             * The color shown for the portion of the progress bar that is filled.
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * The color shown for the portion of the progress bar that is not filled.
             */
            trackTintColor: string | Titanium.UI.Color;

            /**
             * Current value of the slider.
             */
            value: number;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof SliderEventMap>(name: K, callback: (this: Titanium.UI.Slider, event: SliderEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof SliderEventMap>(name: K, event?: SliderEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Slider.children> property.
             * @deprecated Access <Titanium.UI.Slider.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Slider.disabledLeftTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.disabledLeftTrackImage> instead.
             */
            getDisabledLeftTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.disabledRightTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.disabledRightTrackImage> instead.
             */
            getDisabledRightTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.disabledThumbImage> property.
             * @deprecated Access <Titanium.UI.Slider.disabledThumbImage> instead.
             */
            getDisabledThumbImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.enabled> property.
             * @deprecated Access <Titanium.UI.Slider.enabled> instead.
             */
            getEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Slider.height> property.
             * @deprecated Access <Titanium.UI.Slider.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.Slider.highlightedLeftTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.highlightedLeftTrackImage> instead.
             */
            getHighlightedLeftTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.highlightedRightTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.highlightedRightTrackImage> instead.
             */
            getHighlightedRightTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.highlightedThumbImage> property.
             * @deprecated Access <Titanium.UI.Slider.highlightedThumbImage> instead.
             */
            getHighlightedThumbImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.leftTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.leftTrackImage> instead.
             */
            getLeftTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.leftTrackLeftCap> property.
             * @deprecated Access <Titanium.UI.Slider.leftTrackLeftCap> instead.
             */
            getLeftTrackLeftCap(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.leftTrackTopCap> property.
             * @deprecated Access <Titanium.UI.Slider.leftTrackTopCap> instead.
             */
            getLeftTrackTopCap(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.max> property.
             * @deprecated Access <Titanium.UI.Slider.max> instead.
             */
            getMax(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.maxRange> property.
             * @deprecated Access <Titanium.UI.Slider.maxRange> instead.
             */
            getMaxRange(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.min> property.
             * @deprecated Access <Titanium.UI.Slider.min> instead.
             */
            getMin(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.minRange> property.
             * @deprecated Access <Titanium.UI.Slider.minRange> instead.
             */
            getMinRange(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.rightTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.rightTrackImage> instead.
             */
            getRightTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.rightTrackLeftCap> property.
             * @deprecated Access <Titanium.UI.Slider.rightTrackLeftCap> instead.
             */
            getRightTrackLeftCap(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.rightTrackTopCap> property.
             * @deprecated Access <Titanium.UI.Slider.rightTrackTopCap> instead.
             */
            getRightTrackTopCap(): number;

            /**
             * Gets the value of the <Titanium.UI.Slider.selectedLeftTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.selectedLeftTrackImage> instead.
             */
            getSelectedLeftTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.selectedRightTrackImage> property.
             * @deprecated Access <Titanium.UI.Slider.selectedRightTrackImage> instead.
             */
            getSelectedRightTrackImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.selectedThumbImage> property.
             * @deprecated Access <Titanium.UI.Slider.selectedThumbImage> instead.
             */
            getSelectedThumbImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Slider.splitTrack> property.
             * @deprecated Access <Titanium.UI.Slider.splitTrack> instead.
             */
            getSplitTrack(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Slider.thumbImage> property.
             * @deprecated Access <Titanium.UI.Slider.thumbImage> instead.
             */
            getThumbImage(): string | Titanium.Blob;

            /**
             * Gets the value of the <Titanium.UI.Slider.tintColor> property.
             * @deprecated Access <Titanium.UI.Slider.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Slider.trackTintColor> property.
             * @deprecated Access <Titanium.UI.Slider.trackTintColor> instead.
             */
            getTrackTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Slider.value> property.
             * @deprecated Access <Titanium.UI.Slider.value> instead.
             */
            getValue(): number;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof SliderEventMap>(name: K, callback: (this: Titanium.UI.Slider, event: SliderEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Slider.disabledLeftTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.disabledLeftTrackImage> instead.
             */
            setDisabledLeftTrackImage(disabledLeftTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.disabledRightTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.disabledRightTrackImage> instead.
             */
            setDisabledRightTrackImage(disabledRightTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.disabledThumbImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.disabledThumbImage> instead.
             */
            setDisabledThumbImage(disabledThumbImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.enabled> property.
             * @deprecated Set the value using <Titanium.UI.Slider.enabled> instead.
             */
            setEnabled(enabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.height> property.
             * @deprecated Set the value using <Titanium.UI.Slider.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.Slider.highlightedLeftTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.highlightedLeftTrackImage> instead.
             */
            setHighlightedLeftTrackImage(highlightedLeftTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.highlightedRightTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.highlightedRightTrackImage> instead.
             */
            setHighlightedRightTrackImage(highlightedRightTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.highlightedThumbImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.highlightedThumbImage> instead.
             */
            setHighlightedThumbImage(highlightedThumbImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.leftTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.leftTrackImage> instead.
             */
            setLeftTrackImage(leftTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.leftTrackLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.Slider.leftTrackLeftCap> instead.
             */
            setLeftTrackLeftCap(leftTrackLeftCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.leftTrackTopCap> property.
             * @deprecated Set the value using <Titanium.UI.Slider.leftTrackTopCap> instead.
             */
            setLeftTrackTopCap(leftTrackTopCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.max> property.
             * @deprecated Set the value using <Titanium.UI.Slider.max> instead.
             */
            setMax(max: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.maxRange> property.
             * @deprecated Set the value using <Titanium.UI.Slider.maxRange> instead.
             */
            setMaxRange(maxRange: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.min> property.
             * @deprecated Set the value using <Titanium.UI.Slider.min> instead.
             */
            setMin(min: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.minRange> property.
             * @deprecated Set the value using <Titanium.UI.Slider.minRange> instead.
             */
            setMinRange(minRange: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.rightTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.rightTrackImage> instead.
             */
            setRightTrackImage(rightTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.rightTrackLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.Slider.rightTrackLeftCap> instead.
             */
            setRightTrackLeftCap(rightTrackLeftCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.rightTrackTopCap> property.
             * @deprecated Set the value using <Titanium.UI.Slider.rightTrackTopCap> instead.
             */
            setRightTrackTopCap(rightTrackTopCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.selectedLeftTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.selectedLeftTrackImage> instead.
             */
            setSelectedLeftTrackImage(selectedLeftTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.selectedRightTrackImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.selectedRightTrackImage> instead.
             */
            setSelectedRightTrackImage(selectedRightTrackImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.selectedThumbImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.selectedThumbImage> instead.
             */
            setSelectedThumbImage(selectedThumbImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.splitTrack> property.
             * @deprecated Set the value using <Titanium.UI.Slider.splitTrack> instead.
             */
            setSplitTrack(splitTrack: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.thumbImage> property.
             * @deprecated Set the value using <Titanium.UI.Slider.thumbImage> instead.
             */
            setThumbImage(thumbImage: string | Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.Slider.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Slider.trackTintColor> property.
             * @deprecated Set the value using <Titanium.UI.Slider.trackTintColor> instead.
             */
            setTrackTintColor(trackTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the [value](Titanium.UI.Slider.value) property.
             */
            setValue(value: number, options?: AnimatedOptions): void;

        }
        /**
         * Base event for class Titanium.UI.Switch
         */
        interface SwitchBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Switch;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Switch_click_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Switch_dblclick_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Switch_doubletap_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Switch_focus_Event extends SwitchBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Switch_keypressed_Event extends SwitchBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Switch_longclick_Event extends SwitchBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Switch_longpress_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Switch_pinch_Event extends SwitchBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Switch_postlayout_Event extends SwitchBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Switch_singletap_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Switch_swipe_Event extends SwitchBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Switch_touchcancel_Event extends SwitchBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Switch_touchend_Event extends SwitchBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Switch_touchmove_Event extends SwitchBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Switch_touchstart_Event extends SwitchBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Switch_twofingertap_Event extends SwitchBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the switch value changes.
         */
        interface Switch_change_Event extends SwitchBaseEvent {
            /**
             * New value of the switch.
             */
            value: boolean;

        }
        interface SwitchEventMap extends ProxyEventMap {
            change: Switch_change_Event;

            click: Switch_click_Event;

            dblclick: Switch_dblclick_Event;

            doubletap: Switch_doubletap_Event;

            focus: Switch_focus_Event;

            keypressed: Switch_keypressed_Event;

            longclick: Switch_longclick_Event;

            longpress: Switch_longpress_Event;

            pinch: Switch_pinch_Event;

            postlayout: Switch_postlayout_Event;

            singletap: Switch_singletap_Event;

            swipe: Switch_swipe_Event;

            touchcancel: Switch_touchcancel_Event;

            touchend: Switch_touchend_Event;

            touchmove: Switch_touchmove_Event;

            touchstart: Switch_touchstart_Event;

            twofingertap: Switch_twofingertap_Event;

        }
        /**
         * An on/off switch control.
         */
        class Switch extends Titanium.UI.View {
            /**
             * Determines if there is animation when the switch value changes.
             */
            animated: boolean;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Color to use for switch text, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Determines whether the switch is enabled.
             */
            enabled: boolean;

            /**
             * Font to use for the switch text.
             */
            font: Font;

            /**
             * The color used to tint the appearance of the switch when it is turned on.
             */
            onTintColor: string | Titanium.UI.Color;

            /**
             * Style of the switch.
             */
            style: number;

            /**
             * Horizontal text alignment of the switch title.
             */
            textAlign: string | number;

            /**
             * The color used to tint the appearance of the thumb.
             */
            thumbTintColor: string | Titanium.UI.Color;

            /**
             * The color used to tint the outline of the switch when it is turned off.
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * Text to display next to the switch, when the checkbox style is in use.
             */
            title: string;

            /**
             * Text to display on the switch in its "off" state, when the toggle button style is in use.
             */
            titleOff: string;

            /**
             * Text to display on the switch in its "on" state, when the toggle button style is in use.
             */
            titleOn: string;

            /**
             * Indicates whether the switch has been turned on or off by the user. May also be set
             * programmatically.
             */
            value: boolean;

            /**
             * Vertical alignment for the text field.
             */
            verticalAlign: number | string;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof SwitchEventMap>(name: K, callback: (this: Titanium.UI.Switch, event: SwitchEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof SwitchEventMap>(name: K, event?: SwitchEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Switch.animated> property.
             * @deprecated Access <Titanium.UI.Switch.animated> instead.
             */
            getAnimated(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Switch.children> property.
             * @deprecated Access <Titanium.UI.Switch.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Switch.color> property.
             * @deprecated Access <Titanium.UI.Switch.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Switch.enabled> property.
             * @deprecated Access <Titanium.UI.Switch.enabled> instead.
             */
            getEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Switch.font> property.
             * @deprecated Access <Titanium.UI.Switch.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.Switch.onTintColor> property.
             * @deprecated Access <Titanium.UI.Switch.onTintColor> instead.
             */
            getOnTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Switch.style> property.
             * @deprecated Access <Titanium.UI.Switch.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.Switch.textAlign> property.
             * @deprecated Access <Titanium.UI.Switch.textAlign> instead.
             */
            getTextAlign(): string | number;

            /**
             * Gets the value of the <Titanium.UI.Switch.thumbTintColor> property.
             * @deprecated Access <Titanium.UI.Switch.thumbTintColor> instead.
             */
            getThumbTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Switch.tintColor> property.
             * @deprecated Access <Titanium.UI.Switch.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Switch.title> property.
             * @deprecated Access <Titanium.UI.Switch.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Switch.titleOff> property.
             * @deprecated Access <Titanium.UI.Switch.titleOff> instead.
             */
            getTitleOff(): string;

            /**
             * Gets the value of the <Titanium.UI.Switch.titleOn> property.
             * @deprecated Access <Titanium.UI.Switch.titleOn> instead.
             */
            getTitleOn(): string;

            /**
             * Gets the value of the <Titanium.UI.Switch.value> property.
             * @deprecated Access <Titanium.UI.Switch.value> instead.
             */
            getValue(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Switch.verticalAlign> property.
             * @deprecated Access <Titanium.UI.Switch.verticalAlign> instead.
             */
            getVerticalAlign(): number | string;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof SwitchEventMap>(name: K, callback: (this: Titanium.UI.Switch, event: SwitchEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Switch.animated> property.
             * @deprecated Set the value using <Titanium.UI.Switch.animated> instead.
             */
            setAnimated(animated: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.color> property.
             * @deprecated Set the value using <Titanium.UI.Switch.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.enabled> property.
             * @deprecated Set the value using <Titanium.UI.Switch.enabled> instead.
             */
            setEnabled(enabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.font> property.
             * @deprecated Set the value using <Titanium.UI.Switch.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.onTintColor> property.
             * @deprecated Set the value using <Titanium.UI.Switch.onTintColor> instead.
             */
            setOnTintColor(onTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.style> property.
             * @deprecated Set the value using <Titanium.UI.Switch.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.textAlign> property.
             * @deprecated Set the value using <Titanium.UI.Switch.textAlign> instead.
             */
            setTextAlign(textAlign: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.thumbTintColor> property.
             * @deprecated Set the value using <Titanium.UI.Switch.thumbTintColor> instead.
             */
            setThumbTintColor(thumbTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.Switch.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.title> property.
             * @deprecated Set the value using <Titanium.UI.Switch.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.titleOff> property.
             * @deprecated Set the value using <Titanium.UI.Switch.titleOff> instead.
             */
            setTitleOff(titleOff: string): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.titleOn> property.
             * @deprecated Set the value using <Titanium.UI.Switch.titleOn> instead.
             */
            setTitleOn(titleOn: string): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.value> property.
             * @deprecated Set the value using <Titanium.UI.Switch.value> instead.
             */
            setValue(value: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Switch.verticalAlign> property.
             * @deprecated Set the value using <Titanium.UI.Switch.verticalAlign> instead.
             */
            setVerticalAlign(verticalAlign: number | string): void;

        }
        /**
         * Base event for class Titanium.UI.Tab
         */
        interface TabBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Tab;

        }
        /**
         * Fired when this tab is clicked in the tab group.
         */
        interface Tab_click_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Tab_dblclick_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Tab_doubletap_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Tab_keypressed_Event extends TabBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Tab_longclick_Event extends TabBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Tab_longpress_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Tab_pinch_Event extends TabBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Tab_postlayout_Event extends TabBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Tab_singletap_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Tab_swipe_Event extends TabBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Tab_touchcancel_Event extends TabBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Tab_touchend_Event extends TabBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Tab_touchmove_Event extends TabBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Tab_touchstart_Event extends TabBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Tab_twofingertap_Event extends TabBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the tab is no longer selected.
         */
        interface Tab_unselected_Event extends TabBaseEvent {
            /**
             * Index of the current active tab.
             */
            index: number;

            /**
             * Index of the previous active tab.
             */
            previousIndex: number;

            /**
             * Previous active tab object.
             */
            previousTab: Titanium.UI.Tab;

            /**
             * Current active tab object.
             */
            tab: Titanium.UI.Tab;

        }
        /**
         * Fired when the tab is selected.
         */
        interface Tab_selected_Event extends TabBaseEvent {
            /**
             * Index of the current active tab.
             */
            index: number;

            /**
             * Index of the previous active tab.
             */
            previousIndex: number;

            /**
             * Previous active tab object.
             */
            previousTab: Titanium.UI.Tab;

            /**
             * Current active tab object.
             */
            tab: Titanium.UI.Tab;

        }
        interface TabEventMap extends ProxyEventMap {
            click: Tab_click_Event;

            dblclick: Tab_dblclick_Event;

            doubletap: Tab_doubletap_Event;

            keypressed: Tab_keypressed_Event;

            longclick: Tab_longclick_Event;

            longpress: Tab_longpress_Event;

            pinch: Tab_pinch_Event;

            postlayout: Tab_postlayout_Event;

            selected: Tab_selected_Event;

            singletap: Tab_singletap_Event;

            swipe: Tab_swipe_Event;

            touchcancel: Tab_touchcancel_Event;

            touchend: Tab_touchend_Event;

            touchmove: Tab_touchmove_Event;

            touchstart: Tab_touchstart_Event;

            twofingertap: Tab_twofingertap_Event;

            unselected: Tab_unselected_Event;

        }
        /**
         * A tab instance for a [TabGroup](Titanium.UI.TabGroup).
         */
        class Tab extends Titanium.UI.View {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * `true` if this tab is active, `false` if it is not.
             */
            active: boolean;

            /**
             * Icon URL for this tab when active.
             */
            activeIcon: string;

            /**
             * Defines if the active icon property of the tab must be used as a mask.
             */
            activeIconIsMask: boolean;

            /**
             * Defines the color of the tab icon when it is active. Will fallback to activeTitleColor when not defined.
             */
            activeTintColor: string;

            /**
             * Defines the color of the title of tab when it's active.
             */
            activeTitleColor: string | Titanium.UI.Color;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Sets the color of the tab when it is inactive.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Sets the color of the tab when it is focused.
             */
            backgroundFocusedColor: string;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Badge value for this tab. `null` indicates no badge.
             */
            badge: string;

            /**
             * If this item displays a badge, this color will be used for the badge's background.
             * If set to null, the default background color will be used instead.
             */
            badgeColor: string | Titanium.UI.Color;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Icon URL for this tab.
             */
            icon: string;

            /**
             * The icon inset or outset for each edge.
             */
            iconInsets: TabIconInsets;

            /**
             * Defines if the icon property of the tab must be used as a mask.
             */
            iconIsMask: boolean;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * View's left position, in platform-specific units.
             */
            left: never;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: never;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: never;

            /**
             * View's right position, in platform-specific units.
             */
            right: never;

            /**
             * The size of the view in system units.
             */
            readonly size: never;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * Defines the color of the tab icon. Will fallback to titleColor when not defined.
             */
            tintColor: string;

            /**
             * Title for this tab.
             */
            title: string;

            /**
             * Defines the color of the title of tab when it's inactive.
             */
            titleColor: string | Titanium.UI.Color;

            /**
             * Key identifying a string from the locale file to use for the tab title. Only one of `title` or `titleid` should be specified.
             */
            titleid: string;

            /**
             * The view's top position.
             */
            top: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Determines whether the view is visible.
             */
            visible: never;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Root-level tab window.  All tabs must have at least one root-level tab window.
             */
            window: Titanium.UI.Window;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TabEventMap>(name: K, callback: (this: Titanium.UI.Tab, event: TabEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Closes the top-level window for this tab.
             */
            close(window: Titanium.UI.Window, options?: any): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TabEventMap>(name: K, event?: TabEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Tab.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.Tab.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.Tab.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.Tab.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.Tab.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.active> property.
             * @deprecated Access <Titanium.UI.Tab.active> instead.
             */
            getActive(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Tab.activeIcon> property.
             * @deprecated Access <Titanium.UI.Tab.activeIcon> instead.
             */
            getActiveIcon(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.activeIconIsMask> property.
             * @deprecated Access <Titanium.UI.Tab.activeIconIsMask> instead.
             */
            getActiveIconIsMask(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Tab.activeTintColor> property.
             * @deprecated Access <Titanium.UI.Tab.activeTintColor> instead.
             */
            getActiveTintColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.activeTitleColor> property.
             * @deprecated Access <Titanium.UI.Tab.activeTitleColor> instead.
             */
            getActiveTitleColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Tab.anchorPoint> property.
             * @deprecated Access <Titanium.UI.Tab.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.animatedCenter> property.
             * @deprecated Access <Titanium.UI.Tab.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundColor> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.Tab.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.badge> property.
             * @deprecated Access <Titanium.UI.Tab.badge> instead.
             */
            getBadge(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.badgeColor> property.
             * @deprecated Access <Titanium.UI.Tab.badgeColor> instead.
             */
            getBadgeColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Tab.borderColor> property.
             * @deprecated Access <Titanium.UI.Tab.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.borderRadius> property.
             * @deprecated Access <Titanium.UI.Tab.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.borderWidth> property.
             * @deprecated Access <Titanium.UI.Tab.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.bottom> property.
             * @deprecated Access <Titanium.UI.Tab.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.center> property.
             * @deprecated Access <Titanium.UI.Tab.center> instead.
             */
            getCenter: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.children> property.
             * @deprecated Access <Titanium.UI.Tab.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.focusable> property.
             * @deprecated Access <Titanium.UI.Tab.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.height> property.
             * @deprecated Access <Titanium.UI.Tab.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.Tab.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.icon> property.
             * @deprecated Access <Titanium.UI.Tab.icon> instead.
             */
            getIcon(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.iconInsets> property.
             * @deprecated Access <Titanium.UI.Tab.iconInsets> instead.
             */
            getIconInsets(): TabIconInsets;

            /**
             * Gets the value of the <Titanium.UI.Tab.iconIsMask> property.
             * @deprecated Access <Titanium.UI.Tab.iconIsMask> instead.
             */
            getIconIsMask(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Tab.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.Tab.keepScreenOn> instead.
             */
            getKeepScreenOn: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.layout> property.
             * @deprecated Access <Titanium.UI.Tab.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.left> property.
             * @deprecated Access <Titanium.UI.Tab.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.opacity> property.
             * @deprecated Access <Titanium.UI.Tab.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.rect> property.
             * @deprecated Access <Titanium.UI.Tab.rect> instead.
             */
            getRect: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.right> property.
             * @deprecated Access <Titanium.UI.Tab.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.size> property.
             * @deprecated Access <Titanium.UI.Tab.size> instead.
             */
            getSize: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.Tab.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.tintColor> property.
             * @deprecated Access <Titanium.UI.Tab.tintColor> instead.
             */
            getTintColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.title> property.
             * @deprecated Access <Titanium.UI.Tab.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.titleColor> property.
             * @deprecated Access <Titanium.UI.Tab.titleColor> instead.
             */
            getTitleColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Tab.titleid> property.
             * @deprecated Access <Titanium.UI.Tab.titleid> instead.
             */
            getTitleid(): string;

            /**
             * Gets the value of the <Titanium.UI.Tab.top> property.
             * @deprecated Access <Titanium.UI.Tab.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.transform> property.
             * @deprecated Access <Titanium.UI.Tab.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.visible> property.
             * @deprecated Access <Titanium.UI.Tab.visible> instead.
             */
            getVisible: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.width> property.
             * @deprecated Access <Titanium.UI.Tab.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.Tab.window> property.
             * @deprecated Access <Titanium.UI.Tab.window> instead.
             */
            getWindow(): Titanium.UI.Window;

            /**
             * Gets the value of the <Titanium.UI.Tab.zIndex> property.
             * @deprecated Access <Titanium.UI.Tab.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Hides this view.
             */
            hide: never;

            /**
             * Opens a new window.
             */
            open(window: Titanium.UI.Window, options?: openWindowParams): void;

            /**
             * Closes all windows that are currently opened inside the tab.
             */
            popToRootWindow(options?: AnimatedOptions): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TabEventMap>(name: K, callback: (this: Titanium.UI.Tab, event: TabEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.Tab.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.Tab.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.Tab.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.Tab.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.active> property.
             * @deprecated Set the value using <Titanium.UI.Tab.active> instead.
             */
            setActive(active: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.activeIcon> property.
             * @deprecated Set the value using <Titanium.UI.Tab.activeIcon> instead.
             */
            setActiveIcon(activeIcon: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.activeIconIsMask> property.
             * @deprecated Set the value using <Titanium.UI.Tab.activeIconIsMask> instead.
             */
            setActiveIconIsMask(activeIconIsMask: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.activeTintColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.activeTintColor> instead.
             */
            setActiveTintColor(activeTintColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.activeTitleColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.activeTitleColor> instead.
             */
            setActiveTitleColor(activeTitleColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.Tab.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor(backgroundFocusedColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.Tab.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.badge> property.
             * @deprecated Set the value using <Titanium.UI.Tab.badge> instead.
             */
            setBadge(badge: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.badgeColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.badgeColor> instead.
             */
            setBadgeColor(badgeColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.Tab.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.Tab.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.bottom> property.
             * @deprecated Set the value using <Titanium.UI.Tab.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.center> property.
             * @deprecated Set the value using <Titanium.UI.Tab.center> instead.
             */
            setCenter: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.focusable> property.
             * @deprecated Set the value using <Titanium.UI.Tab.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.height> property.
             * @deprecated Set the value using <Titanium.UI.Tab.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.Tab.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.icon> property.
             * @deprecated Set the value using <Titanium.UI.Tab.icon> instead.
             */
            setIcon(icon: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.iconInsets> property.
             * @deprecated Set the value using <Titanium.UI.Tab.iconInsets> instead.
             */
            setIconInsets(iconInsets: TabIconInsets): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.iconIsMask> property.
             * @deprecated Set the value using <Titanium.UI.Tab.iconIsMask> instead.
             */
            setIconIsMask(iconIsMask: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.Tab.keepScreenOn> instead.
             */
            setKeepScreenOn: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.layout> property.
             * @deprecated Set the value using <Titanium.UI.Tab.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.left> property.
             * @deprecated Set the value using <Titanium.UI.Tab.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.opacity> property.
             * @deprecated Set the value using <Titanium.UI.Tab.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.right> property.
             * @deprecated Set the value using <Titanium.UI.Tab.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.Tab.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.tintColor> instead.
             */
            setTintColor(tintColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.title> property.
             * @deprecated Set the value using <Titanium.UI.Tab.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.titleColor> property.
             * @deprecated Set the value using <Titanium.UI.Tab.titleColor> instead.
             */
            setTitleColor(titleColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.titleid> property.
             * @deprecated Set the value using <Titanium.UI.Tab.titleid> instead.
             */
            setTitleid(titleid: string): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.top> property.
             * @deprecated Set the value using <Titanium.UI.Tab.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.transform> property.
             * @deprecated Set the value using <Titanium.UI.Tab.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.visible> property.
             * @deprecated Set the value using <Titanium.UI.Tab.visible> instead.
             */
            setVisible: never;

            /**
             * Sets the value of the <Titanium.UI.Tab.width> property.
             * @deprecated Set the value using <Titanium.UI.Tab.width> instead.
             */
            setWidth: never;

            /**
             * Sets the root window that appears in the tab.
             */
            setWindow(window: Titanium.UI.Window): void;

            /**
             * Sets the value of the <Titanium.UI.Tab.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.Tab.zIndex> instead.
             */
            setZIndex: never;

            /**
             * Makes this view visible.
             */
            show: never;

        }
        /**
         * Base event for class Titanium.UI.TabGroup
         */
        interface TabGroupBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TabGroup;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface TabGroup_click_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TabGroup_dblclick_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface TabGroup_doubletap_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when this tab group gains focus. On Android, fired when a tab in this tab group
         * gains focus.
         */
        interface TabGroup_focus_Event extends TabGroupBaseEvent {
            /**
             * Index of the current active tab.
             */
            index: number;

            /**
             * Index of the previous active tab.
             */
            previousIndex: number;

            /**
             * Previous active tab.
             */
            previousTab: Titanium.UI.Tab;

            /**
             * Active tab.
             */
            tab: Titanium.UI.Tab;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TabGroup_keypressed_Event extends TabGroupBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TabGroup_longclick_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TabGroup_longpress_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TabGroup_pinch_Event extends TabGroupBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TabGroup_postlayout_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TabGroup_singletap_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface TabGroup_swipe_Event extends TabGroupBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface TabGroup_touchcancel_Event extends TabGroupBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface TabGroup_touchend_Event extends TabGroupBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface TabGroup_touchmove_Event extends TabGroupBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface TabGroup_touchstart_Event extends TabGroupBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TabGroup_twofingertap_Event extends TabGroupBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the back button is pressed by the user.
         */
        interface TabGroup_androidback_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the Camera button is released.
         */
        interface TabGroup_androidcamera_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the Camera button is half-pressed then released.
         */
        interface TabGroup_androidfocus_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the Search button is released.
         */
        interface TabGroup_androidsearch_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the volume down button is released.
         */
        interface TabGroup_androidvoldown_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the volume up button is released.
         */
        interface TabGroup_androidvolup_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when this tab group loses focus. On Android, fired when a tab in this tab group
         * loses focus.
         */
        interface TabGroup_blur_Event extends TabGroupBaseEvent {
            /**
             * Index of the current active tab. On iOS, a value of `undefined` indicates that the
             * **More** tab was the active tab.
             */
            index: number;

            /**
             * Index of the previous active tab. On iOS, a value of `undefined` indicates that the
             * **More** tab was the previous tab.
             */
            previousIndex: number;

            /**
             * Previous active tab. On iOS, a value of `undefined` indicates that the **More** tab was
             * the previous tab.
             */
            previousTab: Titanium.UI.Tab;

            /**
             * Active tab.
             */
            tab: Titanium.UI.Tab;

        }
        /**
         * Fired when the tab group is closed.
         */
        interface TabGroup_close_Event extends TabGroupBaseEvent {
        }
        /**
         * Fired when the tab group is opened.
         */
        interface TabGroup_open_Event extends TabGroupBaseEvent {
        }
        interface TabGroupEventMap extends ProxyEventMap {
            androidback: TabGroup_androidback_Event;

            androidcamera: TabGroup_androidcamera_Event;

            androidfocus: TabGroup_androidfocus_Event;

            androidsearch: TabGroup_androidsearch_Event;

            androidvoldown: TabGroup_androidvoldown_Event;

            androidvolup: TabGroup_androidvolup_Event;

            blur: TabGroup_blur_Event;

            click: TabGroup_click_Event;

            close: TabGroup_close_Event;

            dblclick: TabGroup_dblclick_Event;

            doubletap: TabGroup_doubletap_Event;

            focus: TabGroup_focus_Event;

            keypressed: TabGroup_keypressed_Event;

            longclick: TabGroup_longclick_Event;

            longpress: TabGroup_longpress_Event;

            open: TabGroup_open_Event;

            pinch: TabGroup_pinch_Event;

            postlayout: TabGroup_postlayout_Event;

            singletap: TabGroup_singletap_Event;

            swipe: TabGroup_swipe_Event;

            touchcancel: TabGroup_touchcancel_Event;

            touchend: TabGroup_touchend_Event;

            touchmove: TabGroup_touchmove_Event;

            touchstart: TabGroup_touchstart_Event;

            twofingertap: TabGroup_twofingertap_Event;

        }
        /**
         * A tabbed group of windows.
         */
        class TabGroup extends Titanium.UI.Window {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: never;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: never;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: never;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: never;

            /**
             * Active tab.
             */
            activeTab: number | Titanium.UI.Tab;

            /**
             * Default background image for the active tab.
             */
            activeTabBackgroundImage: string;

            /**
             * Color applied to active tabs icons, as a color name or hex triplet, where the tab's activeIcon was not defined.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.activeTintColor](Titanium.UI.TabGroup.activeTintColor) or alternatively [Titanium.UI.Tab.activeTintColor](Titanium.UI.Tab.activeTintColor).
             */
            activeTabIconTint: string | Titanium.UI.Color;

            /**
             * The activeTintColor to apply to tabs.
             */
            activeTintColor: string;

            /**
             * Defines the color of the title of tab when it's active.
             */
            activeTitleColor: string | Titanium.UI.Color;

            /**
             * Reference to the Android Activity object associated with this tab group.
             */
            readonly activity: Titanium.Android.Activity;

            /**
             * Allow the user to reorder tabs in the tab group using the **Edit** button on the **More**
             * tab.
             */
            allowUserCustomization: boolean;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: never;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: never;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Default navigation bar color (typically for the **More** tab), as a color name or hex triplet.
             */
            barColor: string | Titanium.UI.Color;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: never;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: never;

            /**
             * Border width of the view.
             */
            borderWidth: never;

            /**
             * Window's bottom position, in platform-specific units.
             */
            bottom: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Title for the edit button on the **More** tab.
             */
            editButtonTitle: string;

            /**
             * Boolean value indicating if the application should exit when closing the tab group, whether via Android
             * back button or the [close](Titanium.UI.TabGroup.close) method.
             */
            exitOnClose: boolean;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: never;

            /**
             * View height, in platform-specific units.
             */
            height: never;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: never;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * Window's left position, in platform-specific units.
             */
            left: never;

            /**
             * The tintColor to apply to the navigation bar (typically for the **More** tab).
             */
            navTintColor: string | Titanium.UI.Color;

            /**
             * The opacity from 0.0-1.0.
             */
            opacity: never;

            /**
             * Window's right position, in platform-specific units.
             */
            right: never;

            /**
             * Image of the shadow placed between the tab bar and the content area.
             */
            shadowImage: string;

            /**
             * Determines whether the [TABS_STYLE_BOTTOM_NAVIGATION](Titanium.UI.Android.TABS_STYLE_BOTTOM_NAVIGATION) uses shiftMode.
             */
            shiftMode: boolean;

            /**
             * Boolean value indicating if changing pages by tab clicks is animated.
             */
            smoothScrollOnTabClick: boolean;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * Property defining which style for the TabGroup to be used.
             */
            style: number;

            /**
             * Boolean value indicating if tab navigation can be done by swipes, in addition to tab clicks.
             */
            swipeable: boolean;

            /**
             * Tabs managed by the tab group.
             */
            tabs: Titanium.UI.Tab[];

            /**
             * Default background color for inactive tabs, as a color name or hex triplet.
             */
            tabsBackgroundColor: string | Titanium.UI.Color;

            /**
             * Default background image for tabs.
             */
            tabsBackgroundImage: string;

            /**
             * Default background selected color for tabs, as a color name or hex triplet.
             */
            tabsBackgroundSelectedColor: string;

            /**
             * The tintColor to apply to the tabs.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            tabsTintColor: string | Titanium.UI.Color;

            /**
             * A Boolean value that indicates whether the tab bar is translucent.
             */
            tabsTranslucent: boolean;

            /**
             * The tintColor to apply to tabs.
             */
            tintColor: string;

            /**
             * Title for this tabGroup.
             */
            title: string;

            /**
             * Title text attributes of the window to be applied on the **More** tab.
             */
            titleAttributes: titleAttributesParams;

            /**
             * Defines the color of the title of tab when it's inactive.
             */
            titleColor: string | Titanium.UI.Color;

            /**
             * Window's top position, in platform-specific units.
             */
            top: never;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: never;

            /**
             * Boolean value indicating if the nav bar (typically for the **More** tab), is translucent.
             */
            translucent: boolean;

            /**
             * Unselected items in this tab group will be tinted with this color. Setting this value to null
             * indicates that the tab group should use its default value instead.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            unselectedItemTintColor: string | Titanium.UI.Color;

            /**
             * View's width, in platform-specific units.
             */
            width: never;

            /**
             * Determines how the tab group is treated when a soft input method (such as a virtual keyboard)
             * is displayed.
             */
            windowSoftInputMode: number;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: never;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TabGroupEventMap>(name: K, callback: (this: Titanium.UI.TabGroup, event: TabGroupEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a tab to the tab group.
             */
            addTab(tab: Titanium.UI.Tab): void;

            /**
             * Closes the tab group and removes it from the UI.
             */
            close(params?: Titanium.UI.Animation | Dictionary<Titanium.UI.Animation> | closeWindowParams): void;

            /**
             * Disable (or re-enable) tab navigation. If tab navigation is disabled, the tabs are hidden and
             * the last selected tab window is shown.
             */
            disableTabNavigation(disable: boolean): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TabGroupEventMap>(name: K, event?: TabGroupEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.TabGroup.accessibilityHidden> instead.
             */
            getAccessibilityHidden: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.TabGroup.accessibilityHint> instead.
             */
            getAccessibilityHint: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.TabGroup.accessibilityLabel> instead.
             */
            getAccessibilityLabel: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.TabGroup.accessibilityValue> instead.
             */
            getAccessibilityValue: never;

            /**
             * Gets the currently-active tab.
             */
            getActiveTab(): Titanium.UI.Tab;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.activeTabBackgroundImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.activeTabBackgroundImage> instead.
             */
            getActiveTabBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.activeTabIconTint> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.activeTintColor](Titanium.UI.TabGroup.activeTintColor) or alternatively [Titanium.UI.Tab.activeTintColor](Titanium.UI.Tab.activeTintColor).
             */
            getActiveTabIconTint(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.activeTintColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.activeTintColor> instead.
             */
            getActiveTintColor(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.activeTitleColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.activeTitleColor> instead.
             */
            getActiveTitleColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.activity> property.
             * @deprecated Access <Titanium.UI.TabGroup.activity> instead.
             */
            getActivity(): Titanium.Android.Activity;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.allowUserCustomization> property.
             * @deprecated Access <Titanium.UI.TabGroup.allowUserCustomization> instead.
             */
            getAllowUserCustomization(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.anchorPoint> property.
             * @deprecated Access <Titanium.UI.TabGroup.anchorPoint> instead.
             */
            getAnchorPoint: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.animatedCenter> property.
             * @deprecated Access <Titanium.UI.TabGroup.animatedCenter> instead.
             */
            getAnimatedCenter: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundGradient> instead.
             */
            getBackgroundGradient: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundImage> instead.
             */
            getBackgroundImage: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.TabGroup.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.barColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.barColor> instead.
             */
            getBarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.borderColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.borderColor> instead.
             */
            getBorderColor: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.borderRadius> property.
             * @deprecated Access <Titanium.UI.TabGroup.borderRadius> instead.
             */
            getBorderRadius: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.borderWidth> property.
             * @deprecated Access <Titanium.UI.TabGroup.borderWidth> instead.
             */
            getBorderWidth: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.bottom> property.
             * @deprecated Access <Titanium.UI.TabGroup.bottom> instead.
             */
            getBottom: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.children> property.
             * @deprecated Access <Titanium.UI.TabGroup.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.editButtonTitle> property.
             * @deprecated Access <Titanium.UI.TabGroup.editButtonTitle> instead.
             */
            getEditButtonTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.exitOnClose> property.
             * @deprecated Access <Titanium.UI.TabGroup.exitOnClose> instead.
             */
            getExitOnClose(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.focusable> property.
             * @deprecated Access <Titanium.UI.TabGroup.focusable> instead.
             */
            getFocusable: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.height> property.
             * @deprecated Access <Titanium.UI.TabGroup.height> instead.
             */
            getHeight: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.TabGroup.horizontalWrap> instead.
             */
            getHorizontalWrap: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.layout> property.
             * @deprecated Access <Titanium.UI.TabGroup.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.left> property.
             * @deprecated Access <Titanium.UI.TabGroup.left> instead.
             */
            getLeft: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.navTintColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.navTintColor> instead.
             */
            getNavTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.opacity> property.
             * @deprecated Access <Titanium.UI.TabGroup.opacity> instead.
             */
            getOpacity: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.right> property.
             * @deprecated Access <Titanium.UI.TabGroup.right> instead.
             */
            getRight: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.shadowImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.shadowImage> instead.
             */
            getShadowImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.shiftMode> property.
             * @deprecated Access <Titanium.UI.TabGroup.shiftMode> instead.
             */
            getShiftMode(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.smoothScrollOnTabClick> property.
             * @deprecated Access <Titanium.UI.TabGroup.smoothScrollOnTabClick> instead.
             */
            getSmoothScrollOnTabClick(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.TabGroup.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.style> property.
             * @deprecated Access <Titanium.UI.TabGroup.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.swipeable> property.
             * @deprecated Access <Titanium.UI.TabGroup.swipeable> instead.
             */
            getSwipeable(): boolean;

            /**
             * Gets all tabs that are managed by the tab group.
             */
            getTabs(): Titanium.UI.Tab[];

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tabsBackgroundColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.tabsBackgroundColor> instead.
             */
            getTabsBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tabsBackgroundImage> property.
             * @deprecated Access <Titanium.UI.TabGroup.tabsBackgroundImage> instead.
             */
            getTabsBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tabsBackgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.tabsBackgroundSelectedColor> instead.
             */
            getTabsBackgroundSelectedColor(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tabsTintColor> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            getTabsTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tabsTranslucent> property.
             * @deprecated Access <Titanium.UI.TabGroup.tabsTranslucent> instead.
             */
            getTabsTranslucent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.tintColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.tintColor> instead.
             */
            getTintColor(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.title> property.
             * @deprecated Access <Titanium.UI.TabGroup.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.titleAttributes> property.
             * @deprecated Access <Titanium.UI.TabGroup.titleAttributes> instead.
             */
            getTitleAttributes(): titleAttributesParams;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.titleColor> property.
             * @deprecated Access <Titanium.UI.TabGroup.titleColor> instead.
             */
            getTitleColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.top> property.
             * @deprecated Access <Titanium.UI.TabGroup.top> instead.
             */
            getTop: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.transform> property.
             * @deprecated Access <Titanium.UI.TabGroup.transform> instead.
             */
            getTransform: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.translucent> property.
             * @deprecated Access <Titanium.UI.TabGroup.translucent> instead.
             */
            getTranslucent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.unselectedItemTintColor> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            getUnselectedItemTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.width> property.
             * @deprecated Access <Titanium.UI.TabGroup.width> instead.
             */
            getWidth: never;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.windowSoftInputMode> property.
             * @deprecated Access <Titanium.UI.TabGroup.windowSoftInputMode> instead.
             */
            getWindowSoftInputMode(): number;

            /**
             * Gets the value of the <Titanium.UI.TabGroup.zIndex> property.
             * @deprecated Access <Titanium.UI.TabGroup.zIndex> instead.
             */
            getZIndex: never;

            /**
             * Opens the tab group and makes it visible.
             */
            open(params?: openWindowParams): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TabGroupEventMap>(name: K, callback: (this: Titanium.UI.TabGroup, event: TabGroupEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a tab from the tab group.
             */
            removeTab(tab: Titanium.UI.Tab): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.accessibilityHidden> instead.
             */
            setAccessibilityHidden: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.accessibilityHint> instead.
             */
            setAccessibilityHint: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.accessibilityLabel> instead.
             */
            setAccessibilityLabel: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.accessibilityValue> instead.
             */
            setAccessibilityValue: never;

            /**
             * Selects the currently active tab in a tab group.
             */
            setActiveTab(indexOrObject: number | Titanium.UI.Tab): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.activeTabBackgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.activeTabBackgroundImage> instead.
             */
            setActiveTabBackgroundImage(activeTabBackgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.activeTabIconTint> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.activeTintColor](Titanium.UI.TabGroup.activeTintColor) or alternatively [Titanium.UI.Tab.activeTintColor](Titanium.UI.Tab.activeTintColor).
             */
            setActiveTabIconTint(activeTabIconTint: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.activeTintColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.activeTintColor> instead.
             */
            setActiveTintColor(activeTintColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.activeTitleColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.activeTitleColor> instead.
             */
            setActiveTitleColor(activeTitleColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.allowUserCustomization> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.allowUserCustomization> instead.
             */
            setAllowUserCustomization(allowUserCustomization: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.anchorPoint> instead.
             */
            setAnchorPoint: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundGradient> instead.
             */
            setBackgroundGradient: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundImage> instead.
             */
            setBackgroundImage: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.barColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.barColor> instead.
             */
            setBarColor(barColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.borderColor> instead.
             */
            setBorderColor: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.borderRadius> instead.
             */
            setBorderRadius: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.borderWidth> instead.
             */
            setBorderWidth: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.bottom> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.bottom> instead.
             */
            setBottom: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.editButtonTitle> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.editButtonTitle> instead.
             */
            setEditButtonTitle(editButtonTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.exitOnClose> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.exitOnClose> instead.
             */
            setExitOnClose(exitOnClose: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.focusable> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.focusable> instead.
             */
            setFocusable: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.height> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.height> instead.
             */
            setHeight: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.horizontalWrap> instead.
             */
            setHorizontalWrap: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.layout> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.left> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.left> instead.
             */
            setLeft: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.navTintColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.navTintColor> instead.
             */
            setNavTintColor(navTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.opacity> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.opacity> instead.
             */
            setOpacity: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.right> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.right> instead.
             */
            setRight: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.shadowImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.shadowImage> instead.
             */
            setShadowImage(shadowImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.shiftMode> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.shiftMode> instead.
             */
            setShiftMode(shiftMode: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.smoothScrollOnTabClick> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.smoothScrollOnTabClick> instead.
             */
            setSmoothScrollOnTabClick(smoothScrollOnTabClick: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.style> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.swipeable> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.swipeable> instead.
             */
            setSwipeable(swipeable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabs> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tabs> instead.
             */
            setTabs(tabs: ReadonlyArray<Titanium.UI.Tab>): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabsBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tabsBackgroundColor> instead.
             */
            setTabsBackgroundColor(tabsBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabsBackgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tabsBackgroundImage> instead.
             */
            setTabsBackgroundImage(tabsBackgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabsBackgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tabsBackgroundSelectedColor> instead.
             */
            setTabsBackgroundSelectedColor(tabsBackgroundSelectedColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabsTintColor> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            setTabsTintColor(tabsTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tabsTranslucent> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tabsTranslucent> instead.
             */
            setTabsTranslucent(tabsTranslucent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.tintColor> instead.
             */
            setTintColor(tintColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.title> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.titleAttributes> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.titleAttributes> instead.
             */
            setTitleAttributes(titleAttributes: titleAttributesParams): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.titleColor> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.titleColor> instead.
             */
            setTitleColor(titleColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.top> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.top> instead.
             */
            setTop: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.transform> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.transform> instead.
             */
            setTransform: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.translucent> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.translucent> instead.
             */
            setTranslucent(translucent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.unselectedItemTintColor> property.
             * @deprecated Deprecated in favor of [Titanium.UI.TabGroup.tintColor](Titanium.UI.TabGroup.tintColor) or alternatively [Titanium.UI.Tab.tintColor](Titanium.UI.Tab.tintColor).
             */
            setUnselectedItemTintColor(unselectedItemTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.width> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.width> instead.
             */
            setWidth: never;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.windowSoftInputMode> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.windowSoftInputMode> instead.
             */
            setWindowSoftInputMode(windowSoftInputMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.TabGroup.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.TabGroup.zIndex> instead.
             */
            setZIndex: never;

        }
        /**
         * Base event for class Titanium.UI.TabbedBar
         */
        interface TabbedBarBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TabbedBar;

        }
        /**
         * Fired when a button is clicked.
         */
        interface TabbedBar_click_Event extends TabbedBarBaseEvent {
            /**
             * Index of the clicked button.
             */
            index: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TabbedBar_dblclick_Event extends TabbedBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface TabbedBar_doubletap_Event extends TabbedBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface TabbedBar_focus_Event extends TabbedBarBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TabbedBar_keypressed_Event extends TabbedBarBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TabbedBar_longclick_Event extends TabbedBarBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TabbedBar_longpress_Event extends TabbedBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TabbedBar_pinch_Event extends TabbedBarBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TabbedBar_postlayout_Event extends TabbedBarBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TabbedBar_singletap_Event extends TabbedBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface TabbedBar_swipe_Event extends TabbedBarBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface TabbedBar_touchcancel_Event extends TabbedBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface TabbedBar_touchend_Event extends TabbedBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface TabbedBar_touchmove_Event extends TabbedBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface TabbedBar_touchstart_Event extends TabbedBarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TabbedBar_twofingertap_Event extends TabbedBarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface TabbedBarEventMap extends ProxyEventMap {
            click: TabbedBar_click_Event;

            dblclick: TabbedBar_dblclick_Event;

            doubletap: TabbedBar_doubletap_Event;

            focus: TabbedBar_focus_Event;

            keypressed: TabbedBar_keypressed_Event;

            longclick: TabbedBar_longclick_Event;

            longpress: TabbedBar_longpress_Event;

            pinch: TabbedBar_pinch_Event;

            postlayout: TabbedBar_postlayout_Event;

            singletap: TabbedBar_singletap_Event;

            swipe: TabbedBar_swipe_Event;

            touchcancel: TabbedBar_touchcancel_Event;

            touchend: TabbedBar_touchend_Event;

            touchmove: TabbedBar_touchmove_Event;

            touchstart: TabbedBar_touchstart_Event;

            twofingertap: TabbedBar_twofingertap_Event;

        }
        /**
         * A button bar that maintains a selected state.
         */
        class TabbedBar extends Titanium.UI.View {
            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Index of the currently selected button.
             */
            index: number;

            /**
             * Array of labels for the tabbed bar.
             */
            labels: string[] | BarItemType[];

            /**
             * Style of the tabbed bar.
             */
            style: number;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TabbedBarEventMap>(name: K, callback: (this: Titanium.UI.TabbedBar, event: TabbedBarEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TabbedBarEventMap>(name: K, event?: TabbedBarEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.TabbedBar.children> property.
             * @deprecated Access <Titanium.UI.TabbedBar.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.TabbedBar.index> property.
             * @deprecated Access <Titanium.UI.TabbedBar.index> instead.
             */
            getIndex(): number;

            /**
             * Gets the value of the <Titanium.UI.TabbedBar.labels> property.
             * @deprecated Access <Titanium.UI.TabbedBar.labels> instead.
             */
            getLabels(): string[] | BarItemType[];

            /**
             * Gets the value of the <Titanium.UI.TabbedBar.style> property.
             * @deprecated Access <Titanium.UI.TabbedBar.style> instead.
             */
            getStyle(): number;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TabbedBarEventMap>(name: K, callback: (this: Titanium.UI.TabbedBar, event: TabbedBarEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.TabbedBar.index> property.
             * @deprecated Set the value using <Titanium.UI.TabbedBar.index> instead.
             */
            setIndex(index: number): void;

            /**
             * Sets the value of the <Titanium.UI.TabbedBar.labels> property.
             * @deprecated Set the value using <Titanium.UI.TabbedBar.labels> instead.
             */
            setLabels(labels: string[] | BarItemType[]): void;

            /**
             * Sets the value of the <Titanium.UI.TabbedBar.style> property.
             * @deprecated Set the value using <Titanium.UI.TabbedBar.style> instead.
             */
            setStyle(style: number): void;

        }
        /**
         * Base event for class Titanium.UI.TableView
         */
        interface TableViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TableView;

        }
        /**
         * Fired when a table row is clicked by the user.
         */
        interface TableView_click_Event extends TableViewBaseEvent {
            /**
             * Indicates whether the detail button was clicked. Only `true` if `row.hasDetail` is
             * `true` and the detail button was clicked.
             */
            detail: boolean;

            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * Indicates whether the table is in search mode.
             */
            searchMode: boolean;

            /**
             * Table view section object, if the clicked row is contained in a section.
             */
            section: Titanium.UI.TableViewSection;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TableView_dblclick_Event extends TableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against this view.
         */
        interface TableView_doubletap_Event extends TableViewBaseEvent {
            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface TableView_focus_Event extends TableViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TableView_keypressed_Event extends TableViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TableView_longclick_Event extends TableViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TableView_longpress_Event extends TableViewBaseEvent {
            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TableView_pinch_Event extends TableViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TableView_postlayout_Event extends TableViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TableView_singletap_Event extends TableViewBaseEvent {
            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             *     var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             *     var table = Ti.UI.createTableView({data: data});
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture (left or right) against the view.
         */
        interface TableView_swipe_Event extends TableViewBaseEvent {
            /**
             * Direction of the swipe, either `left` or `right`.
             */
            direction: string;

            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch gesture is interrupted by the device.
         */
        interface TableView_touchcancel_Event extends TableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The current force value of the touch event.
             * Note: This property only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             *  Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch gesture is complete.
         */
        interface TableView_touchend_Event extends TableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The current force value of the touch event.
             * Note: This property only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            force: number;

            /**
             * Row index.
             */
            index: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             *  Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface TableView_touchmove_Event extends TableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture against this view.
         */
        interface TableView_touchstart_Event extends TableViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The current force value of the touch event.
             * Note: This property only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            force: number;

            /**
             * Row index.
             */
            index: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row.
             * When the row is created implicitly using a JavaScript dictionary object,
             * use this property rather than `row` to access any custom row properties.
             * Here's an example of creating a row implicitly, which is not the recommended way.
             * ``` js
             * var data = [{title:'Row 1', hasChild:true, color:'red', selectedColor:'#fff', special:'special 1'},];
             * var table = Ti.UI.createTableView({data: data});
             * ```
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             *  Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TableView_twofingertap_Event extends TableViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when user stops two-pan gesture interaction for selecting multiple rows.
         * It is used in conjunction with <Titanium.UI.TableView.allowsMultipleSelectionInteraction>.
         */
        interface TableView_rowsselected_Event extends TableViewBaseEvent {
            /**
             * List of rows selected by user.
             */
            selectedRows: SelectedRowObject[];

            /**
             * First row selected when user started interaction.
             */
            startingRow: SelectedRowObject;

        }
        /**
         * Fired when a table row is deleted by the user.
         */
        interface TableView_delete_Event extends TableViewBaseEvent {
            /**
             * Indicates whether the delete button was clicked. Always `false` for this event.
             */
            detail: boolean;

            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row. Use this property rather than `row` to access any custom row
             * properties.
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * Indicates whether the table is in search mode. Always `false` for this event.
             */
            searchMode: boolean;

            /**
             * Table view section object, if the deleted row is contained in a section.
             */
            section: Titanium.UI.TableViewSection;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the index bar is clicked by the user.
         */
        interface TableView_indexclick_Event extends TableViewBaseEvent {
            /**
             * The index number clicked.
             */
            index: number;

            /**
             * The title of the index clicked.
             */
            title: string;

        }
        /**
         * Fired when a table row is moved by the user.
         */
        interface TableView_move_Event extends TableViewBaseEvent {
            /**
             * Boolean to indicate if the right area was clicked. Always `false` for this event.
             */
            detail: boolean;

            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Properties of the row. Use this property rather than `row` to access any custom row
             * properties.
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * Boolean to indicate if the table is in search mode. Always `false` for this event.
             */
            searchMode: boolean;

            /**
             * Table view section object, if the deleted row is contained in a section.
             */
            section: Titanium.UI.TableViewSection;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the table view is scrolled.
         */
        interface TableView_scroll_Event extends TableViewBaseEvent {
            /**
             * Dictionary with `x` and `y` properties containing the content offset.
             */
            contentOffset: Point;

            /**
             * Dictionary with `width` and `height` properties containing the size of the content
             * (regardless of the display size in the case of scrolling).
             */
            contentSize: Size;

            /**
             * Row index of the topmost visible row in the view.
             */
            firstVisibleItem: number;

            /**
             * Dictionary with `width` and `height` properties containing the size of the visible
             * table view
             */
            size: Size;

            /**
             * Total number of rows in the view.
             */
            totalItemCount: number;

            /**
             * Number of rows currently visible in the view.
             */
            visibleItemCount: number;

        }
        /**
         * Fired when the table view stops scrolling.
         */
        interface TableView_scrollend_Event extends TableViewBaseEvent {
            /**
             * Dictionary with `x` and `y` properties containing the content offset.
             */
            contentOffset: Point;

            /**
             * Dictionary with `width` and `height` properties containing the size of the content
             * (regardless of the display size in the case of scrolling).
             */
            contentSize: Size;

            /**
             * Dictionary with `width` and `height` properties containing the size of the visible
             * table view.
             */
            size: Size;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the scrollable region starts being dragged.
         */
        interface TableView_dragstart_Event extends TableViewBaseEvent {
        }
        /**
         * Fired when the scrollable region stops being dragged.
         */
        interface TableView_dragend_Event extends TableViewBaseEvent {
            /**
             * Indicates whether scrolling will continue but decelerate, now that the drag gesture has
             * been released by the touch. If `false`, scrolling will stop immediately.
             */
            decelerate: boolean;

        }
        interface TableViewEventMap extends ProxyEventMap {
            click: TableView_click_Event;

            dblclick: TableView_dblclick_Event;

            delete: TableView_delete_Event;

            doubletap: TableView_doubletap_Event;

            dragend: TableView_dragend_Event;

            dragstart: TableView_dragstart_Event;

            focus: TableView_focus_Event;

            indexclick: TableView_indexclick_Event;

            keypressed: TableView_keypressed_Event;

            longclick: TableView_longclick_Event;

            longpress: TableView_longpress_Event;

            move: TableView_move_Event;

            pinch: TableView_pinch_Event;

            postlayout: TableView_postlayout_Event;

            rowsselected: TableView_rowsselected_Event;

            scroll: TableView_scroll_Event;

            scrollend: TableView_scrollend_Event;

            singletap: TableView_singletap_Event;

            swipe: TableView_swipe_Event;

            touchcancel: TableView_touchcancel_Event;

            touchend: TableView_touchend_Event;

            touchmove: TableView_touchmove_Event;

            touchstart: TableView_touchstart_Event;

            twofingertap: TableView_twofingertap_Event;

        }
        /**
         * A table view is used to present information, organized in sections and rows, in a
         * vertically-scrolling view.
         */
        class TableView extends Titanium.UI.View {
            /**
             * Determines whether multiple items of this table view can be selected at the same time while editing the table.
             */
            allowsMultipleSelectionDuringEditing: boolean;

            /**
             * Allows a two-finger pan gesture to automatically transition the table view into editing mode and start selecting rows.
             */
            allowsMultipleSelectionInteraction: boolean;

            /**
             * Determines whether this table's rows can be selected.
             */
            allowsSelection: boolean;

            /**
             * Determines whether this table's rows can be selected while editing the table.
             */
            allowsSelectionDuringEditing: boolean;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Rows of the table view.
             */
            data: Titanium.UI.TableViewRow[] | Titanium.UI.TableViewSection[];

            /**
             * A Boolean indicating whether the underlying content is dimmed during a search.
             */
            dimBackgroundForSearch: boolean;

            /**
             * Determines the rows' default editable behavior, which allows them to be deleted by the user
             * when the table is in `editing` or `moving` mode.
             */
            editable: boolean;

            /**
             * Determines whether row editing mode is active.
             */
            editing: boolean;

            /**
             * Determines whether the search is limited to the start of the string
             */
            filterAnchored: boolean;

            /**
             * Filter attribute to be used when searching.
             */
            filterAttribute: string;

            /**
             * Determines whether the search is case insensitive.
             */
            filterCaseInsensitive: boolean;

            /**
             * When set to false, the ListView will not draw the divider before the footer view.
             */
            footerDividersEnabled: boolean;

            /**
             * Table view footer title.
             */
            footerTitle: string;

            /**
             * Table view footer as a view that will be rendered instead of a label.
             */
            footerView: Titanium.UI.View;

            /**
             * When set to false, the ListView will not draw the divider after the header view.
             */
            headerDividersEnabled: boolean;

            /**
             * View positioned above the first row that is only revealed when the user drags the table
             * contents down.
             */
            headerPullView: Titanium.UI.View;

            /**
             * Table view header title.
             */
            headerTitle: string;

            /**
             * Table view header as a view that will be rendered instead of a label.
             */
            headerView: Titanium.UI.View;

            /**
             * Determines whether the search field should hide on completion.
             */
            hideSearchOnSelection: boolean;

            /**
             * Array of objects (with `title` and `index` properties) to control the table view index.
             */
            index: TableViewIndexEntry[];

            /**
             * Max number of row class names.
             */
            maxClassname: number;

            /**
             * Maximum row height for table view rows.
             */
            maxRowHeight: number;

            /**
             * Minimum row height for table view rows.
             */
            minRowHeight: number;

            /**
             * Determines the rows' default moveable behavior, which allows them to be re-ordered by the
             * user when the table is in `editing` or `moving` mode.
             */
            moveable: boolean;

            /**
             * Determines whether row moving mode is active.
             */
            moving: boolean;

            /**
             * Determines the behavior when the user overscrolls the view.
             */
            overScrollMode: number;

            /**
             * View positioned above the first row that is only revealed when the user drags the list view contents down.
             */
            refreshControl: Titanium.UI.RefreshControl;

            /**
             * The background color of the search results (iOS-only).
             */
            resultsBackgroundColor: string | Titanium.UI.Color;

            /**
             * Separator line color between rows inside search results,
             * as a color name or hex triplet (iOS-only).
             */
            resultsSeparatorColor: string | Titanium.UI.Color;

            /**
             * The insets for search results separators (applies to all cells & iOS-only).
             */
            resultsSeparatorInsets: HorizontalInsets;

            /**
             * The separator style of the search results (iOS-only).
             */
            resultsSeparatorStyle: number;

            /**
             * Default row height for table view rows.
             */
            rowHeight: number;

            /**
             * The insets for table view cells (applies to all cells).
             */
            rowSeparatorInsets: HorizontalInsets;

            /**
             * Style of the scrollbar.
             */
            scrollIndicatorStyle: number;

            /**
             * If `true`, the tableview can be scrolled.
             */
            scrollable: boolean;

            /**
             * Controls whether the scroll-to-top gesture is effective.
             */
            scrollsToTop: boolean;

            /**
             * Search field to use for the table view.
             */
            search: Titanium.UI.SearchBar | Titanium.UI.Android.SearchView;

            /**
             * Determines whether the [SearchBar](Titanium.UI.SearchBar) or [SearchView](Titanium.UI.Android.SearchView) appears as part of the TableView.
             */
            searchAsChild: boolean;

            /**
             * Determines whether the search field is visible.
             */
            searchHidden: boolean;

            /**
             * Number of sections in this table view.
             */
            readonly sectionCount: number;

            /**
             * Sections of this table.
             */
            sections: Titanium.UI.TableViewSection[];

            /**
             * Separator line color between rows, as a color name or hex triplet.
             */
            separatorColor: string | Titanium.UI.Color;

            /**
             * The insets for table view separators (applies to all cells).
             * @deprecated Use [Titanium.UI.TableView.tableSeparatorInsets](Titanium.UI.TableView.tableSeparatorInsets) instead.
             */
            separatorInsets: HorizontalInsets;

            /**
             * Separator style constant.
             */
            separatorStyle: number;

            /**
             * A Boolean indicating whether search bar will be in navigation bar.
             */
            showSearchBarInNavBar: boolean;

            /**
             * Determines whether this table view displays a vertical scroll indicator.
             */
            showVerticalScrollIndicator: boolean;

            /**
             * Style of the table view, specified using one of the constants from
             * <Titanium.UI.iOS.TableViewStyle>.
             */
            style: number;

            /**
             * The insets for the table view header and footer.
             */
            tableSeparatorInsets: HorizontalInsets;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TableViewEventMap>(name: K, callback: (this: Titanium.UI.TableView, event: TableViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Appends a single row or an array of rows to the end of the table.
             */
            appendRow(row: Titanium.UI.TableViewRow | Dictionary<Titanium.UI.TableViewRow> | Titanium.UI.TableViewRow[] | Array<Dictionary<Titanium.UI.TableViewRow>>, animation?: TableViewAnimationProperties): void;

            /**
             * Appends a single section or an array of sections to the end of the table.
             */
            appendSection(section: Titanium.UI.TableViewSection | Dictionary<Titanium.UI.TableViewSection> | Titanium.UI.TableViewSection[] | Array<Dictionary<Titanium.UI.TableViewSection>>, animation?: TableViewAnimationProperties): void;

            /**
             * Deletes an existing row.
             */
            deleteRow(row: number | Titanium.UI.TableViewRow, animation?: TableViewAnimationProperties): void;

            /**
             * Deletes an existing section.
             */
            deleteSection(section: number, animation?: TableViewAnimationProperties): void;

            /**
             * Programmatically deselects a row.
             */
            deselectRow(row: number): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TableViewEventMap>(name: K, event?: TableViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.TableView.allowsMultipleSelectionDuringEditing> property.
             * @deprecated Access <Titanium.UI.TableView.allowsMultipleSelectionDuringEditing> instead.
             */
            getAllowsMultipleSelectionDuringEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.allowsMultipleSelectionInteraction> property.
             * @deprecated Access <Titanium.UI.TableView.allowsMultipleSelectionInteraction> instead.
             */
            getAllowsMultipleSelectionInteraction(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.allowsSelection> property.
             * @deprecated Access <Titanium.UI.TableView.allowsSelection> instead.
             */
            getAllowsSelection(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.allowsSelectionDuringEditing> property.
             * @deprecated Access <Titanium.UI.TableView.allowsSelectionDuringEditing> instead.
             */
            getAllowsSelectionDuringEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.backgroundColor> property.
             * @deprecated Access <Titanium.UI.TableView.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableView.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.TableView.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.TableView.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.TableView.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.TableView.children> property.
             * @deprecated Access <Titanium.UI.TableView.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.TableView.data> property.
             * @deprecated Access <Titanium.UI.TableView.data> instead.
             */
            getData(): Titanium.UI.TableViewRow[] | Titanium.UI.TableViewSection[];

            /**
             * Gets the value of the <Titanium.UI.TableView.dimBackgroundForSearch> property.
             * @deprecated Access <Titanium.UI.TableView.dimBackgroundForSearch> instead.
             */
            getDimBackgroundForSearch(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.editable> property.
             * @deprecated Access <Titanium.UI.TableView.editable> instead.
             */
            getEditable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.editing> property.
             * @deprecated Access <Titanium.UI.TableView.editing> instead.
             */
            getEditing(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.filterAnchored> property.
             * @deprecated Access <Titanium.UI.TableView.filterAnchored> instead.
             */
            getFilterAnchored(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.filterAttribute> property.
             * @deprecated Access <Titanium.UI.TableView.filterAttribute> instead.
             */
            getFilterAttribute(): string;

            /**
             * Gets the value of the <Titanium.UI.TableView.filterCaseInsensitive> property.
             * @deprecated Access <Titanium.UI.TableView.filterCaseInsensitive> instead.
             */
            getFilterCaseInsensitive(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.footerDividersEnabled> property.
             * @deprecated Access <Titanium.UI.TableView.footerDividersEnabled> instead.
             */
            getFooterDividersEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.footerTitle> property.
             * @deprecated Access <Titanium.UI.TableView.footerTitle> instead.
             */
            getFooterTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TableView.footerView> property.
             * @deprecated Access <Titanium.UI.TableView.footerView> instead.
             */
            getFooterView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TableView.headerDividersEnabled> property.
             * @deprecated Access <Titanium.UI.TableView.headerDividersEnabled> instead.
             */
            getHeaderDividersEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.headerPullView> property.
             * @deprecated Access <Titanium.UI.TableView.headerPullView> instead.
             */
            getHeaderPullView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TableView.headerTitle> property.
             * @deprecated Access <Titanium.UI.TableView.headerTitle> instead.
             */
            getHeaderTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TableView.headerView> property.
             * @deprecated Access <Titanium.UI.TableView.headerView> instead.
             */
            getHeaderView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TableView.hideSearchOnSelection> property.
             * @deprecated Access <Titanium.UI.TableView.hideSearchOnSelection> instead.
             */
            getHideSearchOnSelection(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.index> property.
             * @deprecated Access <Titanium.UI.TableView.index> instead.
             */
            getIndex(): TableViewIndexEntry[];

            /**
             * Gets the value of the <Titanium.UI.TableView.maxClassname> property.
             * @deprecated Access <Titanium.UI.TableView.maxClassname> instead.
             */
            getMaxClassname(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.maxRowHeight> property.
             * @deprecated Access <Titanium.UI.TableView.maxRowHeight> instead.
             */
            getMaxRowHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.minRowHeight> property.
             * @deprecated Access <Titanium.UI.TableView.minRowHeight> instead.
             */
            getMinRowHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.moveable> property.
             * @deprecated Access <Titanium.UI.TableView.moveable> instead.
             */
            getMoveable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.moving> property.
             * @deprecated Access <Titanium.UI.TableView.moving> instead.
             */
            getMoving(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.overScrollMode> property.
             * @deprecated Access <Titanium.UI.TableView.overScrollMode> instead.
             */
            getOverScrollMode(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.refreshControl> property.
             * @deprecated Access <Titanium.UI.TableView.refreshControl> instead.
             */
            getRefreshControl(): Titanium.UI.RefreshControl;

            /**
             * Gets the value of the <Titanium.UI.TableView.resultsBackgroundColor> property.
             * @deprecated Access <Titanium.UI.TableView.resultsBackgroundColor> instead.
             */
            getResultsBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableView.resultsSeparatorColor> property.
             * @deprecated Access <Titanium.UI.TableView.resultsSeparatorColor> instead.
             */
            getResultsSeparatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableView.resultsSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.TableView.resultsSeparatorInsets> instead.
             */
            getResultsSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.TableView.resultsSeparatorStyle> property.
             * @deprecated Access <Titanium.UI.TableView.resultsSeparatorStyle> instead.
             */
            getResultsSeparatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.rowHeight> property.
             * @deprecated Access <Titanium.UI.TableView.rowHeight> instead.
             */
            getRowHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.rowSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.TableView.rowSeparatorInsets> instead.
             */
            getRowSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.TableView.scrollIndicatorStyle> property.
             * @deprecated Access <Titanium.UI.TableView.scrollIndicatorStyle> instead.
             */
            getScrollIndicatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.scrollable> property.
             * @deprecated Access <Titanium.UI.TableView.scrollable> instead.
             */
            getScrollable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.scrollsToTop> property.
             * @deprecated Access <Titanium.UI.TableView.scrollsToTop> instead.
             */
            getScrollsToTop(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.search> property.
             * @deprecated Access <Titanium.UI.TableView.search> instead.
             */
            getSearch(): Titanium.UI.SearchBar | Titanium.UI.Android.SearchView;

            /**
             * Gets the value of the <Titanium.UI.TableView.searchAsChild> property.
             * @deprecated Access <Titanium.UI.TableView.searchAsChild> instead.
             */
            getSearchAsChild(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.searchHidden> property.
             * @deprecated Access <Titanium.UI.TableView.searchHidden> instead.
             */
            getSearchHidden(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.sectionCount> property.
             * @deprecated Access <Titanium.UI.TableView.sectionCount> instead.
             */
            getSectionCount(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.sections> property.
             * @deprecated Access <Titanium.UI.TableView.sections> instead.
             */
            getSections(): Titanium.UI.TableViewSection[];

            /**
             * Gets the value of the <Titanium.UI.TableView.separatorColor> property.
             * @deprecated Access <Titanium.UI.TableView.separatorColor> instead.
             */
            getSeparatorColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableView.separatorInsets> property.
             * @deprecated Use [Titanium.UI.TableView.tableSeparatorInsets](Titanium.UI.TableView.tableSeparatorInsets) instead.
             */
            getSeparatorInsets(): HorizontalInsets;

            /**
             * Gets the value of the <Titanium.UI.TableView.separatorStyle> property.
             * @deprecated Access <Titanium.UI.TableView.separatorStyle> instead.
             */
            getSeparatorStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.showSearchBarInNavBar> property.
             * @deprecated Access <Titanium.UI.TableView.showSearchBarInNavBar> instead.
             */
            getShowSearchBarInNavBar(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.showVerticalScrollIndicator> property.
             * @deprecated Access <Titanium.UI.TableView.showVerticalScrollIndicator> instead.
             */
            getShowVerticalScrollIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableView.style> property.
             * @deprecated Access <Titanium.UI.TableView.style> instead.
             */
            getStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TableView.tableSeparatorInsets> property.
             * @deprecated Access <Titanium.UI.TableView.tableSeparatorInsets> instead.
             */
            getTableSeparatorInsets(): HorizontalInsets;

            /**
             * Inserts a row after another row.
             */
            insertRowAfter(index: number, row: Titanium.UI.TableViewRow | Dictionary<Titanium.UI.TableViewRow>, animation?: TableViewAnimationProperties): void;

            /**
             * Inserts a row before another row.
             */
            insertRowBefore(index: number, row: Titanium.UI.TableViewRow | Dictionary<Titanium.UI.TableViewRow>, animation?: TableViewAnimationProperties): void;

            /**
             * Inserts a section after another section.
             */
            insertSectionAfter(index: number, section: Titanium.UI.TableViewSection | Dictionary<Titanium.UI.TableViewSection>, animation?: TableViewAnimationProperties): void;

            /**
             * Inserts a section before another section.
             */
            insertSectionBefore(index: number, section: Titanium.UI.TableViewSection | Dictionary<Titanium.UI.TableViewSection>, animation?: TableViewAnimationProperties): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TableViewEventMap>(name: K, callback: (this: Titanium.UI.TableView, event: TableViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Scrolls the table view to ensure that the specified row is on screen.
             */
            scrollToIndex(index: number, animation?: TableViewAnimationProperties): void;

            /**
             * Scrolls the table to a specific top position where 0 is the topmost y position in the
             * table view.
             */
            scrollToTop(top: number, animation?: TableViewAnimationProperties): void;

            /**
             * Programmatically selects a row. In Android, it sets the currently selected item. If in touch mode,
             * the item will not be selected but it will still be positioned appropriately. If the specified
             * selection position is less than 0, then the item at position 0 will be selected.
             */
            selectRow(row: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.allowsMultipleSelectionDuringEditing> property.
             * @deprecated Set the value using <Titanium.UI.TableView.allowsMultipleSelectionDuringEditing> instead.
             */
            setAllowsMultipleSelectionDuringEditing(allowsMultipleSelectionDuringEditing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.allowsMultipleSelectionInteraction> property.
             * @deprecated Set the value using <Titanium.UI.TableView.allowsMultipleSelectionInteraction> instead.
             */
            setAllowsMultipleSelectionInteraction(allowsMultipleSelectionInteraction: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.allowsSelection> property.
             * @deprecated Set the value using <Titanium.UI.TableView.allowsSelection> instead.
             */
            setAllowsSelection(allowsSelection: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.allowsSelectionDuringEditing> property.
             * @deprecated Set the value using <Titanium.UI.TableView.allowsSelectionDuringEditing> instead.
             */
            setAllowsSelectionDuringEditing(allowsSelectionDuringEditing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.TableView.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.TableView.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.TableView.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.TableView.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets this tableview's content insets.
             */
            setContentInsets(edgeInsets: Padding, options?: AnimatedWithDurationOptions): void;

            /**
             * Sets the value of the content offset of the table view without animation by default.
             */
            setContentOffset(contentOffset: Point, options?: AnimatedOptions): void;

            /**
             * Sets the data in the table.
             */
            setData(data: Titanium.UI.TableViewRow[] | Array<Dictionary<Titanium.UI.TableViewRow>> | Titanium.UI.TableViewSection[], animation?: TableViewAnimationProperties): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.dimBackgroundForSearch> property.
             * @deprecated Set the value using <Titanium.UI.TableView.dimBackgroundForSearch> instead.
             */
            setDimBackgroundForSearch(dimBackgroundForSearch: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.editable> property.
             * @deprecated Set the value using <Titanium.UI.TableView.editable> instead.
             */
            setEditable(editable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.editing> property.
             * @deprecated Set the value using <Titanium.UI.TableView.editing> instead.
             */
            setEditing(editing: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.filterAnchored> property.
             * @deprecated Set the value using <Titanium.UI.TableView.filterAnchored> instead.
             */
            setFilterAnchored(filterAnchored: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.filterAttribute> property.
             * @deprecated Set the value using <Titanium.UI.TableView.filterAttribute> instead.
             */
            setFilterAttribute(filterAttribute: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.filterCaseInsensitive> property.
             * @deprecated Set the value using <Titanium.UI.TableView.filterCaseInsensitive> instead.
             */
            setFilterCaseInsensitive(filterCaseInsensitive: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.footerDividersEnabled> property.
             * @deprecated Set the value using <Titanium.UI.TableView.footerDividersEnabled> instead.
             */
            setFooterDividersEnabled(footerDividersEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.footerTitle> property.
             * @deprecated Set the value using <Titanium.UI.TableView.footerTitle> instead.
             */
            setFooterTitle(footerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.footerView> property.
             * @deprecated Set the value using <Titanium.UI.TableView.footerView> instead.
             */
            setFooterView(footerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.headerDividersEnabled> property.
             * @deprecated Set the value using <Titanium.UI.TableView.headerDividersEnabled> instead.
             */
            setHeaderDividersEnabled(headerDividersEnabled: boolean): void;

            /**
             * Sets the value of the [Titanium.UI.TableView.headerPullView] property.
             */
            setHeaderPullView(view: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.headerTitle> property.
             * @deprecated Set the value using <Titanium.UI.TableView.headerTitle> instead.
             */
            setHeaderTitle(headerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.headerView> property.
             * @deprecated Set the value using <Titanium.UI.TableView.headerView> instead.
             */
            setHeaderView(headerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.hideSearchOnSelection> property.
             * @deprecated Set the value using <Titanium.UI.TableView.hideSearchOnSelection> instead.
             */
            setHideSearchOnSelection(hideSearchOnSelection: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.index> property.
             * @deprecated Set the value using <Titanium.UI.TableView.index> instead.
             */
            setIndex(index: ReadonlyArray<TableViewIndexEntry>): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.maxClassname> property.
             * @deprecated Set the value using <Titanium.UI.TableView.maxClassname> instead.
             */
            setMaxClassname(maxClassname: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.maxRowHeight> property.
             * @deprecated Set the value using <Titanium.UI.TableView.maxRowHeight> instead.
             */
            setMaxRowHeight(maxRowHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.minRowHeight> property.
             * @deprecated Set the value using <Titanium.UI.TableView.minRowHeight> instead.
             */
            setMinRowHeight(minRowHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.moveable> property.
             * @deprecated Set the value using <Titanium.UI.TableView.moveable> instead.
             */
            setMoveable(moveable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.moving> property.
             * @deprecated Set the value using <Titanium.UI.TableView.moving> instead.
             */
            setMoving(moving: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.overScrollMode> property.
             * @deprecated Set the value using <Titanium.UI.TableView.overScrollMode> instead.
             */
            setOverScrollMode(overScrollMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.refreshControl> property.
             * @deprecated Set the value using <Titanium.UI.TableView.refreshControl> instead.
             */
            setRefreshControl(refreshControl: Titanium.UI.RefreshControl): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.resultsBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.TableView.resultsBackgroundColor> instead.
             */
            setResultsBackgroundColor(resultsBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.resultsSeparatorColor> property.
             * @deprecated Set the value using <Titanium.UI.TableView.resultsSeparatorColor> instead.
             */
            setResultsSeparatorColor(resultsSeparatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.resultsSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.TableView.resultsSeparatorInsets> instead.
             */
            setResultsSeparatorInsets(resultsSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.resultsSeparatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.TableView.resultsSeparatorStyle> instead.
             */
            setResultsSeparatorStyle(resultsSeparatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.rowHeight> property.
             * @deprecated Set the value using <Titanium.UI.TableView.rowHeight> instead.
             */
            setRowHeight(rowHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.rowSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.TableView.rowSeparatorInsets> instead.
             */
            setRowSeparatorInsets(rowSeparatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.scrollIndicatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.TableView.scrollIndicatorStyle> instead.
             */
            setScrollIndicatorStyle(scrollIndicatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.scrollable> property.
             * @deprecated Set the value using <Titanium.UI.TableView.scrollable> instead.
             */
            setScrollable(scrollable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.scrollsToTop> property.
             * @deprecated Set the value using <Titanium.UI.TableView.scrollsToTop> instead.
             */
            setScrollsToTop(scrollsToTop: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.search> property.
             * @deprecated Set the value using <Titanium.UI.TableView.search> instead.
             */
            setSearch(search: Titanium.UI.SearchBar | Titanium.UI.Android.SearchView): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.searchAsChild> property.
             * @deprecated Set the value using <Titanium.UI.TableView.searchAsChild> instead.
             */
            setSearchAsChild(searchAsChild: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.searchHidden> property.
             * @deprecated Set the value using <Titanium.UI.TableView.searchHidden> instead.
             */
            setSearchHidden(searchHidden: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.sections> property.
             * @deprecated Set the value using <Titanium.UI.TableView.sections> instead.
             */
            setSections(sections: ReadonlyArray<Titanium.UI.TableViewSection>): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.separatorColor> property.
             * @deprecated Set the value using <Titanium.UI.TableView.separatorColor> instead.
             */
            setSeparatorColor(separatorColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.separatorInsets> property.
             * @deprecated Use [Titanium.UI.TableView.tableSeparatorInsets](Titanium.UI.TableView.tableSeparatorInsets) instead.
             */
            setSeparatorInsets(separatorInsets: HorizontalInsets): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.separatorStyle> property.
             * @deprecated Set the value using <Titanium.UI.TableView.separatorStyle> instead.
             */
            setSeparatorStyle(separatorStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.showSearchBarInNavBar> property.
             * @deprecated Set the value using <Titanium.UI.TableView.showSearchBarInNavBar> instead.
             */
            setShowSearchBarInNavBar(showSearchBarInNavBar: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.showVerticalScrollIndicator> property.
             * @deprecated Set the value using <Titanium.UI.TableView.showVerticalScrollIndicator> instead.
             */
            setShowVerticalScrollIndicator(showVerticalScrollIndicator: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.style> property.
             * @deprecated Set the value using <Titanium.UI.TableView.style> instead.
             */
            setStyle(style: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableView.tableSeparatorInsets> property.
             * @deprecated Set the value using <Titanium.UI.TableView.tableSeparatorInsets> instead.
             */
            setTableSeparatorInsets(tableSeparatorInsets: HorizontalInsets): void;

            /**
             * Updates an existing row, optionally with animation.
             */
            updateRow(index: number, row: Titanium.UI.TableViewRow, animation: TableViewAnimationProperties): void;

            /**
             * Updates an existing section, optionally with animation.
             */
            updateSection(index: number, section: Titanium.UI.TableViewSection, animation: TableViewAnimationProperties): void;

        }
        /**
         * Base event for class Titanium.UI.TableViewRow
         */
        interface TableViewRowBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TableViewRow;

        }
        /**
         * Fired when a table row is clicked by the user.
         */
        interface TableViewRow_click_Event extends TableViewRowBaseEvent {
            /**
             * Indicates whether the detail button was clicked. Only `true` if `row.hasDetail` is
             * `true` and the detail button was clicked.
             */
            detail: boolean;

            /**
             * Row index.
             */
            index: number;

            /**
             * Table view row object.
             */
            row: Titanium.UI.TableViewRow;

            /**
             * Dictionary containing the properties set on the row.
             */
            rowData: Dictionary<Titanium.UI.TableViewRow>;

            /**
             * Boolean to indicate if the table is in search mode.
             */
            searchMode: boolean;

            /**
             * Table view section object, if the clicked row is contained in a section.
             */
            section: Titanium.UI.TableViewSection;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TableViewRow_dblclick_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface TableViewRow_doubletap_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface TableViewRow_focus_Event extends TableViewRowBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TableViewRow_keypressed_Event extends TableViewRowBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TableViewRow_longclick_Event extends TableViewRowBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TableViewRow_longpress_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TableViewRow_pinch_Event extends TableViewRowBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TableViewRow_postlayout_Event extends TableViewRowBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TableViewRow_singletap_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface TableViewRow_swipe_Event extends TableViewRowBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch gesture is interrupted by the device.
         */
        interface TableViewRow_touchcancel_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch gesture is complete.
         */
        interface TableViewRow_touchend_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch..
         */
        interface TableViewRow_touchmove_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture against this view.
         */
        interface TableViewRow_touchstart_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TableViewRow_twofingertap_Event extends TableViewRowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface TableViewRowEventMap extends ProxyEventMap {
            click: TableViewRow_click_Event;

            dblclick: TableViewRow_dblclick_Event;

            doubletap: TableViewRow_doubletap_Event;

            focus: TableViewRow_focus_Event;

            keypressed: TableViewRow_keypressed_Event;

            longclick: TableViewRow_longclick_Event;

            longpress: TableViewRow_longpress_Event;

            pinch: TableViewRow_pinch_Event;

            postlayout: TableViewRow_postlayout_Event;

            singletap: TableViewRow_singletap_Event;

            swipe: TableViewRow_swipe_Event;

            touchcancel: TableViewRow_touchcancel_Event;

            touchend: TableViewRow_touchend_Event;

            touchmove: TableViewRow_touchmove_Event;

            touchstart: TableViewRow_touchstart_Event;

            twofingertap: TableViewRow_twofingertap_Event;

        }
        /**
         * A table view row is an individual item in a table, organized into table view sections.
         */
        class TableViewRow extends Titanium.UI.View {
            /**
             * A succint label associated with the table row for the device's accessibility service.
             */
            accessibilityLabel: string;

            /**
             * Class name for the row.
             */
            className: string;

            /**
             * Default text color of the row when not selected, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Text to display on the delete button when editable is enabled
             */
            deleteButtonTitle: string;

            /**
             * Determines the rows' editable behavior, which allows them to be deleted by the user when the
             * table is in `editing` or `moving` mode.
             */
            editable: boolean;

            /**
             * Font to use for the row title.
             */
            font: Font;

            /**
             * The footer title of the row.
             */
            footer: string;

            /**
             * Determines whether a system-provided checkmark is displayed on the right-hand side of
             * the row.
             */
            hasCheck: boolean;

            /**
             * Determines whether a system-provided arrow is displayed on the right-hand side of the row.
             */
            hasChild: boolean;

            /**
             * Determines whether a system-provided detail disclosure button is displayed on the right-hand
             * side of the row.
             */
            hasDetail: boolean;

            /**
             * The header title of the row.
             */
            header: string;

            /**
             * Indention level for the row.
             */
            indentionLevel: number;

            /**
             * Image to render in the left image area of the row, specified as a local path or URL.
             */
            leftImage: string;

            /**
             * Determines the rows' moveable behavior, which allows them to be re-ordered by the user when
             * the table is in `editing` or `moving` mode.
             */
            moveable: boolean;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: number;

            /**
             * Image to render in the right image area of the row, specified as a local path or URL.
             */
            rightImage: string;

            /**
             * Background color to render when the row is selected, as a color name or hex triplet.
             */
            selectedBackgroundColor: string | Titanium.UI.Color;

            /**
             * Background image to render when the row is selected.
             */
            selectedBackgroundImage: string;

            /**
             * Color of the row text when the row is selected, as a color name or hex triplet.
             */
            selectedColor: string | Titanium.UI.Color;

            /**
             * Selection style constant to control the selection color.
             */
            selectionStyle: number;

            /**
             * Text to display on the row.
             */
            title: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TableViewRowEventMap>(name: K, callback: (this: Titanium.UI.TableViewRow, event: TableViewRowEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TableViewRowEventMap>(name: K, event?: TableViewRowEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.TableViewRow.accessibilityLabel> instead.
             */
            getAccessibilityLabel(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.className> property.
             * @deprecated Access <Titanium.UI.TableViewRow.className> instead.
             */
            getClassName(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.color> property.
             * @deprecated Access <Titanium.UI.TableViewRow.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.deleteButtonTitle> property.
             * @deprecated Access <Titanium.UI.TableViewRow.deleteButtonTitle> instead.
             */
            getDeleteButtonTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.editable> property.
             * @deprecated Access <Titanium.UI.TableViewRow.editable> instead.
             */
            getEditable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.font> property.
             * @deprecated Access <Titanium.UI.TableViewRow.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.footer> property.
             * @deprecated Access <Titanium.UI.TableViewRow.footer> instead.
             */
            getFooter(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.hasCheck> property.
             * @deprecated Access <Titanium.UI.TableViewRow.hasCheck> instead.
             */
            getHasCheck(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.hasChild> property.
             * @deprecated Access <Titanium.UI.TableViewRow.hasChild> instead.
             */
            getHasChild(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.hasDetail> property.
             * @deprecated Access <Titanium.UI.TableViewRow.hasDetail> instead.
             */
            getHasDetail(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.header> property.
             * @deprecated Access <Titanium.UI.TableViewRow.header> instead.
             */
            getHeader(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.indentionLevel> property.
             * @deprecated Access <Titanium.UI.TableViewRow.indentionLevel> instead.
             */
            getIndentionLevel(): number;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.leftImage> property.
             * @deprecated Access <Titanium.UI.TableViewRow.leftImage> instead.
             */
            getLeftImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.moveable> property.
             * @deprecated Access <Titanium.UI.TableViewRow.moveable> instead.
             */
            getMoveable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.opacity> property.
             * @deprecated Access <Titanium.UI.TableViewRow.opacity> instead.
             */
            getOpacity(): number;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.rightImage> property.
             * @deprecated Access <Titanium.UI.TableViewRow.rightImage> instead.
             */
            getRightImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.selectedBackgroundColor> property.
             * @deprecated Access <Titanium.UI.TableViewRow.selectedBackgroundColor> instead.
             */
            getSelectedBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.selectedBackgroundImage> property.
             * @deprecated Access <Titanium.UI.TableViewRow.selectedBackgroundImage> instead.
             */
            getSelectedBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.selectedColor> property.
             * @deprecated Access <Titanium.UI.TableViewRow.selectedColor> instead.
             */
            getSelectedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.selectionStyle> property.
             * @deprecated Access <Titanium.UI.TableViewRow.selectionStyle> instead.
             */
            getSelectionStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TableViewRow.title> property.
             * @deprecated Access <Titanium.UI.TableViewRow.title> instead.
             */
            getTitle(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TableViewRowEventMap>(name: K, callback: (this: Titanium.UI.TableViewRow, event: TableViewRowEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.accessibilityLabel> instead.
             */
            setAccessibilityLabel(accessibilityLabel: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.className> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.className> instead.
             */
            setClassName(className: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.color> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.deleteButtonTitle> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.deleteButtonTitle> instead.
             */
            setDeleteButtonTitle(deleteButtonTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.editable> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.editable> instead.
             */
            setEditable(editable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.font> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.footer> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.footer> instead.
             */
            setFooter(footer: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.hasCheck> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.hasCheck> instead.
             */
            setHasCheck(hasCheck: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.hasChild> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.hasChild> instead.
             */
            setHasChild(hasChild: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.hasDetail> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.hasDetail> instead.
             */
            setHasDetail(hasDetail: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.header> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.header> instead.
             */
            setHeader(header: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.indentionLevel> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.indentionLevel> instead.
             */
            setIndentionLevel(indentionLevel: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.leftImage> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.leftImage> instead.
             */
            setLeftImage(leftImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.moveable> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.moveable> instead.
             */
            setMoveable(moveable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.opacity> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.opacity> instead.
             */
            setOpacity(opacity: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.rightImage> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.rightImage> instead.
             */
            setRightImage(rightImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.selectedBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.selectedBackgroundColor> instead.
             */
            setSelectedBackgroundColor(selectedBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.selectedBackgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.selectedBackgroundImage> instead.
             */
            setSelectedBackgroundImage(selectedBackgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.selectedColor> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.selectedColor> instead.
             */
            setSelectedColor(selectedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.selectionStyle> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.selectionStyle> instead.
             */
            setSelectionStyle(selectionStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewRow.title> property.
             * @deprecated Set the value using <Titanium.UI.TableViewRow.title> instead.
             */
            setTitle(title: string): void;

        }
        /**
         * A table view section is a container within a table used to organize table view rows.
         */
        class TableViewSection extends Titanium.Proxy {
            /**
             * Title of this section footer.
             */
            footerTitle: string;

            /**
             * View to use for this section footer.
             */
            footerView: Titanium.UI.View;

            /**
             * Title of this section header.
             */
            headerTitle: string;

            /**
             * View to use for this section header.
             */
            headerView: Titanium.UI.View;

            /**
             * Number of rows in this section.
             */
            readonly rowCount: number;

            /**
             * Rows in this section.
             */
            readonly rows: Titanium.UI.TableViewRow[];

            /**
             * Adds a table view row to this section.
             */
            add(row: Titanium.UI.TableViewRow): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.footerTitle> property.
             * @deprecated Access <Titanium.UI.TableViewSection.footerTitle> instead.
             */
            getFooterTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.footerView> property.
             * @deprecated Access <Titanium.UI.TableViewSection.footerView> instead.
             */
            getFooterView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.headerTitle> property.
             * @deprecated Access <Titanium.UI.TableViewSection.headerTitle> instead.
             */
            getHeaderTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.headerView> property.
             * @deprecated Access <Titanium.UI.TableViewSection.headerView> instead.
             */
            getHeaderView(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.rowCount> property.
             * @deprecated Access <Titanium.UI.TableViewSection.rowCount> instead.
             */
            getRowCount(): number;

            /**
             * Gets the value of the <Titanium.UI.TableViewSection.rows> property.
             * @deprecated Access <Titanium.UI.TableViewSection.rows> instead.
             */
            getRows(): Titanium.UI.TableViewRow[];

            /**
             * Removes a table view row from this section.
             */
            remove(row: Titanium.UI.TableViewRow): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Returns a row in this section.
             */
            rowAtIndex(index: number): Titanium.UI.TableViewRow;

            /**
             * Sets the value of the <Titanium.UI.TableViewSection.footerTitle> property.
             * @deprecated Set the value using <Titanium.UI.TableViewSection.footerTitle> instead.
             */
            setFooterTitle(footerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewSection.footerView> property.
             * @deprecated Set the value using <Titanium.UI.TableViewSection.footerView> instead.
             */
            setFooterView(footerView: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewSection.headerTitle> property.
             * @deprecated Set the value using <Titanium.UI.TableViewSection.headerTitle> instead.
             */
            setHeaderTitle(headerTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.TableViewSection.headerView> property.
             * @deprecated Set the value using <Titanium.UI.TableViewSection.headerView> instead.
             */
            setHeaderView(headerView: Titanium.UI.View): void;

        }
        /**
         * Base event for class Titanium.UI.TextArea
         */
        interface TextAreaBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TextArea;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface TextArea_click_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TextArea_dblclick_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface TextArea_doubletap_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when this text area gains focus.
         */
        interface TextArea_focus_Event extends TextAreaBaseEvent {
            /**
             * Value of this text area.
             */
            value: string;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TextArea_keypressed_Event extends TextAreaBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TextArea_longclick_Event extends TextAreaBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TextArea_longpress_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TextArea_pinch_Event extends TextAreaBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TextArea_postlayout_Event extends TextAreaBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TextArea_singletap_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface TextArea_swipe_Event extends TextAreaBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface TextArea_touchcancel_Event extends TextAreaBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface TextArea_touchend_Event extends TextAreaBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface TextArea_touchmove_Event extends TextAreaBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface TextArea_touchstart_Event extends TextAreaBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TextArea_twofingertap_Event extends TextAreaBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when this text area loses focus.
         */
        interface TextArea_blur_Event extends TextAreaBaseEvent {
            /**
             * Value of this text area.
             */
            value: string;

        }
        /**
         * Fired when this text area value changes.
         */
        interface TextArea_change_Event extends TextAreaBaseEvent {
            /**
             * New value of this text area.
             */
            value: string;

        }
        /**
         * Fired when user interacts with a URL in the text area. See [handleLinks](Titanium.UI.TextArea.handleLinks).
         */
        interface TextArea_link_Event extends TextAreaBaseEvent {
            /**
             * This is false. This event does not bubble.
             */
            bubbles: boolean;

            /**
             * An array of two numbers [location, length] describing the character range of the text associated with this URL.
             */
            range: any[];

            /**
             * The URL that is associated with this event.
             */
            url: string;

        }
        /**
         * Fired when the return key is pressed on the keyboard.
         */
        interface TextArea_return_Event extends TextAreaBaseEvent {
            /**
             * Value of this text area.
             */
            value: string;

        }
        /**
         * Fired when text in this text area is selected.
         */
        interface TextArea_selected_Event extends TextAreaBaseEvent {
            /**
             * Dictionary that describes the position and length of the selected text.
             */
            range: textAreaSelectedParams;

        }
        interface TextAreaEventMap extends ProxyEventMap {
            blur: TextArea_blur_Event;

            change: TextArea_change_Event;

            click: TextArea_click_Event;

            dblclick: TextArea_dblclick_Event;

            doubletap: TextArea_doubletap_Event;

            focus: TextArea_focus_Event;

            keypressed: TextArea_keypressed_Event;

            link: TextArea_link_Event;

            longclick: TextArea_longclick_Event;

            longpress: TextArea_longpress_Event;

            pinch: TextArea_pinch_Event;

            postlayout: TextArea_postlayout_Event;

            return: TextArea_return_Event;

            selected: TextArea_selected_Event;

            singletap: TextArea_singletap_Event;

            swipe: TextArea_swipe_Event;

            touchcancel: TextArea_touchcancel_Event;

            touchend: TextArea_touchend_Event;

            touchmove: TextArea_touchmove_Event;

            touchstart: TextArea_touchstart_Event;

            twofingertap: TextArea_twofingertap_Event;

        }
        /**
         * A multiline text field that supports editing and scrolling.
         */
        class TextArea extends Titanium.UI.View {
            /**
             * Determines the appearance of the keyboard displayed when this text area is focused.
             * @deprecated Use [Titanium.UI.TextArea.keyboardAppearance](Titanium.UI.TextArea.keyboardAppearance) instead.
             */
            appearance: never;

            /**
             * Hint text attributed string.
             */
            attributedHintText: Titanium.UI.AttributedString;

            /**
             * TextArea attributed string.
             */
            attributedString: Titanium.UI.AttributedString;

            /**
             * Automatically convert text to clickable links.
             */
            autoLink: number;

            /**
             * Determines how text is capitalized during typing.
             */
            autocapitalization: number;

            /**
             * Determines whether to automatically correct text entered into this text area.
             */
            autocorrect: boolean;

            /**
             * Sets the autofill type for the text area.
             */
            autofillType: string;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Determines whether the value of this text area should be cleared when it is focused.
             */
            clearOnEdit: boolean;

            /**
             * Color of the text in this text area, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Determines whether this field can be edited.
             */
            editable: boolean;

            /**
             * Determines whether an ellipsis (`...`) should be used to indicate truncated text.
             */
            ellipsize: boolean;

            /**
             * Determines whether the return key is enabled automatically when there is text in this text
             * area.
             */
            enableReturnKey: boolean;

            /**
             * Determines whether this TextArea has focus.
             */
            readonly focused: boolean;

            /**
             * Font to use for text.
             */
            font: Font;

            /**
             * Leave some space above the keyboard in landscape mode or not.
             */
            fullscreen: boolean;

            /**
             * Specifies if the text area should allow user interaction with the given URL in the given range of text.
             */
            handleLinks: boolean;

            /**
             * Hint text to display when the field is empty.
             */
            hintText: string;

            /**
             * Color of hint text that displays when field is empty.
             */
            hintTextColor: string;

            /**
             * Hint type to display on the text field.
             */
            hintType: number;

            /**
             * Determines the appearance of the keyboard displayed when this text area is focused.
             */
            keyboardAppearance: number;

            /**
             * Array of toolbar button objects or a [toolbar](Titanium.UI.iOS.Toolbar) to be used when the
             * keyboard is displayed.
             */
            keyboardToolbar: Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar;

            /**
             * Color of the keyboard toolbar if keyboardToolbar is an array, as a color name or hex triplet.
             */
            keyboardToolbarColor: string | Titanium.UI.Color;

            /**
             * Height of the keyboard toolbar if keyboardToolbar is an array.
             */
            keyboardToolbarHeight: number;

            /**
             * Keyboard type to display when this text area is focused.
             */
            keyboardType: number;

            /**
             * Number of lines tall the text area height will be, if set.
             */
            lines: number;

            /**
             * Maximum length of text field input.
             */
            maxLength: number;

            /**
             * Maximum line count of text field input.
             */
            maxLines: number;

            /**
             * Sets the left and right padding of this TextArea. The text will always be vertically centered.
             */
            padding: Padding;

            /**
             * Specifies the text to display on the keyboard `Return` key when this text area is focused.
             */
            returnKeyType: number;

            /**
             * Determines whether this text area can be scrolled.
             */
            scrollable: boolean;

            /**
             * Controls whether the scroll-to-top gesture is effective.
             */
            scrollsToTop: boolean;

            /**
             * Returns the currently selected text of the text area.
             */
            readonly selection: textAreaSelectedParams;

            /**
             * Determinates if the undo and redo buttons on the left side of the keyboard should be displayed or not. Only valid on iOS9 and above. This property can only be set upon creation.
             */
            showUndoRedoActions: boolean;

            /**
             * Determines if the return key should be suppressed during text entry.
             */
            suppressReturn: boolean;

            /**
             * Text alignment within this text area.
             * This has no effect on `hintText` when `hintType` is Ti.UI.HINT_TYPE_ANIMATED.
             */
            textAlign: string | number;

            /**
             * Value of this text area, which may be set programmatically and modified by the user.
             */
            value: string;

            /**
             * Vertical alignment within this text area.
             */
            verticalAlign: number | string;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TextAreaEventMap>(name: K, callback: (this: Titanium.UI.TextArea, event: TextAreaEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Forces this text area to lose focus.
             */
            blur(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TextAreaEventMap>(name: K, event?: TextAreaEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Forces this text area to gain focus.
             */
            focus(): void;

            /**
             * Gets the value of the <Titanium.UI.TextArea.appearance> property.
             * @deprecated Use [Titanium.UI.TextArea.keyboardAppearance](Titanium.UI.TextArea.keyboardAppearance) instead.
             */
            getAppearance: never;

            /**
             * Gets the value of the <Titanium.UI.TextArea.attributedHintText> property.
             * @deprecated Access <Titanium.UI.TextArea.attributedHintText> instead.
             */
            getAttributedHintText(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.TextArea.attributedString> property.
             * @deprecated Access <Titanium.UI.TextArea.attributedString> instead.
             */
            getAttributedString(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.TextArea.autoLink> property.
             * @deprecated Access <Titanium.UI.TextArea.autoLink> instead.
             */
            getAutoLink(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.autocapitalization> property.
             * @deprecated Access <Titanium.UI.TextArea.autocapitalization> instead.
             */
            getAutocapitalization(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.autocorrect> property.
             * @deprecated Access <Titanium.UI.TextArea.autocorrect> instead.
             */
            getAutocorrect(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.autofillType> property.
             * @deprecated Access <Titanium.UI.TextArea.autofillType> instead.
             */
            getAutofillType(): string;

            /**
             * Gets the value of the <Titanium.UI.TextArea.children> property.
             * @deprecated Access <Titanium.UI.TextArea.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.TextArea.clearOnEdit> property.
             * @deprecated Access <Titanium.UI.TextArea.clearOnEdit> instead.
             */
            getClearOnEdit(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.color> property.
             * @deprecated Access <Titanium.UI.TextArea.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TextArea.editable> property.
             * @deprecated Access <Titanium.UI.TextArea.editable> instead.
             */
            getEditable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.ellipsize> property.
             * @deprecated Access <Titanium.UI.TextArea.ellipsize> instead.
             */
            getEllipsize(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.enableReturnKey> property.
             * @deprecated Access <Titanium.UI.TextArea.enableReturnKey> instead.
             */
            getEnableReturnKey(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.focused> property.
             * @deprecated Access <Titanium.UI.TextArea.focused> instead.
             */
            getFocused(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.font> property.
             * @deprecated Access <Titanium.UI.TextArea.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.TextArea.fullscreen> property.
             * @deprecated Access <Titanium.UI.TextArea.fullscreen> instead.
             */
            getFullscreen(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.handleLinks> property.
             * @deprecated Access <Titanium.UI.TextArea.handleLinks> instead.
             */
            getHandleLinks(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.hintText> property.
             * @deprecated Access <Titanium.UI.TextArea.hintText> instead.
             */
            getHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.TextArea.hintTextColor> property.
             * @deprecated Access <Titanium.UI.TextArea.hintTextColor> instead.
             */
            getHintTextColor(): string;

            /**
             * Gets the value of the <Titanium.UI.TextArea.hintType> property.
             * @deprecated Access <Titanium.UI.TextArea.hintType> instead.
             */
            getHintType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.keyboardAppearance> property.
             * @deprecated Access <Titanium.UI.TextArea.keyboardAppearance> instead.
             */
            getKeyboardAppearance(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.keyboardToolbar> property.
             * @deprecated Access <Titanium.UI.TextArea.keyboardToolbar> instead.
             */
            getKeyboardToolbar(): Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar;

            /**
             * Gets the value of the <Titanium.UI.TextArea.keyboardToolbarColor> property.
             * @deprecated Access <Titanium.UI.TextArea.keyboardToolbarColor> instead.
             */
            getKeyboardToolbarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TextArea.keyboardToolbarHeight> property.
             * @deprecated Access <Titanium.UI.TextArea.keyboardToolbarHeight> instead.
             */
            getKeyboardToolbarHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.keyboardType> property.
             * @deprecated Access <Titanium.UI.TextArea.keyboardType> instead.
             */
            getKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.lines> property.
             * @deprecated Access <Titanium.UI.TextArea.lines> instead.
             */
            getLines(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.maxLength> property.
             * @deprecated Access <Titanium.UI.TextArea.maxLength> instead.
             */
            getMaxLength(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.maxLines> property.
             * @deprecated Access <Titanium.UI.TextArea.maxLines> instead.
             */
            getMaxLines(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.padding> property.
             * @deprecated Access <Titanium.UI.TextArea.padding> instead.
             */
            getPadding(): Padding;

            /**
             * Gets the value of the <Titanium.UI.TextArea.returnKeyType> property.
             * @deprecated Access <Titanium.UI.TextArea.returnKeyType> instead.
             */
            getReturnKeyType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.scrollable> property.
             * @deprecated Access <Titanium.UI.TextArea.scrollable> instead.
             */
            getScrollable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.scrollsToTop> property.
             * @deprecated Access <Titanium.UI.TextArea.scrollsToTop> instead.
             */
            getScrollsToTop(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.selection> property.
             * @deprecated Access <Titanium.UI.TextArea.selection> instead.
             */
            getSelection(): textAreaSelectedParams;

            /**
             * Gets the value of the <Titanium.UI.TextArea.showUndoRedoActions> property.
             * @deprecated Access <Titanium.UI.TextArea.showUndoRedoActions> instead.
             */
            getShowUndoRedoActions(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.suppressReturn> property.
             * @deprecated Access <Titanium.UI.TextArea.suppressReturn> instead.
             */
            getSuppressReturn(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextArea.textAlign> property.
             * @deprecated Access <Titanium.UI.TextArea.textAlign> instead.
             */
            getTextAlign(): string | number;

            /**
             * Gets the value of the <Titanium.UI.TextArea.value> property.
             * @deprecated Access <Titanium.UI.TextArea.value> instead.
             */
            getValue(): string;

            /**
             * Gets the value of the <Titanium.UI.TextArea.verticalAlign> property.
             * @deprecated Access <Titanium.UI.TextArea.verticalAlign> instead.
             */
            getVerticalAlign(): number | string;

            /**
             * Returns `true` if this text area contains text.
             */
            hasText(): boolean;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TextAreaEventMap>(name: K, callback: (this: Titanium.UI.TextArea, event: TextAreaEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.TextArea.appearance> property.
             * @deprecated Use [Titanium.UI.TextArea.keyboardAppearance](Titanium.UI.TextArea.keyboardAppearance) instead.
             */
            setAppearance: never;

            /**
             * Sets the value of the <Titanium.UI.TextArea.attributedHintText> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.attributedHintText> instead.
             */
            setAttributedHintText(attributedHintText: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.attributedString> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.attributedString> instead.
             */
            setAttributedString(attributedString: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.autoLink> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.autoLink> instead.
             */
            setAutoLink(autoLink: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.autocapitalization> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.autocapitalization> instead.
             */
            setAutocapitalization(autocapitalization: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.autocorrect> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.autocorrect> instead.
             */
            setAutocorrect(autocorrect: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.autofillType> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.autofillType> instead.
             */
            setAutofillType(autofillType: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.clearOnEdit> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.clearOnEdit> instead.
             */
            setClearOnEdit(clearOnEdit: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.color> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.editable> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.editable> instead.
             */
            setEditable(editable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.ellipsize> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.ellipsize> instead.
             */
            setEllipsize(ellipsize: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.enableReturnKey> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.enableReturnKey> instead.
             */
            setEnableReturnKey(enableReturnKey: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.font> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.fullscreen> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.fullscreen> instead.
             */
            setFullscreen(fullscreen: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.handleLinks> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.handleLinks> instead.
             */
            setHandleLinks(handleLinks: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.hintText> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.hintText> instead.
             */
            setHintText(hintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.hintTextColor> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.hintTextColor> instead.
             */
            setHintTextColor(hintTextColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.hintType> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.hintType> instead.
             */
            setHintType(hintType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.keyboardAppearance> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.keyboardAppearance> instead.
             */
            setKeyboardAppearance(keyboardAppearance: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.keyboardToolbar> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.keyboardToolbar> instead.
             */
            setKeyboardToolbar(keyboardToolbar: Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.keyboardToolbarColor> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.keyboardToolbarColor> instead.
             */
            setKeyboardToolbarColor(keyboardToolbarColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.keyboardToolbarHeight> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.keyboardToolbarHeight> instead.
             */
            setKeyboardToolbarHeight(keyboardToolbarHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.keyboardType> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.keyboardType> instead.
             */
            setKeyboardType(keyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.lines> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.lines> instead.
             */
            setLines(lines: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.maxLength> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.maxLength> instead.
             */
            setMaxLength(maxLength: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.maxLines> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.maxLines> instead.
             */
            setMaxLines(maxLines: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.padding> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.padding> instead.
             */
            setPadding(padding: Padding): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.returnKeyType> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.returnKeyType> instead.
             */
            setReturnKeyType(returnKeyType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.scrollable> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.scrollable> instead.
             */
            setScrollable(scrollable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.scrollsToTop> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.scrollsToTop> instead.
             */
            setScrollsToTop(scrollsToTop: boolean): void;

            /**
             * Selects the text in range (start, end).
             */
            setSelection(start: number, end: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.showUndoRedoActions> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.showUndoRedoActions> instead.
             */
            setShowUndoRedoActions(showUndoRedoActions: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.suppressReturn> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.suppressReturn> instead.
             */
            setSuppressReturn(suppressReturn: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.textAlign> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.textAlign> instead.
             */
            setTextAlign(textAlign: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.value> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.value> instead.
             */
            setValue(value: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextArea.verticalAlign> property.
             * @deprecated Set the value using <Titanium.UI.TextArea.verticalAlign> instead.
             */
            setVerticalAlign(verticalAlign: number | string): void;

        }
        /**
         * Base event for class Titanium.UI.TextField
         */
        interface TextFieldBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.TextField;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface TextField_click_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface TextField_dblclick_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface TextField_doubletap_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the field gains focus.
         */
        interface TextField_focus_Event extends TextFieldBaseEvent {
            /**
             * Value of the field.
             */
            value: string;

        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface TextField_keypressed_Event extends TextFieldBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface TextField_longclick_Event extends TextFieldBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface TextField_longpress_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface TextField_pinch_Event extends TextFieldBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface TextField_postlayout_Event extends TextFieldBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface TextField_singletap_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface TextField_swipe_Event extends TextFieldBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface TextField_touchcancel_Event extends TextFieldBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface TextField_touchend_Event extends TextFieldBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface TextField_touchmove_Event extends TextFieldBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface TextField_touchstart_Event extends TextFieldBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface TextField_twofingertap_Event extends TextFieldBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the field loses focus.
         */
        interface TextField_blur_Event extends TextFieldBaseEvent {
            /**
             * Value of the field.
             */
            value: string;

        }
        /**
         * Fired when the field value changes.
         */
        interface TextField_change_Event extends TextFieldBaseEvent {
            /**
             * New value of the field.
             */
            value: string;

        }
        /**
         * Fired when the return key is pressed on the keyboard.
         */
        interface TextField_return_Event extends TextFieldBaseEvent {
            /**
             * Value of this text area.
             */
            value: string;

        }
        interface TextFieldEventMap extends ProxyEventMap {
            blur: TextField_blur_Event;

            change: TextField_change_Event;

            click: TextField_click_Event;

            dblclick: TextField_dblclick_Event;

            doubletap: TextField_doubletap_Event;

            focus: TextField_focus_Event;

            keypressed: TextField_keypressed_Event;

            longclick: TextField_longclick_Event;

            longpress: TextField_longpress_Event;

            pinch: TextField_pinch_Event;

            postlayout: TextField_postlayout_Event;

            return: TextField_return_Event;

            singletap: TextField_singletap_Event;

            swipe: TextField_swipe_Event;

            touchcancel: TextField_touchcancel_Event;

            touchend: TextField_touchend_Event;

            touchmove: TextField_touchmove_Event;

            touchstart: TextField_touchstart_Event;

            twofingertap: TextField_twofingertap_Event;

        }
        /**
         * A single line text field.
         */
        class TextField extends Titanium.UI.View {
            /**
             * Determines the appearance of the keyboard displayed when this field is focused.
             * @deprecated Use [Titanium.UI.TextField.keyboardAppearance](Titanium.UI.TextField.keyboardAppearance) instead.
             */
            appearance: never;

            /**
             * Hint text attributed string.
             */
            attributedHintText: Titanium.UI.AttributedString;

            /**
             * TextField attributed string.
             */
            attributedString: Titanium.UI.AttributedString;

            /**
             * Automatically convert text to clickable links.
             */
            autoLink: number;

            /**
             * Determines how text is capitalized during typing.
             */
            autocapitalization: number;

            /**
             * Determines whether to automatically correct text entered into this text field.
             */
            autocorrect: boolean;

            /**
             * Sets the autofill type for the text field.
             */
            autofillType: string;

            /**
             * Border style for the field.
             */
            borderStyle: number;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Determines when the clear button is displayed.
             */
            clearButtonMode: number;

            /**
             * Determines whether the value of this text field should be cleared when it is focused.
             */
            clearOnEdit: boolean;

            /**
             * Color of the text in this text field, as a color name or hex triplet.
             */
            color: string | Titanium.UI.Color;

            /**
             * Determines whether this field can be edited.
             */
            editable: boolean;

            /**
             * Determines whether an ellipsis (`...`) should be used to indicate truncated text.
             */
            ellipsize: boolean;

            /**
             * Determines whether the return key is enabled automatically when there is text in this text
             * field.
             */
            enableReturnKey: boolean;

            /**
             * Determines whether this TextField has focus.
             */
            readonly focused: boolean;

            /**
             * Font to use for text.
             */
            font: Font;

            /**
             * Leave some space above the keyboard in landscape mode or not.
             */
            fullscreen: boolean;

            /**
             * Hint text to display when the field is empty.
             */
            hintText: string;

            /**
             * Hint text color to display when the field is empty.
             */
            hintTextColor: string | Titanium.UI.Color;

            /**
             * Hint type to display on the text field.
             */
            hintType: number;

            /**
             * Key identifying a string from the locale file to use for the
             * [hintText](Titanium.UI.TextField.hintText) property.
             */
            hinttextid: string;

            /**
             * Input type to accept in the text field. Also influences the Keyboard type to display.
             */
            inputType: number[];

            /**
             * Determines the appearance of the keyboard displayed when this field is focused.
             */
            keyboardAppearance: number;

            /**
             * Array of toolbar button objects or a [toolbar](Titanium.UI.iOS.Toolbar) to be used when the
             * keyboard is displayed.
             */
            keyboardToolbar: Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar;

            /**
             * Color of the keyboard toolbar if keyboardToolbar is an array, as a color name or hex triplet.
             */
            keyboardToolbarColor: string | Titanium.UI.Color;

            /**
             * Height of the keyboard toolbar if keyboardToolbar is an array.
             */
            keyboardToolbarHeight: number;

            /**
             * Keyboard type to display when this text field is focused.
             */
            keyboardType: number;

            /**
             * Left button view to display in the `TextField`.
             */
            leftButton: Titanium.UI.View;

            /**
             * Determines when to display the left button view.
             */
            leftButtonMode: number;

            /**
             * Padding between the left button and the edge of the field.
             */
            leftButtonPadding: number;

            /**
             * Maximum length of text field input.
             */
            maxLength: number;

            /**
             * Minimum size of the font when the font is sized based on the contents.  Enables font
             * scaling to fit.
             */
            minimumFontSize: number;

            /**
             * Sets the padding of this text field.
             */
            padding: TextFieldPadding;

            /**
             * Left padding of this text field.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            paddingLeft: never;

            /**
             * Right padding of this text field.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            paddingRight: never;

            /**
             * Obscure the input text from the user.
             */
            passwordMask: boolean;

            /**
             * Set password rules that should be used for this text field.
             */
            passwordRules: string;

            /**
             * Specifies the text to display on the keyboard `Return` key when this field is focused.
             */
            returnKeyType: number;

            /**
             * Right button view.
             */
            rightButton: Titanium.UI.View;

            /**
             * Determines when to display the right button view.
             */
            rightButtonMode: number;

            /**
             * Padding between the right button and the edge of the field.
             */
            rightButtonPadding: number;

            /**
             * Returns the currently selected text of the text field.
             */
            readonly selection: textFieldSelectedParams;

            /**
             * Determinates if the undo and redo buttons on the left side of the keyboard should be displayed or not. Only valid on iOS9 and above.
             */
            showUndoRedoActions: boolean;

            /**
             * Determines whether the return key should be suppressed during entry.
             */
            suppressReturn: boolean;

            /**
             * Text alignment within this text field.
             * This has no effect on `hintText` when `hintType` is Ti.UI.HINT_TYPE_ANIMATED.
             */
            textAlign: string | number;

            /**
             * Value of this text field, which may be set programmatically and modified by the user.
             */
            value: string;

            /**
             * Vertical alignment within this text field.
             */
            verticalAlign: number | string;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof TextFieldEventMap>(name: K, callback: (this: Titanium.UI.TextField, event: TextFieldEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Forces the field to lose focus.
             */
            blur(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof TextFieldEventMap>(name: K, event?: TextFieldEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Forces the field to gain focus.
             */
            focus(): void;

            /**
             * Gets the value of the <Titanium.UI.TextField.appearance> property.
             * @deprecated Use [Titanium.UI.TextField.keyboardAppearance](Titanium.UI.TextField.keyboardAppearance) instead.
             */
            getAppearance: never;

            /**
             * Gets the value of the <Titanium.UI.TextField.attributedHintText> property.
             * @deprecated Access <Titanium.UI.TextField.attributedHintText> instead.
             */
            getAttributedHintText(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.TextField.attributedString> property.
             * @deprecated Access <Titanium.UI.TextField.attributedString> instead.
             */
            getAttributedString(): Titanium.UI.AttributedString;

            /**
             * Gets the value of the <Titanium.UI.TextField.autoLink> property.
             * @deprecated Access <Titanium.UI.TextField.autoLink> instead.
             */
            getAutoLink(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.autocapitalization> property.
             * @deprecated Access <Titanium.UI.TextField.autocapitalization> instead.
             */
            getAutocapitalization(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.autocorrect> property.
             * @deprecated Access <Titanium.UI.TextField.autocorrect> instead.
             */
            getAutocorrect(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.autofillType> property.
             * @deprecated Access <Titanium.UI.TextField.autofillType> instead.
             */
            getAutofillType(): string;

            /**
             * Gets the value of the <Titanium.UI.TextField.borderStyle> property.
             * @deprecated Access <Titanium.UI.TextField.borderStyle> instead.
             */
            getBorderStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.children> property.
             * @deprecated Access <Titanium.UI.TextField.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.TextField.clearButtonMode> property.
             * @deprecated Access <Titanium.UI.TextField.clearButtonMode> instead.
             */
            getClearButtonMode(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.clearOnEdit> property.
             * @deprecated Access <Titanium.UI.TextField.clearOnEdit> instead.
             */
            getClearOnEdit(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.color> property.
             * @deprecated Access <Titanium.UI.TextField.color> instead.
             */
            getColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TextField.editable> property.
             * @deprecated Access <Titanium.UI.TextField.editable> instead.
             */
            getEditable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.ellipsize> property.
             * @deprecated Access <Titanium.UI.TextField.ellipsize> instead.
             */
            getEllipsize(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.enableReturnKey> property.
             * @deprecated Access <Titanium.UI.TextField.enableReturnKey> instead.
             */
            getEnableReturnKey(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.focused> property.
             * @deprecated Access <Titanium.UI.TextField.focused> instead.
             */
            getFocused(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.font> property.
             * @deprecated Access <Titanium.UI.TextField.font> instead.
             */
            getFont(): Font;

            /**
             * Gets the value of the <Titanium.UI.TextField.fullscreen> property.
             * @deprecated Access <Titanium.UI.TextField.fullscreen> instead.
             */
            getFullscreen(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.hintText> property.
             * @deprecated Access <Titanium.UI.TextField.hintText> instead.
             */
            getHintText(): string;

            /**
             * Gets the value of the <Titanium.UI.TextField.hintTextColor> property.
             * @deprecated Access <Titanium.UI.TextField.hintTextColor> instead.
             */
            getHintTextColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TextField.hintType> property.
             * @deprecated Access <Titanium.UI.TextField.hintType> instead.
             */
            getHintType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.hinttextid> property.
             * @deprecated Access <Titanium.UI.TextField.hinttextid> instead.
             */
            getHinttextid(): string;

            /**
             * Gets the value of the <Titanium.UI.TextField.inputType> property.
             * @deprecated Access <Titanium.UI.TextField.inputType> instead.
             */
            getInputType(): number[];

            /**
             * Gets the value of the <Titanium.UI.TextField.keyboardAppearance> property.
             * @deprecated Access <Titanium.UI.TextField.keyboardAppearance> instead.
             */
            getKeyboardAppearance(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.keyboardToolbar> property.
             * @deprecated Access <Titanium.UI.TextField.keyboardToolbar> instead.
             */
            getKeyboardToolbar(): Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar;

            /**
             * Gets the value of the <Titanium.UI.TextField.keyboardToolbarColor> property.
             * @deprecated Access <Titanium.UI.TextField.keyboardToolbarColor> instead.
             */
            getKeyboardToolbarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.TextField.keyboardToolbarHeight> property.
             * @deprecated Access <Titanium.UI.TextField.keyboardToolbarHeight> instead.
             */
            getKeyboardToolbarHeight(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.keyboardType> property.
             * @deprecated Access <Titanium.UI.TextField.keyboardType> instead.
             */
            getKeyboardType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.leftButton> property.
             * @deprecated Access <Titanium.UI.TextField.leftButton> instead.
             */
            getLeftButton(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TextField.leftButtonMode> property.
             * @deprecated Access <Titanium.UI.TextField.leftButtonMode> instead.
             */
            getLeftButtonMode(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.leftButtonPadding> property.
             * @deprecated Access <Titanium.UI.TextField.leftButtonPadding> instead.
             */
            getLeftButtonPadding(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.maxLength> property.
             * @deprecated Access <Titanium.UI.TextField.maxLength> instead.
             */
            getMaxLength(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.minimumFontSize> property.
             * @deprecated Access <Titanium.UI.TextField.minimumFontSize> instead.
             */
            getMinimumFontSize(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.padding> property.
             * @deprecated Access <Titanium.UI.TextField.padding> instead.
             */
            getPadding(): TextFieldPadding;

            /**
             * Gets the value of the <Titanium.UI.TextField.paddingLeft> property.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            getPaddingLeft: never;

            /**
             * Gets the value of the <Titanium.UI.TextField.paddingRight> property.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            getPaddingRight: never;

            /**
             * Gets the value of the <Titanium.UI.TextField.passwordMask> property.
             * @deprecated Access <Titanium.UI.TextField.passwordMask> instead.
             */
            getPasswordMask(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.passwordRules> property.
             * @deprecated Access <Titanium.UI.TextField.passwordRules> instead.
             */
            getPasswordRules(): string;

            /**
             * Gets the value of the <Titanium.UI.TextField.returnKeyType> property.
             * @deprecated Access <Titanium.UI.TextField.returnKeyType> instead.
             */
            getReturnKeyType(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.rightButton> property.
             * @deprecated Access <Titanium.UI.TextField.rightButton> instead.
             */
            getRightButton(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.TextField.rightButtonMode> property.
             * @deprecated Access <Titanium.UI.TextField.rightButtonMode> instead.
             */
            getRightButtonMode(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.rightButtonPadding> property.
             * @deprecated Access <Titanium.UI.TextField.rightButtonPadding> instead.
             */
            getRightButtonPadding(): number;

            /**
             * Gets the value of the <Titanium.UI.TextField.selection> property.
             * @deprecated Access <Titanium.UI.TextField.selection> instead.
             */
            getSelection(): textFieldSelectedParams;

            /**
             * Gets the value of the <Titanium.UI.TextField.showUndoRedoActions> property.
             * @deprecated Access <Titanium.UI.TextField.showUndoRedoActions> instead.
             */
            getShowUndoRedoActions(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.suppressReturn> property.
             * @deprecated Access <Titanium.UI.TextField.suppressReturn> instead.
             */
            getSuppressReturn(): boolean;

            /**
             * Gets the value of the <Titanium.UI.TextField.textAlign> property.
             * @deprecated Access <Titanium.UI.TextField.textAlign> instead.
             */
            getTextAlign(): string | number;

            /**
             * Gets the value of the <Titanium.UI.TextField.value> property.
             * @deprecated Access <Titanium.UI.TextField.value> instead.
             */
            getValue(): string;

            /**
             * Gets the value of the <Titanium.UI.TextField.verticalAlign> property.
             * @deprecated Access <Titanium.UI.TextField.verticalAlign> instead.
             */
            getVerticalAlign(): number | string;

            /**
             * Returns `true` if this text field contains text.
             */
            hasText(): boolean;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof TextFieldEventMap>(name: K, callback: (this: Titanium.UI.TextField, event: TextFieldEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.TextField.appearance> property.
             * @deprecated Use [Titanium.UI.TextField.keyboardAppearance](Titanium.UI.TextField.keyboardAppearance) instead.
             */
            setAppearance: never;

            /**
             * Sets the value of the <Titanium.UI.TextField.attributedHintText> property.
             * @deprecated Set the value using <Titanium.UI.TextField.attributedHintText> instead.
             */
            setAttributedHintText(attributedHintText: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.attributedString> property.
             * @deprecated Set the value using <Titanium.UI.TextField.attributedString> instead.
             */
            setAttributedString(attributedString: Titanium.UI.AttributedString): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.autoLink> property.
             * @deprecated Set the value using <Titanium.UI.TextField.autoLink> instead.
             */
            setAutoLink(autoLink: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.autocapitalization> property.
             * @deprecated Set the value using <Titanium.UI.TextField.autocapitalization> instead.
             */
            setAutocapitalization(autocapitalization: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.autocorrect> property.
             * @deprecated Set the value using <Titanium.UI.TextField.autocorrect> instead.
             */
            setAutocorrect(autocorrect: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.autofillType> property.
             * @deprecated Set the value using <Titanium.UI.TextField.autofillType> instead.
             */
            setAutofillType(autofillType: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.borderStyle> property.
             * @deprecated Set the value using <Titanium.UI.TextField.borderStyle> instead.
             */
            setBorderStyle(borderStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.clearButtonMode> property.
             * @deprecated Set the value using <Titanium.UI.TextField.clearButtonMode> instead.
             */
            setClearButtonMode(clearButtonMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.clearOnEdit> property.
             * @deprecated Set the value using <Titanium.UI.TextField.clearOnEdit> instead.
             */
            setClearOnEdit(clearOnEdit: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.color> property.
             * @deprecated Set the value using <Titanium.UI.TextField.color> instead.
             */
            setColor(color: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.editable> property.
             * @deprecated Set the value using <Titanium.UI.TextField.editable> instead.
             */
            setEditable(editable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.ellipsize> property.
             * @deprecated Set the value using <Titanium.UI.TextField.ellipsize> instead.
             */
            setEllipsize(ellipsize: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.enableReturnKey> property.
             * @deprecated Set the value using <Titanium.UI.TextField.enableReturnKey> instead.
             */
            setEnableReturnKey(enableReturnKey: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.font> property.
             * @deprecated Set the value using <Titanium.UI.TextField.font> instead.
             */
            setFont(font: Font): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.fullscreen> property.
             * @deprecated Set the value using <Titanium.UI.TextField.fullscreen> instead.
             */
            setFullscreen(fullscreen: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.hintText> property.
             * @deprecated Set the value using <Titanium.UI.TextField.hintText> instead.
             */
            setHintText(hintText: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.hintTextColor> property.
             * @deprecated Set the value using <Titanium.UI.TextField.hintTextColor> instead.
             */
            setHintTextColor(hintTextColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.hintType> property.
             * @deprecated Set the value using <Titanium.UI.TextField.hintType> instead.
             */
            setHintType(hintType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.hinttextid> property.
             * @deprecated Set the value using <Titanium.UI.TextField.hinttextid> instead.
             */
            setHinttextid(hinttextid: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.inputType> property.
             * @deprecated Set the value using <Titanium.UI.TextField.inputType> instead.
             */
            setInputType(inputType: ReadonlyArray<number>): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.keyboardAppearance> property.
             * @deprecated Set the value using <Titanium.UI.TextField.keyboardAppearance> instead.
             */
            setKeyboardAppearance(keyboardAppearance: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.keyboardToolbar> property.
             * @deprecated Set the value using <Titanium.UI.TextField.keyboardToolbar> instead.
             */
            setKeyboardToolbar(keyboardToolbar: Titanium.UI.View[] | Titanium.UI.Toolbar | Titanium.UI.iOS.Toolbar): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.keyboardToolbarColor> property.
             * @deprecated Set the value using <Titanium.UI.TextField.keyboardToolbarColor> instead.
             */
            setKeyboardToolbarColor(keyboardToolbarColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.keyboardToolbarHeight> property.
             * @deprecated Set the value using <Titanium.UI.TextField.keyboardToolbarHeight> instead.
             */
            setKeyboardToolbarHeight(keyboardToolbarHeight: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.keyboardType> property.
             * @deprecated Set the value using <Titanium.UI.TextField.keyboardType> instead.
             */
            setKeyboardType(keyboardType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.leftButton> property.
             * @deprecated Set the value using <Titanium.UI.TextField.leftButton> instead.
             */
            setLeftButton(leftButton: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.leftButtonMode> property.
             * @deprecated Set the value using <Titanium.UI.TextField.leftButtonMode> instead.
             */
            setLeftButtonMode(leftButtonMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.leftButtonPadding> property.
             * @deprecated Set the value using <Titanium.UI.TextField.leftButtonPadding> instead.
             */
            setLeftButtonPadding(leftButtonPadding: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.maxLength> property.
             * @deprecated Set the value using <Titanium.UI.TextField.maxLength> instead.
             */
            setMaxLength(maxLength: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.minimumFontSize> property.
             * @deprecated Set the value using <Titanium.UI.TextField.minimumFontSize> instead.
             */
            setMinimumFontSize(minimumFontSize: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.padding> property.
             * @deprecated Set the value using <Titanium.UI.TextField.padding> instead.
             */
            setPadding(padding: TextFieldPadding): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.paddingLeft> property.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            setPaddingLeft: never;

            /**
             * Sets the value of the <Titanium.UI.TextField.paddingRight> property.
             * @deprecated Use [Titanium.UI.TextField.padding](Titanium.UI.TextField.padding) for parity instead.
             */
            setPaddingRight: never;

            /**
             * Sets the value of the <Titanium.UI.TextField.passwordMask> property.
             * @deprecated Set the value using <Titanium.UI.TextField.passwordMask> instead.
             */
            setPasswordMask(passwordMask: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.passwordRules> property.
             * @deprecated Set the value using <Titanium.UI.TextField.passwordRules> instead.
             */
            setPasswordRules(passwordRules: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.returnKeyType> property.
             * @deprecated Set the value using <Titanium.UI.TextField.returnKeyType> instead.
             */
            setReturnKeyType(returnKeyType: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.rightButton> property.
             * @deprecated Set the value using <Titanium.UI.TextField.rightButton> instead.
             */
            setRightButton(rightButton: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.rightButtonMode> property.
             * @deprecated Set the value using <Titanium.UI.TextField.rightButtonMode> instead.
             */
            setRightButtonMode(rightButtonMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.rightButtonPadding> property.
             * @deprecated Set the value using <Titanium.UI.TextField.rightButtonPadding> instead.
             */
            setRightButtonPadding(rightButtonPadding: number): void;

            /**
             * Selects the text in range (start, end).
             */
            setSelection(start: number, end: number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.showUndoRedoActions> property.
             * @deprecated Set the value using <Titanium.UI.TextField.showUndoRedoActions> instead.
             */
            setShowUndoRedoActions(showUndoRedoActions: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.suppressReturn> property.
             * @deprecated Set the value using <Titanium.UI.TextField.suppressReturn> instead.
             */
            setSuppressReturn(suppressReturn: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.textAlign> property.
             * @deprecated Set the value using <Titanium.UI.TextField.textAlign> instead.
             */
            setTextAlign(textAlign: string | number): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.value> property.
             * @deprecated Set the value using <Titanium.UI.TextField.value> instead.
             */
            setValue(value: string): void;

            /**
             * Sets the value of the <Titanium.UI.TextField.verticalAlign> property.
             * @deprecated Set the value using <Titanium.UI.TextField.verticalAlign> instead.
             */
            setVerticalAlign(verticalAlign: number | string): void;

        }
        /**
         * Base event for class Titanium.UI.Toolbar
         */
        interface ToolbarBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Toolbar;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Toolbar_click_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Toolbar_dblclick_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Toolbar_doubletap_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface Toolbar_focus_Event extends ToolbarBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Toolbar_keypressed_Event extends ToolbarBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Toolbar_longclick_Event extends ToolbarBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Toolbar_longpress_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Toolbar_pinch_Event extends ToolbarBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Toolbar_postlayout_Event extends ToolbarBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Toolbar_singletap_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Toolbar_swipe_Event extends ToolbarBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Toolbar_touchcancel_Event extends ToolbarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Toolbar_touchend_Event extends ToolbarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Toolbar_touchmove_Event extends ToolbarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Toolbar_touchstart_Event extends ToolbarBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Toolbar_twofingertap_Event extends ToolbarBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ToolbarEventMap extends ProxyEventMap {
            click: Toolbar_click_Event;

            dblclick: Toolbar_dblclick_Event;

            doubletap: Toolbar_doubletap_Event;

            focus: Toolbar_focus_Event;

            keypressed: Toolbar_keypressed_Event;

            longclick: Toolbar_longclick_Event;

            longpress: Toolbar_longpress_Event;

            pinch: Toolbar_pinch_Event;

            postlayout: Toolbar_postlayout_Event;

            singletap: Toolbar_singletap_Event;

            swipe: Toolbar_swipe_Event;

            touchcancel: Toolbar_touchcancel_Event;

            touchend: Toolbar_touchend_Event;

            touchmove: Toolbar_touchmove_Event;

            touchstart: Toolbar_touchstart_Event;

            twofingertap: Toolbar_twofingertap_Event;

        }
        /**
         * A Toolbar can contain buttons, as well as certain other widgets, including text fields and labels.
         */
        class Toolbar extends Titanium.UI.View {
            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: never;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: never;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: never;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: never;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: never;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: never;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: never;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: never;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: never;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: never;

            /**
             * Background color for the toolbar, as a color name or hex triplet.
             */
            barColor: string | Titanium.UI.Color;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * Returns the margin after the toolbar's content when there are action buttons.
             */
            contentInsetEndWithActions: number;

            /**
             * Returns the margin at the toolbar's content start when there is a navigation button.
             */
            contentInsetStartWithNavigation: number;

            /**
             * If `true`, the background of the toolbar extends upwards.
             */
            extendBackground: boolean;

            /**
             * An array of buttons (or other widgets) contained in the toolbar.
             */
            items: Titanium.UI.View[];

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: never;

            /**
             * Image to be used as a logo in the Toolbar.
             */
            logo: string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Image to be used for a navigation icon.
             */
            navigationIcon: string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Image to be used for the overflow menu.
             */
            overflowIcon: string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: never;

            /**
             * Text of the subtitle.
             */
            subtitle: string;

            /**
             * Color for toolbar's subtitle
             */
            subtitleTextColor: string;

            /**
             * Text of the title.
             */
            title: string;

            /**
             * Color string with any Titanium supported format
             */
            titleTextColor: string;

            /**
             * If `true`, a translucent background color is used for the toolbar.
             */
            translucent: boolean;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ToolbarEventMap>(name: K, callback: (this: Titanium.UI.Toolbar, event: ToolbarEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Collapses expanded ActionViews if there is any
             */
            collapseActionViews(): void;

            /**
             * Collapses expandend ActionViews and hides overflow menu
             */
            dismissPopupMenus(): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ToolbarEventMap>(name: K, event?: ToolbarEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundColor> instead.
             */
            getBackgroundColor: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundRepeat> instead.
             */
            getBackgroundRepeat: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.Toolbar.backgroundTopCap> instead.
             */
            getBackgroundTopCap: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.barColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.barColor> instead.
             */
            getBarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.children> property.
             * @deprecated Access <Titanium.UI.Toolbar.children> instead.
             */
            getChildren: never;

            /**
             * Returns the margin at the toolbar's content end.
             */
            getContentInsetEnd(): number;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.contentInsetEndWithActions> property.
             * @deprecated Access <Titanium.UI.Toolbar.contentInsetEndWithActions> instead.
             */
            getContentInsetEndWithActions(): number;

            /**
             * Returns the margin on the left of the toolbar's content.
             */
            getContentInsetLeft(): number;

            /**
             * Returns the margin on the right of the toolbar's content.
             */
            getContentInsetRight(): number;

            /**
             * Returns the margin at the toolbar's content start.
             */
            getContentInsetStart(): number;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.contentInsetStartWithNavigation> property.
             * @deprecated Access <Titanium.UI.Toolbar.contentInsetStartWithNavigation> instead.
             */
            getContentInsetStartWithNavigation(): number;

            /**
             * Returns the margin at the toolbar's content end that will be used with the current configuration of the toolbar.
             */
            getCurrentContentInsetEnd(): number;

            /**
             * Returns the margin on the left of the toolbar's content that will be used with the current configuration of the toolbar.
             */
            getCurrentContentInsetLeft(): number;

            /**
             * Returns the margin on the right of the toolbar's content that will be used with the current configuration of the toolbar.
             */
            getCurrentContentInsetRight(): number;

            /**
             * Returns the margin at the toolbar's content start that will be used with the current configuration of the toolbar.
             */
            getCurrentContentInsetStart(): number;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.items> property.
             * @deprecated Access <Titanium.UI.Toolbar.items> instead.
             */
            getItems(): Titanium.UI.View[];

            /**
             * Gets the value of the <Titanium.UI.Toolbar.layout> property.
             * @deprecated Access <Titanium.UI.Toolbar.layout> instead.
             */
            getLayout: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.logo> property.
             * @deprecated Access <Titanium.UI.Toolbar.logo> instead.
             */
            getLogo(): string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.navigationIcon> property.
             * @deprecated Access <Titanium.UI.Toolbar.navigationIcon> instead.
             */
            getNavigationIcon(): string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.overflowIcon> property.
             * @deprecated Access <Titanium.UI.Toolbar.overflowIcon> instead.
             */
            getOverflowIcon(): string | Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.Toolbar.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus: never;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.subtitle> property.
             * @deprecated Access <Titanium.UI.Toolbar.subtitle> instead.
             */
            getSubtitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.subtitleTextColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.subtitleTextColor> instead.
             */
            getSubtitleTextColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.title> property.
             * @deprecated Access <Titanium.UI.Toolbar.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.titleTextColor> property.
             * @deprecated Access <Titanium.UI.Toolbar.titleTextColor> instead.
             */
            getTitleTextColor(): string;

            /**
             * Gets the value of the <Titanium.UI.Toolbar.translucent> property.
             * @deprecated Access <Titanium.UI.Toolbar.translucent> instead.
             */
            getTranslucent(): boolean;

            /**
             * Checks if the toolbar is currently hosting an expanded action view.
             */
            hasExpandedActionView(): boolean;

            /**
             * Hides the overflow menu if there is one.
             */
            hideOverflowMenu(): void;

            /**
             * Checks if the toolbar is currently hosting an expanded action view.
             */
            isOverflowMenuShowing(): boolean;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ToolbarEventMap>(name: K, callback: (this: Titanium.UI.Toolbar, event: ToolbarEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundColor> instead.
             */
            setBackgroundColor: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundRepeat> instead.
             */
            setBackgroundRepeat: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.backgroundTopCap> instead.
             */
            setBackgroundTopCap: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.barColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.barColor> instead.
             */
            setBarColor(barColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.contentInsetEndWithActions> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.contentInsetEndWithActions> instead.
             */
            setContentInsetEndWithActions(contentInsetEndWithActions: number): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.contentInsetStartWithNavigation> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.contentInsetStartWithNavigation> instead.
             */
            setContentInsetStartWithNavigation(contentInsetStartWithNavigation: number): void;

            /**
             * Sets the content margins of the toolbar
             */
            setContentInsetsAbsolute(insetLeft: number, insetRight: number): void;

            /**
             * Sets the content margins relative to the layout direction
             */
            setContentInsetsRelative(insetStart: number, insetEnd: number): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.items> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.items> instead.
             */
            setItems(items: ReadonlyArray<Titanium.UI.View>): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.layout> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.layout> instead.
             */
            setLayout: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.logo> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.logo> instead.
             */
            setLogo(logo: string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.navigationIcon> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.navigationIcon> instead.
             */
            setNavigationIcon(navigationIcon: string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.overflowIcon> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.overflowIcon> instead.
             */
            setOverflowIcon(overflowIcon: string | Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus: never;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.subtitle> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.subtitle> instead.
             */
            setSubtitle(subtitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.subtitleTextColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.subtitleTextColor> instead.
             */
            setSubtitleTextColor(subtitleTextColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.title> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.titleTextColor> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.titleTextColor> instead.
             */
            setTitleTextColor(titleTextColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.Toolbar.translucent> property.
             * @deprecated Set the value using <Titanium.UI.Toolbar.translucent> instead.
             */
            setTranslucent(translucent: boolean): void;

            /**
             * Shows the overflow menu if there is one
             */
            showOverflowMenu(): void;

        }
        /**
         * Base event for class Titanium.UI.View
         */
        interface ViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.View;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface View_click_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface View_dblclick_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface View_doubletap_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface View_focus_Event extends ViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface View_keypressed_Event extends ViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface View_longclick_Event extends ViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface View_longpress_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface View_pinch_Event extends ViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface View_postlayout_Event extends ViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface View_singletap_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface View_swipe_Event extends ViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface View_touchcancel_Event extends ViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface View_touchend_Event extends ViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface View_touchmove_Event extends ViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface View_touchstart_Event extends ViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface View_twofingertap_Event extends ViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        interface ViewEventMap extends ProxyEventMap {
            click: View_click_Event;

            dblclick: View_dblclick_Event;

            doubletap: View_doubletap_Event;

            focus: View_focus_Event;

            keypressed: View_keypressed_Event;

            longclick: View_longclick_Event;

            longpress: View_longpress_Event;

            pinch: View_pinch_Event;

            postlayout: View_postlayout_Event;

            singletap: View_singletap_Event;

            swipe: View_swipe_Event;

            touchcancel: View_touchcancel_Event;

            touchend: View_touchend_Event;

            touchmove: View_touchmove_Event;

            touchstart: View_touchstart_Event;

            twofingertap: View_twofingertap_Event;

        }
        /**
         * An empty drawing surface or container
         */
        class View extends Titanium.Proxy {
            /**
             * Whether the view should be "hidden" from (i.e., ignored by) the accessibility service.
             */
            accessibilityHidden: boolean;

            /**
             * Briefly describes what performing an action (such as a click) on the view will do.
             */
            accessibilityHint: string;

            /**
             * A succint label identifying the view for the device's accessibility service.
             */
            accessibilityLabel: string;

            /**
             * A string describing the value (if any) of the view for the device's accessibility service.
             */
            accessibilityValue: string;

            /**
             * Coordinate of the view about which to pivot an animation.
             */
            anchorPoint: Point;

            /**
             * Current position of the view during an animation.
             */
            readonly animatedCenter: Point;

            /**
             * Background color of the view, as a color name or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Disabled background color of the view, as a color name or hex triplet.
             */
            backgroundDisabledColor: string;

            /**
             * Disabled background image for the view, specified as a local file path or URL.
             */
            backgroundDisabledImage: string;

            /**
             * Focused background color of the view, as a color name or hex triplet.
             */
            backgroundFocusedColor: string;

            /**
             * Focused background image for the view, specified as a local file path or URL.
             */
            backgroundFocusedImage: string;

            /**
             * A background gradient for the view.
             */
            backgroundGradient: Gradient;

            /**
             * Background image for the view, specified as a local file path or URL.
             */
            backgroundImage: string;

            /**
             * Size of the left end cap.
             */
            backgroundLeftCap: number;

            /**
             * Determines whether to tile a background across a view.
             */
            backgroundRepeat: boolean;

            /**
             * Selected background color of the view, as a color name or hex triplet.
             */
            backgroundSelectedColor: string | Titanium.UI.Color;

            /**
             * Selected background image url for the view, specified as a local file path or URL.
             */
            backgroundSelectedImage: string;

            /**
             * Size of the top end cap.
             */
            backgroundTopCap: number;

            /**
             * Border color of the view, as a color name or hex triplet.
             */
            borderColor: string | Titanium.UI.Color;

            /**
             * Radius for the rounded corners of the view's border.
             */
            borderRadius: number | string | number[] | string[];

            /**
             * Border width of the view.
             */
            borderWidth: number;

            /**
             * View's bottom position, in platform-specific units.
             */
            bottom: number | string;

            /**
             * View's center position, in the parent view's coordinates.
             */
            center: Point;

            /**
             * Array of this view's child views.
             */
            readonly children: Titanium.UI.View[];

            /**
             * View's clipping behavior.
             */
            clipMode: number;

            /**
             * Base elevation of the view relative to its parent in pixels.
             */
            elevation: number;

            /**
             * Whether view should be focusable while navigating with the trackball.
             */
            focusable: boolean;

            /**
             * View height, in platform-specific units.
             */
            height: number | string;

            /**
             * Sets the behavior when hiding an object to release or keep the free space
             */
            hiddenBehavior: number;

            /**
             * Adds a horizontal parallax effect to the view
             */
            horizontalMotionEffect: MinMaxOptions;

            /**
             * Determines whether the layout has wrapping behavior.
             */
            horizontalWrap: boolean;

            /**
             * View's identifier.
             */
            id?: string;

            /**
             * Determines whether to keep the device screen on.
             */
            keepScreenOn: boolean;

            /**
             * Specifies how the view positions its children.
             * One of: 'composite', 'vertical', or 'horizontal'.
             */
            layout: string;

            /**
             * View's left position, in platform-specific units.
             */
            left: number | string;

            /**
             * Opacity of this view, from 0.0 (transparent) to 1.0 (opaque). Defaults to 1.0 (opaque).
             */
            opacity: number;

            /**
             * When on, animate call overrides current animation if applicable.
             */
            overrideCurrentAnimation: boolean;

            /**
             * The preview context used in the 3D-Touch feature "Peek and Pop".
             */
            previewContext: Titanium.UI.iOS.PreviewContext;

            /**
             * Background color of the wrapper view when this view is used as either <Titanium.UI.ListView.pullView> or <Titanium.UI.TableView.headerPullView>.
             * Defaults to `undefined`. Results in a light grey background color on the wrapper view.
             */
            pullBackgroundColor: string | Titanium.UI.Color;

            /**
             * The bounding box of the view relative to its parent, in system units.
             */
            readonly rect: DimensionWithAbsolutes;

            /**
             * View's right position, in platform-specific units.
             */
            right: number | string;

            /**
             * Clockwise 2D rotation of the view in degrees.
             */
            rotation: number;

            /**
             * Clockwise rotation of the view in degrees (x-axis).
             */
            rotationX: number;

            /**
             * Clockwise rotation of the view in degrees (y-axis).
             */
            rotationY: number;

            /**
             * Scaling of the view in x-axis in pixels.
             */
            scaleX: number;

            /**
             * Scaling of the view in y-axis in pixels.
             */
            scaleY: number;

            /**
             * The size of the view in system units.
             */
            readonly size: Dimension;

            /**
             * Determines keyboard behavior when this view is focused. Defaults to <Titanium.UI.Android.SOFT_KEYBOARD_DEFAULT_ON_FOCUS>.
             */
            softKeyboardOnFocus: number;

            /**
             * The view's tintColor
             */
            tintColor: string | Titanium.UI.Color;

            /**
             * The view's top position.
             */
            top: number | string;

            /**
             * Determines whether view should receive touch events.
             */
            touchEnabled: boolean;

            /**
             * A material design visual construct that provides an instantaneous visual confirmation of touch point.
             */
            touchFeedback: boolean;

            /**
             * Optional touch feedback ripple color. This has no effect unless `touchFeedback` is true.
             */
            touchFeedbackColor: string;

            /**
             * Transformation matrix to apply to the view.
             */
            transform: Titanium.UI.Matrix2D | Titanium.UI.Matrix3D;

            /**
             * A name to identify this view in activity transition.
             */
            transitionName: string;

            /**
             * Horizontal location of the view relative to its left position in pixels.
             */
            translationX: number;

            /**
             * Vertical location of the view relative to its top position in pixels.
             */
            translationY: number;

            /**
             * Depth of the view relative to its elevation in pixels.
             */
            translationZ: number;

            /**
             * Adds a vertical parallax effect to the view
             */
            verticalMotionEffect: MinMaxOptions;

            /**
             * Determines the color of the shadow.
             */
            viewShadowColor: string | Titanium.UI.Color;

            /**
             * Determines the offset for the shadow of the view.
             */
            viewShadowOffset: Point;

            /**
             * Determines the blur radius used to create the shadow.
             */
            viewShadowRadius: number;

            /**
             * Determines whether the view is visible.
             */
            visible: boolean;

            /**
             * View's width, in platform-specific units.
             */
            width: number | string;

            /**
             * Z-index stack order position, relative to other sibling views.
             */
            zIndex: number;

            /**
             * Adds a child to this view's hierarchy.
             */
            add(view: Titanium.UI.View | Titanium.UI.View[]): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof ViewEventMap>(name: K, callback: (this: Titanium.UI.View, event: ViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Animates this view.
             */
            animate(animation: Titanium.UI.Animation | Dictionary<Titanium.UI.Animation>, callback?: (param0: any) => void): void;

            /**
             * Removes all previously added motion effects.
             */
            clearMotionEffects(): void;

            /**
             * Translates a point from this view's coordinate system to another view's coordinate system.
             */
            convertPointToView(point: Point, destinationView: Titanium.UI.View): Point;

            /**
             * Finishes a batch update of the View's layout properties and schedules a layout pass of the
             * view tree.
             * @deprecated Use the [applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            finishLayout: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof ViewEventMap>(name: K, event?: ViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.View.accessibilityHidden> property.
             * @deprecated Access <Titanium.UI.View.accessibilityHidden> instead.
             */
            getAccessibilityHidden(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.accessibilityHint> property.
             * @deprecated Access <Titanium.UI.View.accessibilityHint> instead.
             */
            getAccessibilityHint(): string;

            /**
             * Gets the value of the <Titanium.UI.View.accessibilityLabel> property.
             * @deprecated Access <Titanium.UI.View.accessibilityLabel> instead.
             */
            getAccessibilityLabel(): string;

            /**
             * Gets the value of the <Titanium.UI.View.accessibilityValue> property.
             * @deprecated Access <Titanium.UI.View.accessibilityValue> instead.
             */
            getAccessibilityValue(): string;

            /**
             * Gets the value of the <Titanium.UI.View.anchorPoint> property.
             * @deprecated Access <Titanium.UI.View.anchorPoint> instead.
             */
            getAnchorPoint(): Point;

            /**
             * Gets the value of the <Titanium.UI.View.animatedCenter> property.
             * @deprecated Access <Titanium.UI.View.animatedCenter> instead.
             */
            getAnimatedCenter(): Point;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundColor> property.
             * @deprecated Access <Titanium.UI.View.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundDisabledColor> property.
             * @deprecated Access <Titanium.UI.View.backgroundDisabledColor> instead.
             */
            getBackgroundDisabledColor(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundDisabledImage> property.
             * @deprecated Access <Titanium.UI.View.backgroundDisabledImage> instead.
             */
            getBackgroundDisabledImage(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundFocusedColor> property.
             * @deprecated Access <Titanium.UI.View.backgroundFocusedColor> instead.
             */
            getBackgroundFocusedColor(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundFocusedImage> property.
             * @deprecated Access <Titanium.UI.View.backgroundFocusedImage> instead.
             */
            getBackgroundFocusedImage(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundGradient> property.
             * @deprecated Access <Titanium.UI.View.backgroundGradient> instead.
             */
            getBackgroundGradient(): Gradient;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundImage> property.
             * @deprecated Access <Titanium.UI.View.backgroundImage> instead.
             */
            getBackgroundImage(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundLeftCap> property.
             * @deprecated Access <Titanium.UI.View.backgroundLeftCap> instead.
             */
            getBackgroundLeftCap(): number;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundRepeat> property.
             * @deprecated Access <Titanium.UI.View.backgroundRepeat> instead.
             */
            getBackgroundRepeat(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundSelectedColor> property.
             * @deprecated Access <Titanium.UI.View.backgroundSelectedColor> instead.
             */
            getBackgroundSelectedColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundSelectedImage> property.
             * @deprecated Access <Titanium.UI.View.backgroundSelectedImage> instead.
             */
            getBackgroundSelectedImage(): string;

            /**
             * Gets the value of the <Titanium.UI.View.backgroundTopCap> property.
             * @deprecated Access <Titanium.UI.View.backgroundTopCap> instead.
             */
            getBackgroundTopCap(): number;

            /**
             * Gets the value of the <Titanium.UI.View.borderColor> property.
             * @deprecated Access <Titanium.UI.View.borderColor> instead.
             */
            getBorderColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.borderRadius> property.
             * @deprecated Access <Titanium.UI.View.borderRadius> instead.
             */
            getBorderRadius(): number | string | number[] | string[];

            /**
             * Gets the value of the <Titanium.UI.View.borderWidth> property.
             * @deprecated Access <Titanium.UI.View.borderWidth> instead.
             */
            getBorderWidth(): number;

            /**
             * Gets the value of the <Titanium.UI.View.bottom> property.
             * @deprecated Access <Titanium.UI.View.bottom> instead.
             */
            getBottom(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.center> property.
             * @deprecated Access <Titanium.UI.View.center> instead.
             */
            getCenter(): Point;

            /**
             * Gets the value of the <Titanium.UI.View.children> property.
             * @deprecated Access <Titanium.UI.View.children> instead.
             */
            getChildren(): Titanium.UI.View[];

            /**
             * Gets the value of the <Titanium.UI.View.clipMode> property.
             * @deprecated Access <Titanium.UI.View.clipMode> instead.
             */
            getClipMode(): number;

            /**
             * Gets the value of the <Titanium.UI.View.elevation> property.
             * @deprecated Access <Titanium.UI.View.elevation> instead.
             */
            getElevation(): number;

            /**
             * Gets the value of the <Titanium.UI.View.focusable> property.
             * @deprecated Access <Titanium.UI.View.focusable> instead.
             */
            getFocusable(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.height> property.
             * @deprecated Access <Titanium.UI.View.height> instead.
             */
            getHeight(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.hiddenBehavior> property.
             * @deprecated Access <Titanium.UI.View.hiddenBehavior> instead.
             */
            getHiddenBehavior(): number;

            /**
             * Gets the value of the <Titanium.UI.View.horizontalMotionEffect> property.
             * @deprecated Access <Titanium.UI.View.horizontalMotionEffect> instead.
             */
            getHorizontalMotionEffect(): MinMaxOptions;

            /**
             * Gets the value of the <Titanium.UI.View.horizontalWrap> property.
             * @deprecated Access <Titanium.UI.View.horizontalWrap> instead.
             */
            getHorizontalWrap(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.keepScreenOn> property.
             * @deprecated Access <Titanium.UI.View.keepScreenOn> instead.
             */
            getKeepScreenOn(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.layout> property.
             * @deprecated Access <Titanium.UI.View.layout> instead.
             */
            getLayout(): string;

            /**
             * Gets the value of the <Titanium.UI.View.left> property.
             * @deprecated Access <Titanium.UI.View.left> instead.
             */
            getLeft(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.opacity> property.
             * @deprecated Access <Titanium.UI.View.opacity> instead.
             */
            getOpacity(): number;

            /**
             * Gets the value of the <Titanium.UI.View.overrideCurrentAnimation> property.
             * @deprecated Access <Titanium.UI.View.overrideCurrentAnimation> instead.
             */
            getOverrideCurrentAnimation(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.previewContext> property.
             * @deprecated Access <Titanium.UI.View.previewContext> instead.
             */
            getPreviewContext(): Titanium.UI.iOS.PreviewContext;

            /**
             * Gets the value of the <Titanium.UI.View.pullBackgroundColor> property.
             * @deprecated Access <Titanium.UI.View.pullBackgroundColor> instead.
             */
            getPullBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.rect> property.
             * @deprecated Access <Titanium.UI.View.rect> instead.
             */
            getRect(): DimensionWithAbsolutes;

            /**
             * Gets the value of the <Titanium.UI.View.right> property.
             * @deprecated Access <Titanium.UI.View.right> instead.
             */
            getRight(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.rotation> property.
             * @deprecated Access <Titanium.UI.View.rotation> instead.
             */
            getRotation(): number;

            /**
             * Gets the value of the <Titanium.UI.View.rotationX> property.
             * @deprecated Access <Titanium.UI.View.rotationX> instead.
             */
            getRotationX(): number;

            /**
             * Gets the value of the <Titanium.UI.View.rotationY> property.
             * @deprecated Access <Titanium.UI.View.rotationY> instead.
             */
            getRotationY(): number;

            /**
             * Gets the value of the <Titanium.UI.View.scaleX> property.
             * @deprecated Access <Titanium.UI.View.scaleX> instead.
             */
            getScaleX(): number;

            /**
             * Gets the value of the <Titanium.UI.View.scaleY> property.
             * @deprecated Access <Titanium.UI.View.scaleY> instead.
             */
            getScaleY(): number;

            /**
             * Gets the value of the <Titanium.UI.View.size> property.
             * @deprecated Access <Titanium.UI.View.size> instead.
             */
            getSize(): Dimension;

            /**
             * Gets the value of the <Titanium.UI.View.softKeyboardOnFocus> property.
             * @deprecated Access <Titanium.UI.View.softKeyboardOnFocus> instead.
             */
            getSoftKeyboardOnFocus(): number;

            /**
             * Gets the value of the <Titanium.UI.View.tintColor> property.
             * @deprecated Access <Titanium.UI.View.tintColor> instead.
             */
            getTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.top> property.
             * @deprecated Access <Titanium.UI.View.top> instead.
             */
            getTop(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.touchEnabled> property.
             * @deprecated Access <Titanium.UI.View.touchEnabled> instead.
             */
            getTouchEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.touchFeedback> property.
             * @deprecated Access <Titanium.UI.View.touchFeedback> instead.
             */
            getTouchFeedback(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.touchFeedbackColor> property.
             * @deprecated Access <Titanium.UI.View.touchFeedbackColor> instead.
             */
            getTouchFeedbackColor(): string;

            /**
             * Gets the value of the <Titanium.UI.View.transform> property.
             * @deprecated Access <Titanium.UI.View.transform> instead.
             */
            getTransform(): Titanium.UI.Matrix2D | Titanium.UI.Matrix3D;

            /**
             * Gets the value of the <Titanium.UI.View.transitionName> property.
             * @deprecated Access <Titanium.UI.View.transitionName> instead.
             */
            getTransitionName(): string;

            /**
             * Gets the value of the <Titanium.UI.View.translationX> property.
             * @deprecated Access <Titanium.UI.View.translationX> instead.
             */
            getTranslationX(): number;

            /**
             * Gets the value of the <Titanium.UI.View.translationY> property.
             * @deprecated Access <Titanium.UI.View.translationY> instead.
             */
            getTranslationY(): number;

            /**
             * Gets the value of the <Titanium.UI.View.translationZ> property.
             * @deprecated Access <Titanium.UI.View.translationZ> instead.
             */
            getTranslationZ(): number;

            /**
             * Gets the value of the <Titanium.UI.View.verticalMotionEffect> property.
             * @deprecated Access <Titanium.UI.View.verticalMotionEffect> instead.
             */
            getVerticalMotionEffect(): MinMaxOptions;

            /**
             * Returns the matching view of a given view ID.
             */
            getViewById(id: string): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.View.viewShadowColor> property.
             * @deprecated Access <Titanium.UI.View.viewShadowColor> instead.
             */
            getViewShadowColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.View.viewShadowOffset> property.
             * @deprecated Access <Titanium.UI.View.viewShadowOffset> instead.
             */
            getViewShadowOffset(): Point;

            /**
             * Gets the value of the <Titanium.UI.View.viewShadowRadius> property.
             * @deprecated Access <Titanium.UI.View.viewShadowRadius> instead.
             */
            getViewShadowRadius(): number;

            /**
             * Gets the value of the <Titanium.UI.View.visible> property.
             * @deprecated Access <Titanium.UI.View.visible> instead.
             */
            getVisible(): boolean;

            /**
             * Gets the value of the <Titanium.UI.View.width> property.
             * @deprecated Access <Titanium.UI.View.width> instead.
             */
            getWidth(): number | string;

            /**
             * Gets the value of the <Titanium.UI.View.zIndex> property.
             * @deprecated Access <Titanium.UI.View.zIndex> instead.
             */
            getZIndex(): number;

            /**
             * Hides this view.
             */
            hide(options?: AnimatedOptions): void;

            /**
             * Inserts a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            insertAt(params: ViewPositionOptions): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove(view: Titanium.UI.View): void;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof ViewEventMap>(name: K, callback: (this: Titanium.UI.View, event: ViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt(params: ViewPositionOptions): void;

            /**
             * Sets the value of the <Titanium.UI.View.accessibilityHidden> property.
             * @deprecated Set the value using <Titanium.UI.View.accessibilityHidden> instead.
             */
            setAccessibilityHidden(accessibilityHidden: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.accessibilityHint> property.
             * @deprecated Set the value using <Titanium.UI.View.accessibilityHint> instead.
             */
            setAccessibilityHint(accessibilityHint: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.accessibilityLabel> property.
             * @deprecated Set the value using <Titanium.UI.View.accessibilityLabel> instead.
             */
            setAccessibilityLabel(accessibilityLabel: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.accessibilityValue> property.
             * @deprecated Set the value using <Titanium.UI.View.accessibilityValue> instead.
             */
            setAccessibilityValue(accessibilityValue: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.anchorPoint> property.
             * @deprecated Set the value using <Titanium.UI.View.anchorPoint> instead.
             */
            setAnchorPoint(anchorPoint: Point): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundDisabledColor> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundDisabledColor> instead.
             */
            setBackgroundDisabledColor(backgroundDisabledColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundDisabledImage> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundDisabledImage> instead.
             */
            setBackgroundDisabledImage(backgroundDisabledImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundFocusedColor> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundFocusedColor> instead.
             */
            setBackgroundFocusedColor(backgroundFocusedColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundFocusedImage> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundFocusedImage> instead.
             */
            setBackgroundFocusedImage(backgroundFocusedImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundGradient> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundGradient> instead.
             */
            setBackgroundGradient(backgroundGradient: Gradient): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundImage> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundImage> instead.
             */
            setBackgroundImage(backgroundImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundLeftCap> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundLeftCap> instead.
             */
            setBackgroundLeftCap(backgroundLeftCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundRepeat> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundRepeat> instead.
             */
            setBackgroundRepeat(backgroundRepeat: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundSelectedColor> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundSelectedColor> instead.
             */
            setBackgroundSelectedColor(backgroundSelectedColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundSelectedImage> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundSelectedImage> instead.
             */
            setBackgroundSelectedImage(backgroundSelectedImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.backgroundTopCap> property.
             * @deprecated Set the value using <Titanium.UI.View.backgroundTopCap> instead.
             */
            setBackgroundTopCap(backgroundTopCap: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.borderColor> property.
             * @deprecated Set the value using <Titanium.UI.View.borderColor> instead.
             */
            setBorderColor(borderColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.borderRadius> property.
             * @deprecated Set the value using <Titanium.UI.View.borderRadius> instead.
             */
            setBorderRadius(borderRadius: number | string | number[] | string[]): void;

            /**
             * Sets the value of the <Titanium.UI.View.borderWidth> property.
             * @deprecated Set the value using <Titanium.UI.View.borderWidth> instead.
             */
            setBorderWidth(borderWidth: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.bottom> property.
             * @deprecated Set the value using <Titanium.UI.View.bottom> instead.
             */
            setBottom(bottom: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.center> property.
             * @deprecated Set the value using <Titanium.UI.View.center> instead.
             */
            setCenter(center: Point): void;

            /**
             * Sets the value of the <Titanium.UI.View.clipMode> property.
             * @deprecated Set the value using <Titanium.UI.View.clipMode> instead.
             */
            setClipMode(clipMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.elevation> property.
             * @deprecated Set the value using <Titanium.UI.View.elevation> instead.
             */
            setElevation(elevation: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.focusable> property.
             * @deprecated Set the value using <Titanium.UI.View.focusable> instead.
             */
            setFocusable(focusable: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.height> property.
             * @deprecated Set the value using <Titanium.UI.View.height> instead.
             */
            setHeight(height: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.hiddenBehavior> property.
             * @deprecated Set the value using <Titanium.UI.View.hiddenBehavior> instead.
             */
            setHiddenBehavior(hiddenBehavior: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.horizontalMotionEffect> property.
             * @deprecated Set the value using <Titanium.UI.View.horizontalMotionEffect> instead.
             */
            setHorizontalMotionEffect(horizontalMotionEffect: MinMaxOptions): void;

            /**
             * Sets the value of the <Titanium.UI.View.horizontalWrap> property.
             * @deprecated Set the value using <Titanium.UI.View.horizontalWrap> instead.
             */
            setHorizontalWrap(horizontalWrap: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.keepScreenOn> property.
             * @deprecated Set the value using <Titanium.UI.View.keepScreenOn> instead.
             */
            setKeepScreenOn(keepScreenOn: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.layout> property.
             * @deprecated Set the value using <Titanium.UI.View.layout> instead.
             */
            setLayout(layout: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.left> property.
             * @deprecated Set the value using <Titanium.UI.View.left> instead.
             */
            setLeft(left: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.opacity> property.
             * @deprecated Set the value using <Titanium.UI.View.opacity> instead.
             */
            setOpacity(opacity: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.overrideCurrentAnimation> property.
             * @deprecated Set the value using <Titanium.UI.View.overrideCurrentAnimation> instead.
             */
            setOverrideCurrentAnimation(overrideCurrentAnimation: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.previewContext> property.
             * @deprecated Set the value using <Titanium.UI.View.previewContext> instead.
             */
            setPreviewContext(previewContext: Titanium.UI.iOS.PreviewContext): void;

            /**
             * Sets the value of the <Titanium.UI.View.pullBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.View.pullBackgroundColor> instead.
             */
            setPullBackgroundColor(pullBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.right> property.
             * @deprecated Set the value using <Titanium.UI.View.right> instead.
             */
            setRight(right: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.rotation> property.
             * @deprecated Set the value using <Titanium.UI.View.rotation> instead.
             */
            setRotation(rotation: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.rotationX> property.
             * @deprecated Set the value using <Titanium.UI.View.rotationX> instead.
             */
            setRotationX(rotationX: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.rotationY> property.
             * @deprecated Set the value using <Titanium.UI.View.rotationY> instead.
             */
            setRotationY(rotationY: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.scaleX> property.
             * @deprecated Set the value using <Titanium.UI.View.scaleX> instead.
             */
            setScaleX(scaleX: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.scaleY> property.
             * @deprecated Set the value using <Titanium.UI.View.scaleY> instead.
             */
            setScaleY(scaleY: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.softKeyboardOnFocus> property.
             * @deprecated Set the value using <Titanium.UI.View.softKeyboardOnFocus> instead.
             */
            setSoftKeyboardOnFocus(softKeyboardOnFocus: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.tintColor> property.
             * @deprecated Set the value using <Titanium.UI.View.tintColor> instead.
             */
            setTintColor(tintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.top> property.
             * @deprecated Set the value using <Titanium.UI.View.top> instead.
             */
            setTop(top: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.touchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.View.touchEnabled> instead.
             */
            setTouchEnabled(touchEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.touchFeedback> property.
             * @deprecated Set the value using <Titanium.UI.View.touchFeedback> instead.
             */
            setTouchFeedback(touchFeedback: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.touchFeedbackColor> property.
             * @deprecated Set the value using <Titanium.UI.View.touchFeedbackColor> instead.
             */
            setTouchFeedbackColor(touchFeedbackColor: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.transform> property.
             * @deprecated Set the value using <Titanium.UI.View.transform> instead.
             */
            setTransform(transform: Titanium.UI.Matrix2D | Titanium.UI.Matrix3D): void;

            /**
             * Sets the value of the <Titanium.UI.View.transitionName> property.
             * @deprecated Set the value using <Titanium.UI.View.transitionName> instead.
             */
            setTransitionName(transitionName: string): void;

            /**
             * Sets the value of the <Titanium.UI.View.translationX> property.
             * @deprecated Set the value using <Titanium.UI.View.translationX> instead.
             */
            setTranslationX(translationX: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.translationY> property.
             * @deprecated Set the value using <Titanium.UI.View.translationY> instead.
             */
            setTranslationY(translationY: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.translationZ> property.
             * @deprecated Set the value using <Titanium.UI.View.translationZ> instead.
             */
            setTranslationZ(translationZ: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.verticalMotionEffect> property.
             * @deprecated Set the value using <Titanium.UI.View.verticalMotionEffect> instead.
             */
            setVerticalMotionEffect(verticalMotionEffect: MinMaxOptions): void;

            /**
             * Sets the value of the <Titanium.UI.View.viewShadowColor> property.
             * @deprecated Set the value using <Titanium.UI.View.viewShadowColor> instead.
             */
            setViewShadowColor(viewShadowColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.View.viewShadowOffset> property.
             * @deprecated Set the value using <Titanium.UI.View.viewShadowOffset> instead.
             */
            setViewShadowOffset(viewShadowOffset: Point): void;

            /**
             * Sets the value of the <Titanium.UI.View.viewShadowRadius> property.
             * @deprecated Set the value using <Titanium.UI.View.viewShadowRadius> instead.
             */
            setViewShadowRadius(viewShadowRadius: number): void;

            /**
             * Sets the value of the <Titanium.UI.View.visible> property.
             * @deprecated Set the value using <Titanium.UI.View.visible> instead.
             */
            setVisible(visible: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.View.width> property.
             * @deprecated Set the value using <Titanium.UI.View.width> instead.
             */
            setWidth(width: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.View.zIndex> property.
             * @deprecated Set the value using <Titanium.UI.View.zIndex> instead.
             */
            setZIndex(zIndex: number): void;

            /**
             * Makes this view visible.
             */
            show(options?: AnimatedOptions): void;

            /**
             * Starts a batch update of this view's layout properties.
             * @deprecated Use the [Titanium.Proxy.applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            startLayout: never;

            /**
             * Returns an image of the rendered view, as a Blob.
             */
            toImage(callback?: (param0: Titanium.Blob) => void, honorScaleFactor?: boolean): Titanium.Blob;

            /**
             * Performs a batch update of all supplied layout properties and schedules a layout pass after
             * they have been updated.
             * @deprecated Use the [Titanium.Proxy.applyProperties](Titanium.Proxy.applyProperties) method to batch-update layout properties.
             */
            updateLayout: never;

        }
        /**
         * Base event for class Titanium.UI.WebView
         */
        interface WebViewBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.WebView;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface WebView_click_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface WebView_dblclick_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface WebView_doubletap_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the view element gains focus.
         */
        interface WebView_focus_Event extends WebViewBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface WebView_keypressed_Event extends WebViewBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface WebView_longclick_Event extends WebViewBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface WebView_longpress_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface WebView_pinch_Event extends WebViewBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface WebView_postlayout_Event extends WebViewBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface WebView_singletap_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface WebView_swipe_Event extends WebViewBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface WebView_touchcancel_Event extends WebViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface WebView_touchend_Event extends WebViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface WebView_touchmove_Event extends WebViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface WebView_touchstart_Event extends WebViewBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface WebView_twofingertap_Event extends WebViewBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired before the web view starts loading its content.
         */
        interface WebView_beforeload_Event extends WebViewBaseEvent {
            /**
             * Indicate if the event was generated from the main page or an iframe.
             */
            isMainFrame: boolean;

            /**
             * Constant indicating the user's action.
             */
            navigationType: number;

            /**
             * URL of the web document being loaded.
             */
            url: string;

        }
        /**
         * Fired when the web view cannot load the content.
         */
        interface WebView_error_Event extends WebViewBaseEvent {
            /**
             * Error code.
             * If the error was generated by the operating system, that system's error value
             * is used. Otherwise, this value will be -1.
             */
            code: number;

            /**
             * Error message, if any returned. May be undefined.
             */
            error: string;

            /**
             * A constant or underlying platform specific error code. Use code instead.
             * @deprecated Removed on ios in 8.0.0. Removed on android in 9.0.0.
             */
            errorCode: never;

            /**
             * Error message. Use error instead.
             * @deprecated Removed on ios in 8.0.0. Removed on android in 9.0.0.
             */
            message: never;

            /**
             * Indicates a successful operation. Returns `false`.
             */
            success: boolean;

            /**
             * URL of the web document.
             */
            url: string;

        }
        /**
         * Fired when the web view content is loaded.
         */
        interface WebView_load_Event extends WebViewBaseEvent {
            /**
             * URL of the web document.
             */
            url: string;

        }
        /**
         * Fired when loading resource.
         */
        interface WebView_onLoadResource_Event extends WebViewBaseEvent {
            /**
             * The url of the resource that will load.
             */
            url: string;

        }
        /**
         * Fired when an SSL error occurred.
         */
        interface WebView_sslerror_Event extends WebViewBaseEvent {
            /**
             * SSL error code.
             */
            code: number;

        }
        /**
         * Fired when a blacklisted URL is stopped.
         */
        interface WebView_blacklisturl_Event extends WebViewBaseEvent {
            /**
             * The URL of the web document that is stopped.
             */
            url: string;

        }
        /**
         * Fired when a URL has been blocked from loading.
         */
        interface WebView_blockedurl_Event extends WebViewBaseEvent {
            /**
             * The URL of the web document that has been blocked from loading.
             */
            url: string;

        }
        /**
         * Fired when a script message is received from a webpage.
         */
        interface WebView_message_Event extends WebViewBaseEvent {
            /**
             * The body of the message sent from webview.
             */
            body: string;

            /**
             * A Boolean value indicating whether the frame is the web site's main frame or a subframe.
             */
            isMainFrame: boolean;

            /**
             * The name of the message handler to which the message is sent.
             */
            name: string;

            /**
             * URL of the web document being loaded.
             */
            url: string;

        }
        /**
         * Fired when webpage download progresses.
         */
        interface WebView_progress_Event extends WebViewBaseEvent {
            /**
             * URL of the web document being loaded.
             */
            url: string;

            /**
             * An estimate of what fraction of the current navigation has been loaded.
             */
            value: number;

        }
        /**
         * Fired when a web view receives a server redirect.
         */
        interface WebView_redirect_Event extends WebViewBaseEvent {
            /**
             * Page title of webpage.
             */
            title: string;

            /**
             * URL of the web document being loaded.
             */
            url: string;

        }
        /**
         * Fired when <Titanium.UI.WebView.allowedURLSchemes> contains scheme of opening url.
         */
        interface WebView_handleurl_Event extends WebViewBaseEvent {
            /**
             * Handler <Titanium.UI.iOS.WebViewDecisionHandler>.
             */
            handler: string;

            /**
             * URL of the web document being loaded.
             */
            url: string;

        }
        interface WebViewEventMap extends ProxyEventMap {
            beforeload: WebView_beforeload_Event;

            blacklisturl: WebView_blacklisturl_Event;

            blockedurl: WebView_blockedurl_Event;

            click: WebView_click_Event;

            dblclick: WebView_dblclick_Event;

            doubletap: WebView_doubletap_Event;

            error: WebView_error_Event;

            focus: WebView_focus_Event;

            handleurl: WebView_handleurl_Event;

            keypressed: WebView_keypressed_Event;

            load: WebView_load_Event;

            longclick: WebView_longclick_Event;

            longpress: WebView_longpress_Event;

            message: WebView_message_Event;

            onLoadResource: WebView_onLoadResource_Event;

            pinch: WebView_pinch_Event;

            postlayout: WebView_postlayout_Event;

            progress: WebView_progress_Event;

            redirect: WebView_redirect_Event;

            singletap: WebView_singletap_Event;

            sslerror: WebView_sslerror_Event;

            swipe: WebView_swipe_Event;

            touchcancel: WebView_touchcancel_Event;

            touchend: WebView_touchend_Event;

            touchmove: WebView_touchmove_Event;

            touchstart: WebView_touchstart_Event;

            twofingertap: WebView_twofingertap_Event;

        }
        /**
         * The web view allows you to open an HTML5 based view which can load either local or remote content.
         */
        class WebView extends Titanium.UI.View {
            /**
             * List of allowed URL schemes for the web view.
             */
            allowedURLSchemes: string[];

            /**
             * A Boolean value indicating whether horizontal swipe gestures will trigger back-forward list navigations.
             */
            allowsBackForwardNavigationGestures: boolean;

            /**
             * A Boolean value that determines whether pressing on a link displays a preview of the
             * destination for the link.
             */
            allowsLinkPreview: boolean;

            /**
             * Path of file or directory to allow read access by the WebView.
             */
            assetsDirectory: string;

            /**
             * An array of url strings to blacklist.
             * @deprecated Use the <Titanium.UI.WebView.blockedURLs> property instead.
             */
            blacklistedURLs: string[];

            /**
             * An array of url strings to be blocked.
             */
            blockedURLs: string[];

            /**
             * Determines how a cache is used in this web view.
             */
            cacheMode: number;

            /**
             * The cache policy for the request.
             */
            cachePolicy: number;

            /**
             * Array of this view's child views.
             */
            readonly children: never;

            /**
             * The configuration for the new web view.
             */
            configuration: Titanium.UI.iOS.WebViewConfiguration;

            /**
             * Web content to load.
             */
            data: Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Determines whether the view will bounce when scrolling to the edge of the scrollable region.
             */
            disableBounce: boolean;

            /**
             * Determines whether or not the webview should not be able to display the context menu.
             */
            disableContextMenu: boolean;

            /**
             * Enable adding javascript interfaces internally to webview prior to JELLY_BEAN_MR1 (Android 4.2)
             */
            enableJavascriptInterface: boolean;

            /**
             * If `true`, zoom controls are enabled.
             */
            enableZoomControls: boolean;

            /**
             * Lets the webview handle platform supported urls
             * @deprecated This property in no more supported in Titanium SDK 8.0.0+. Use property <Titanium.UI.WebView.allowedURLSchemes>
             * in conjuction with <Titanium.UI.WebView.handleurl>. See the example section
             * "Usage of allowedURLSchemes and handleurl in iOS".
             *
             */
            handlePlatformUrl: boolean;

            /**
             * Hides activity indicator when loading remote URL.
             */
            hideLoadIndicator: boolean;

            /**
             * HTML content of this web view.
             */
            html: string;

            /**
             * Controls whether to ignore invalid SSL certificates or not.
             */
            ignoreSslError: boolean;

            /**
             * A Boolean value indicating whether web content can programmatically display the keyboard.
             */
            keyboardDisplayRequiresUserAction: boolean;

            /**
             * Enables using light touches to make a selection and activate mouseovers.
             */
            lightTouchEnabled: boolean;

            /**
             * Indicates if the webview is loading content.
             */
            loading: boolean;

            /**
             * If `true`, allows the loading of insecure resources from a secure origin.
             */
            mixedContentMode: boolean;

            /**
             * Callback function called when there is a request for the application to create a new window
             * to host new content.
             */
            onCreateWindow: (param0: any) => void;

            /**
             * Fired before navigating to a link.
             */
            onlink: (param0: OnLinkURLResponse) => void;

            /**
             * Determines the behavior when the user overscrolls the view.
             */
            overScrollMode: number;

            /**
             * Determines how to treat content that requires plugins in this web view.
             */
            pluginState: number;

            /**
             * An estimate of what fraction of the current navigation has been loaded.
             */
            readonly progress: number;

            /**
             * Sets extra request headers for this web view to use on subsequent URL requests.
             */
            requestHeaders: any;

            /**
             * If `true`, scale contents to fit the web view.
             */
            scalesPageToFit: boolean;

            /**
             * Controls whether the scroll-to-top gesture is effective.
             */
            scrollsToTop: boolean;

            /**
             * A Boolean value indicating whether all resources on the page have been loaded through
             * securely encrypted connections.
             */
            readonly secure: boolean;

            /**
             * The level of granularity with which the user can interactively select content in the web view.
             */
            readonly selectionGranularity: number;

            /**
             * The timeout interval for the request, in seconds.
             */
            timeout: number;

            /**
             * Returns page title of webpage.
             */
            readonly title: string;

            /**
             * URL to the web document.
             */
            url: string;

            /**
             * The User-Agent header used by the web view when requesting content.
             */
            userAgent: string;

            /**
             * Explicitly specifies if this web view handles touches.
             */
            willHandleTouches: boolean;

            /**
             * Manage the zoom-level of the current page.
             */
            zoomLevel: number;

            /**
             * Adds a child to this view's hierarchy.
             */
            add: never;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof WebViewEventMap>(name: K, callback: (this: Titanium.UI.WebView, event: WebViewEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a script message handler.
             */
            addScriptMessageHandler(handlerName: string): void;

            /**
             * Adds a user script.
             */
            addUserScript(params: UserScriptParams): void;

            /**
             * An object which maintains a list of visited pages used to go back and forward to the most recent page.
             */
            backForwardList(): BackForwardList;

            /**
             * Returns `true` if the web view can go back in its history list.
             */
            canGoBack(): boolean;

            /**
             * Returns `true` if the web view can go forward in its history list.
             */
            canGoForward(): boolean;

            /**
             * Create a PDF document representation from the web page currently displayed in the WebView.
             */
            createPDF(callback: (param0: DataCreationResult) => void): void;

            /**
             * Create WebKit web archive data representing the current web content of the WebView.
             */
            createWebArchive(callback: (param0: DataCreationResult) => void): void;

            /**
             * Evaluates a JavaScript expression inside the context of the web view and
             * optionally, returns a result. If a callback function is passed in as second argument,
             * the evaluation will take place asynchronously and the the callback function will be called with the result.
             */
            evalJS(code: string, callback?: (param0: string) => void): string;

            /**
             * Searches the page contents for the given string.
             */
            findString(searchString: string, options?: StringSearchOptions, callback?: (param0: SearchResult) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof WebViewEventMap>(name: K, event?: WebViewEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.WebView.allowedURLSchemes> property.
             * @deprecated Access <Titanium.UI.WebView.allowedURLSchemes> instead.
             */
            getAllowedURLSchemes(): string[];

            /**
             * Gets the value of the <Titanium.UI.WebView.allowsBackForwardNavigationGestures> property.
             * @deprecated Access <Titanium.UI.WebView.allowsBackForwardNavigationGestures> instead.
             */
            getAllowsBackForwardNavigationGestures(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.allowsLinkPreview> property.
             * @deprecated Access <Titanium.UI.WebView.allowsLinkPreview> instead.
             */
            getAllowsLinkPreview(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.assetsDirectory> property.
             * @deprecated Access <Titanium.UI.WebView.assetsDirectory> instead.
             */
            getAssetsDirectory(): string;

            /**
             * Gets the value of the <Titanium.UI.WebView.blacklistedURLs> property.
             * @deprecated Use the <Titanium.UI.WebView.blockedURLs> property instead.
             */
            getBlacklistedURLs(): string[];

            /**
             * Gets the value of the <Titanium.UI.WebView.blockedURLs> property.
             * @deprecated Access <Titanium.UI.WebView.blockedURLs> instead.
             */
            getBlockedURLs(): string[];

            /**
             * Gets the value of the <Titanium.UI.WebView.cacheMode> property.
             * @deprecated Access <Titanium.UI.WebView.cacheMode> instead.
             */
            getCacheMode(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.cachePolicy> property.
             * @deprecated Access <Titanium.UI.WebView.cachePolicy> instead.
             */
            getCachePolicy(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.children> property.
             * @deprecated Access <Titanium.UI.WebView.children> instead.
             */
            getChildren: never;

            /**
             * Gets the value of the <Titanium.UI.WebView.configuration> property.
             * @deprecated Access <Titanium.UI.WebView.configuration> instead.
             */
            getConfiguration(): Titanium.UI.iOS.WebViewConfiguration;

            /**
             * Gets the value of the <Titanium.UI.WebView.data> property.
             * @deprecated Access <Titanium.UI.WebView.data> instead.
             */
            getData(): Titanium.Blob | Titanium.Filesystem.File;

            /**
             * Gets the value of the <Titanium.UI.WebView.disableBounce> property.
             * @deprecated Access <Titanium.UI.WebView.disableBounce> instead.
             */
            getDisableBounce(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.disableContextMenu> property.
             * @deprecated Access <Titanium.UI.WebView.disableContextMenu> instead.
             */
            getDisableContextMenu(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.enableJavascriptInterface> property.
             * @deprecated Access <Titanium.UI.WebView.enableJavascriptInterface> instead.
             */
            getEnableJavascriptInterface(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.enableZoomControls> property.
             * @deprecated Access <Titanium.UI.WebView.enableZoomControls> instead.
             */
            getEnableZoomControls(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.handlePlatformUrl> property.
             * @deprecated This property in no more supported in Titanium SDK 8.0.0+. Use property <Titanium.UI.WebView.allowedURLSchemes>
             * in conjuction with <Titanium.UI.WebView.handleurl>. See the example section
             * "Usage of allowedURLSchemes and handleurl in iOS".
             *
             */
            getHandlePlatformUrl(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.hideLoadIndicator> property.
             * @deprecated Access <Titanium.UI.WebView.hideLoadIndicator> instead.
             */
            getHideLoadIndicator(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.html> property.
             * @deprecated Access <Titanium.UI.WebView.html> instead.
             */
            getHtml(): string;

            /**
             * Gets the value of the <Titanium.UI.WebView.ignoreSslError> property.
             * @deprecated Access <Titanium.UI.WebView.ignoreSslError> instead.
             */
            getIgnoreSslError(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.keyboardDisplayRequiresUserAction> property.
             * @deprecated Access <Titanium.UI.WebView.keyboardDisplayRequiresUserAction> instead.
             */
            getKeyboardDisplayRequiresUserAction(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.lightTouchEnabled> property.
             * @deprecated Access <Titanium.UI.WebView.lightTouchEnabled> instead.
             */
            getLightTouchEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.loading> property.
             * @deprecated Access <Titanium.UI.WebView.loading> instead.
             */
            getLoading(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.mixedContentMode> property.
             * @deprecated Access <Titanium.UI.WebView.mixedContentMode> instead.
             */
            getMixedContentMode(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.onCreateWindow> property.
             * @deprecated Access <Titanium.UI.WebView.onCreateWindow> instead.
             */
            getOnCreateWindow(): (param0: any) => void;

            /**
             * Gets the value of the <Titanium.UI.WebView.onlink> property.
             * @deprecated Access <Titanium.UI.WebView.onlink> instead.
             */
            getOnlink(): (param0: OnLinkURLResponse) => void;

            /**
             * Gets the value of the <Titanium.UI.WebView.overScrollMode> property.
             * @deprecated Access <Titanium.UI.WebView.overScrollMode> instead.
             */
            getOverScrollMode(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.pluginState> property.
             * @deprecated Access <Titanium.UI.WebView.pluginState> instead.
             */
            getPluginState(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.progress> property.
             * @deprecated Access <Titanium.UI.WebView.progress> instead.
             */
            getProgress(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.requestHeaders> property.
             * @deprecated Access <Titanium.UI.WebView.requestHeaders> instead.
             */
            getRequestHeaders(): any;

            /**
             * Gets the value of the <Titanium.UI.WebView.scalesPageToFit> property.
             * @deprecated Access <Titanium.UI.WebView.scalesPageToFit> instead.
             */
            getScalesPageToFit(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.scrollsToTop> property.
             * @deprecated Access <Titanium.UI.WebView.scrollsToTop> instead.
             */
            getScrollsToTop(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.secure> property.
             * @deprecated Access <Titanium.UI.WebView.secure> instead.
             */
            getSecure(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.selectionGranularity> property.
             * @deprecated Access <Titanium.UI.WebView.selectionGranularity> instead.
             */
            getSelectionGranularity(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.timeout> property.
             * @deprecated Access <Titanium.UI.WebView.timeout> instead.
             */
            getTimeout(): number;

            /**
             * Gets the value of the <Titanium.UI.WebView.title> property.
             * @deprecated Access <Titanium.UI.WebView.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.WebView.url> property.
             * @deprecated Access <Titanium.UI.WebView.url> instead.
             */
            getUrl(): string;

            /**
             * Gets the value of the <Titanium.UI.WebView.userAgent> property.
             * @deprecated Access <Titanium.UI.WebView.userAgent> instead.
             */
            getUserAgent(): string;

            /**
             * Gets the value of the <Titanium.UI.WebView.willHandleTouches> property.
             * @deprecated Access <Titanium.UI.WebView.willHandleTouches> instead.
             */
            getWillHandleTouches(): boolean;

            /**
             * Gets the value of the <Titanium.UI.WebView.zoomLevel> property.
             * @deprecated Access <Titanium.UI.WebView.zoomLevel> instead.
             */
            getZoomLevel(): number;

            /**
             * Goes back one entry in the web view's history list, to the previous page.
             */
            goBack(): void;

            /**
             * Goes forward one entry in this web view's history list, if possible.
             */
            goForward(): void;

            /**
             * Pauses native webview plugins.
             */
            pause(): void;

            /**
             * Releases memory when the web view is no longer needed.
             */
            release(): void;

            /**
             * Reloads the current webpage.
             */
            reload(): void;

            /**
             * Removes a child view from this view's hierarchy.
             */
            remove: never;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Removes all associated user scripts.
             */
            removeAllUserScripts(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof WebViewEventMap>(name: K, callback: (this: Titanium.UI.WebView, event: WebViewEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a script message handler.
             */
            removeScriptMessageHandler(name: string): void;

            /**
             * Forces the web view to repaint its contents.
             */
            repaint(): void;

            /**
             * Replaces a view at the specified position in the [children](Titanium.UI.View.children) array.
             */
            replaceAt: never;

            /**
             * Resume native webview plugins.
             */
            resume(): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.allowedURLSchemes> property.
             * @deprecated Set the value using <Titanium.UI.WebView.allowedURLSchemes> instead.
             */
            setAllowedURLSchemes(allowedURLSchemes: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.allowsBackForwardNavigationGestures> property.
             * @deprecated Set the value using <Titanium.UI.WebView.allowsBackForwardNavigationGestures> instead.
             */
            setAllowsBackForwardNavigationGestures(allowsBackForwardNavigationGestures: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.allowsLinkPreview> property.
             * @deprecated Set the value using <Titanium.UI.WebView.allowsLinkPreview> instead.
             */
            setAllowsLinkPreview(allowsLinkPreview: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.assetsDirectory> property.
             * @deprecated Set the value using <Titanium.UI.WebView.assetsDirectory> instead.
             */
            setAssetsDirectory(assetsDirectory: string): void;

            /**
             * Sets the basic authentication for this web view to use on subsequent URL requests.
             */
            setBasicAuthentication(username: string, password: string, persistence: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.blacklistedURLs> property.
             * @deprecated Use the <Titanium.UI.WebView.blockedURLs> property instead.
             */
            setBlacklistedURLs(blacklistedURLs: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.blockedURLs> property.
             * @deprecated Set the value using <Titanium.UI.WebView.blockedURLs> instead.
             */
            setBlockedURLs(blockedURLs: ReadonlyArray<string>): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.cacheMode> property.
             * @deprecated Set the value using <Titanium.UI.WebView.cacheMode> instead.
             */
            setCacheMode(cacheMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.cachePolicy> property.
             * @deprecated Set the value using <Titanium.UI.WebView.cachePolicy> instead.
             */
            setCachePolicy(cachePolicy: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.configuration> property.
             * @deprecated Set the value using <Titanium.UI.WebView.configuration> instead.
             */
            setConfiguration(configuration: Titanium.UI.iOS.WebViewConfiguration): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.data> property.
             * @deprecated Set the value using <Titanium.UI.WebView.data> instead.
             */
            setData(data: Titanium.Blob | Titanium.Filesystem.File): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.disableBounce> property.
             * @deprecated Set the value using <Titanium.UI.WebView.disableBounce> instead.
             */
            setDisableBounce(disableBounce: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.disableContextMenu> property.
             * @deprecated Set the value using <Titanium.UI.WebView.disableContextMenu> instead.
             */
            setDisableContextMenu(disableContextMenu: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.enableJavascriptInterface> property.
             * @deprecated Set the value using <Titanium.UI.WebView.enableJavascriptInterface> instead.
             */
            setEnableJavascriptInterface(enableJavascriptInterface: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.enableZoomControls> property.
             * @deprecated Set the value using <Titanium.UI.WebView.enableZoomControls> instead.
             */
            setEnableZoomControls(enableZoomControls: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.handlePlatformUrl> property.
             * @deprecated This property in no more supported in Titanium SDK 8.0.0+. Use property <Titanium.UI.WebView.allowedURLSchemes>
             * in conjuction with <Titanium.UI.WebView.handleurl>. See the example section
             * "Usage of allowedURLSchemes and handleurl in iOS".
             *
             */
            setHandlePlatformUrl(handlePlatformUrl: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.hideLoadIndicator> property.
             * @deprecated Set the value using <Titanium.UI.WebView.hideLoadIndicator> instead.
             */
            setHideLoadIndicator(hideLoadIndicator: boolean): void;

            /**
             * Sets the value of [html](Titanium.UI.WebView.html) property.
             */
            setHtml(html: any, options?: any): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.ignoreSslError> property.
             * @deprecated Set the value using <Titanium.UI.WebView.ignoreSslError> instead.
             */
            setIgnoreSslError(ignoreSslError: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.keyboardDisplayRequiresUserAction> property.
             * @deprecated Set the value using <Titanium.UI.WebView.keyboardDisplayRequiresUserAction> instead.
             */
            setKeyboardDisplayRequiresUserAction(keyboardDisplayRequiresUserAction: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.lightTouchEnabled> property.
             * @deprecated Set the value using <Titanium.UI.WebView.lightTouchEnabled> instead.
             */
            setLightTouchEnabled(lightTouchEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.loading> property.
             * @deprecated Set the value using <Titanium.UI.WebView.loading> instead.
             */
            setLoading(loading: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.mixedContentMode> property.
             * @deprecated Set the value using <Titanium.UI.WebView.mixedContentMode> instead.
             */
            setMixedContentMode(mixedContentMode: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.onCreateWindow> property.
             * @deprecated Set the value using <Titanium.UI.WebView.onCreateWindow> instead.
             */
            setOnCreateWindow(onCreateWindow: (param0: any) => void): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.onlink> property.
             * @deprecated Set the value using <Titanium.UI.WebView.onlink> instead.
             */
            setOnlink(onlink: (param0: OnLinkURLResponse) => void): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.overScrollMode> property.
             * @deprecated Set the value using <Titanium.UI.WebView.overScrollMode> instead.
             */
            setOverScrollMode(overScrollMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.pluginState> property.
             * @deprecated Set the value using <Titanium.UI.WebView.pluginState> instead.
             */
            setPluginState(pluginState: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.requestHeaders> property.
             * @deprecated Set the value using <Titanium.UI.WebView.requestHeaders> instead.
             */
            setRequestHeaders(requestHeaders: any): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.scalesPageToFit> property.
             * @deprecated Set the value using <Titanium.UI.WebView.scalesPageToFit> instead.
             */
            setScalesPageToFit(scalesPageToFit: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.scrollsToTop> property.
             * @deprecated Set the value using <Titanium.UI.WebView.scrollsToTop> instead.
             */
            setScrollsToTop(scrollsToTop: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.timeout> property.
             * @deprecated Set the value using <Titanium.UI.WebView.timeout> instead.
             */
            setTimeout(timeout: number): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.url> property.
             * @deprecated Set the value using <Titanium.UI.WebView.url> instead.
             */
            setUrl(url: string): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.userAgent> property.
             * @deprecated Set the value using <Titanium.UI.WebView.userAgent> instead.
             */
            setUserAgent(userAgent: string): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.willHandleTouches> property.
             * @deprecated Set the value using <Titanium.UI.WebView.willHandleTouches> instead.
             */
            setWillHandleTouches(willHandleTouches: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.WebView.zoomLevel> property.
             * @deprecated Set the value using <Titanium.UI.WebView.zoomLevel> instead.
             */
            setZoomLevel(zoomLevel: number): void;

            /**
             * Add native properties for observing for change.
             */
            startListeningToProperties(propertyList: ReadonlyArray<string>): void;

            /**
             * Remove native properties from observing.
             */
            stopListeningToProperties(propertyList: ReadonlyArray<string>): void;

            /**
             * Stops loading a currently loading page.
             */
            stopLoading(): void;

            /**
             * Takes a snapshot of the view's visible viewport.
             */
            takeSnapshot(callback: (param0: SnapshotResult) => void): void;

        }
        /**
         * Base event for class Titanium.UI.Window
         */
        interface WindowBaseEvent extends Ti.Event {
            /**
             * Source object that fired the event.
             */
            source: Titanium.UI.Window;

        }
        /**
         * Fired when the device detects a click against the view.
         */
        interface Window_click_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double click against the view.
         */
        interface Window_dblclick_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a double tap against the view.
         */
        interface Window_doubletap_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the window gains focus.
         */
        interface Window_focus_Event extends WindowBaseEvent {
        }
        /**
         * Fired when a hardware key is pressed in the view.
         */
        interface Window_keypressed_Event extends WindowBaseEvent {
            /**
             * The code for the physical key that was pressed. For more details, see [KeyEvent](https://developer.android.com/reference/android/view/KeyEvent.html). This API is experimental and subject to change.
             */
            keyCode: number;

        }
        /**
         * Fired when the device detects a long click.
         */
        interface Window_longclick_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the device detects a long press.
         */
        interface Window_longpress_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a pinch gesture.
         */
        interface Window_pinch_Event extends WindowBaseEvent {
            /**
             * The average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpan: number;

            /**
             * The average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanX: number;

            /**
             * The average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            currentSpanY: number;

            /**
             * The X coordinate of the current gesture's focal point.
             */
            focusX: number;

            /**
             * The Y coordinate of the current gesture's focal point.
             */
            focusY: number;

            /**
             * Returns `true` if a scale gesture is in progress, `false` otherwise.
             */
            inProgress: boolean;

            /**
             * The previous average distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpan: number;

            /**
             * The previous average X distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanX: number;

            /**
             * The previous average Y distance between each of the pointers forming the gesture in progress through
             * the focal point.
             */
            previousSpanY: number;

            /**
             * The scale factor relative to the points of the two touches in screen coordinates.
             */
            scale: number;

            /**
             * The event time of the current event being processed.
             */
            time: number;

            /**
             * The time difference in milliseconds between the previous accepted scaling event and the
             * current scaling event.
             */
            timeDelta: number;

            /**
             * The velocity of the pinch in scale factor per second.
             */
            velocity: number;

        }
        /**
         * Fired when a layout cycle is finished.
         */
        interface Window_postlayout_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the device detects a single tap against the view.
         */
        interface Window_singletap_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a swipe gesture against the view.
         */
        interface Window_swipe_Event extends WindowBaseEvent {
            /**
             * Direction of the swipe--either 'left', 'right', 'up', or 'down'.
             */
            direction: string;

            /**
             * X coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event's endpoint from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is interrupted by the device.
         */
        interface Window_touchcancel_Event extends WindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when a touch event is completed.
         */
        interface Window_touchend_Event extends WindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Penciland are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects movement of a touch.
         */
        interface Window_touchmove_Event extends WindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired as soon as the device detects a touch gesture.
         */
        interface Window_touchstart_Event extends WindowBaseEvent {
            /**
             * A value which indicates the stylus angle on the screen. If the stylus is perpendicular to the screen or no stylus is
             * being used, the value will be Pi/2. If the stylus is parallel to the screen, the value will be 0.
             * Note: This property is only available for iOS devices that support 3D-Touch and are 9.1 or later.
             */
            altitudeAngle: number;

            /**
             * The x value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewX: number;

            /**
             * The y value of the unit vector that points in the direction of the azimuth of the stylus.
             * Note: This property is only available for iOS devices that support the Apple Pencil and are 9.1 or later.
             */
            azimuthUnitVectorInViewY: number;

            /**
             * The current force value of the touch event.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later and on some Android devices.
             */
            force: number;

            /**
             * Maximum possible value of the force property.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            maximumPossibleForce: number;

            /**
             * The current size of the touch area. Note: This property is only available on some Android devices.
             */
            size: number;

            /**
             * The time (in seconds) when the touch was used in correlation with the system start up.
             * Note: This property is only available for iOS devices that support 3D-Touch and run 9.0 or later.
             */
            timestamp: number;

            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the device detects a two-finger tap against the view.
         */
        interface Window_twofingertap_Event extends WindowBaseEvent {
            /**
             * X coordinate of the event from the `source` view's coordinate system.
             */
            x: number;

            /**
             * Y coordinate of the event from the `source` view's coordinate system.
             */
            y: number;

        }
        /**
         * Fired when the back button is pressed by the user.
         */
        interface Window_androidback_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the Camera button is released.
         */
        interface Window_androidcamera_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the Camera button is half-pressed then released.
         */
        interface Window_androidfocus_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the Search button is released.
         */
        interface Window_androidsearch_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the volume down button is released.
         */
        interface Window_androidvoldown_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the volume up button is released.
         */
        interface Window_androidvolup_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the window loses focus.
         */
        interface Window_blur_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the window is closed.
         */
        interface Window_close_Event extends WindowBaseEvent {
        }
        /**
         * Fired when the window is opened.
         */
        interface Window_open_Event extends WindowBaseEvent {
        }
        interface WindowEventMap extends ProxyEventMap {
            androidback: Window_androidback_Event;

            androidcamera: Window_androidcamera_Event;

            androidfocus: Window_androidfocus_Event;

            androidsearch: Window_androidsearch_Event;

            androidvoldown: Window_androidvoldown_Event;

            androidvolup: Window_androidvolup_Event;

            blur: Window_blur_Event;

            click: Window_click_Event;

            close: Window_close_Event;

            dblclick: Window_dblclick_Event;

            doubletap: Window_doubletap_Event;

            focus: Window_focus_Event;

            keypressed: Window_keypressed_Event;

            longclick: Window_longclick_Event;

            longpress: Window_longpress_Event;

            open: Window_open_Event;

            pinch: Window_pinch_Event;

            postlayout: Window_postlayout_Event;

            singletap: Window_singletap_Event;

            swipe: Window_swipe_Event;

            touchcancel: Window_touchcancel_Event;

            touchend: Window_touchend_Event;

            touchmove: Window_touchmove_Event;

            touchstart: Window_touchstart_Event;

            twofingertap: Window_twofingertap_Event;

        }
        /**
         * The Window is an empty drawing surface or container.
         */
        class Window extends Titanium.UI.View {
            /**
             * Contains a reference to the Android Activity object associated with this window.
             */
            readonly activity: Titanium.Android.Activity;

            /**
             * The type of transition used when activity is entering.
             */
            activityEnterTransition: number;

            /**
             * The type of transition used when activity is exiting.
             */
            activityExitTransition: number;

            /**
             * The type of transition used when reentering to a previously started activity.
             */
            activityReenterTransition: number;

            /**
             * The type of transition used when returning from a previously started activity.
             */
            activityReturnTransition: number;

            /**
             * The type of enter transition used when animating shared elements between two activities.
             */
            activitySharedElementEnterTransition: number;

            /**
             * The type of exit transition used when animating shared elements between two activities.
             */
            activitySharedElementExitTransition: number;

            /**
             * The type of reenter transition used when animating shared elements between two activities.
             */
            activitySharedElementReenterTransition: number;

            /**
             * The type of return transition used when animating shared elements between two activities.
             */
            activitySharedElementReturnTransition: number;

            /**
             * Specifies whether or not the view controller should automatically adjust its scroll view insets.
             */
            autoAdjustScrollViewInsets: boolean;

            /**
             * Title for the back button. This is only valid when the window is a child of a tab.
             */
            backButtonTitle: string;

            /**
             * The image to show as the back button. This is only valid when the window is a child of a tab.
             */
            backButtonTitleImage: string | Titanium.Blob;

            /**
             * Background color of the window, as a color name or hex triplet.
             */
            backgroundColor: string | Titanium.UI.Color;

            /**
             * Background color for the nav bar, as a color name or hex triplet.
             */
            barColor: string | Titanium.UI.Color;

            /**
             * Background image for the nav bar, specified as a URL to a local image.
             */
            barImage: string;

            /**
             * Window's bottom position, in platform-specific units.
             */
            bottom: number | string;

            /**
             * Determines whether this Window is closed.
             */
            readonly closed: boolean;

            /**
             * Boolean value indicating if the application should exit when the Android
             * Back button is pressed while the window is being shown or when the window
             * is closed programmatically.
             */
            exitOnClose: boolean;

            /**
             * An array of supported values specified using the EXTEND_EDGE constants in <Titanium.UI>.
             */
            extendEdges: number[];

            /**
             * Specifies whether the screen insets/notches are allowed to overlap the window's content or not.
             */
            extendSafeArea: boolean;

            /**
             * Treat the content of the window as secure, preventing it from appearing in screenshots or from being viewed on non-secure displays.
             */
            flagSecure: boolean;

            /**
             * Determines whether this TextArea has focus.
             */
            readonly focused: boolean;

            /**
             * Boolean value indicating if the window is fullscreen.
             */
            fullscreen: boolean;

            /**
             * Set this to true to hide the shadow image of the navigation bar.
             */
            hideShadow: boolean;

            /**
             * Set this to true to hide the back button of navigation bar.
             */
            hidesBackButton: boolean;

            /**
             * Set this to true to hide the navigation bar on swipe.
             */
            hidesBarsOnSwipe: boolean;

            /**
             * Set this to true to hide the navigation bar on tap.
             */
            hidesBarsOnTap: boolean;

            /**
             * Set this to true to hide the navigation bar when the keyboard appears.
             */
            hidesBarsWhenKeyboardAppears: boolean;

            /**
             * A Boolean value indicating whether the integrated search bar is hidden when scrolling any underlying content.
             */
            hidesSearchBarWhenScrolling: boolean;

            /**
             * Boolean value indicating whether the system is allowed to hide the visual indicator for returning to the Home screen.
             */
            homeIndicatorAutoHidden: boolean;

            /**
             * Specifies if the edges should extend beyond opaque bars (navigation bar, tab bar, toolbar).
             */
            includeOpaqueBars: boolean;

            /**
             * The mode to use when displaying the title of the navigation bar.
             */
            largeTitleDisplayMode: number;

            /**
             * A Boolean value indicating whether the title should be displayed in a large format.
             */
            largeTitleEnabled: boolean;

            /**
             * Window's left position, in platform-specific units.
             */
            left: number | string;

            /**
             * View to show in the left nav bar area.
             */
            leftNavButton: Titanium.UI.View;

            /**
             * An Array of views to show in the left nav bar area.
             */
            leftNavButtons: Titanium.UI.View[];

            /**
             * Indicates to open a modal window or not.
             */
            modal: boolean;

            /**
             * Hides the navigation bar (`true`) or shows the navigation bar (`false`).
             */
            navBarHidden: boolean;

            /**
             * The tintColor to apply to the navigation bar.
             */
            navTintColor: string | Titanium.UI.Color;

            /**
             * The <Titanium.UI.NavigationWindow> instance hosting this window.
             */
            readonly navigationWindow: Titanium.UI.NavigationWindow;

            /**
             * Callback function that overrides the default behavior when the user presses the **Back**
             * button.
             */
            onBack: () => void;

            /**
             * The opacity from 0.0-1.0.
             */
            opacity: number;

            /**
             * Current orientation of the window.
             */
            readonly orientation: number;

            /**
             * Array of supported orientation modes, specified using the orientation
             * constants defined in <Titanium.UI>.
             */
            orientationModes: number[];

            /**
             * Window's right position, in platform-specific units.
             */
            right: number | string;

            /**
             * View to show in the right nav bar area.
             */
            rightNavButton: Titanium.UI.View;

            /**
             * An Array of views to show in the right nav bar area.
             */
            rightNavButtons: Titanium.UI.View[];

            /**
             * The padding needed to safely display content without it being overlapped by the screen insets and notches.
             */
            readonly safeAreaPadding: Padding;

            /**
             * Shadow image for the navigation bar, specified as a URL to a local image..
             */
            shadowImage: string;

            /**
             * Boolean value to enable split action bar.
             * @deprecated Deprecated in AppCompat theme. The same behaviour can be achived by using Toolbar.
             */
            splitActionBar: boolean;

            /**
             * The status bar style associated with this window.
             */
            statusBarStyle: number;

            /**
             * Maintain a sustainable level of performance.
             */
            sustainedPerformanceMode: boolean;

            /**
             * Boolean value indicating if the user should be able to close a window using a swipe gesture.
             */
            swipeToClose: boolean;

            /**
             * Boolean value indicating if the tab bar should be hidden.
             */
            tabBarHidden: boolean;

            /**
             * Name of the theme to apply to the window.
             */
            theme: string;

            /**
             * Title of the window.
             */
            title: string;

            /**
             * Title text attributes of the window.
             */
            titleAttributes: titleAttributesParams;

            /**
             * View to show in the title area of the nav bar.
             */
            titleControl: Titanium.UI.View;

            /**
             * Image to show in the title area of the nav bar, specified as a local file path or URL.
             */
            titleImage: string;

            /**
             * Title prompt for the window.
             */
            titlePrompt: string;

            /**
             * Key identifying a string from the locale file to use for the window title.
             */
            titleid: string;

            /**
             * Key identifying a string from the locale file to use for the window title prompt.
             */
            titlepromptid: string;

            /**
             * Array of button objects to show in the window's toolbar.
             */
            toolbar: Titanium.UI.View[];

            /**
             * Window's top position, in platform-specific units.
             */
            top: number | string;

            /**
             * Use a transition animation when opening or closing windows in a
             * <Titanium.UI.NavigationWindow> or <Titanium.UI.Tab>.
             */
            transitionAnimation: Titanium.Proxy;

            /**
             * Boolean value indicating if the nav bar is translucent.
             */
            translucent: boolean;

            /**
             * Loads a JavaScript file from a local URL.
             * @deprecated
             */
            url: never;

            /**
             * Additional flags to set on the Activity Window.
             */
            windowFlags: number;

            /**
             * Set the pixel format for the Activity's Window.
             */
            windowPixelFormat: number;

            /**
             * Determines whether a window's soft input area (ie software keyboard) is visible
             * as it receives focus and how the window behaves in order to accomodate it while keeping its
             * contents in view.
             */
            windowSoftInputMode: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener<K extends keyof WindowEventMap>(name: K, callback: (this: Titanium.UI.Window, event: WindowEventMap[K]) => void): void;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a common UI element to participate in window transition animation.
             */
            addSharedElement(view: Titanium.UI.View, transitionName: string): void;

            /**
             * Closes the window.
             */
            close(params?: Titanium.UI.Animation | Dictionary<Titanium.UI.Animation> | closeWindowParams): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent<K extends keyof WindowEventMap>(name: K, event?: WindowEventMap[K]): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.Window.activity> property.
             * @deprecated Access <Titanium.UI.Window.activity> instead.
             */
            getActivity(): Titanium.Android.Activity;

            /**
             * Gets the value of the <Titanium.UI.Window.activityEnterTransition> property.
             * @deprecated Access <Titanium.UI.Window.activityEnterTransition> instead.
             */
            getActivityEnterTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activityExitTransition> property.
             * @deprecated Access <Titanium.UI.Window.activityExitTransition> instead.
             */
            getActivityExitTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activityReenterTransition> property.
             * @deprecated Access <Titanium.UI.Window.activityReenterTransition> instead.
             */
            getActivityReenterTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activityReturnTransition> property.
             * @deprecated Access <Titanium.UI.Window.activityReturnTransition> instead.
             */
            getActivityReturnTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activitySharedElementEnterTransition> property.
             * @deprecated Access <Titanium.UI.Window.activitySharedElementEnterTransition> instead.
             */
            getActivitySharedElementEnterTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activitySharedElementExitTransition> property.
             * @deprecated Access <Titanium.UI.Window.activitySharedElementExitTransition> instead.
             */
            getActivitySharedElementExitTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activitySharedElementReenterTransition> property.
             * @deprecated Access <Titanium.UI.Window.activitySharedElementReenterTransition> instead.
             */
            getActivitySharedElementReenterTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.activitySharedElementReturnTransition> property.
             * @deprecated Access <Titanium.UI.Window.activitySharedElementReturnTransition> instead.
             */
            getActivitySharedElementReturnTransition(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.autoAdjustScrollViewInsets> property.
             * @deprecated Access <Titanium.UI.Window.autoAdjustScrollViewInsets> instead.
             */
            getAutoAdjustScrollViewInsets(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.backButtonTitle> property.
             * @deprecated Access <Titanium.UI.Window.backButtonTitle> instead.
             */
            getBackButtonTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.backButtonTitleImage> property.
             * @deprecated Access <Titanium.UI.Window.backButtonTitleImage> instead.
             */
            getBackButtonTitleImage(): string | Titanium.Blob;

            /**
             * Gets the value of the <Titanium.UI.Window.backgroundColor> property.
             * @deprecated Access <Titanium.UI.Window.backgroundColor> instead.
             */
            getBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Window.barColor> property.
             * @deprecated Access <Titanium.UI.Window.barColor> instead.
             */
            getBarColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Window.barImage> property.
             * @deprecated Access <Titanium.UI.Window.barImage> instead.
             */
            getBarImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.bottom> property.
             * @deprecated Access <Titanium.UI.Window.bottom> instead.
             */
            getBottom(): number | string;

            /**
             * Gets the value of the <Titanium.UI.Window.closed> property.
             * @deprecated Access <Titanium.UI.Window.closed> instead.
             */
            getClosed(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.exitOnClose> property.
             * @deprecated Access <Titanium.UI.Window.exitOnClose> instead.
             */
            getExitOnClose(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.extendEdges> property.
             * @deprecated Access <Titanium.UI.Window.extendEdges> instead.
             */
            getExtendEdges(): number[];

            /**
             * Gets the value of the <Titanium.UI.Window.extendSafeArea> property.
             * @deprecated Access <Titanium.UI.Window.extendSafeArea> instead.
             */
            getExtendSafeArea(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.flagSecure> property.
             * @deprecated Access <Titanium.UI.Window.flagSecure> instead.
             */
            getFlagSecure(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.focused> property.
             * @deprecated Access <Titanium.UI.Window.focused> instead.
             */
            getFocused(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.fullscreen> property.
             * @deprecated Access <Titanium.UI.Window.fullscreen> instead.
             */
            getFullscreen(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hideShadow> property.
             * @deprecated Access <Titanium.UI.Window.hideShadow> instead.
             */
            getHideShadow(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hidesBackButton> property.
             * @deprecated Access <Titanium.UI.Window.hidesBackButton> instead.
             */
            getHidesBackButton(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hidesBarsOnSwipe> property.
             * @deprecated Access <Titanium.UI.Window.hidesBarsOnSwipe> instead.
             */
            getHidesBarsOnSwipe(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hidesBarsOnTap> property.
             * @deprecated Access <Titanium.UI.Window.hidesBarsOnTap> instead.
             */
            getHidesBarsOnTap(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hidesBarsWhenKeyboardAppears> property.
             * @deprecated Access <Titanium.UI.Window.hidesBarsWhenKeyboardAppears> instead.
             */
            getHidesBarsWhenKeyboardAppears(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.hidesSearchBarWhenScrolling> property.
             * @deprecated Access <Titanium.UI.Window.hidesSearchBarWhenScrolling> instead.
             */
            getHidesSearchBarWhenScrolling(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.homeIndicatorAutoHidden> property.
             * @deprecated Access <Titanium.UI.Window.homeIndicatorAutoHidden> instead.
             */
            getHomeIndicatorAutoHidden(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.includeOpaqueBars> property.
             * @deprecated Access <Titanium.UI.Window.includeOpaqueBars> instead.
             */
            getIncludeOpaqueBars(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.largeTitleDisplayMode> property.
             * @deprecated Access <Titanium.UI.Window.largeTitleDisplayMode> instead.
             */
            getLargeTitleDisplayMode(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.largeTitleEnabled> property.
             * @deprecated Access <Titanium.UI.Window.largeTitleEnabled> instead.
             */
            getLargeTitleEnabled(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.left> property.
             * @deprecated Access <Titanium.UI.Window.left> instead.
             */
            getLeft(): number | string;

            /**
             * Gets the value of the <Titanium.UI.Window.leftNavButton> property.
             * @deprecated Access <Titanium.UI.Window.leftNavButton> instead.
             */
            getLeftNavButton(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.Window.leftNavButtons> property.
             * @deprecated Access <Titanium.UI.Window.leftNavButtons> instead.
             */
            getLeftNavButtons(): Titanium.UI.View[];

            /**
             * Gets the value of the <Titanium.UI.Window.modal> property.
             * @deprecated Access <Titanium.UI.Window.modal> instead.
             */
            getModal(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.navBarHidden> property.
             * @deprecated Access <Titanium.UI.Window.navBarHidden> instead.
             */
            getNavBarHidden(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.navTintColor> property.
             * @deprecated Access <Titanium.UI.Window.navTintColor> instead.
             */
            getNavTintColor(): string | Titanium.UI.Color;

            /**
             * Gets the value of the <Titanium.UI.Window.navigationWindow> property.
             * @deprecated Access <Titanium.UI.Window.navigationWindow> instead.
             */
            getNavigationWindow(): Titanium.UI.NavigationWindow;

            /**
             * Gets the value of the <Titanium.UI.Window.onBack> property.
             * @deprecated Access <Titanium.UI.Window.onBack> instead.
             */
            getOnBack(): () => void;

            /**
             * Gets the value of the <Titanium.UI.Window.opacity> property.
             * @deprecated Access <Titanium.UI.Window.opacity> instead.
             */
            getOpacity(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.orientation> property.
             * @deprecated Access <Titanium.UI.Window.orientation> instead.
             */
            getOrientation(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.orientationModes> property.
             * @deprecated Access <Titanium.UI.Window.orientationModes> instead.
             */
            getOrientationModes(): number[];

            /**
             * Gets the value of the <Titanium.UI.Window.right> property.
             * @deprecated Access <Titanium.UI.Window.right> instead.
             */
            getRight(): number | string;

            /**
             * Gets the value of the <Titanium.UI.Window.rightNavButton> property.
             * @deprecated Access <Titanium.UI.Window.rightNavButton> instead.
             */
            getRightNavButton(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.Window.rightNavButtons> property.
             * @deprecated Access <Titanium.UI.Window.rightNavButtons> instead.
             */
            getRightNavButtons(): Titanium.UI.View[];

            /**
             * Gets the value of the <Titanium.UI.Window.safeAreaPadding> property.
             * @deprecated Access <Titanium.UI.Window.safeAreaPadding> instead.
             */
            getSafeAreaPadding(): Padding;

            /**
             * Gets the value of the <Titanium.UI.Window.shadowImage> property.
             * @deprecated Access <Titanium.UI.Window.shadowImage> instead.
             */
            getShadowImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.splitActionBar> property.
             * @deprecated Deprecated in AppCompat theme. The same behaviour can be achived by using Toolbar.
             */
            getSplitActionBar(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.statusBarStyle> property.
             * @deprecated Access <Titanium.UI.Window.statusBarStyle> instead.
             */
            getStatusBarStyle(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.sustainedPerformanceMode> property.
             * @deprecated Access <Titanium.UI.Window.sustainedPerformanceMode> instead.
             */
            getSustainedPerformanceMode(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.swipeToClose> property.
             * @deprecated Access <Titanium.UI.Window.swipeToClose> instead.
             */
            getSwipeToClose(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.tabBarHidden> property.
             * @deprecated Access <Titanium.UI.Window.tabBarHidden> instead.
             */
            getTabBarHidden(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.theme> property.
             * @deprecated Access <Titanium.UI.Window.theme> instead.
             */
            getTheme(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.title> property.
             * @deprecated Access <Titanium.UI.Window.title> instead.
             */
            getTitle(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.titleAttributes> property.
             * @deprecated Access <Titanium.UI.Window.titleAttributes> instead.
             */
            getTitleAttributes(): titleAttributesParams;

            /**
             * Gets the value of the <Titanium.UI.Window.titleControl> property.
             * @deprecated Access <Titanium.UI.Window.titleControl> instead.
             */
            getTitleControl(): Titanium.UI.View;

            /**
             * Gets the value of the <Titanium.UI.Window.titleImage> property.
             * @deprecated Access <Titanium.UI.Window.titleImage> instead.
             */
            getTitleImage(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.titlePrompt> property.
             * @deprecated Access <Titanium.UI.Window.titlePrompt> instead.
             */
            getTitlePrompt(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.titleid> property.
             * @deprecated Access <Titanium.UI.Window.titleid> instead.
             */
            getTitleid(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.titlepromptid> property.
             * @deprecated Access <Titanium.UI.Window.titlepromptid> instead.
             */
            getTitlepromptid(): string;

            /**
             * Gets the value of the <Titanium.UI.Window.toolbar> property.
             * @deprecated Access <Titanium.UI.Window.toolbar> instead.
             */
            getToolbar(): Titanium.UI.View[];

            /**
             * Gets the value of the <Titanium.UI.Window.top> property.
             * @deprecated Access <Titanium.UI.Window.top> instead.
             */
            getTop(): number | string;

            /**
             * Gets the value of the <Titanium.UI.Window.transitionAnimation> property.
             * @deprecated Access <Titanium.UI.Window.transitionAnimation> instead.
             */
            getTransitionAnimation(): Titanium.Proxy;

            /**
             * Gets the value of the <Titanium.UI.Window.translucent> property.
             * @deprecated Access <Titanium.UI.Window.translucent> instead.
             */
            getTranslucent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.Window.url> property.
             * @deprecated
             */
            getUrl: never;

            /**
             * Gets the value of the <Titanium.UI.Window.windowFlags> property.
             * @deprecated Access <Titanium.UI.Window.windowFlags> instead.
             */
            getWindowFlags(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.windowPixelFormat> property.
             * @deprecated Access <Titanium.UI.Window.windowPixelFormat> instead.
             */
            getWindowPixelFormat(): number;

            /**
             * Gets the value of the <Titanium.UI.Window.windowSoftInputMode> property.
             * @deprecated Access <Titanium.UI.Window.windowSoftInputMode> instead.
             */
            getWindowSoftInputMode(): number;

            /**
             * Hides the navigation bar.
             */
            hideNavBar(options?: AnimatedOptions): void;

            /**
             * Hides the tab bar. Must be called before opening the window.
             */
            hideTabBar(): void;

            /**
             * Makes the bottom toolbar invisible.
             */
            hideToolbar(options?: AnimatedOptions): void;

            /**
             * Opens the window.
             */
            open(params?: openWindowParams): void;

            /**
             * Removes all child views from this view's hierarchy.
             */
            removeAllChildren: never;

            /**
             * Clears all added shared elements.
             */
            removeAllSharedElements(): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener<K extends keyof WindowEventMap>(name: K, callback: (this: Titanium.UI.Window, event: WindowEventMap[K]) => void): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activityEnterTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activityEnterTransition> instead.
             */
            setActivityEnterTransition(activityEnterTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activityExitTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activityExitTransition> instead.
             */
            setActivityExitTransition(activityExitTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activityReenterTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activityReenterTransition> instead.
             */
            setActivityReenterTransition(activityReenterTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activityReturnTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activityReturnTransition> instead.
             */
            setActivityReturnTransition(activityReturnTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activitySharedElementEnterTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activitySharedElementEnterTransition> instead.
             */
            setActivitySharedElementEnterTransition(activitySharedElementEnterTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activitySharedElementExitTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activitySharedElementExitTransition> instead.
             */
            setActivitySharedElementExitTransition(activitySharedElementExitTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activitySharedElementReenterTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activitySharedElementReenterTransition> instead.
             */
            setActivitySharedElementReenterTransition(activitySharedElementReenterTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.activitySharedElementReturnTransition> property.
             * @deprecated Set the value using <Titanium.UI.Window.activitySharedElementReturnTransition> instead.
             */
            setActivitySharedElementReturnTransition(activitySharedElementReturnTransition: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.autoAdjustScrollViewInsets> property.
             * @deprecated Set the value using <Titanium.UI.Window.autoAdjustScrollViewInsets> instead.
             */
            setAutoAdjustScrollViewInsets(autoAdjustScrollViewInsets: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.backButtonTitle> property.
             * @deprecated Set the value using <Titanium.UI.Window.backButtonTitle> instead.
             */
            setBackButtonTitle(backButtonTitle: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.backButtonTitleImage> property.
             * @deprecated Set the value using <Titanium.UI.Window.backButtonTitleImage> instead.
             */
            setBackButtonTitleImage(backButtonTitleImage: string | Titanium.Blob): void;

            /**
             * Sets the value of the <Titanium.UI.Window.backgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.Window.backgroundColor> instead.
             */
            setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Window.barColor> property.
             * @deprecated Set the value using <Titanium.UI.Window.barColor> instead.
             */
            setBarColor(barColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Window.barImage> property.
             * @deprecated Set the value using <Titanium.UI.Window.barImage> instead.
             */
            setBarImage(barImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.bottom> property.
             * @deprecated Set the value using <Titanium.UI.Window.bottom> instead.
             */
            setBottom(bottom: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.exitOnClose> property.
             * @deprecated Set the value using <Titanium.UI.Window.exitOnClose> instead.
             */
            setExitOnClose(exitOnClose: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.extendEdges> property.
             * @deprecated Set the value using <Titanium.UI.Window.extendEdges> instead.
             */
            setExtendEdges(extendEdges: ReadonlyArray<number>): void;

            /**
             * Sets the value of the <Titanium.UI.Window.extendSafeArea> property.
             * @deprecated Set the value using <Titanium.UI.Window.extendSafeArea> instead.
             */
            setExtendSafeArea(extendSafeArea: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.flagSecure> property.
             * @deprecated Set the value using <Titanium.UI.Window.flagSecure> instead.
             */
            setFlagSecure(flagSecure: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.fullscreen> property.
             * @deprecated Set the value using <Titanium.UI.Window.fullscreen> instead.
             */
            setFullscreen(fullscreen: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hideShadow> property.
             * @deprecated Set the value using <Titanium.UI.Window.hideShadow> instead.
             */
            setHideShadow(hideShadow: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hidesBackButton> property.
             * @deprecated Set the value using <Titanium.UI.Window.hidesBackButton> instead.
             */
            setHidesBackButton(hidesBackButton: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hidesBarsOnSwipe> property.
             * @deprecated Set the value using <Titanium.UI.Window.hidesBarsOnSwipe> instead.
             */
            setHidesBarsOnSwipe(hidesBarsOnSwipe: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hidesBarsOnTap> property.
             * @deprecated Set the value using <Titanium.UI.Window.hidesBarsOnTap> instead.
             */
            setHidesBarsOnTap(hidesBarsOnTap: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hidesBarsWhenKeyboardAppears> property.
             * @deprecated Set the value using <Titanium.UI.Window.hidesBarsWhenKeyboardAppears> instead.
             */
            setHidesBarsWhenKeyboardAppears(hidesBarsWhenKeyboardAppears: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.hidesSearchBarWhenScrolling> property.
             * @deprecated Set the value using <Titanium.UI.Window.hidesSearchBarWhenScrolling> instead.
             */
            setHidesSearchBarWhenScrolling(hidesSearchBarWhenScrolling: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.homeIndicatorAutoHidden> property.
             * @deprecated Set the value using <Titanium.UI.Window.homeIndicatorAutoHidden> instead.
             */
            setHomeIndicatorAutoHidden(homeIndicatorAutoHidden: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.includeOpaqueBars> property.
             * @deprecated Set the value using <Titanium.UI.Window.includeOpaqueBars> instead.
             */
            setIncludeOpaqueBars(includeOpaqueBars: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.largeTitleDisplayMode> property.
             * @deprecated Set the value using <Titanium.UI.Window.largeTitleDisplayMode> instead.
             */
            setLargeTitleDisplayMode(largeTitleDisplayMode: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.largeTitleEnabled> property.
             * @deprecated Set the value using <Titanium.UI.Window.largeTitleEnabled> instead.
             */
            setLargeTitleEnabled(largeTitleEnabled: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.left> property.
             * @deprecated Set the value using <Titanium.UI.Window.left> instead.
             */
            setLeft(left: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.leftNavButton> property.
             * @deprecated Set the value using <Titanium.UI.Window.leftNavButton> instead.
             */
            setLeftNavButton(leftNavButton: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.Window.leftNavButtons> property.
             * @deprecated Set the value using <Titanium.UI.Window.leftNavButtons> instead.
             */
            setLeftNavButtons(leftNavButtons: ReadonlyArray<Titanium.UI.View>): void;

            /**
             * Sets the value of the <Titanium.UI.Window.modal> property.
             * @deprecated Set the value using <Titanium.UI.Window.modal> instead.
             */
            setModal(modal: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.navBarHidden> property.
             * @deprecated Set the value using <Titanium.UI.Window.navBarHidden> instead.
             */
            setNavBarHidden(navBarHidden: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.navTintColor> property.
             * @deprecated Set the value using <Titanium.UI.Window.navTintColor> instead.
             */
            setNavTintColor(navTintColor: string | Titanium.UI.Color): void;

            /**
             * Sets the value of the <Titanium.UI.Window.onBack> property.
             * @deprecated Set the value using <Titanium.UI.Window.onBack> instead.
             */
            setOnBack(onBack: () => void): void;

            /**
             * Sets the value of the <Titanium.UI.Window.opacity> property.
             * @deprecated Set the value using <Titanium.UI.Window.opacity> instead.
             */
            setOpacity(opacity: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.orientationModes> property.
             * @deprecated Set the value using <Titanium.UI.Window.orientationModes> instead.
             */
            setOrientationModes(orientationModes: ReadonlyArray<number>): void;

            /**
             * Sets the value of the <Titanium.UI.Window.right> property.
             * @deprecated Set the value using <Titanium.UI.Window.right> instead.
             */
            setRight(right: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.rightNavButton> property.
             * @deprecated Set the value using <Titanium.UI.Window.rightNavButton> instead.
             */
            setRightNavButton(rightNavButton: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.Window.rightNavButtons> property.
             * @deprecated Set the value using <Titanium.UI.Window.rightNavButtons> instead.
             */
            setRightNavButtons(rightNavButtons: ReadonlyArray<Titanium.UI.View>): void;

            /**
             * Sets the value of the <Titanium.UI.Window.shadowImage> property.
             * @deprecated Set the value using <Titanium.UI.Window.shadowImage> instead.
             */
            setShadowImage(shadowImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.splitActionBar> property.
             * @deprecated Deprecated in AppCompat theme. The same behaviour can be achived by using Toolbar.
             */
            setSplitActionBar(splitActionBar: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.statusBarStyle> property.
             * @deprecated Set the value using <Titanium.UI.Window.statusBarStyle> instead.
             */
            setStatusBarStyle(statusBarStyle: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.sustainedPerformanceMode> property.
             * @deprecated Set the value using <Titanium.UI.Window.sustainedPerformanceMode> instead.
             */
            setSustainedPerformanceMode(sustainedPerformanceMode: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.swipeToClose> property.
             * @deprecated Set the value using <Titanium.UI.Window.swipeToClose> instead.
             */
            setSwipeToClose(swipeToClose: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.tabBarHidden> property.
             * @deprecated Set the value using <Titanium.UI.Window.tabBarHidden> instead.
             */
            setTabBarHidden(tabBarHidden: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.theme> property.
             * @deprecated Set the value using <Titanium.UI.Window.theme> instead.
             */
            setTheme(theme: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.title> property.
             * @deprecated Set the value using <Titanium.UI.Window.title> instead.
             */
            setTitle(title: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titleAttributes> property.
             * @deprecated Set the value using <Titanium.UI.Window.titleAttributes> instead.
             */
            setTitleAttributes(titleAttributes: titleAttributesParams): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titleControl> property.
             * @deprecated Set the value using <Titanium.UI.Window.titleControl> instead.
             */
            setTitleControl(titleControl: Titanium.UI.View): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titleImage> property.
             * @deprecated Set the value using <Titanium.UI.Window.titleImage> instead.
             */
            setTitleImage(titleImage: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titlePrompt> property.
             * @deprecated Set the value using <Titanium.UI.Window.titlePrompt> instead.
             */
            setTitlePrompt(titlePrompt: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titleid> property.
             * @deprecated Set the value using <Titanium.UI.Window.titleid> instead.
             */
            setTitleid(titleid: string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.titlepromptid> property.
             * @deprecated Set the value using <Titanium.UI.Window.titlepromptid> instead.
             */
            setTitlepromptid(titlepromptid: string): void;

            /**
             * Sets the array of items to show in the window's toolbar.
             */
            setToolbar(items: ReadonlyArray<any>, params?: windowToolbarParam): void;

            /**
             * Sets the value of the <Titanium.UI.Window.top> property.
             * @deprecated Set the value using <Titanium.UI.Window.top> instead.
             */
            setTop(top: number | string): void;

            /**
             * Sets the value of the <Titanium.UI.Window.transitionAnimation> property.
             * @deprecated Set the value using <Titanium.UI.Window.transitionAnimation> instead.
             */
            setTransitionAnimation(transitionAnimation: Titanium.Proxy): void;

            /**
             * Sets the value of the <Titanium.UI.Window.translucent> property.
             * @deprecated Set the value using <Titanium.UI.Window.translucent> instead.
             */
            setTranslucent(translucent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.Window.url> property.
             * @deprecated
             */
            setUrl: never;

            /**
             * Sets the value of the <Titanium.UI.Window.windowFlags> property.
             * @deprecated Set the value using <Titanium.UI.Window.windowFlags> instead.
             */
            setWindowFlags(windowFlags: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.windowPixelFormat> property.
             * @deprecated Set the value using <Titanium.UI.Window.windowPixelFormat> instead.
             */
            setWindowPixelFormat(windowPixelFormat: number): void;

            /**
             * Sets the value of the <Titanium.UI.Window.windowSoftInputMode> property.
             * @deprecated Set the value using <Titanium.UI.Window.windowSoftInputMode> instead.
             */
            setWindowSoftInputMode(windowSoftInputMode: number): void;

            /**
             * Makes the navigation bar visible.
             */
            showNavBar(options?: AnimatedOptions): void;

            /**
             * Makes the bottom toolbar visible.
             */
            showToolbar(options?: AnimatedOptions): void;

        }
        /**
         * Apple iOS specific UI capabilities.  All properties, methods and events in this namespace will
         * only work on Apple iOS devices.
         */
        class iOS extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Value of the badge for the application's springboard icon.
             */
            static appBadge: number;

            /**
             * Determines whether the shake to edit system-wide capability is enabled.
             */
            static appSupportsShakeToEdit: boolean;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * Determines if the 3D-Touch capability "Force Touch" is supported (`true`) or not (`false`) by the device.
             */
            static readonly forceTouchSupported: boolean;

            /**
             * Sets the global status bar background color for the application. Android does not support setting instances of <Titanium.UI.Color>
             */
            static statusBarBackgroundColor: string | Titanium.UI.Color;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.AdView>.
             * @deprecated iAd has been deprecated in iOS 10 and SDK 5.5.0. It was removed as part of the SDK 7.0.0.
             */
            static createAdView: never;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.AnchorAttachmentBehavior>.
             */
            static createAnchorAttachmentBehavior(parameters?: Dictionary<Titanium.UI.iOS.AnchorAttachmentBehavior>): Titanium.UI.iOS.AnchorAttachmentBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.Animator>.
             */
            static createAnimator(parameters?: Dictionary<Titanium.UI.iOS.Animator>): Titanium.UI.iOS.Animator;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.ApplicationShortcuts>.
             * @deprecated Use [Titanium.UI.Shortcut](Titanium.UI.Shortcut) instead.
             */
            static createApplicationShortcuts(parameters?: Dictionary<Titanium.UI.iOS.ApplicationShortcuts>): Titanium.UI.iOS.ApplicationShortcuts;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.Attribute>.
             * @deprecated Use [Attribute](Attribute) instead.
             */
            static createAttribute: never;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.AttributedString>.
             * @deprecated Use [Titanium.UI.AttributedString](Titanium.UI.AttributedString) instead.
             */
            static createAttributedString: never;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.BlurView>.
             */
            static createBlurView(parameters?: Dictionary<Titanium.UI.iOS.BlurView>): Titanium.UI.iOS.BlurView;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.CollisionBehavior>.
             */
            static createCollisionBehavior(parameters?: Dictionary<Titanium.UI.iOS.CollisionBehavior>): Titanium.UI.iOS.CollisionBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.CoverFlowView>.
             */
            static createCoverFlowView(parameters?: Dictionary<Titanium.UI.iOS.CoverFlowView>): Titanium.UI.iOS.CoverFlowView;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.DocumentViewer>.
             */
            static createDocumentViewer(parameters?: Dictionary<Titanium.UI.iOS.DocumentViewer>): Titanium.UI.iOS.DocumentViewer;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.DynamicItemBehavior>.
             */
            static createDynamicItemBehavior(parameters?: Dictionary<Titanium.UI.iOS.DynamicItemBehavior>): Titanium.UI.iOS.DynamicItemBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.FeedbackGenerator>.
             */
            static createFeedbackGenerator(parameters?: Dictionary<Titanium.UI.iOS.FeedbackGenerator>): Titanium.UI.iOS.FeedbackGenerator;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.GravityBehavior>.
             */
            static createGravityBehavior(parameters?: Dictionary<Titanium.UI.iOS.GravityBehavior>): Titanium.UI.iOS.GravityBehavior;

            /**
             * Creates a live photo badge to be used together with the
             * <Titanium.UI.iOS.LivePhotoView> API.
             */
            static createLivePhotoBadge(type: number): Titanium.Blob;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.LivePhotoView>.
             */
            static createLivePhotoView(parameters?: Dictionary<Titanium.UI.iOS.LivePhotoView>): Titanium.UI.iOS.LivePhotoView;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.MenuPopup>.
             */
            static createMenuPopup(parameters?: Dictionary<Titanium.UI.iOS.MenuPopup>): Titanium.UI.iOS.MenuPopup;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.NavigationWindow>.
             * @deprecated Use [Titanium.UI.NavigationWindow](Titanium.UI.NavigationWindow) instead.
             */
            static createNavigationWindow(parameters?: Dictionary<Titanium.UI.iOS.NavigationWindow>): Titanium.UI.iOS.NavigationWindow;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.PreviewAction>.
             */
            static createPreviewAction(parameters?: Dictionary<Titanium.UI.iOS.PreviewAction>): Titanium.UI.iOS.PreviewAction;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.PreviewActionGroup>.
             */
            static createPreviewActionGroup(parameters?: Dictionary<Titanium.UI.iOS.PreviewActionGroup>): Titanium.UI.iOS.PreviewActionGroup;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.PreviewContext>.
             */
            static createPreviewContext(parameters?: Dictionary<Titanium.UI.iOS.PreviewContext>): Titanium.UI.iOS.PreviewContext;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.PushBehavior>.
             */
            static createPushBehavior(parameters?: Dictionary<Titanium.UI.iOS.PushBehavior>): Titanium.UI.iOS.PushBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.SnapBehavior>.
             */
            static createSnapBehavior(parameters?: Dictionary<Titanium.UI.iOS.SnapBehavior>): Titanium.UI.iOS.SnapBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.SplitWindow>.
             */
            static createSplitWindow(parameters?: Dictionary<Titanium.UI.iOS.SplitWindow>): Titanium.UI.iOS.SplitWindow;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.Stepper>.
             */
            static createStepper(parameters?: Dictionary<Titanium.UI.iOS.Stepper>): Titanium.UI.iOS.Stepper;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.SystemButton>.
             */
            static createSystemButton(parameters?: Dictionary<Titanium.UI.iOS.SystemButton>): Titanium.UI.iOS.SystemButton;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.TabbedBar>.
             * @deprecated Use [Titanium.UI.TabbedBar](Titanium.UI.TabbedBar) instead.
             */
            static createTabbedBar(parameters?: Dictionary<Titanium.UI.iOS.TabbedBar>): Titanium.UI.iOS.TabbedBar;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.Toolbar>.
             * @deprecated Use the cross-platform [Titanium.UI.Toolbar](Titanium.UI.Toolbar) instead.
             */
            static createToolbar(parameters?: Dictionary<Titanium.UI.iOS.Toolbar>): Titanium.UI.iOS.Toolbar;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.TransitionAnimation>.
             */
            static createTransitionAnimation(parameters?: Dictionary<Titanium.UI.iOS.TransitionAnimation>): Titanium.UI.iOS.TransitionAnimation;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.ViewAttachmentBehavior>.
             */
            static createViewAttachmentBehavior(parameters?: Dictionary<Titanium.UI.iOS.ViewAttachmentBehavior>): Titanium.UI.iOS.ViewAttachmentBehavior;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.WebViewConfiguration>.
             */
            static createWebViewConfiguration(parameters?: Dictionary<Titanium.UI.iOS.WebViewConfiguration>): Titanium.UI.iOS.WebViewConfiguration;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.WebViewDecisionHandler>.
             */
            static createWebViewDecisionHandler(parameters?: Dictionary<Titanium.UI.iOS.WebViewDecisionHandler>): Titanium.UI.iOS.WebViewDecisionHandler;

            /**
             * Creates and returns an instance of <Titanium.UI.iOS.WebViewProcessPool>.
             */
            static createWebViewProcessPool(parameters?: Dictionary<Titanium.UI.iOS.WebViewProcessPool>): Titanium.UI.iOS.WebViewProcessPool;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.iOS.apiName> property.
             * @deprecated Access <Titanium.UI.iOS.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.UI.iOS.appBadge> property.
             * @deprecated Access <Titanium.UI.iOS.appBadge> instead.
             */
            static getAppBadge(): number;

            /**
             * Gets the value of the <Titanium.UI.iOS.appSupportsShakeToEdit> property.
             * @deprecated Access <Titanium.UI.iOS.appSupportsShakeToEdit> instead.
             */
            static getAppSupportsShakeToEdit(): boolean;

            /**
             * Gets the value of the <Titanium.UI.iOS.bubbleParent> property.
             * @deprecated Access <Titanium.UI.iOS.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Gets the value of the <Titanium.UI.iOS.forceTouchSupported> property.
             * @deprecated Access <Titanium.UI.iOS.forceTouchSupported> instead.
             */
            static getForceTouchSupported(): boolean;

            /**
             * Gets the value of the <Titanium.UI.iOS.statusBarBackgroundColor> property.
             * @deprecated Access <Titanium.UI.iOS.statusBarBackgroundColor> instead.
             */
            static getStatusBarBackgroundColor(): string | Titanium.UI.Color;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.appBadge> property.
             * @deprecated Set the value using <Titanium.UI.iOS.appBadge> instead.
             */
            static setAppBadge(appBadge: number): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.appSupportsShakeToEdit> property.
             * @deprecated Set the value using <Titanium.UI.iOS.appSupportsShakeToEdit> instead.
             */
            static setAppSupportsShakeToEdit(appSupportsShakeToEdit: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.iOS.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.MODAL_PRESENTATION_CURRENT_CONTEXT> property.
             * @deprecated Set the value using <Titanium.UI.iOS.MODAL_PRESENTATION_CURRENT_CONTEXT> instead.
             */
            static setMODAL_PRESENTATION_CURRENT_CONTEXT(MODAL_PRESENTATION_CURRENT_CONTEXT: number): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.MODAL_PRESENTATION_OVER_CURRENT_CONTEXT> property.
             * @deprecated Set the value using <Titanium.UI.iOS.MODAL_PRESENTATION_OVER_CURRENT_CONTEXT> instead.
             */
            static setMODAL_PRESENTATION_OVER_CURRENT_CONTEXT(MODAL_PRESENTATION_OVER_CURRENT_CONTEXT: number): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.MODAL_PRESENTATION_OVER_CURRENT_FULL_SCREEN> property.
             * @deprecated Set the value using <Titanium.UI.iOS.MODAL_PRESENTATION_OVER_CURRENT_FULL_SCREEN> instead.
             */
            static setMODAL_PRESENTATION_OVER_CURRENT_FULL_SCREEN(MODAL_PRESENTATION_OVER_CURRENT_FULL_SCREEN: number): void;

            /**
             * Sets the value of the <Titanium.UI.iOS.statusBarBackgroundColor> property.
             * @deprecated Set the value using <Titanium.UI.iOS.statusBarBackgroundColor> instead.
             */
            static setStatusBarBackgroundColor(statusBarBackgroundColor: string | Titanium.UI.Color): void;

            /**
             * Get image from SF Symbols provided by Apple.
             */
            static systemImage(name: string): Titanium.Blob;

        }
        /**
         * iPad specific UI capabilities.
         */
        class iPad extends Titanium.Module {
            /**
             * The name of the API that this proxy corresponds to.
             */
            static readonly apiName: string;

            /**
             * Indicates if the proxy will bubble an event to its parent.
             */
            static bubbleParent: boolean;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Applies the properties to the proxy.
             */
            static applyProperties(props: any): void;

            /**
             * Creates and returns an instance of <Titanium.UI.iPad.DocumentViewer>.
             * @deprecated Use [Titanium.UI.iOS.DocumentViewer](Titanium.UI.iOS.DocumentViewer) instead.
             */
            static createDocumentViewer: never;

            /**
             * Creates and returns an instance of <Titanium.UI.iPad.Popover>.
             */
            static createPopover(parameters?: Dictionary<Titanium.UI.iPad.Popover>): Titanium.UI.iPad.Popover;

            /**
             * Creates and returns an instance of <Titanium.UI.iPad.SplitWindow>.
             * @deprecated Use [Titanium.UI.iOS.SplitWindow](Titanium.UI.iOS.SplitWindow) instead.
             */
            static createSplitWindow: never;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            static fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.UI.iPad.apiName> property.
             * @deprecated Access <Titanium.UI.iPad.apiName> instead.
             */
            static getApiName(): string;

            /**
             * Gets the value of the <Titanium.UI.iPad.bubbleParent> property.
             * @deprecated Access <Titanium.UI.iPad.bubbleParent> instead.
             */
            static getBubbleParent(): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.UI.iPad.bubbleParent> property.
             * @deprecated Set the value using <Titanium.UI.iPad.bubbleParent> instead.
             */
            static setBubbleParent(bubbleParent: boolean): void;

        }
        /**
         * The iPhone/iPad-specific UI capabilities.  All properties, methods and events in this namespace
         * will only work on Apple iOS systems.
         * @deprecated Use the unified [Titanium.UI.iOS](Titanium.UI.iOS) namespace instead.
         */
        const iPhone: never;
    }
    /**
     * The top level XML module.  The XML module is used for parsing and processing XML-based content.
     */
    namespace XML {
        /**
         * Represents an attribute of an [Element](Titanium.XML.Element).
         */
        class Attr extends Titanium.XML.Node {
            /**
             * Attribute name
             */
            readonly name: string;

            /**
             * The <Titanium.XML.Element> to which the attribute belongs.
             */
            readonly ownerElement: Titanium.XML.Element;

            /**
             * True if this attribute was explicitly given a value in the instance document, false otherwise.
             */
            readonly specified: boolean;

            /**
             * The attribute value as a string.
             */
            value: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.Attr.name> property.
             * @deprecated Access <Titanium.XML.Attr.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.XML.Attr.ownerElement> property.
             * @deprecated Access <Titanium.XML.Attr.ownerElement> instead.
             */
            getOwnerElement(): Titanium.XML.Element;

            /**
             * Gets the value of the <Titanium.XML.Attr.specified> property.
             * @deprecated Access <Titanium.XML.Attr.specified> instead.
             */
            getSpecified(): boolean;

            /**
             * Gets the value of the <Titanium.XML.Attr.value> property.
             * @deprecated Access <Titanium.XML.Attr.value> instead.
             */
            getValue(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.XML.Attr.value> property.
             * @deprecated Set the value using <Titanium.XML.Attr.value> instead.
             */
            setValue(value: string): void;

        }
        /**
         * Used to include blocks of literal text containing characters that would otherwise need
         * to be escaped.
         */
        class CDATASection extends Titanium.XML.Text {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * An interface extending <Titanium.XML.Node> with a set of attributes and methods for accessing character data in the DOM.
         * Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-FF21A306) on Android and iOS. For reasons of compatibility with the javascript engine, text is represented by UTF-8 instead of UTF-16 on Android and iOS.
         */
        class CharacterData extends Titanium.XML.Node {
            /**
             * The character data of the node that implements this interface. Throws an exception during setting if this node is readonly.
             */
            data: string;

            /**
             * The number of characters that are available through data and the substringData method. This may have the value zero, i.e., <Titanium.XML.CharacterData> may be empty.
             */
            readonly length: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Append the string to the end of the character data of the node. Upon success, data provides access to the concatenation of data and the string specified. Throws an exception if this node is readonly.
             */
            appendData(arg: string): void;

            /**
             * Remove a range of characters from the node. Upon success, data and length reflect the change. Throws an exception if this node is readonly, if offset is negative, offset is beyond the data's length, or if count is negative.
             */
            deleteData(offset: number, count: number): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.CharacterData.data> property.
             * @deprecated Access <Titanium.XML.CharacterData.data> instead.
             */
            getData(): string;

            /**
             * Gets the value of the <Titanium.XML.CharacterData.length> property.
             * @deprecated Access <Titanium.XML.CharacterData.length> instead.
             */
            getLength(): number;

            /**
             * Insert a string at the specified offset. Throws an exception if this node is readonly, if offset is negative, or if offset is beyond the data's length.
             */
            insertData(offset: number, arg: string): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replace the characters starting at the specified offset with the specified string. Throws an exception if this node is readonly, if offset is negative, offset is beyond the data's length, or if count is negative.
             */
            replaceData(offset: number, count: number, arg: string): void;

            /**
             * Sets the value of the <Titanium.XML.CharacterData.data> property.
             * @deprecated Set the value using <Titanium.XML.CharacterData.data> instead.
             */
            setData(data: string): void;

            /**
             * Extracts a range of data from the node. Throws an exception if offset is negative, offset is beyond the data's length, or if count is negative.
             */
            substringData(offset: number, count: number): string;

        }
        /**
         * Represents the contents of an XML comment.
         */
        class Comment extends Titanium.XML.CharacterData {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * The <Titanium.XML.DOMImplementation> interface provides a number of methods for performing operations that are independent of any particular instance of the document object model.Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-102161490) on Android and iOS.
         */
        class DOMImplementation extends Titanium.Proxy {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Creates an <Titanium.XML.Document> object of the specified type with its document element. Raises an exception if qualifiedName is malformed, contains an illegal character, or is inconsistent with namespaceURI. Also raises an exception if doctype has already been used with a different document.
             */
            createDocument(namespaceURI: string, qualifiedName: string, doctype: Titanium.XML.DocumentType): Titanium.XML.Document;

            /**
             * Creates an empty <Titanium.XML.DocumentType> node. Entity declarations and notations are not made available. Entity reference expansions and default attribute additions do not occur. Raises an exception if qualifiedName is malformed or contains an illegal character.
             */
            createDocumentType(qualifiedName: string, publicId: string, systemId: string): Titanium.XML.DocumentType;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Test if the <Titanium.XML.DOMImplementation> implements a specific feature.
             */
            hasFeature(feature: string, version: string): boolean;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * The DOM Document returned from <Titanium.XML.parseString>.
         */
        class Document extends Titanium.XML.Node {
            /**
             * An interface to the list of entities that are defined for the document, such as via a Document Type Definition (DTD).
             */
            readonly doctype: Titanium.XML.DocumentType;

            /**
             * Root element of this document.
             */
            readonly documentElement: Titanium.XML.Element;

            /**
             * [DOMImplementation](Titanium.XML.DOMImplementation) object associated with this
             * document.
             */
            readonly implementation: Titanium.XML.DOMImplementation;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Creates an attribute with the given name.
             */
            createAttribute(name: string): Titanium.XML.Attr;

            /**
             * Creates an attribute with the given name and namespace.
             */
            createAttributeNS(namespaceURI: string, name: string): Titanium.XML.Attr;

            /**
             * Creates and returns a [CDATASection](Titanium.XML.CDATASection).
             */
            createCDATASection(data: string): Titanium.XML.CDATASection;

            /**
             * Creates a [Comment](Titanium.XML.Comment) with the supplied string data.
             */
            createComment(data: string): Titanium.XML.Comment;

            /**
             * Creates an empty [DocumentFragment](Titanium.XML.DocumentFragment).
             */
            createDocumentFragment(): Titanium.XML.DocumentFragment;

            /**
             * Creates an element with the given tag name.
             */
            createElement(tagName: string): Titanium.XML.Element;

            /**
             * Create a new element with the given namespace and name.
             */
            createElementNS(namespaceURI: string, name: string): Titanium.XML.Element;

            /**
             * Creates an [EntityReference](Titanium.XML.EntityReference) with the given name.
             */
            createEntityReference(name: string): Titanium.XML.EntityReference;

            /**
             * Creates a processing instruction for inserting into the DOM tree.
             */
            createProcessingInstruction(target: string, data: string): Titanium.XML.ProcessingInstruction;

            /**
             * Creates a text node.
             */
            createTextNode(data: string): Titanium.XML.Text;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.Document.doctype> property.
             * @deprecated Access <Titanium.XML.Document.doctype> instead.
             */
            getDoctype(): Titanium.XML.DocumentType;

            /**
             * Gets the value of the <Titanium.XML.Document.documentElement> property.
             * @deprecated Access <Titanium.XML.Document.documentElement> instead.
             */
            getDocumentElement(): Titanium.XML.Element;

            /**
             * Returns an [Element](Titanium.XML.Element) that has an ID attribute with the given value.
             */
            getElementById(elementId: string): Titanium.XML.Element;

            /**
             * Returns a node list of elements in the document which have the given tag.
             */
            getElementsByTagName(tagname: string): Titanium.XML.NodeList;

            /**
             * Returns a node list of elements in the document which belong to the given namespace and have the given tag name.
             */
            getElementsByTagNameNS(namespaceURI: string, localname: string): Titanium.XML.NodeList;

            /**
             * Gets the value of the <Titanium.XML.Document.implementation> property.
             * @deprecated Access <Titanium.XML.Document.implementation> instead.
             */
            getImplementation(): Titanium.XML.DOMImplementation;

            /**
             * Imports a node from another document to this document,
             * without altering or removing the source node from the original document.
             */
            importNode(importedNode: Titanium.XML.Node, deep: boolean): Titanium.XML.Node;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * A lightweight document object used as a container for a group of nodes.
         */
        class DocumentFragment extends Titanium.XML.Node {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * Each <Titanium.XML.Document> has a `doctype` attribute whose value is either 'null' or a <Titanium.XML.DocumentType> object.
         */
        class DocumentType extends Titanium.XML.Node {
            /**
             * A <Titanium.XML.NamedNodeMap> containing the general entities, both external and internal, declared in the DTD. Parameter entities are not contained. Duplicates are discarded.
             */
            readonly entities: Titanium.XML.NamedNodeMap;

            /**
             * The internal subset as a string.
             */
            readonly internalSubset: string;

            /**
             * The name of DTD; i.e., the name immediately following the `DOCTYPE` keyword.
             */
            readonly name: string;

            /**
             * A <Titanium.XML.NamedNodeMap> containing the notations declared in the DTD. Duplicates are discarded. Every node in this map also implements the <Titanium.XML.Notation> interface.
             */
            readonly notations: Titanium.XML.NamedNodeMap;

            /**
             * The public identifier of the external subset.
             */
            readonly publicId: string;

            /**
             * The system identifier of the external subset.
             */
            readonly systemId: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.entities> property.
             * @deprecated Access <Titanium.XML.DocumentType.entities> instead.
             */
            getEntities(): Titanium.XML.NamedNodeMap;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.internalSubset> property.
             * @deprecated Access <Titanium.XML.DocumentType.internalSubset> instead.
             */
            getInternalSubset(): string;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.name> property.
             * @deprecated Access <Titanium.XML.DocumentType.name> instead.
             */
            getName(): string;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.notations> property.
             * @deprecated Access <Titanium.XML.DocumentType.notations> instead.
             */
            getNotations(): Titanium.XML.NamedNodeMap;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.publicId> property.
             * @deprecated Access <Titanium.XML.DocumentType.publicId> instead.
             */
            getPublicId(): string;

            /**
             * Gets the value of the <Titanium.XML.DocumentType.systemId> property.
             * @deprecated Access <Titanium.XML.DocumentType.systemId> instead.
             */
            getSystemId(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * Represents an element in a DOM document, a <Titanium.XML.Node> defined by a start-tag and end-tag (or an empty tag). Elements may have [attributes](Titanium.XML.Attr) associated with them.
         * Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-745549614) on Android and iOS with some non-standard extensions.
         */
        class Element extends Titanium.XML.Node {
            /**
             * The name of the element, as defined by its tag.
             */
            readonly tagName: string;

            /**
             * Content (value) of all text nodes within this node.
             * @deprecated Use [Titanium.XML.Element.textContent](Titanium.XML.Element.textContent) instead.
             */
            readonly text: string;

            /**
             * Content (value) of all text nodes within this node.
             */
            readonly textContent: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Retrieves an attribute value by name, returning it as a string.
             */
            getAttribute(name: string): string;

            /**
             * Retrieves an attribute value by local name and namespace URI, returning it as a string.
             */
            getAttributeNS(namespaceURI: string, localName: string): string;

            /**
             * Retrieves an attribute value by name, returning it as a <Titanium.XML.Attr> object.
             */
            getAttributeNode(name: string): Titanium.XML.Attr;

            /**
             * Retrieves an attribute value by local name and namespace URI, returning it as a <Titanium.XML.Attr> object.
             */
            getAttributeNodeNS(namespaceURI: string, localName: string): Titanium.XML.Attr;

            /**
             * Retrieves a <Titanium.XML.NodeList> of all descendant elements with a given tag name, in preorder traversal.
             */
            getElementsByTagName(name: string): Titanium.XML.NodeList;

            /**
             * Retrieves a <Titanium.XML.NodeList> of all descendant elements with a given local name and namespace URI, in preorder traversal.
             */
            getElementsByTagNameNS(namespaceURI: string, localName: string): Titanium.XML.NodeList;

            /**
             * Gets the value of the <Titanium.XML.Element.tagName> property.
             * @deprecated Access <Titanium.XML.Element.tagName> instead.
             */
            getTagName(): string;

            /**
             * Determines whether or not an attribute with the given name is available in the element, or has a default value.
             */
            hasAttribute(name: string): boolean;

            /**
             * Determines whether or not an attribute with the given name is available in the element, or has a default value.
             */
            hasAttributeNS(namespaceURI: string, localName: string): boolean;

            /**
             * Removes an attribute by name. If the attribute has a default value, it is immediately replaced with this default, including namespace URI and local name. Throws an exception if the element is read-only.
             */
            removeAttribute(name: string): void;

            /**
             * Removes an attribute by local name and namespace URI. If the attribute has a default value, it is immediately replaced with this default, including namespace URI and local name. Throws an exception if the element is read-only.
             */
            removeAttributeNS(namespaceURI: string, localName: string): void;

            /**
             * Removes the specified attribute node. If the removed attribute has a default value, it is replaced immediately, with the same namespace and local name as the removed attribute, if applicable. Throws an exception if the element is read-only, or the attribute is not an attribute of the element.
             */
            removeAttributeNode(oldAttr: Titanium.XML.Attr): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Adds a new attribute. Any attribute with the same name is replaced. Throws an exception if the element is read-only, or if the name contains an illegal character.
             */
            setAttribute(name: string, value: string): void;

            /**
             * Adds a new attribute. Any attribute with the same local name and namespace URI is present on the element is replaced, with its prefix changed to that of the `qualifiedName` parameter. Throws an exception if the element is read-only, if the name contains an illegal character, or if the qualified name contains an error.
             */
            setAttributeNS(namespaceURI: string, qualifiedName: string, value: string): void;

            /**
             * Adds a new attribute. Any attribute with the same `nodeName` as the argument is replaced. Throws an exception if the element is read-only, if `newAttr` is from a different document, or if `newAttr` is already an attribute of another element.
             */
            setAttributeNode(newAttr: Titanium.XML.Attr): Titanium.XML.Attr;

            /**
             * Adds a new attribute. Any attribute with the same local name and namespace URI is replaced. Throws an exception if the element is read-only, if `newAttr` is from a different document, or if `newAttr` is already an attribute of another element.
             */
            setAttributeNodeNS(newAttr: Titanium.XML.Attr): Titanium.XML.Attr;

        }
        /**
         * This interface represents an entity, either parsed or unparsed, in an XML document. Note that this models the entity itself not the entity declaration. The nodeName attribute that is inherited from Node contains the name of the entity. An Entity node does not have any parent.
         * Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-527DCFF2) on Android and iOS.
         */
        class Entity extends Titanium.XML.Node {
            /**
             * For unparsed entities, the name of the notation for the entity. For parsed entities, this is `null`.
             */
            readonly notationName: string;

            /**
             * The public identifier associated with the entity, if specified. If the public identifier was not specified, this is `null`.
             */
            readonly publicId: string;

            /**
             * The system identifier associated with the entity, if specified. If the system identifier was not specified, this is null.
             */
            readonly systemId: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.Entity.notationName> property.
             * @deprecated Access <Titanium.XML.Entity.notationName> instead.
             */
            getNotationName(): string;

            /**
             * Gets the value of the <Titanium.XML.Entity.publicId> property.
             * @deprecated Access <Titanium.XML.Entity.publicId> instead.
             */
            getPublicId(): string;

            /**
             * Gets the value of the <Titanium.XML.Entity.systemId> property.
             * @deprecated Access <Titanium.XML.Entity.systemId> instead.
             */
            getSystemId(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * Represents an XML entity reference.
         */
        class EntityReference extends Titanium.XML.Node {
            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * A key-value paired map that maps String objects to <Titanium.XML.Node> objects.
         * Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-1780488922) on Android and iOS.
         */
        class NamedNodeMap extends Titanium.Proxy {
            /**
             * The number of nodes in the map. The valid range of child node indices is 0-`length`-1, inclusive.
             */
            readonly length: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.NamedNodeMap.length> property.
             * @deprecated Access <Titanium.XML.NamedNodeMap.length> instead.
             */
            getLength(): number;

            /**
             * Retrieves a node specified by name.
             */
            getNamedItem(name: string): Titanium.XML.Node;

            /**
             * Retrieves a node specified by name and namespace. Returns `null` if no matching node is in the map.
             */
            getNamedItemNS(namespaceURI: string, localName: string): Titanium.XML.Node;

            /**
             * Retrieves the node at the specified index of the map. Note that NamedNodeMaps are not ordered.
             */
            item(index: number): Titanium.XML.Node;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Removes a node from the map specified by name. When this map contains attributes attached to an element, if the removed attribtue is known to have a default, it is replaced with that value.
             */
            removeNamedItem(name: string): Titanium.XML.Node;

            /**
             * Removes a node from the map specified by local name and namespace URI. When this map contains attributes attached to an element, if the removed attribtue is known to have a default, it is replaced with that value. Returns the node removed from the map, or `null` if there is no corresponding node.
             */
            removeNamedItemNS(namespaceURI: string, localName: string): Titanium.XML.Node;

            /**
             * Adds a node using its `nodeName` attribute. If a node with that name is already present, it is replaced. Throws an exception if the argument is from a different document, the map is read-only, or the argument is an attribute of another element.
             */
            setNamedItem(node: Titanium.XML.Node): Titanium.XML.Node;

            /**
             * Adds a node using its `namespaceURI` and `localName` attributes. If a node with that name is already present, it is replaced. Throws an exception if the argument is from a different document, the map is read-only, or the argument is an attribute of another element.
             */
            setNamedItemNS(node: Titanium.XML.Node): Titanium.XML.Node;

        }
        /**
         * A single node in the [Document](Titanium.XML.Document) tree.
         */
        class Node extends Titanium.Proxy {
            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify an
             * [Attr](Titanium.XML.Attr) node.
             */
            readonly ATTRIBUTE_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [CDATASection](Titanium.XML.CDATASection) node.
             */
            readonly CDATA_SECTION_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [Comment](Titanium.XML.Comment) node.
             */
            readonly COMMENT_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [DocumentFragment](Titanium.XML.DocumentFragment) node.
             */
            readonly DOCUMENT_FRAGMENT_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [Document](Titanium.XML.Document) node.
             */
            readonly DOCUMENT_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [DocumentType](Titanium.XML.DocumentType) node.
             */
            readonly DOCUMENT_TYPE_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify an
             * [Element](Titanium.XML.Element) node.
             */
            readonly ELEMENT_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify an
             * [Entity](Titanium.XML.Entity) node.
             */
            readonly ENTITY_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify an
             * [EntityReference](Titanium.XML.EntityReference) node.
             */
            readonly ENTITY_REFERENCE_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [Notation](Titanium.XML.Notation) node.
             */
            readonly NOTATION_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [ProcessingInstruction](Titanium.XML.ProcessingInstruction) node.
             */
            readonly PROCESSING_INSTRUCTION_NODE: number;

            /**
             * Used with [nodeType](Titanium.XML.Node.nodeType) to identify a
             * [Text](Titanium.XML.Text) node.
             */
            readonly TEXT_NODE: number;

            /**
             * A map of this node's attributes.
             */
            readonly attributes: Titanium.XML.NamedNodeMap;

            /**
             * A <Titanium.XML.NodeList> of this node's children.
             */
            readonly childNodes: Titanium.XML.NodeList;

            /**
             * This node's first child.
             */
            readonly firstChild: Titanium.XML.Node;

            /**
             * This node's last child.
             */
            readonly lastChild: Titanium.XML.Node;

            /**
             * Local part of the qualified name of this node.
             */
            localName: string;

            /**
             * Namespace URI of this node.
             */
            readonly namespaceURI: string;

            /**
             * This node's next sibling.
             */
            readonly nextSibling: Titanium.XML.Node;

            /**
             * Name of this node.
             */
            readonly nodeName: string;

            /**
             * This node's type. One of `ELEMENT_NODE`, `ATTRIBUTE_NODE`, `TEXT_NODE`, `CDATA_SECTION_NODE`,
             * `ENTITY_REFERENCE_NODE`, `ENTITY_NODE`, `PROCESSING_INSTRUCTION_NODE`, `COMMENT_NODE`,
             * `DOCUMENT_NODE`, `DOCUMENT_TYPE_NODE`, `DOCUMENT_FRAGMENT_NODE`, `NOTATION_NODE`.
             */
            readonly nodeType: number;

            /**
             * Content (value) of this node.
             */
            nodeValue: string;

            /**
             * This node's owning document.
             */
            readonly ownerDocument: Titanium.XML.Document;

            /**
             * This node's parent node.
             */
            readonly parentNode: Titanium.XML.Node;

            /**
             * Namespace prefix of this node.
             */
            prefix: string;

            /**
             * This node's previous sibling.
             */
            readonly previousSibling: Titanium.XML.Node;

            /**
             * Content (value) of all text nodes within this node.
             * @deprecated Use [Titanium.XML.Node.textContent](Titanium.XML.Node.textContent) instead.
             */
            readonly text: string;

            /**
             * Content (value) of all text nodes within this node.
             */
            readonly textContent: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Appends the node `newChild` as a child of this node.
             */
            appendChild(newChild: Titanium.XML.Node): Titanium.XML.Node;

            /**
             * Returns a duplicate of this node.
             */
            cloneNode(deep: boolean): Titanium.XML.Node;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.Node.attributes> property.
             * @deprecated Access <Titanium.XML.Node.attributes> instead.
             */
            getAttributes(): Titanium.XML.NamedNodeMap;

            /**
             * Returns `true` if this node has attributes.
             */
            hasAttributes(): boolean;

            /**
             * Returns `true` if this node has child nodes.
             */
            hasChildNodes(): boolean;

            /**
             * Inserts the node `newChild` before the node `refChild`.
             */
            insertBefore(newChild: Titanium.XML.Node, refChild: Titanium.XML.Node): Titanium.XML.Node;

            /**
             * Tests whether the DOM implementation supports a specific feature.
             */
            isSupported(feature: string, version: string): boolean;

            /**
             * Normalizes text and attribute nodes in this node's child hierarchy.
             */
            normalize(): void;

            /**
             * Removes a child node from this node.
             */
            removeChild(oldChild: Titanium.XML.Node): Titanium.XML.Node;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Replaces the node `oldChild` with the node `newChild`.
             */
            replaceChild(newChild: Titanium.XML.Node, oldChild: Titanium.XML.Node): Titanium.XML.Node;

        }
        /**
         * A list of <Titanium.XML.Node> objects. Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-536297177) on Android and iOS.
         */
        class NodeList extends Titanium.Proxy {
            /**
             * The length of the node list.
             */
            readonly length: number;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.NodeList.length> property.
             * @deprecated Access <Titanium.XML.NodeList.length> instead.
             */
            getLength(): number;

            /**
             * Returns the <Titanium.XML.Node> object at the specified index.
             */
            item(index: number): Titanium.XML.Node;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * Represents a notation declared in the DTD.  Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-5431D1B9) on Android and iOS.
         */
        class Notation extends Titanium.Proxy {
            /**
             * The public identifier of this notation. If the public identifier was not specified, this is `null`.
             */
            readonly publicId: string;

            /**
             * The system identifier of this notation. If the system identifier was not specified, this is `null`.
             */
            readonly systemId: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.Notation.publicId> property.
             * @deprecated Access <Titanium.XML.Notation.publicId> instead.
             */
            getPublicId(): string;

            /**
             * Gets the value of the <Titanium.XML.Notation.systemId> property.
             * @deprecated Access <Titanium.XML.Notation.systemId> instead.
             */
            getSystemId(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        }
        /**
         * A way to keep processor-specific information in the text of the document. Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-1004215813) on Android and iOS.
         */
        class ProcessingInstruction extends Titanium.Proxy {
            /**
             * Retrieve the content of this processing instruction. This from the first non white space character after the target to the character immediatly preceding the ?>. When setting a processing instruction, a DOMException may be thrown on an invalid instruction.
             */
            data: string;

            /**
             * Retrieve the target of this processing instruction. XML defines this as being the first token following the markup that begins the processing instruction.
             */
            readonly target: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Gets the value of the <Titanium.XML.ProcessingInstruction.data> property.
             * @deprecated Access <Titanium.XML.ProcessingInstruction.data> instead.
             */
            getData(): string;

            /**
             * Gets the value of the <Titanium.XML.ProcessingInstruction.target> property.
             * @deprecated Access <Titanium.XML.ProcessingInstruction.target> instead.
             */
            getTarget(): string;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Sets the value of the <Titanium.XML.ProcessingInstruction.data> property.
             * @deprecated Set the value using <Titanium.XML.ProcessingInstruction.data> instead.
             */
            setData(data: string): void;

        }
        /**
         * Represents the textual content of an <Titanium.XML.Element> or <Titanium.XML.Attr> Implements the [DOM Level 2 API](https://www.w3.org/TR/DOM-Level-2-Core/core.html#ID-1312295772) on Android and iOS.
         */
        class Text extends Titanium.XML.CharacterData {
            /**
             * Content (value) of all text nodes within this node.
             */
            readonly textContent: string;

            /**
             * Adds the specified callback as an event listener for the named event.
             */
            addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Fires a synthesized event to any registered listeners.
             */
            fireEvent(name: string, event?: any): void;

            /**
             * Removes the specified callback as an event listener for the named event.
             */
            removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

            /**
             * Breaks this node into two nodes at the specified by offset, and returns a new node of the same type, which contains all the content at and after the offset point. Throws an exception if the specified offset is negative or if this node is read only.
             */
            splitText(offset: number): Titanium.XML.Text;

        }
    }
    /**
     * The top-level API module, containing methods to output messages to the system log.
     */
    class API extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Logs messages with a `debug` severity-level.
         */
        static debug(message: string[] | string): void;

        /**
         * Logs messages with an `error` severity-level.
         */
        static error(message: string[] | string): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.API.apiName> property.
         * @deprecated Access <Titanium.API.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.API.bubbleParent> property.
         * @deprecated Access <Titanium.API.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.API.lifecycleContainer> property.
         * @deprecated Access <Titanium.API.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Logs messages with an `info` severity-level.
         */
        static info(message: string[] | string): void;

        /**
         * Logs messages with the specified severity-level.
         */
        static log(level: string, message: string[] | string): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.API.bubbleParent> property.
         * @deprecated Set the value using <Titanium.API.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.API.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.API.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Logs messages with a `timestamp` severity-level, prefixed with a timestamp float number
         * representing the number of seconds since January 1st, 2001.
         */
        static timestamp(message: string[] | string): void;

        /**
         * Logs messages with a `trace` severity-level.
         */
        static trace(message: string[] | string): void;

        /**
         * Logs messages with a `warn` severity-level.
         */
        static warn(message: string[] | string): void;

    }
    /**
     * Base event for class Titanium.Accelerometer
     */
    interface AccelerometerBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Accelerometer;

    }
    /**
     * Fired when the accelerometer changes.
     */
    interface Accelerometer_update_Event extends AccelerometerBaseEvent {
        /**
         * Reference timestamp since the previous change. This is not a valid timestamp and should
         * simply be used to determine the number of milliseconds between events.
         */
        timestamp: number;

        /**
         * Current `x` axis of the device.
         */
        x: number;

        /**
         * Current `y` axis of the device.
         */
        y: number;

        /**
         * Current `z` axis of the device.
         */
        z: number;

    }
    interface AccelerometerEventMap extends ProxyEventMap {
        update: Accelerometer_update_Event;

    }
    /**
     * The top-level Accelerometer module, used to determine the device's physical position.
     */
    class Accelerometer extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof AccelerometerEventMap>(name: K, callback: (this: Titanium.Accelerometer, event: AccelerometerEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof AccelerometerEventMap>(name: K, event?: AccelerometerEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Accelerometer.apiName> property.
         * @deprecated Access <Titanium.Accelerometer.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Accelerometer.bubbleParent> property.
         * @deprecated Access <Titanium.Accelerometer.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Accelerometer.lifecycleContainer> property.
         * @deprecated Access <Titanium.Accelerometer.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof AccelerometerEventMap>(name: K, callback: (this: Titanium.Accelerometer, event: AccelerometerEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Accelerometer.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Accelerometer.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Accelerometer.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Accelerometer.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Used for transmitting developer-defined Analytics events to the Appcelerator Analytics product.
     */
    class Analytics extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * JSON representation of the last Analytics event generated.
         */
        static readonly lastEvent: string;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Allows the user to opt out from Analytics during runtime to comply to GPDR.
         */
        static optedOut: boolean;

        /**
         * Sends a generic event for this application session.
         * **Not displayed in Analytics UI**.
         * @deprecated
         */
        static addEvent: never;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener: never;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties: never;

        /**
         * Sends a feature event for this application session.
         */
        static featureEvent(name: string, data?: any): number;

        /**
         * Sets a list of events that will not be sent to the Analytics server.
         */
        static filterEvents(events: ReadonlyArray<string>): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent: never;

        /**
         * Gets the value of the <Titanium.Analytics.apiName> property.
         * @deprecated Access <Titanium.Analytics.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Analytics.bubbleParent> property.
         * @deprecated Access <Titanium.Analytics.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Analytics.lastEvent> property.
         * @deprecated Access <Titanium.Analytics.lastEvent> instead.
         */
        static getLastEvent(): string;

        /**
         * Gets the value of the <Titanium.Analytics.lifecycleContainer> property.
         * @deprecated Access <Titanium.Analytics.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Analytics.optedOut> property.
         * @deprecated Access <Titanium.Analytics.optedOut> instead.
         */
        static getOptedOut(): boolean;

        /**
         * Sends a navigation event for this application session.
         * **Not displayed in Analytics UI**.
         * @deprecated
         */
        static navEvent(from: string, to: string, name?: string, data?: any): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener: never;

        /**
         * Sets the value of the <Titanium.Analytics.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Analytics.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Analytics.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Analytics.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Sets the value of the <Titanium.Analytics.optedOut> property.
         * @deprecated Set the value using <Titanium.Analytics.optedOut> instead.
         */
        static setOptedOut(optedOut: boolean): void;

        /**
         * Sends a settings event for this application session.
         * **Not displayed in Analytics UI**.
         * @deprecated
         */
        static settingsEvent: never;

        /**
         * Send a timed event for this application session.
         * **Not displayed in Analytics UI**.
         * @deprecated
         */
        static timedEvent: never;

        /**
         * Sends a user event for this application session.
         * **Not displayed in Analytics UI**.
         * @deprecated
         */
        static userEvent: never;

    }
    /**
     * The top-level Android module.
     */
    class Android extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * References the top-most window's activity.
         */
        static readonly currentActivity: Titanium.Android.Activity;

        /**
         * Service in the active context.
         */
        static readonly currentService: Titanium.Android.Service;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * The first activity launched by the application.
         */
        static readonly rootActivity: Titanium.Android.Activity;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Creates and returns an instance of <Titanium.Android.BigPictureStyle>.
         */
        static createBigPictureStyle(parameters?: Dictionary<Titanium.Android.BigPictureStyle>): Titanium.Android.BigPictureStyle;

        /**
         * Creates and returns an instance of <Titanium.Android.BigTextStyle>.
         */
        static createBigTextStyle(parameters?: Dictionary<Titanium.Android.BigTextStyle>): Titanium.Android.BigTextStyle;

        /**
         * Create an `Intent` to be used in a broadcast.
         */
        static createBroadcastIntent(parameters?: Dictionary<Titanium.Android.Intent>): Titanium.Android.Intent;

        /**
         * Creates and returns an instance of <Titanium.Android.BroadcastReceiver>.
         */
        static createBroadcastReceiver(parameters?: Dictionary<Titanium.Android.BroadcastReceiver>): Titanium.Android.BroadcastReceiver;

        /**
         * Creates a [DrawerLayout](Titanium.UI.Android.DrawerLayout).
         */
        static createDrawerLayout(parameters?: Dictionary<Titanium.UI.Android.DrawerLayout>): Titanium.UI.Android.DrawerLayout;

        /**
         * Creates and returns an instance of <Titanium.Android.Intent>.
         */
        static createIntent(parameters?: Dictionary<Titanium.Android.Intent>): Titanium.Android.Intent;

        /**
         * Creates an activity chooser intent, used to allow the user to select a target activity
         * for an intent.
         */
        static createIntentChooser(intent: Titanium.Android.Intent, title: string): Titanium.Android.Intent;

        /**
         * Creates and returns an instance of <Titanium.Android.Notification>.
         */
        static createNotification(parameters?: Dictionary<Titanium.Android.Notification>): Titanium.Android.Notification;

        /**
         * Creates and returns an instance of <Titanium.Android.NotificationChannel>.
         */
        static createNotificationChannel(parameters?: Dictionary<Titanium.Android.NotificationChannel>): Titanium.Android.NotificationChannel;

        /**
         * Creates a [PendingIntent](Titanium.Android.PendingIntent) to be used inside a
         * [Notification](Titanium.Android.Notification).
         */
        static createPendingIntent(parameters?: Dictionary<Titanium.Android.PendingIntent>): Titanium.Android.PendingIntent;

        /**
         * Creates and returns an instance of <Titanium.Android.QuickSettingsService>.
         */
        static createQuickSettingsService(parameters?: Dictionary<Titanium.Android.QuickSettingsService>): Titanium.Android.QuickSettingsService;

        /**
         * Creates and returns an instance of <Titanium.Android.RemoteViews>.
         */
        static createRemoteViews(parameters?: Dictionary<Titanium.Android.RemoteViews>): Titanium.Android.RemoteViews;

        /**
         * Create a <Titanium.Android.Service> so you can start/stop it and listen for events from it.
         */
        static createService(intent: Titanium.Android.Intent): Titanium.Android.Service;

        /**
         * Create an `Intent` to be used to start a service.
         */
        static createServiceIntent(options: ServiceIntentOptions): Titanium.Android.Intent;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Android.apiName> property.
         * @deprecated Access <Titanium.Android.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Android.bubbleParent> property.
         * @deprecated Access <Titanium.Android.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Android.lifecycleContainer> property.
         * @deprecated Access <Titanium.Android.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Returns `true` if the app has permission access.
         */
        static hasPermission(permission: string | string[]): boolean;

        /**
         * Check on state of Service.
         */
        static isServiceRunning(intent: Titanium.Android.Intent): boolean;

        /**
         * Registers broadcast receiver for the given actions.
         */
        static registerBroadcastReceiver(broadcastReceiver: Titanium.Android.BroadcastReceiver, actions: ReadonlyArray<string>): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Request for permission access.
         */
        static requestPermissions(permissions: string | string[], callback?: (param0: RequestPermissionAccessResult) => void): void;

        /**
         * Sets the value of the <Titanium.Android.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Android.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Android.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Android.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Starts a simple service.
         */
        static startService(intent: Titanium.Android.Intent): void;

        /**
         * Stop a simple service that was started with `startService`.
         */
        static stopService(intent: Titanium.Android.Intent): void;

        /**
         * Unregisters a broadcast receiver.
         */
        static unregisterBroadcastReceiver(broadcastReceiver: Titanium.Android.BroadcastReceiver): void;

    }
    /**
     * Base event for class Titanium.App
     */
    interface AppBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.App;

    }
    /**
     * Fired by the system when the device's accessibility service is turned on or off.
     */
    interface App_accessibilitychanged_Event extends AppBaseEvent {
        /**
         * Whether accessibility is now enabled or disabled.
         */
        enabled: boolean;

    }
    /**
     * Fired by the system when the application is about to be terminated.
     */
    interface App_close_Event extends AppBaseEvent {
    }
    /**
     * Fired when the app receives a warning from the operating system about low memory availability.
     */
    interface App_memorywarning_Event extends AppBaseEvent {
    }
    /**
     * Fired when the application transitions from active to inactive state on a multitasked system.
     */
    interface App_pause_Event extends AppBaseEvent {
    }
    /**
     * Fired when the application transitions to the background on a multitasked system.
     */
    interface App_paused_Event extends AppBaseEvent {
    }
    /**
     * Fired when the proximity sensor changes state.
     */
    interface App_proximity_Event extends AppBaseEvent {
        /**
         * Proximity state value.
         */
        state: boolean;

    }
    /**
     * Fired when an uncaught JavaScript exception occurs.
     */
    interface App_uncaughtException_Event extends AppBaseEvent {
        /**
         * The backtrace of function calls when the error occurred.
         * @deprecated
         */
        backtrace: never;

        /**
         * The column offset on the line where the error occured.
         */
        column: number;

        /**
         * The java stack trace of the exception.
         * @deprecated Use `nativeStack` property for cross-platform parity.
         */
        javaStack: string;

        /**
         * The javascript stack trace of the exception.
         * @deprecated Use `stack` property for cross-platform parity.
         */
        jsStack: string;

        /**
         * The line where the error occurred.
         */
        line: number;

        /**
         * The offset on the line where the error occurred.
         * @deprecated Use `column` property for cross-platform parity.
         */
        lineOffset: number;

        /**
         * The line source reference.
         */
        lineSource: string;

        /**
         * The error message.
         */
        message: string;

        /**
         * The native platform stack trace of the exception.
         */
        nativeStack: string;

        /**
         * A unique identification for the source file.
         */
        sourceId: number;

        /**
         * The name of the source file.
         */
        sourceName: string;

        /**
         * The URL to the source file.
         */
        sourceURL: string;

        /**
         * The javascript stack trace of the exception.
         */
        stack: string;

        /**
         * The title for the error.
         */
        title: string;

        /**
         * The type of error.
         */
        type: string;

    }
    /**
     * Fired when the application returns to the foreground on a multitasked system.
     */
    interface App_resume_Event extends AppBaseEvent {
    }
    /**
     * Fired when the application returns to the foreground.
     */
    interface App_resumed_Event extends AppBaseEvent {
    }
    /**
     * Fired after the "app.js" or "alloy.js" gets executed during application startup.
     */
    interface App_started_Event extends AppBaseEvent {
    }
    /**
     * Fired when the soft keyboard is presented, on and off the screen.
     */
    interface App_keyboardframechanged_Event extends AppBaseEvent {
        /**
         * The duration of the keyboard animation. This parameter is only available on Titanium SDK 4.0.0 and later.
         */
        animationDuration: number;

        /**
         * A dictionary with keys x, y, width and height representing the frame of keyboard on screen.
         */
        keyboardFrame: Dimension;

    }
    /**
     * Fired when there is a significant change in the time.
     */
    interface App_significanttimechange_Event extends AppBaseEvent {
    }
    /**
     * Fired when a <Titanium.UI.ShortcutItem> is clicked.
     */
    interface App_shortcutitemclick_Event extends AppBaseEvent {
        /**
         * Identifier of the clicked shortcut item.
         */
        id: string;

    }
    /**
     * Called whenever an interaction with the window occurred. To be used together with the <Titanium.App.trackUserInteraction> property.
     */
    interface App_userinteraction_Event extends AppBaseEvent {
    }
    interface AppEventMap extends ProxyEventMap {
        accessibilitychanged: App_accessibilitychanged_Event;

        close: App_close_Event;

        keyboardframechanged: App_keyboardframechanged_Event;

        memorywarning: App_memorywarning_Event;

        pause: App_pause_Event;

        paused: App_paused_Event;

        proximity: App_proximity_Event;

        resume: App_resume_Event;

        resumed: App_resumed_Event;

        shortcutitemclick: App_shortcutitemclick_Event;

        significanttimechange: App_significanttimechange_Event;

        started: App_started_Event;

        uncaughtException: App_uncaughtException_Event;

        userinteraction: App_userinteraction_Event;

    }
    /**
     * The top-level App module is mainly used for accessing information about the
     * application at runtime, and for sending or listening for system events.
     */
    class App extends Titanium.Module {
        /**
         * Indicates whether Accessibility is enabled by the system.
         */
        static readonly accessibilityEnabled: boolean;

        /**
         * Indicates whether Analytics is enabled, determined by `tiapp.xml`.
         */
        static readonly analytics: boolean;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Application copyright statement, determined by `tiapp.xml`.
         */
        static readonly copyright: string;

        /**
         * A reference to the currnet background service running when the application is placed in the background.
         */
        static readonly currentService: Titanium.App.iOS.BackgroundService;

        /**
         * Build type that reflects how the application was packaged.
         * Returns one of the following values:
         * * `development` (Simulator)
         * * `test` (Device)
         * * `production` (App Store / Adhoc)
         */
        static readonly deployType: string;

        /**
         * Application description, determined by `tiapp.xml`.
         */
        static readonly description: string;

        /**
         * Prevents network activity indicator from being displayed.
         */
        static disableNetworkActivityIndicator: boolean;

        /**
         * Shows the application's splash screen on app resume.
         */
        static forceSplashAsSnapshot: boolean;

        /**
         * Application globally-unique ID, determined by `tiapp.xml`.
         */
        static readonly guid: string;

        /**
         * Application ID, from `tiapp.xml`.
         */
        static readonly id: string;

        /**
         * Determines whether the screen is locked when the device is idle.
         */
        static idleTimerDisabled: boolean;

        /**
         * The install ID for this application.
         */
        static readonly installId: string;

        /**
         * Indicates whether or not the soft keyboard is visible.
         */
        static readonly keyboardVisible: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Application name, determined by `tiapp.xml`.
         */
        static readonly name: string;

        /**
         * Determines whether proximity detection is enabled.
         */
        static proximityDetection: boolean;

        /**
         * Indicates the state of the device's proximity sensor, according to the
         * <Titanium.App.proximity> event.
         */
        static readonly proximityState: boolean;

        /**
         * Application publisher, from `tiapp.xml`.
         */
        static readonly publisher: string;

        /**
         * Unique session identifier for the current continuous run of the application.
         */
        static readonly sessionId: string;

        /**
         * Indicates whether or not the user interaction shoud be tracked.
         */
        static trackUserInteraction: boolean;

        /**
         * Application URL, from `tiapp.xml`.
         */
        static readonly url: string;

        /**
         * Application version, from `tiapp.xml`.
         */
        static readonly version: string;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof AppEventMap>(name: K, callback: (this: Titanium.App, event: AppEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof AppEventMap>(name: K, event?: AppEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Fire a system-level event such as <Titanium.App.EVENT_ACCESSIBILITY_ANNOUNCEMENT>.
         */
        static fireSystemEvent(eventName: string, param?: any): void;

        /**
         * Gets the value of the <Titanium.App.accessibilityEnabled> property.
         * @deprecated Access <Titanium.App.accessibilityEnabled> instead.
         */
        static getAccessibilityEnabled(): boolean;

        /**
         * Gets the value of the <Titanium.App.analytics> property.
         * @deprecated Access <Titanium.App.analytics> instead.
         */
        static getAnalytics(): boolean;

        /**
         * Gets the value of the <Titanium.App.apiName> property.
         * @deprecated Access <Titanium.App.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Returns the arguments passed to the application on startup.
         */
        static getArguments(): launchOptions;

        /**
         * Gets the value of the <Titanium.App.bubbleParent> property.
         * @deprecated Access <Titanium.App.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.App.copyright> property.
         * @deprecated Access <Titanium.App.copyright> instead.
         */
        static getCopyright(): string;

        /**
         * Gets the value of the <Titanium.App.currentService> property.
         * @deprecated Access <Titanium.App.currentService> instead.
         */
        static getCurrentService(): Titanium.App.iOS.BackgroundService;

        /**
         * Gets the value of the <Titanium.App.deployType> property.
         * @deprecated Access <Titanium.App.deployType> instead.
         */
        static getDeployType(): string;

        /**
         * Gets the value of the <Titanium.App.description> property.
         * @deprecated Access <Titanium.App.description> instead.
         */
        static getDescription(): string;

        /**
         * Gets the value of the <Titanium.App.disableNetworkActivityIndicator> property.
         * @deprecated Access <Titanium.App.disableNetworkActivityIndicator> instead.
         */
        static getDisableNetworkActivityIndicator(): boolean;

        /**
         * Gets the value of the <Titanium.App.forceSplashAsSnapshot> property.
         * @deprecated Access <Titanium.App.forceSplashAsSnapshot> instead.
         */
        static getForceSplashAsSnapshot(): boolean;

        /**
         * Gets the value of the <Titanium.App.guid> property.
         * @deprecated Access <Titanium.App.guid> instead.
         */
        static getGuid(): string;

        /**
         * Gets the value of the <Titanium.App.id> property.
         * @deprecated Access <Titanium.App.id> instead.
         */
        static getId(): string;

        /**
         * Gets the value of the <Titanium.App.idleTimerDisabled> property.
         * @deprecated Access <Titanium.App.idleTimerDisabled> instead.
         */
        static getIdleTimerDisabled(): boolean;

        /**
         * Gets the value of the <Titanium.App.installId> property.
         * @deprecated Access <Titanium.App.installId> instead.
         */
        static getInstallId(): string;

        /**
         * Gets the value of the <Titanium.App.keyboardVisible> property.
         * @deprecated Access <Titanium.App.keyboardVisible> instead.
         */
        static getKeyboardVisible(): boolean;

        /**
         * Gets the value of the <Titanium.App.lifecycleContainer> property.
         * @deprecated Access <Titanium.App.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.App.name> property.
         * @deprecated Access <Titanium.App.name> instead.
         */
        static getName(): string;

        /**
         * Gets the value of the <Titanium.App.proximityDetection> property.
         * @deprecated Access <Titanium.App.proximityDetection> instead.
         */
        static getProximityDetection(): boolean;

        /**
         * Gets the value of the <Titanium.App.proximityState> property.
         * @deprecated Access <Titanium.App.proximityState> instead.
         */
        static getProximityState(): boolean;

        /**
         * Gets the value of the <Titanium.App.publisher> property.
         * @deprecated Access <Titanium.App.publisher> instead.
         */
        static getPublisher(): string;

        /**
         * Gets the value of the <Titanium.App.sessionId> property.
         * @deprecated Access <Titanium.App.sessionId> instead.
         */
        static getSessionId(): string;

        /**
         * Gets the value of the <Titanium.App.url> property.
         * @deprecated Access <Titanium.App.url> instead.
         */
        static getUrl(): string;

        /**
         * Gets the value of the <Titanium.App.version> property.
         * @deprecated Access <Titanium.App.version> instead.
         */
        static getVersion(): string;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof AppEventMap>(name: K, callback: (this: Titanium.App, event: AppEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.App.bubbleParent> property.
         * @deprecated Set the value using <Titanium.App.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.App.disableNetworkActivityIndicator> property.
         * @deprecated Set the value using <Titanium.App.disableNetworkActivityIndicator> instead.
         */
        static setDisableNetworkActivityIndicator(disableNetworkActivityIndicator: boolean): void;

        /**
         * Sets the value of the <Titanium.App.forceSplashAsSnapshot> property.
         * @deprecated Set the value using <Titanium.App.forceSplashAsSnapshot> instead.
         */
        static setForceSplashAsSnapshot(forceSplashAsSnapshot: boolean): void;

        /**
         * Sets the value of the <Titanium.App.idleTimerDisabled> property.
         * @deprecated Set the value using <Titanium.App.idleTimerDisabled> instead.
         */
        static setIdleTimerDisabled(idleTimerDisabled: boolean): void;

        /**
         * Sets the value of the <Titanium.App.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.App.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Sets the value of the <Titanium.App.proximityDetection> property.
         * @deprecated Set the value using <Titanium.App.proximityDetection> instead.
         */
        static setProximityDetection(proximityDetection: boolean): void;

    }
    /**
     * A container for binary data.
     */
    class Blob extends Titanium.Proxy {
        /**
         * File object represented by this blob, or `null` if this blob is not
         * associated with a file.
         */
        readonly file: Titanium.Filesystem.File;

        /**
         * If this blob represents an image, this is the height of the image in pixels.
         */
        readonly height: number;

        /**
         * Length of this blob in bytes.
         */
        readonly length: number;

        /**
         * Mime type of the data in this blob.
         */
        readonly mimeType: string;

        /**
         * If this blob represents a [File](Titanium.Filesystem.File), this is the file URL
         * that represents it.
         */
        readonly nativePath: string;

        /**
         * Size of the blob in pixels (for image blobs) or bytes (for all other blobs).
         */
        readonly size: number;

        /**
         * UTF-8 string representation of the data in this blob.
         */
        readonly text: string;

        /**
         * If the blob references an image, this provides the height in pixels after factoring in EXIF orientation.
         */
        readonly uprightHeight: number;

        /**
         * If the blob references an image, this provides the width in pixels after factoring in EXIF orientation.
         */
        readonly uprightWidth: number;

        /**
         * If this blob represents an image, this is the width of the image in pixels.
         */
        readonly width: number;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Appends the data from another blob to this blob.
         */
        append(blob: Titanium.Blob): void;

        /**
         * Returns a `Promise` that resolves with the contents of the blob as binary data contained in an `ArrayBuffer`.
         */
        arrayBuffer(): Promise<ArrayBuffer>;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Blob.file> property.
         * @deprecated Access <Titanium.Blob.file> instead.
         */
        getFile(): Titanium.Filesystem.File;

        /**
         * Gets the value of the <Titanium.Blob.height> property.
         * @deprecated Access <Titanium.Blob.height> instead.
         */
        getHeight(): number;

        /**
         * Gets the value of the <Titanium.Blob.length> property.
         * @deprecated Access <Titanium.Blob.length> instead.
         */
        getLength(): number;

        /**
         * Gets the value of the <Titanium.Blob.mimeType> property.
         * @deprecated Access <Titanium.Blob.mimeType> instead.
         */
        getMimeType(): string;

        /**
         * Gets the value of the <Titanium.Blob.nativePath> property.
         * @deprecated Access <Titanium.Blob.nativePath> instead.
         */
        getNativePath(): string;

        /**
         * Gets the value of the <Titanium.Blob.size> property.
         * @deprecated Access <Titanium.Blob.size> instead.
         */
        getSize(): number;

        /**
         * Gets the value of the <Titanium.Blob.text> property.
         * @deprecated Access <Titanium.Blob.text> instead.
         */
        getText(): string;

        /**
         * Gets the value of the <Titanium.Blob.uprightHeight> property.
         * @deprecated Access <Titanium.Blob.uprightHeight> instead.
         */
        getUprightHeight(): number;

        /**
         * Gets the value of the <Titanium.Blob.uprightWidth> property.
         * @deprecated Access <Titanium.Blob.uprightWidth> instead.
         */
        getUprightWidth(): number;

        /**
         * Gets the value of the <Titanium.Blob.width> property.
         * @deprecated Access <Titanium.Blob.width> instead.
         */
        getWidth(): number;

        /**
         * Creates a new blob by compressing the underlying image to the specified quality.
         */
        imageAsCompressed(quality: number): Titanium.Blob;

        /**
         * Creates a new blob by cropping the underlying image to the specified dimensions.
         */
        imageAsCropped(options: Dimension): Titanium.Blob;

        /**
         * Creates a new blob by resizing and scaling the underlying image to the specified dimensions.
         */
        imageAsResized(width: number, height: number): Titanium.Blob;

        /**
         * Returns a thumbnail version of the underlying image, optionally with a border and rounded corners.
         */
        imageAsThumbnail(size: number, borderSize?: number, cornerRadius?: number): Titanium.Blob;

        /**
         * Returns a copy of the underlying image with an added alpha channel.
         */
        imageWithAlpha(): Titanium.Blob;

        /**
         * Returns a copy of the underlying image with rounded corners added.
         */
        imageWithRoundedCorner(cornerSize: number, borderSize?: number): Titanium.Blob;

        /**
         * Returns a copy of the underlying image with an added transparent border.
         */
        imageWithTransparentBorder(size: number): Titanium.Blob;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Returns an `ArrayBuffer` representation of this blob.
         */
        toArrayBuffer(): ArrayBuffer;

        /**
         * Returns a string representation of this blob.
         */
        toString(): string;

    }
    /**
     * Wrapper around <Titanium.Blob> that implements the <Titanium.IOStream> interface.
     */
    class BlobStream extends Titanium.IOStream {
        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

    }
    /**
     * Buffer is a mutable, resizable container for raw data.
     */
    class Buffer extends Titanium.Proxy {
        /**
         * Byte order of this buffer.
         */
        byteOrder: number;

        /**
         * Length of the buffer in bytes.
         */
        length: number;

        /**
         * The type of data encoding to use with `value`.
         */
        type: string;

        /**
         * Data to be encoded.
         */
        value: number | string;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Appends `sourceBuffer` to the this buffer.
         */
        append(sourceBuffer: Titanium.Buffer, sourceOffset?: number, sourceLength?: number): number;

        /**
         * Clears this buffer's contents but does not change the size of the buffer.
         */
        clear(): void;

        /**
         * Creates a complete or partial copy of this buffer.
         */
        clone(offset?: number, length?: number): Titanium.Buffer;

        /**
         * Copies data from `sourceBuffer` into the current buffer at `offset`.
         */
        copy(sourceBuffer: Titanium.Buffer, offset: number, sourceOffset?: number, sourceLength?: number): number;

        /**
         * Fills this buffer with the specified byte value.
         */
        fill(fillByte: number, offset?: number, length?: number): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Buffer.byteOrder> property.
         * @deprecated Access <Titanium.Buffer.byteOrder> instead.
         */
        getByteOrder(): number;

        /**
         * Gets the value of the <Titanium.Buffer.length> property.
         * @deprecated Access <Titanium.Buffer.length> instead.
         */
        getLength(): number;

        /**
         * Gets the value of the <Titanium.Buffer.type> property.
         * @deprecated Access <Titanium.Buffer.type> instead.
         */
        getType(): string;

        /**
         * Gets the value of the <Titanium.Buffer.value> property.
         * @deprecated Access <Titanium.Buffer.value> instead.
         */
        getValue(): number | string;

        /**
         * Inserts data from `sourceBuffer` into this buffer at `offset`.
         */
        insert(sourceBuffer: Titanium.Buffer, offset: number, sourceOffset?: number, sourceLength?: number): number;

        /**
         * Releases the space allocated to the buffer, and sets its length to 0.
         */
        release(): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Buffer.byteOrder> property.
         * @deprecated Set the value using <Titanium.Buffer.byteOrder> instead.
         */
        setByteOrder(byteOrder: number): void;

        /**
         * Sets the value of the <Titanium.Buffer.length> property.
         * @deprecated Set the value using <Titanium.Buffer.length> instead.
         */
        setLength(length: number): void;

        /**
         * Sets the value of the <Titanium.Buffer.type> property.
         * @deprecated Set the value using <Titanium.Buffer.type> instead.
         */
        setType(type: string): void;

        /**
         * Sets the value of the <Titanium.Buffer.value> property.
         * @deprecated Set the value using <Titanium.Buffer.value> instead.
         */
        setValue(value: number | string): void;

        /**
         * Converts this buffer to a <Titanium.Blob>.
         */
        toBlob(): Titanium.Blob;

        /**
         * Converts this buffer to a String.
         */
        toString(): string;

    }
    /**
     * Wrapper around <Titanium.Buffer> that implements the <Titanium.IOStream> interface.
     */
    class BufferStream extends Titanium.IOStream {
        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

    }
    /**
     * Base event for class Titanium.Calendar
     */
    interface CalendarBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Calendar;

    }
    /**
     * Fired when the database backing the EventKit module is modified.
     */
    interface Calendar_change_Event extends CalendarBaseEvent {
    }
    interface CalendarEventMap extends ProxyEventMap {
        change: Calendar_change_Event;

    }
    /**
     * The Calendar module provides an API for accessing the native calendar functionality.
     */
    class Calendar extends Titanium.Module {
        /**
         * All alerts in selected calendars.
         */
        static readonly allAlerts: Titanium.Calendar.Alert[];

        /**
         * All calendars known to the native calendar app.
         */
        static readonly allCalendars: Titanium.Calendar.Calendar[];

        /**
         * All calendars known to the native calendar app that can add, edit, and
         * delete items in the calendar.
         */
        static readonly allEditableCalendars: Titanium.Calendar.Calendar[];

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Returns an authorization constant indicating if the application has access to the events in the EventKit.
         */
        static readonly calendarAuthorization: number;

        /**
         * Calendar that events are added to by default, as specified by user settings.
         */
        static readonly defaultCalendar: Titanium.Calendar.Calendar;

        /**
         * Returns an authorization constant indicating if the application has access to the events in the EventKit.
         * @deprecated Use [Titanium.Calendar.calendarAuthorization](Titanium.Calendar.calendarAuthorization) instead.
         */
        static readonly eventsAuthorization: never;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * All calendars selected within the native calendar app, which may be a subset of `allCalendars`.
         */
        static readonly selectableCalendars: Titanium.Calendar.Calendar[];

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof CalendarEventMap>(name: K, callback: (this: Titanium.Calendar, event: CalendarEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof CalendarEventMap>(name: K, event?: CalendarEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Calendar.allAlerts> property.
         * @deprecated Access <Titanium.Calendar.allAlerts> instead.
         */
        static getAllAlerts(): Titanium.Calendar.Alert[];

        /**
         * Gets the value of the <Titanium.Calendar.allCalendars> property.
         * @deprecated Access <Titanium.Calendar.allCalendars> instead.
         */
        static getAllCalendars(): Titanium.Calendar.Calendar[];

        /**
         * Gets the value of the <Titanium.Calendar.allEditableCalendars> property.
         * @deprecated Access <Titanium.Calendar.allEditableCalendars> instead.
         */
        static getAllEditableCalendars(): Titanium.Calendar.Calendar[];

        /**
         * Gets the value of the <Titanium.Calendar.apiName> property.
         * @deprecated Access <Titanium.Calendar.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Calendar.bubbleParent> property.
         * @deprecated Access <Titanium.Calendar.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Calendar.calendarAuthorization> property.
         * @deprecated Access <Titanium.Calendar.calendarAuthorization> instead.
         */
        static getCalendarAuthorization(): number;

        /**
         * Gets the calendar with the specified identifier.
         */
        static getCalendarById(id: string): Titanium.Calendar.Calendar;

        /**
         * Gets the value of the <Titanium.Calendar.defaultCalendar> property.
         * @deprecated Access <Titanium.Calendar.defaultCalendar> instead.
         */
        static getDefaultCalendar(): Titanium.Calendar.Calendar;

        /**
         * Gets the value of the <Titanium.Calendar.eventsAuthorization> property.
         * @deprecated Use [Titanium.Calendar.calendarAuthorization](Titanium.Calendar.calendarAuthorization) instead.
         */
        static getEventsAuthorization: never;

        /**
         * Gets the value of the <Titanium.Calendar.lifecycleContainer> property.
         * @deprecated Access <Titanium.Calendar.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Calendar.selectableCalendars> property.
         * @deprecated Access <Titanium.Calendar.selectableCalendars> instead.
         */
        static getSelectableCalendars(): Titanium.Calendar.Calendar[];

        /**
         * Returns `true` if the app has calendar access.
         */
        static hasCalendarPermissions(): boolean;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof CalendarEventMap>(name: K, callback: (this: Titanium.Calendar, event: CalendarEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Requests for calendar access.
         */
        static requestCalendarPermissions(callback: (param0: EventsAuthorizationResponse) => void): void;

        /**
         * If authorization is unknown, the system will bring up a dialog requesting permission.
         * @deprecated Use [Titanium.Calendar.requestCalendarPermissions](Titanium.Calendar.requestCalendarPermissions) instead.
         */
        static requestEventsAuthorization: never;

        /**
         * Sets the value of the <Titanium.Calendar.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Calendar.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Calendar.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Calendar.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * A module for translating between primitive types and raw byte streams.
     */
    class Codec extends Titanium.Module {
        /**
         * Big endian (network) byte order -- that is, the most significant byte first.
         */
        static readonly BIG_ENDIAN: number;

        /**
         * ASCII character encoding..
         */
        static readonly CHARSET_ASCII: string;

        /**
         * ISO 8859-1 (Latin-1) character encoding.
         */
        static readonly CHARSET_ISO_LATIN_1: string;

        /**
         * UTF-16 character encoding with default byte order.
         */
        static readonly CHARSET_UTF16: string;

        /**
         * UTF-16 character encoding with big endian byte order.
         */
        static readonly CHARSET_UTF16BE: string;

        /**
         * UTF-16 character encoding with little endian byte order.
         */
        static readonly CHARSET_UTF16LE: string;

        /**
         * UTF-8 character encoding.
         */
        static readonly CHARSET_UTF8: string;

        /**
         * Little endian byte order -- that is, the least significant byte first.
         */
        static readonly LITTLE_ENDIAN: number;

        /**
         * 8-bit integer encoding type.
         */
        static readonly TYPE_BYTE: string;

        /**
         * 64-bit double precision floating-point type.
         */
        static readonly TYPE_DOUBLE: string;

        /**
         * 32-bit single precision floating-point type.
         */
        static readonly TYPE_FLOAT: string;

        /**
         * 32-bit integer encoding type.
         */
        static readonly TYPE_INT: string;

        /**
         * 64-bit integer encoding type.
         */
        static readonly TYPE_LONG: string;

        /**
         * 16-bit integer encoding type.
         */
        static readonly TYPE_SHORT: string;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Decodes a number from the `source` buffer using the specified data type.
         */
        static decodeNumber(options: DecodeNumberDict): number;

        /**
         * Decodes the source buffer into a String using the supplied character set.
         */
        static decodeString(options: DecodeStringDict): string;

        /**
         * Encodes a number and writes it to a buffer.
         */
        static encodeNumber(options: EncodeNumberDict): number;

        /**
         * Encodes a string into a series of bytes in a buffer using the specified character set.
         */
        static encodeString(options: Dictionary<EncodeStringDict>): number;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Codec.apiName> property.
         * @deprecated Access <Titanium.Codec.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Codec.bubbleParent> property.
         * @deprecated Access <Titanium.Codec.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Codec.lifecycleContainer> property.
         * @deprecated Access <Titanium.Codec.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Get the OS native byte order (either <Titanium.Codec.BIG_ENDIAN> or
         * <Titanium.Codec.LITTLE_ENDIAN>).
         */
        static getNativeByteOrder(): number;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Codec.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Codec.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Codec.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Codec.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Base event for class Titanium.Contacts
     */
    interface ContactsBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Contacts;

    }
    /**
     * Fired when the database backing the contacts module is modified externally.
     */
    interface Contacts_reload_Event extends ContactsBaseEvent {
    }
    interface ContactsEventMap extends ProxyEventMap {
        reload: Contacts_reload_Event;

    }
    /**
     * The top-level Contacts module, used for accessing and modifying the system contacts address book.
     */
    class Contacts extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Returns an authorization constant indicating if the application has access to the address book.
         */
        static readonly contactsAuthorization: number;

        /**
         * A boolean value that indicates whether to fetch the notes stored in contacts or not.
         */
        static includeNote: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof ContactsEventMap>(name: K, callback: (this: Titanium.Contacts, event: ContactsEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Creates and returns an instance of <Titanium.Contacts.Group>.
         */
        static createGroup(parameters?: Dictionary<Titanium.Contacts.Group>): Titanium.Contacts.Group;

        /**
         * Creates and returns an instance of <Titanium.Contacts.Person>, and commits all pending
         * changes to the underlying contacts database.
         */
        static createPerson(parameters?: Dictionary<Titanium.Contacts.Person>): Titanium.Contacts.Person;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof ContactsEventMap>(name: K, event?: ContactsEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets all groups.
         */
        static getAllGroups(): Titanium.Contacts.Group[];

        /**
         * Gets all people, unless a limit is specified.
         */
        static getAllPeople(limit: number): Titanium.Contacts.Person[];

        /**
         * Gets the value of the <Titanium.Contacts.apiName> property.
         * @deprecated Access <Titanium.Contacts.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Contacts.bubbleParent> property.
         * @deprecated Access <Titanium.Contacts.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Contacts.contactsAuthorization> property.
         * @deprecated Access <Titanium.Contacts.contactsAuthorization> instead.
         */
        static getContactsAuthorization(): number;

        /**
         * Gets the group with the specified identifier.
         * @deprecated Use [Titanium.Contacts.getGroupByIdentifier](Titanium.Contacts.getGroupByIdentifier) instead.
         */
        static getGroupByID: never;

        /**
         * Gets the group with the specified identifier.
         */
        static getGroupByIdentifier(id: string): Titanium.Contacts.Group;

        /**
         * Gets the value of the <Titanium.Contacts.includeNote> property.
         * @deprecated Access <Titanium.Contacts.includeNote> instead.
         */
        static getIncludeNote(): boolean;

        /**
         * Gets the value of the <Titanium.Contacts.lifecycleContainer> property.
         * @deprecated Access <Titanium.Contacts.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets people with a `firstName`, `middleName` or `lastName` field, or a combination
         * of these fields, that match the specified name.
         */
        static getPeopleWithName(name: string): Titanium.Contacts.Person[];

        /**
         * Gets the person with the specified identifier.
         * @deprecated Use [Titanium.Contacts.getPersonByIdentifier](Titanium.Contacts.getPersonByIdentifier) instead.
         */
        static getPersonByID: never;

        /**
         * Gets the person with the specified identifier.
         */
        static getPersonByIdentifier(id: number): Titanium.Contacts.Person;

        /**
         * Returns `true` if the app has contacts access.
         */
        static hasContactsPermissions(): boolean;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof ContactsEventMap>(name: K, callback: (this: Titanium.Contacts, event: ContactsEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Removes a group from the address book.
         */
        static removeGroup(group: Titanium.Contacts.Group): void;

        /**
         * Removes a contact from the address book.
         */
        static removePerson(person: Titanium.Contacts.Person): void;

        /**
         * If authorization is unknown, will bring up a dialog requesting permission.
         * @deprecated Use [Titanium.Contacts.requestContactsPermissions](Titanium.Contacts.requestContactsPermissions) instead.
         */
        static requestAuthorization: never;

        /**
         * Requests for contacts access.
         */
        static requestContactsPermissions(callback: (param0: ContactsAuthorizationResponse) => void): void;

        /**
         * Reverts all changes made by the previous save to the address book. Deprecated for >= iOS9.
         */
        static revert(): void;

        /**
         * Commits all pending changes to the underlying contacts database.
         */
        static save(contacts: ReadonlyArray<Titanium.Contacts.Person>): void;

        /**
         * Sets the value of the <Titanium.Contacts.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Contacts.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Contacts.includeNote> property.
         * @deprecated Set the value using <Titanium.Contacts.includeNote> instead.
         */
        static setIncludeNote(includeNote: boolean): void;

        /**
         * Sets the value of the <Titanium.Contacts.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Contacts.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Displays a picker that allows a person to be selected.
         */
        static showContacts(params: showContactsParams): void;

    }
    /**
     * The top-level `Database` module, used for creating and accessing the
     * in-application SQLite database.
     */
    class Database extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Database.apiName> property.
         * @deprecated Access <Titanium.Database.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Database.bubbleParent> property.
         * @deprecated Access <Titanium.Database.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Database.lifecycleContainer> property.
         * @deprecated Access <Titanium.Database.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Installs an SQLite database to device's internal storage.
         */
        static install(path: string, dbName: string): Titanium.Database.DB;

        /**
         * Opens an SQLite database.
         */
        static open(dbName: string): Titanium.Database.DB;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Database.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Database.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Database.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Database.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * The base type for all Titanium events.
     */
    interface Event {
        /**
         * True if the event will try to bubble up if possible.
         */
        readonly bubbles: boolean;

        /**
         * Set to true to stop the event from bubbling.
         */
        cancelBubble: boolean;

        /**
         * Source object that fired the event.
         */
        readonly source: any;

        /**
         * Name of the event fired.
         */
        readonly type: string;

    }
    /**
     * The top level filesystem module, used to access files and directories on the device.
     */
    class Filesystem extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Path to the application's internal cache directory.
         */
        static readonly applicationCacheDirectory: string;

        /**
         * Path to the application's data directory.
         */
        static readonly applicationDataDirectory: string;

        /**
         * Path to the iOS application directory.
         */
        static readonly applicationDirectory: string;

        /**
         * Path to the application support directory.
         */
        static readonly applicationSupportDirectory: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Path to a directory on removable storage, such as SD card.
         */
        static readonly externalStorageDirectory: string;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Platform-specific line ending constant.
         */
        static readonly lineEnding: string;

        /**
         * Path to the application's raw resource directory.
         */
        static readonly resRawDirectory: string;

        /**
         * Path to the application's resource directory.
         */
        static readonly resourcesDirectory: string;

        /**
         * Platform-specific path separator constant.
         */
        static readonly separator: string;

        /**
         * Path for the application's temporary directory.
         */
        static readonly tempDirectory: string;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Creates a temporary directory and returns a [File](Titanium.Filesystem.File) object representing the new directory.
         */
        static createTempDirectory(): Titanium.Filesystem.File;

        /**
         * Creates a temporary file and returns a [File](Titanium.Filesystem.File) object representing the new file.
         */
        static createTempFile(): Titanium.Filesystem.File;

        /**
         * Returns the path to the container directory associated with the specified security application group ID.
         */
        static directoryForSuite(suiteName: string): string;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Filesystem.apiName> property.
         * @deprecated Access <Titanium.Filesystem.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.applicationCacheDirectory> property.
         * @deprecated Access <Titanium.Filesystem.applicationCacheDirectory> instead.
         */
        static getApplicationCacheDirectory(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.applicationDataDirectory> property.
         * @deprecated Access <Titanium.Filesystem.applicationDataDirectory> instead.
         */
        static getApplicationDataDirectory(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.applicationDirectory> property.
         * @deprecated Access <Titanium.Filesystem.applicationDirectory> instead.
         */
        static getApplicationDirectory(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.applicationSupportDirectory> property.
         * @deprecated Access <Titanium.Filesystem.applicationSupportDirectory> instead.
         */
        static getApplicationSupportDirectory(): string;

        /**
         * Returns a `Blob` object representing the asset catalog image identified by the path arguments.
         */
        static getAsset(...path: string[]): Titanium.Blob;

        /**
         * Gets the value of the <Titanium.Filesystem.bubbleParent> property.
         * @deprecated Access <Titanium.Filesystem.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Filesystem.externalStorageDirectory> property.
         * @deprecated Access <Titanium.Filesystem.externalStorageDirectory> instead.
         */
        static getExternalStorageDirectory(): string;

        /**
         * Returns a `File` object representing the file identified by the path arguments.
         */
        static getFile(...path: string[]): Titanium.Filesystem.File;

        /**
         * Returns a `File` object representing the file identified by the path arguments.
         */
        static getFile(path: ReadonlyArray<string>): Titanium.Filesystem.File;

        /**
         * Gets the value of the <Titanium.Filesystem.lifecycleContainer> property.
         * @deprecated Access <Titanium.Filesystem.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Filesystem.lineEnding> property.
         * @deprecated Access <Titanium.Filesystem.lineEnding> instead.
         */
        static getLineEnding(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.resRawDirectory> property.
         * @deprecated Access <Titanium.Filesystem.resRawDirectory> instead.
         */
        static getResRawDirectory(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.resourcesDirectory> property.
         * @deprecated Access <Titanium.Filesystem.resourcesDirectory> instead.
         */
        static getResourcesDirectory(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.separator> property.
         * @deprecated Access <Titanium.Filesystem.separator> instead.
         */
        static getSeparator(): string;

        /**
         * Gets the value of the <Titanium.Filesystem.tempDirectory> property.
         * @deprecated Access <Titanium.Filesystem.tempDirectory> instead.
         */
        static getTempDirectory(): string;

        /**
         * Returns `true` if the app has storage permissions.
         */
        static hasStoragePermissions(): boolean;

        /**
         * Returns `true` if the device supports external storage *and* the external storage device is mounted.
         */
        static isExternalStoragePresent(): boolean;

        /**
         * Opens file using the <Titanium.IOStream> interface.
         */
        static openStream(mode: number, path: string): Titanium.Filesystem.FileStream;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Requests for storage permissions
         */
        static requestStoragePermissions(callback: (param0: RequestStorageAccessResult) => void): void;

        /**
         * Sets the value of the <Titanium.Filesystem.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Filesystem.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Filesystem.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Filesystem.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Base event for class Titanium.Geolocation
     */
    interface GeolocationBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Geolocation;

    }
    /**
     * Fired when the device detects interface and requires calibration.
     */
    interface Geolocation_calibration_Event extends GeolocationBaseEvent {
    }
    /**
     * Fired when an heading update is received.
     */
    interface Geolocation_heading_Event extends GeolocationBaseEvent {
        /**
         * If `success` is `false`, the error code is available.
         */
        code: number;

        /**
         * If `success` is false, a string describing the error.
         */
        error: string;

        /**
         * Dictionary object containing the heading data.
         */
        heading: HeadingData;

        /**
         * Indicate if the heading event was successfully received. Android returns this since SDK 7.5.0.
         */
        success: boolean;

    }
    /**
     * Fired when a location update is received.
     */
    interface Geolocation_location_Event extends GeolocationBaseEvent {
        /**
         * if `success` is false, the error code if available.
         */
        code: number;

        /**
         * If `success` is true, actual location data for this update.
         */
        coords: LocationCoordinates;

        /**
         * If `success` is false, a string describing the error.
         */
        error: string;

        /**
         * If `success` is true, object describing the location provider generating this update.
         */
        provider: LocationProviderDict;

        /**
         * Indicates if location data was successfully retrieved.
         */
        success: boolean;

    }
    /**
     * Fired when location updates are paused by the OS.
     */
    interface Geolocation_locationupdatepaused_Event extends GeolocationBaseEvent {
    }
    /**
     * Fired when location manager is resumed by the OS.
     */
    interface Geolocation_locationupdateresumed_Event extends GeolocationBaseEvent {
    }
    /**
     * Fired when changes are made to the authorization status for location services.
     */
    interface Geolocation_authorization_Event extends GeolocationBaseEvent {
        /**
         * New authorization status for the application.
         */
        authorizationStatus: number;

    }
    interface GeolocationEventMap extends ProxyEventMap {
        authorization: Geolocation_authorization_Event;

        calibration: Geolocation_calibration_Event;

        heading: Geolocation_heading_Event;

        location: Geolocation_location_Event;

        locationupdatepaused: Geolocation_locationupdatepaused_Event;

        locationupdateresumed: Geolocation_locationupdateresumed_Event;

    }
    /**
     * The top level Geolocation module. The Geolocation module is used for accessing device location based information.
     */
    class Geolocation extends Titanium.Module {
        /**
         * Specifies the requested accuracy for location updates.
         */
        static accuracy: number;

        /**
         * The type of user activity to be associated with the location updates.
         */
        static activityType: number;

        /**
         * Determines if the app can do background location updates.
         */
        static allowsBackgroundLocationUpdates: boolean;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The minimum change of position (in meters) before a 'location' event is fired.
         */
        static distanceFilter: number;

        /**
         * Requested frequency for location updates, in milliseconds.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static frequency: number;

        /**
         * Indicates whether the current device supports a compass.
         */
        static readonly hasCompass: boolean;

        /**
         * Minimum heading change (in degrees) before a `heading` event is fired.
         */
        static headingFilter: number;

        /**
         * JSON representation of the last geolocation received.
         */
        static readonly lastGeolocation: string;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * A value that indicates the level of location accuracy the app has permission to use.
         */
        static readonly locationAccuracyAuthorization: number;

        /**
         * Returns an authorization constant indicating if the application has access to location services.
         */
        static readonly locationServicesAuthorization: number;

        /**
         * Indicates if the user has enabled or disabled location services for the device (not the application).
         */
        static readonly locationServicesEnabled: boolean;

        /**
         * Indicates whether the location updates may be paused.
         */
        static pauseLocationUpdateAutomatically: boolean;

        /**
         * Determines the preferred location provider.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static preferredProvider: string;

        /**
         * Specifies that an indicator be shown when the app makes use of continuous
         * background location updates.
         */
        static showBackgroundLocationIndicator: boolean;

        /**
         * Determines whether the compass calibration UI is shown if needed.
         */
        static showCalibration: boolean;

        /**
         * Indicates if the location changes should be updated only when a significant change
         * in location occurs.
         */
        static trackSignificantLocationChange: boolean;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof GeolocationEventMap>(name: K, callback: (this: Titanium.Geolocation, event: GeolocationEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof GeolocationEventMap>(name: K, event?: GeolocationEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Resolves an address to a location.
         */
        static forwardGeocoder(address: string, callback: (param0: ForwardGeocodeResponse) => void): void;

        /**
         * Gets the value of the <Titanium.Geolocation.accuracy> property.
         * @deprecated Access <Titanium.Geolocation.accuracy> instead.
         */
        static getAccuracy(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.activityType> property.
         * @deprecated Access <Titanium.Geolocation.activityType> instead.
         */
        static getActivityType(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.allowsBackgroundLocationUpdates> property.
         * @deprecated Access <Titanium.Geolocation.allowsBackgroundLocationUpdates> instead.
         */
        static getAllowsBackgroundLocationUpdates(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.apiName> property.
         * @deprecated Access <Titanium.Geolocation.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Geolocation.bubbleParent> property.
         * @deprecated Access <Titanium.Geolocation.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Retrieves the current compass heading.
         */
        static getCurrentHeading(callback: (param0: HeadingResponse) => void): void;

        /**
         * Retrieves the last known location from the device.
         */
        static getCurrentPosition(callback: (param0: LocationResults) => void): void;

        /**
         * Gets the value of the <Titanium.Geolocation.distanceFilter> property.
         * @deprecated Access <Titanium.Geolocation.distanceFilter> instead.
         */
        static getDistanceFilter(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.frequency> property.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static getFrequency(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.hasCompass> property.
         * @deprecated Access <Titanium.Geolocation.hasCompass> instead.
         */
        static getHasCompass(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.headingFilter> property.
         * @deprecated Access <Titanium.Geolocation.headingFilter> instead.
         */
        static getHeadingFilter(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.lastGeolocation> property.
         * @deprecated Access <Titanium.Geolocation.lastGeolocation> instead.
         */
        static getLastGeolocation(): string;

        /**
         * Gets the value of the <Titanium.Geolocation.lifecycleContainer> property.
         * @deprecated Access <Titanium.Geolocation.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Geolocation.locationAccuracyAuthorization> property.
         * @deprecated Access <Titanium.Geolocation.locationAccuracyAuthorization> instead.
         */
        static getLocationAccuracyAuthorization(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.locationServicesAuthorization> property.
         * @deprecated Access <Titanium.Geolocation.locationServicesAuthorization> instead.
         */
        static getLocationServicesAuthorization(): number;

        /**
         * Gets the value of the <Titanium.Geolocation.locationServicesEnabled> property.
         * @deprecated Access <Titanium.Geolocation.locationServicesEnabled> instead.
         */
        static getLocationServicesEnabled(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.pauseLocationUpdateAutomatically> property.
         * @deprecated Access <Titanium.Geolocation.pauseLocationUpdateAutomatically> instead.
         */
        static getPauseLocationUpdateAutomatically(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.preferredProvider> property.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static getPreferredProvider(): string;

        /**
         * Gets the value of the <Titanium.Geolocation.showBackgroundLocationIndicator> property.
         * @deprecated Access <Titanium.Geolocation.showBackgroundLocationIndicator> instead.
         */
        static getShowBackgroundLocationIndicator(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.showCalibration> property.
         * @deprecated Access <Titanium.Geolocation.showCalibration> instead.
         */
        static getShowCalibration(): boolean;

        /**
         * Gets the value of the <Titanium.Geolocation.trackSignificantLocationChange> property.
         * @deprecated Access <Titanium.Geolocation.trackSignificantLocationChange> instead.
         */
        static getTrackSignificantLocationChange(): boolean;

        /**
         * Returns `true` if the app has location access.
         */
        static hasLocationPermissions(authorizationType: number): boolean;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof GeolocationEventMap>(name: K, callback: (this: Titanium.Geolocation, event: GeolocationEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Requests for location access.
         */
        static requestLocationPermissions(authorizationType: number, callback: (param0: LocationAuthorizationResponse) => void): void;

        /**
         * Requests the user's permission to temporarily use location services with full accuracy.
         */
        static requestTemporaryFullAccuracyAuthorization(purposeKey: string, callback: (param0: LocationAccuracyAuthorizationResponse) => void): void;

        /**
         * Tries to resolve a location to an address.
         */
        static reverseGeocoder(latitude: number, longitude: number, callback: (param0: ReverseGeocodeResponse) => void): void;

        /**
         * Sets the value of the <Titanium.Geolocation.accuracy> property.
         * @deprecated Set the value using <Titanium.Geolocation.accuracy> instead.
         */
        static setAccuracy(accuracy: number): void;

        /**
         * Sets the value of the <Titanium.Geolocation.activityType> property.
         * @deprecated Set the value using <Titanium.Geolocation.activityType> instead.
         */
        static setActivityType(activityType: number): void;

        /**
         * Sets the value of the <Titanium.Geolocation.allowsBackgroundLocationUpdates> property.
         * @deprecated Set the value using <Titanium.Geolocation.allowsBackgroundLocationUpdates> instead.
         */
        static setAllowsBackgroundLocationUpdates(allowsBackgroundLocationUpdates: boolean): void;

        /**
         * Sets the value of the <Titanium.Geolocation.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Geolocation.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Geolocation.distanceFilter> property.
         * @deprecated Set the value using <Titanium.Geolocation.distanceFilter> instead.
         */
        static setDistanceFilter(distanceFilter: number): void;

        /**
         * Sets the value of the <Titanium.Geolocation.frequency> property.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static setFrequency(frequency: number): void;

        /**
         * Sets the value of the <Titanium.Geolocation.headingFilter> property.
         * @deprecated Set the value using <Titanium.Geolocation.headingFilter> instead.
         */
        static setHeadingFilter(headingFilter: number): void;

        /**
         * Sets the value of the <Titanium.Geolocation.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Geolocation.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Sets the value of the <Titanium.Geolocation.pauseLocationUpdateAutomatically> property.
         * @deprecated Set the value using <Titanium.Geolocation.pauseLocationUpdateAutomatically> instead.
         */
        static setPauseLocationUpdateAutomatically(pauseLocationUpdateAutomatically: boolean): void;

        /**
         * Sets the value of the <Titanium.Geolocation.preferredProvider> property.
         * @deprecated Android legacy mode operation is deprecated. For new development, use
         * either simple mode or manual mode. See "Configurating Location Updates on Android"
         * in the main description of this class for more information.
         *
         */
        static setPreferredProvider(preferredProvider: string): void;

        /**
         * Sets the value of the <Titanium.Geolocation.showBackgroundLocationIndicator> property.
         * @deprecated Set the value using <Titanium.Geolocation.showBackgroundLocationIndicator> instead.
         */
        static setShowBackgroundLocationIndicator(showBackgroundLocationIndicator: boolean): void;

        /**
         * Sets the value of the <Titanium.Geolocation.showCalibration> property.
         * @deprecated Set the value using <Titanium.Geolocation.showCalibration> instead.
         */
        static setShowCalibration(showCalibration: boolean): void;

        /**
         * Sets the value of the <Titanium.Geolocation.trackSignificantLocationChange> property.
         * @deprecated Set the value using <Titanium.Geolocation.trackSignificantLocationChange> instead.
         */
        static setTrackSignificantLocationChange(trackSignificantLocationChange: boolean): void;

    }
    /**
     * Base event for class Titanium.Gesture
     */
    interface GestureBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Gesture;

    }
    /**
     * Fired when the device orientation changes.
     */
    interface Gesture_orientationchange_Event extends GestureBaseEvent {
        /**
         * Orientation of the device.
         */
        orientation: number;

    }
    /**
     * Fired when the device is shaken.
     */
    interface Gesture_shake_Event extends GestureBaseEvent {
        /**
         * Time interval since previous shake event. On iOS, this value is 0 for the first shake
         * event in a series.
         */
        timestamp: number;

        /**
         * Acceleration along the X axis, in Gs.
         */
        x: number;

        /**
         * Acceleration along the Y axis, in Gs.
         */
        y: number;

        /**
         * Acceleration along the Z axis, in Gs.
         */
        z: number;

    }
    interface GestureEventMap extends ProxyEventMap {
        orientationchange: Gesture_orientationchange_Event;

        shake: Gesture_shake_Event;

    }
    /**
     * The Gesture module is responsible for high-level device gestures such as orientation changes
     * and shake gestures.
     */
    class Gesture extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Indicates if the device is currently held in landscape form.
         */
        static readonly landscape: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Orientation of the device.
         */
        static readonly orientation: number;

        /**
         * Indicates if the device is currently held in portrait form.
         */
        static readonly portrait: boolean;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof GestureEventMap>(name: K, callback: (this: Titanium.Gesture, event: GestureEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof GestureEventMap>(name: K, event?: GestureEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Gesture.apiName> property.
         * @deprecated Access <Titanium.Gesture.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Gesture.bubbleParent> property.
         * @deprecated Access <Titanium.Gesture.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Gesture.lifecycleContainer> property.
         * @deprecated Access <Titanium.Gesture.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Gesture.orientation> property.
         * @deprecated Access <Titanium.Gesture.orientation> instead.
         */
        static getOrientation(): number;

        /**
         * Returns whether or not the device is currently held in landscape form.
         * @deprecated Use [Titanium.Gesture.landscape](Titanium.Gesture.landscape) for parity instead. Removed in 7.0.0 on Android, 8.1.0 on iOS.
         */
        static isLandscape: never;

        /**
         * Returns whether or not the device is currently held in portrait form.
         * @deprecated Use [Titanium.Gesture.portrait](Titanium.Gesture.portrait) for parity instead. Removed in 7.0.0 on Android, 8.1.0 on iOS.
         */
        static isPortrait: never;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof GestureEventMap>(name: K, callback: (this: Titanium.Gesture, event: GestureEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Gesture.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Gesture.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Gesture.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Gesture.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * IOStream is the interface that all stream types implement.
     */
    class IOStream extends Titanium.Proxy {
        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Closes this stream.
         */
        close(): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Indicates whether this stream is readable.
         */
        isReadable(): boolean;

        /**
         * Indicates whether this stream is writable.
         */
        isWritable(): boolean;

        /**
         * Reads data from this stream into a buffer.
         */
        read(buffer: Titanium.Buffer, offset?: number, length?: number, resultsCallback?: (param0: ReadCallbackArgs) => void): number;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Writes data from a buffer to this stream.
         */
        write(buffer: Titanium.Buffer, offset?: number, length?: number, resultsCallback?: (param0: WriteCallbackArgs) => void): number;

    }
    /**
     * Base event for class Titanium.Locale
     */
    interface LocaleBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Locale;

    }
    /**
     * Fired when the device locale changes.
     */
    interface Locale_change_Event extends LocaleBaseEvent {
    }
    interface LocaleEventMap extends ProxyEventMap {
        change: Locale_change_Event;

    }
    /**
     * The top level Locale module.
     */
    class Locale extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Country of the current system locale, as an ISO 2-letter code.
         */
        static readonly currentCountry: string;

        /**
         * Language of the current system locale, as an ISO 2-letter code.
         */
        static readonly currentLanguage: string;

        /**
         * Current system locale, as a combination of ISO 2-letter language and country codes.
         */
        static readonly currentLocale: string;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof LocaleEventMap>(name: K, callback: (this: Titanium.Locale, event: LocaleEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof LocaleEventMap>(name: K, event?: LocaleEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Formats a telephone number according to the current system locale.
         */
        static formatTelephoneNumber(number: string): string;

        /**
         * Gets the value of the <Titanium.Locale.apiName> property.
         * @deprecated Access <Titanium.Locale.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Locale.bubbleParent> property.
         * @deprecated Access <Titanium.Locale.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Returns the ISO 3-letter currency code for the specified locale.
         */
        static getCurrencyCode(locale: string): string;

        /**
         * Returns the currency symbol for the specified currency code.
         */
        static getCurrencySymbol(currencyCode: string): string;

        /**
         * Gets the value of the <Titanium.Locale.currentCountry> property.
         * @deprecated Access <Titanium.Locale.currentCountry> instead.
         */
        static getCurrentCountry(): string;

        /**
         * Gets the value of the <Titanium.Locale.currentLanguage> property.
         * @deprecated Access <Titanium.Locale.currentLanguage> instead.
         */
        static getCurrentLanguage(): string;

        /**
         * Gets the value of the <Titanium.Locale.currentLocale> property.
         * @deprecated Access <Titanium.Locale.currentLocale> instead.
         */
        static getCurrentLocale(): string;

        /**
         * Gets the value of the <Titanium.Locale.lifecycleContainer> property.
         * @deprecated Access <Titanium.Locale.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Returns the currency symbol for the specified locale.
         */
        static getLocaleCurrencySymbol(locale: string): string;

        /**
         * Returns a string, localized according to the current system locale using the appropriate
         * `/i18n/LANG/strings.xml` localization file.
         */
        static getString(key: string, hint?: string): string;

        /**
         * Parses a number from the given string using the current or given locale.
         */
        static parseDecimal(text: string, locale?: string): number;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof LocaleEventMap>(name: K, callback: (this: Titanium.Locale, event: LocaleEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Locale.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Locale.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the current language of the application.
         */
        static setLanguage(language: string): void;

        /**
         * Sets the value of the <Titanium.Locale.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Locale.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Base event for class Titanium.Media
     */
    interface MediaBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Media;

    }
    /**
     * Fires when the camera overlay is ready to take pictures.
     */
    interface Media_cameraready_Event extends MediaBaseEvent {
    }
    /**
     * Fired when an audio line type change is detected.
     */
    interface Media_routechange_Event extends MediaBaseEvent {
        /**
         * Returns a description of the current route, consisting of zero or more input ports and zero or more output ports.
         */
        currentRoute: RouteDescription;

        /**
         * Returns a description of the old route, consisting of zero or more input ports and zero or more output ports.
         */
        oldRoute: RouteDescription;

        /**
         * The reason for route change.
         */
        reason: string;

    }
    /**
     * Fired when the volume output changes.
     */
    interface Media_volume_Event extends MediaBaseEvent {
        /**
         * New volume level in dB.
         */
        volume: number;

    }
    interface MediaEventMap extends ProxyEventMap {
        cameraready: Media_cameraready_Event;

        routechange: Media_routechange_Event;

        volume: Media_volume_Event;

    }
    /**
     * The top-level Media module.
     */
    class Media extends Titanium.Module {
        /**
         * Media type constant for medium-quality video recording.
         */
        static readonly QUALITY_640x480: number;

        /**
         * Media type constant for medium-quality video recording.
         */
        static readonly QUALITY_IFRAME_1280x720: number;

        /**
         * Media type constant for medium-quality video recording.
         */
        static readonly QUALITY_IFRAME_960x540: number;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * An instance of <Titanium.Media.MusicPlayer> representing the app-specific music player.
         */
        static readonly appMusicPlayer: Titanium.Media.MusicPlayer;

        /**
         * Returns the line type constant for the current line type.
         * @deprecated Use [Titanium.Media.currentRoute](Titanium.Media.currentRoute) instead.
         */
        static readonly audioLineType: never;

        /**
         * Returns `true` if the device is playing audio.
         */
        static readonly audioPlaying: boolean;

        /**
         * A constant for the audio session category to be used.
         */
        static audioSessionCategory: string;

        /**
         * A constant for the audio session mode to be used.
         * @deprecated Use [Titanium.Media.audioSessionCategory](Titanium.Media.audioSessionCategory) instead.
         */
        static audioSessionMode: never;

        /**
         * Array of media type constants supported for the camera.
         */
        static availableCameraMediaTypes: any[];

        /**
         * Array indicating which cameras are available, `CAMERA_FRONT`, `CAMERA_REAR` or both.
         */
        static readonly availableCameras: number[];

        /**
         * Array of media type constants supported for saving to the device's camera roll or saved images album.
         */
        static availablePhotoGalleryMediaTypes: any[];

        /**
         * Array of media type constants supported for the photo library.
         */
        static availablePhotoMediaTypes: any[];

        /**
         * Current average microphone level in dB or -1 if microphone monitoring is disabled.
         */
        static averageMicrophonePower: number;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Returns the authorization status for the camera.
         */
        static readonly cameraAuthorization: number;

        /**
         * Returns the authorization status for the camera.
         * @deprecated Use [Titanium.Media.cameraAuthorization](Titanium.Media.cameraAuthorization) instead.
         */
        static readonly cameraAuthorizationStatus: never;

        /**
         * Determines how the flash is fired when using the device's camera.
         */
        static cameraFlashMode: number;

        /**
         * `true` if the device has a recording input device available.
         */
        static readonly canRecord: boolean;

        /**
         * Returns a description of the current route, consisting of zero or more input ports and zero or more output ports.
         */
        static readonly currentRoute: RouteDescription;

        /**
         * `true` if the device has camera support.
         */
        static readonly isCameraSupported: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Current microphone level peak power in dB or -1 if microphone monitoring is disabled.
         */
        static readonly peakMicrophonePower: number;

        /**
         * An instance of <Titanium.Media.MusicPlayer> representing the system-wide music player.
         */
        static readonly systemMusicPlayer: Titanium.Media.MusicPlayer;

        /**
         * Current volume of the playback device.
         */
        static readonly volume: number;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof MediaEventMap>(name: K, callback: (this: Titanium.Media, event: MediaEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Plays a device beep notification.
         */
        static beep(): void;

        /**
         * Creates and returns an instance of <Titanium.Media.AudioPlayer>.
         */
        static createAudioPlayer(parameters?: Dictionary<Titanium.Media.AudioPlayer>): Titanium.Media.AudioPlayer;

        /**
         * Creates and returns an instance of <Titanium.Media.AudioRecorder>.
         */
        static createAudioRecorder(parameters?: Dictionary<Titanium.Media.AudioRecorder>): Titanium.Media.AudioRecorder;

        /**
         * Creates and returns an instance of <Titanium.Media.Sound>.
         */
        static createSound(parameters?: Dictionary<Titanium.Media.Sound>): Titanium.Media.Sound;

        /**
         * Creates and returns an instance of <Titanium.Media.SystemAlert>.
         * @deprecated This iOS-only API has been deprecated and moved to the [Ti.SystemAlert](https://github.com/appcelerator-modules/ti.systemalert) module in 8.0.0.
         */
        static createSystemAlert(parameters?: Dictionary<Titanium.Media.SystemAlert>): Titanium.Media.SystemAlert;

        /**
         * Creates and returns an instance of <Titanium.Media.VideoPlayer>.
         */
        static createVideoPlayer(parameters?: Dictionary<Titanium.Media.VideoPlayer>): Titanium.Media.VideoPlayer;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof MediaEventMap>(name: K, event?: MediaEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Media.apiName> property.
         * @deprecated Access <Titanium.Media.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Media.appMusicPlayer> property.
         * @deprecated Access <Titanium.Media.appMusicPlayer> instead.
         */
        static getAppMusicPlayer(): Titanium.Media.MusicPlayer;

        /**
         * Gets the value of the <Titanium.Media.audioLineType> property.
         * @deprecated Use [Titanium.Media.currentRoute](Titanium.Media.currentRoute) instead.
         */
        static getAudioLineType: never;

        /**
         * Gets the value of the <Titanium.Media.audioPlaying> property.
         * @deprecated Access <Titanium.Media.audioPlaying> instead.
         */
        static getAudioPlaying(): boolean;

        /**
         * Gets the value of the <Titanium.Media.audioSessionCategory> property.
         * @deprecated Access <Titanium.Media.audioSessionCategory> instead.
         */
        static getAudioSessionCategory(): string;

        /**
         * Gets the value of the <Titanium.Media.audioSessionMode> property.
         * @deprecated Use [Titanium.Media.audioSessionCategory](Titanium.Media.audioSessionCategory) instead.
         */
        static getAudioSessionMode: never;

        /**
         * Gets the value of the <Titanium.Media.availableCameraMediaTypes> property.
         * @deprecated Access <Titanium.Media.availableCameraMediaTypes> instead.
         */
        static getAvailableCameraMediaTypes(): any[];

        /**
         * Gets the value of the <Titanium.Media.availableCameras> property.
         * @deprecated Access <Titanium.Media.availableCameras> instead.
         */
        static getAvailableCameras(): number[];

        /**
         * Gets the value of the <Titanium.Media.availablePhotoGalleryMediaTypes> property.
         * @deprecated Access <Titanium.Media.availablePhotoGalleryMediaTypes> instead.
         */
        static getAvailablePhotoGalleryMediaTypes(): any[];

        /**
         * Gets the value of the <Titanium.Media.availablePhotoMediaTypes> property.
         * @deprecated Access <Titanium.Media.availablePhotoMediaTypes> instead.
         */
        static getAvailablePhotoMediaTypes(): any[];

        /**
         * Gets the value of the <Titanium.Media.averageMicrophonePower> property.
         * @deprecated Access <Titanium.Media.averageMicrophonePower> instead.
         */
        static getAverageMicrophonePower(): number;

        /**
         * Gets the value of the <Titanium.Media.bubbleParent> property.
         * @deprecated Access <Titanium.Media.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Media.cameraAuthorization> property.
         * @deprecated Access <Titanium.Media.cameraAuthorization> instead.
         */
        static getCameraAuthorization(): number;

        /**
         * Gets the value of the <Titanium.Media.cameraAuthorizationStatus> property.
         * @deprecated Use [Titanium.Media.cameraAuthorization](Titanium.Media.cameraAuthorization) instead.
         */
        static getCameraAuthorizationStatus: never;

        /**
         * Gets the value of the <Titanium.Media.cameraFlashMode> property.
         * @deprecated Access <Titanium.Media.cameraFlashMode> instead.
         */
        static getCameraFlashMode(): number;

        /**
         * Gets the value of the <Titanium.Media.canRecord> property.
         * @deprecated Access <Titanium.Media.canRecord> instead.
         */
        static getCanRecord(): boolean;

        /**
         * Gets the value of the <Titanium.Media.currentRoute> property.
         * @deprecated Access <Titanium.Media.currentRoute> instead.
         */
        static getCurrentRoute(): RouteDescription;

        /**
         * Gets the value of the <Titanium.Media.isCameraSupported> property.
         * @deprecated Access <Titanium.Media.isCameraSupported> instead.
         */
        static getIsCameraSupported(): boolean;

        /**
         * Gets the value of the <Titanium.Media.lifecycleContainer> property.
         * @deprecated Access <Titanium.Media.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Media.peakMicrophonePower> property.
         * @deprecated Access <Titanium.Media.peakMicrophonePower> instead.
         */
        static getPeakMicrophonePower(): number;

        /**
         * Gets the value of the <Titanium.Media.QUALITY_640x480> property.
         * @deprecated Access <Titanium.Media.QUALITY_640x480> instead.
         */
        static getQUALITY_640x480(): number;

        /**
         * Gets the value of the <Titanium.Media.QUALITY_IFRAME_1280x720> property.
         * @deprecated Access <Titanium.Media.QUALITY_IFRAME_1280x720> instead.
         */
        static getQUALITY_IFRAME_1280x720(): number;

        /**
         * Gets the value of the <Titanium.Media.QUALITY_IFRAME_960x540> property.
         * @deprecated Access <Titanium.Media.QUALITY_IFRAME_960x540> instead.
         */
        static getQUALITY_IFRAME_960x540(): number;

        /**
         * Gets the value of the <Titanium.Media.systemMusicPlayer> property.
         * @deprecated Access <Titanium.Media.systemMusicPlayer> instead.
         */
        static getSystemMusicPlayer(): Titanium.Media.MusicPlayer;

        /**
         * Gets the value of the <Titanium.Media.volume> property.
         * @deprecated Access <Titanium.Media.volume> instead.
         */
        static getVolume(): number;

        /**
         * Returns `true` if the app has audio permissions.
         * @deprecated Use [Titanium.Media.hasAudioRecorderPermissions](Titanium.Media.hasAudioRecorderPermissions) instead.
         */
        static hasAudioPermissions(): boolean;

        /**
         * Returns `true` if the app has audio permissions.
         */
        static hasAudioRecorderPermissions(): boolean;

        /**
         * Returns `true` if the app has camera access.
         */
        static hasCameraPermissions(): boolean;

        /**
         * Returns `true` if the app has music library access.
         */
        static hasMusicLibraryPermissions(): boolean;

        /**
         * Returns `true` if the app has photo gallery permissions.
         */
        static hasPhotoGalleryPermissions(): boolean;

        /**
         * Hides the device camera UI.
         */
        static hideCamera(): void;

        /**
         * Hides the music library.
         */
        static hideMusicLibrary(): void;

        /**
         * Returns `true` if the source supports the specified media type.
         */
        static isMediaTypeSupported(source: string, type: string): boolean;

        /**
         * Shows the music library and allows the user to select one or more tracks.
         */
        static openMusicLibrary(options: MusicLibraryOptionsType): void;

        /**
         * Opens the photo gallery image picker.
         */
        static openPhotoGallery(options: PhotoGalleryOptionsType): void;

        /**
         * Displays the given image.
         */
        static previewImage(options: Dictionary<PreviewImageOptions>): void;

        /**
         * Searches the music library for items matching the specified search predicates.
         */
        static queryMusicLibrary(query: MediaQueryType): Titanium.Media.Item[];

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof MediaEventMap>(name: K, callback: (this: Titanium.Media, event: MediaEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Request the user's permission for audio recording.
         * @deprecated Use [Titanium.Media.requestAudioRecorderPermissions](Titanium.Media.requestAudioRecorderPermissions) instead.
         */
        static requestAudioPermissions: never;

        /**
         * Request the user's permission for audio recording.
         */
        static requestAudioRecorderPermissions(callback: (param0: MediaAuthorizationResponse) => void): void;

        /**
         * Request the user's permission for audio recording.
         * @deprecated Use [Titanium.Media.requestAudioRecorderPermissions](Titanium.Media.requestAudioRecorderPermissions) instead.
         */
        static requestAuthorization: never;

        /**
         * Requests for camera access.
         * @deprecated Please use [Titanium.Media.requestCameraPermissions](Titanium.Media.requestCameraPermissions) instead.
         */
        static requestCameraAccess: never;

        /**
         * Requests for camera access.
         */
        static requestCameraPermissions(callback: (param0: RequestCameraAccessResult) => void): void;

        /**
         * Request permissions for the native music-library.
         */
        static requestMusicLibraryPermissions(callback: (param0: RequestMusicLibraryAccessResult) => void): void;

        /**
         * Requests for photo gallery permissions.
         */
        static requestPhotoGalleryPermissions(callback: (param0: RequestPhotoGalleryAccessResult) => void): void;

        /**
         * Saves media to the device's photo gallery / camera roll.
         */
        static saveToPhotoGallery(media: Titanium.Blob | Titanium.Filesystem.File, callbacks: any): void;

        /**
         * Sets the value of the <Titanium.Media.audioSessionCategory> property.
         * @deprecated Set the value using <Titanium.Media.audioSessionCategory> instead.
         */
        static setAudioSessionCategory(audioSessionCategory: string): void;

        /**
         * Sets the value of the <Titanium.Media.audioSessionMode> property.
         * @deprecated Use [Titanium.Media.audioSessionCategory](Titanium.Media.audioSessionCategory) instead.
         */
        static setAudioSessionMode: never;

        /**
         * Sets the value of the <Titanium.Media.availableCameraMediaTypes> property.
         * @deprecated Set the value using <Titanium.Media.availableCameraMediaTypes> instead.
         */
        static setAvailableCameraMediaTypes(availableCameraMediaTypes: ReadonlyArray<any>): void;

        /**
         * Sets the value of the <Titanium.Media.availablePhotoGalleryMediaTypes> property.
         * @deprecated Set the value using <Titanium.Media.availablePhotoGalleryMediaTypes> instead.
         */
        static setAvailablePhotoGalleryMediaTypes(availablePhotoGalleryMediaTypes: ReadonlyArray<any>): void;

        /**
         * Sets the value of the <Titanium.Media.availablePhotoMediaTypes> property.
         * @deprecated Set the value using <Titanium.Media.availablePhotoMediaTypes> instead.
         */
        static setAvailablePhotoMediaTypes(availablePhotoMediaTypes: ReadonlyArray<any>): void;

        /**
         * Sets the value of the <Titanium.Media.averageMicrophonePower> property.
         * @deprecated Set the value using <Titanium.Media.averageMicrophonePower> instead.
         */
        static setAverageMicrophonePower(averageMicrophonePower: number): void;

        /**
         * Sets the value of the <Titanium.Media.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Media.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Media.cameraFlashMode> property.
         * @deprecated Set the value using <Titanium.Media.cameraFlashMode> instead.
         */
        static setCameraFlashMode(cameraFlashMode: number): void;

        /**
         * Sets the value of the <Titanium.Media.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Media.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Overrides the default audio route when using the <Titanium.Media.AUDIO_SESSION_CATEGORY_PLAY_AND_RECORD> session mode.
         */
        static setOverrideAudioRoute(route: number): void;

        /**
         * Shows the camera.
         */
        static showCamera(options: CameraOptionsType): void;

        /**
         * Starts monitoring the microphone sound level.
         */
        static startMicrophoneMonitor(): void;

        /**
         * Starts video capture using the camera specified.
         */
        static startVideoCapture(): void;

        /**
         * Stops monitoring the microphone sound level.
         */
        static stopMicrophoneMonitor(): void;

        /**
         * Stops video capture using the camera specified.
         */
        static stopVideoCapture(): void;

        /**
         * Switches between front and rear-facing cameras. Make sure to set one of the below constants to determine
         * the camera you want to switch to.
         */
        static switchCamera(camera: number): void;

        /**
         * Uses the device camera to capture a photo.
         */
        static takePicture(): void;

        /**
         * Takes a screen shot of the visible UI on the device.
         */
        static takeScreenshot(callback: (param0: ScreenshotResult) => void): void;

        /**
         * Makes the device vibrate.
         */
        static vibrate(pattern?: ReadonlyArray<number>): void;

    }
    /**
     * Base type for all Titanium modules.
     */
    class Module extends Titanium.Proxy {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Module.apiName> property.
         * @deprecated Access <Titanium.Module.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Module.bubbleParent> property.
         * @deprecated Access <Titanium.Module.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Module.lifecycleContainer> property.
         * @deprecated Access <Titanium.Module.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Module.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Module.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Module.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Module.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Base event for class Titanium.Network
     */
    interface NetworkBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Network;

    }
    /**
     * Fired when network connectivity changes.
     */
    interface Network_change_Event extends NetworkBaseEvent {
        /**
         * New network type
         */
        networkType: number;

        /**
         * New network type as a string.
         */
        networkTypeName: string;

        /**
         * Boolean indicating if the device is connected to the network.
         */
        online: boolean;

        /**
         * Human-readable text describing the reason for the change.
         */
        reason: string;

    }
    interface NetworkEventMap extends ProxyEventMap {
        change: Network_change_Event;

    }
    /**
     * The top level network module.
     */
    class Network extends Titanium.Module {
        /**
         * A list of all cookies in the cookie storage.
         */
        static readonly allHTTPCookies: Titanium.Network.Cookie[];

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Network type value as a constant.
         */
        static readonly networkType: number;

        /**
         * Network type as a String. Returns one of `NONE`, `WIFI`, `LAN`, `MOBILE`, or `UNKNOWN`.
         */
        static readonly networkTypeName: string;

        /**
         * Boolean value indicating if the device is connected to the network.
         */
        static readonly online: boolean;

        /**
         * Remote device UUID if the device is registered with the Apple Push Notification
         * Service, or null if it is not registered.
         */
        static readonly remoteDeviceUUID: string;

        /**
         * Array of push notification type constants enabled for the application.
         */
        static readonly remoteNotificationTypes: number[];

        /**
         * Indicates whether push  notifications have been enabled using
         * [registerForPushNotifications](Titanium.Network.registerForPushNotifications).
         */
        static readonly remoteNotificationsEnabled: boolean;

        /**
         * Legacy method to add a connectivity listener to listen for network changes.
         * @deprecated Use the [Titanium.Network.change](Titanium.Network.change) event to monitor connectivity changes.
         */
        static addConnectivityListener: never;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof NetworkEventMap>(name: K, callback: (this: Titanium.Network, event: NetworkEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Adds a cookie to the HTTP client cookie store.
         */
        static addHTTPCookie(cookie: Titanium.Network.Cookie): void;

        /**
         * Adds a cookie to the system cookie store.
         */
        static addSystemCookie(cookie: Titanium.Network.Cookie): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Creates and returns a `BonjourBrowser` object.
         */
        static createBonjourBrowser(serviceType: string, domain: string, parameters?: Dictionary<Titanium.Network.BonjourBrowser>): Titanium.Network.BonjourBrowser;

        /**
         * Creates and returns a `BonjourService` object.
         */
        static createBonjourService(name: string, type: string, domain: string, parameters?: Dictionary<Titanium.Network.BonjourService>): Titanium.Network.BonjourService;

        /**
         * Creates and returns an instance of <Titanium.Network.Cookie>.
         */
        static createCookie(parameters?: Dictionary<Titanium.Network.Cookie>): Titanium.Network.Cookie;

        /**
         * Creates and returns an instance of <Titanium.Network.HTTPClient>.
         */
        static createHTTPClient(parameters?: Dictionary<Titanium.Network.HTTPClient>): Titanium.Network.HTTPClient;

        /**
         * Legacy method to create and return an instance of <Titanium.Network.TCPSocket>.
         * @deprecated Use [Titanium.Network.Socket.createTCP](Titanium.Network.Socket.createTCP) instead.
         */
        static createTCPSocket: never;

        /**
         * Returns a decoded version of a URI encoded value.
         */
        static decodeURIComponent(value: string): string;

        /**
         * Returns a URI encoded version of the specified URI component.
         */
        static encodeURIComponent(value: string): string;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof NetworkEventMap>(name: K, event?: NetworkEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Network.allHTTPCookies> property.
         * @deprecated Access <Titanium.Network.allHTTPCookies> instead.
         */
        static getAllHTTPCookies(): Titanium.Network.Cookie[];

        /**
         * Gets the value of the <Titanium.Network.apiName> property.
         * @deprecated Access <Titanium.Network.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Network.bubbleParent> property.
         * @deprecated Access <Titanium.Network.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets all the cookies with the domain, path and name matched with the given values from the HTTP client cookie store.
         */
        static getHTTPCookies(domain: string, path: string, name: string): Titanium.Network.Cookie[];

        /**
         * Gets all the cookies with the domain matched with the given values from the HTTP client cookie store.
         */
        static getHTTPCookiesForDomain(domain: string): Titanium.Network.Cookie[];

        /**
         * Gets the value of the <Titanium.Network.lifecycleContainer> property.
         * @deprecated Access <Titanium.Network.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Network.networkType> property.
         * @deprecated Access <Titanium.Network.networkType> instead.
         */
        static getNetworkType(): number;

        /**
         * Gets the value of the <Titanium.Network.networkTypeName> property.
         * @deprecated Access <Titanium.Network.networkTypeName> instead.
         */
        static getNetworkTypeName(): string;

        /**
         * Gets the value of the <Titanium.Network.online> property.
         * @deprecated Access <Titanium.Network.online> instead.
         */
        static getOnline(): boolean;

        /**
         * Gets the value of the <Titanium.Network.remoteDeviceUUID> property.
         * @deprecated Access <Titanium.Network.remoteDeviceUUID> instead.
         */
        static getRemoteDeviceUUID(): string;

        /**
         * Gets the value of the <Titanium.Network.remoteNotificationTypes> property.
         * @deprecated Access <Titanium.Network.remoteNotificationTypes> instead.
         */
        static getRemoteNotificationTypes(): number[];

        /**
         * Gets the value of the <Titanium.Network.remoteNotificationsEnabled> property.
         * @deprecated Access <Titanium.Network.remoteNotificationsEnabled> instead.
         */
        static getRemoteNotificationsEnabled(): boolean;

        /**
         * Gets all the cookies with the domain, path and name matched with the given values from the system cookie store.
         */
        static getSystemCookies(domain: string, path: string, name: string): Titanium.Network.Cookie[];

        /**
         * Registers for push notifications with the Apple Push Notification Service.
         */
        static registerForPushNotifications(config: PushNotificationConfig): void;

        /**
         * Removes all the cookies from the HTTP client cookie store.
         */
        static removeAllHTTPCookies(): void;

        /**
         * Removes all the cookie from the system client cookie store.
         */
        static removeAllSystemCookies(): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof NetworkEventMap>(name: K, callback: (this: Titanium.Network, event: NetworkEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Removes the cookie with the domain, path and name exactly the same as the given values from the HTTP client cookie store.
         */
        static removeHTTPCookie(domain: string, path: string, name: string): void;

        /**
         * Removes the cookies with the domain matched with the given values from the HTTP client cookie store.
         */
        static removeHTTPCookiesForDomain(domain: string): void;

        /**
         * Removes the cookie with the domain, path and name exactly the same as the given values from the system cookie store.
         */
        static removeSystemCookie(domain: string, path: string, name: string): void;

        /**
         * Sets the value of the <Titanium.Network.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Network.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Network.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Network.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Unregisters the application for push notifications.
         */
        static unregisterForPushNotifications(): void;

    }
    /**
     * Base event for class Titanium.Platform
     */
    interface PlatformBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.Platform;

    }
    /**
     * Fired when the battery state changes. This is measured in 5% increments on iPhone/iPad.
     */
    interface Platform_battery_Event extends PlatformBaseEvent {
        /**
         * Percentage battery power level.
         */
        level: number;

        /**
         * The battery state.
         */
        state: number;

    }
    interface PlatformEventMap extends ProxyEventMap {
        battery: Platform_battery_Event;

    }
    /**
     * The top-level Platform module.  The Platform module is used to access the device's platform-related
     * functionality.
     */
    class Platform extends Titanium.Module {
        /**
         * System's WIFI IP address. No other network types are supported.
         */
        static readonly address: string;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * System's processor architecture.
         */
        static readonly architecture: string;

        /**
         * System's unused memory, measured in bytes.
         */
        static readonly availableMemory: number;

        /**
         * Battery level in percent, accessible only when `batteryMonitoring` is enabled. Measured
         * in 5% increments on iPhone/iPad.
         */
        static readonly batteryLevel: number;

        /**
         * Determines whether battery monitoring is enabled.
         */
        static batteryMonitoring: boolean;

        /**
         * Indicates the state of the battery. Accessible only when `batteryMonitoring` is enabled.
         */
        static readonly batteryState: number;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Returns the DisplayCaps object.
         */
        static readonly displayCaps: Titanium.Platform.DisplayCaps;

        /**
         * Applications's globally-unique ID (UUID).
         */
        static readonly id: string;

        /**
         * An alphanumeric string unique to each device, used only for serving advertisements.
         */
        static identifierForAdvertising: string;

        /**
         * An alphanumeric string that uniquely identifies a device to the app's vendor.
         */
        static readonly identifierForVendor: string;

        /**
         * A Boolean value that indicates whether the user has limited ad tracking.
         */
        static readonly isAdvertisingTrackingEnabled: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * System's default language.
         */
        static readonly locale: string;

        /**
         * System's network interface mac address, or app UUID.
         */
        static readonly macaddress: string;

        /**
         * Manufacturer of the device.
         */
        static readonly manufacturer: string;

        /**
         * Model of the device.
         */
        static readonly model: string;

        /**
         * Name of the platform. Returns `android` for the Android platform, `iPhone OS` for the iOS
         * platform (iPhone, iPad, or iPod Touch), and `windows` for the Windows platform.
         * Since iOS 10 this property returns `iOS` for for the iOS platform (iPhone, iPad, or iPod Touch).
         */
        static readonly name: string;

        /**
         * System's WIFI network mask. No other network types are supported.
         */
        static readonly netmask: string;

        /**
         * Short name of the system's Operating System. Returns `android` for the Android platfrom,
         * `iphone` for the iPhone or iPod Touch, `ipad` for the iPad, `windowsphone` for Windows Phone, and `windowsstore` for Windows Store
         * platform.
         */
        static readonly osname: string;

        /**
         * Operating System architecture. On Android, this is `32bit`.
         */
        static readonly ostype: string;

        /**
         * Number of logical processing cores.
         */
        static readonly processorCount: number;

        /**
         * Short name of the JavaScript runtime in use.
         */
        static readonly runtime: string;

        /**
         * System's total memory, measured in bytes.
         */
        static readonly totalMemory: number;

        /**
         * System uptime since last boot in seconds.
         */
        static readonly uptime: number;

        /**
         * System name, if set. On iOS, this can be found in Settings > General > About > Name.
         */
        static readonly username: string;

        /**
         * The operating system's version string.
         */
        static readonly version: string;

        /**
         * The operating system's major version number.
         */
        static readonly versionMajor: number;

        /**
         * The operating system's minor version number.
         */
        static readonly versionMinor: number;

        /**
         * The operating system's patch version number.
         */
        static readonly versionPatch: number;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof PlatformEventMap>(name: K, callback: (this: Titanium.Platform, event: PlatformEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Returns whether the system is configured with a default application to handle the URL's protocol/scheme.
         */
        static canOpenURL(url: string): boolean;

        /**
         * Returns an array of basic cpu information for all logical processors
         */
        static cpus(): CPU[];

        /**
         * Creates a globally-unique identifier.
         */
        static createUUID(): string;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof PlatformEventMap>(name: K, event?: PlatformEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Platform.address> property.
         * @deprecated Access <Titanium.Platform.address> instead.
         */
        static getAddress(): string;

        /**
         * Gets the value of the <Titanium.Platform.apiName> property.
         * @deprecated Access <Titanium.Platform.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Platform.architecture> property.
         * @deprecated Access <Titanium.Platform.architecture> instead.
         */
        static getArchitecture(): string;

        /**
         * Gets the value of the <Titanium.Platform.availableMemory> property.
         * @deprecated Access <Titanium.Platform.availableMemory> instead.
         */
        static getAvailableMemory(): number;

        /**
         * Gets the value of the <Titanium.Platform.batteryLevel> property.
         * @deprecated Access <Titanium.Platform.batteryLevel> instead.
         */
        static getBatteryLevel(): number;

        /**
         * Gets the value of the <Titanium.Platform.batteryMonitoring> property.
         * @deprecated Access <Titanium.Platform.batteryMonitoring> instead.
         */
        static getBatteryMonitoring(): boolean;

        /**
         * Gets the value of the <Titanium.Platform.batteryState> property.
         * @deprecated Access <Titanium.Platform.batteryState> instead.
         */
        static getBatteryState(): number;

        /**
         * Gets the value of the <Titanium.Platform.bubbleParent> property.
         * @deprecated Access <Titanium.Platform.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Platform.displayCaps> property.
         * @deprecated Access <Titanium.Platform.displayCaps> instead.
         */
        static getDisplayCaps(): Titanium.Platform.DisplayCaps;

        /**
         * Gets the value of the <Titanium.Platform.id> property.
         * @deprecated Access <Titanium.Platform.id> instead.
         */
        static getId(): string;

        /**
         * Gets the value of the <Titanium.Platform.identifierForAdvertising> property.
         * @deprecated Access <Titanium.Platform.identifierForAdvertising> instead.
         */
        static getIdentifierForAdvertising(): string;

        /**
         * Gets the value of the <Titanium.Platform.identifierForVendor> property.
         * @deprecated Access <Titanium.Platform.identifierForVendor> instead.
         */
        static getIdentifierForVendor(): string;

        /**
         * Gets the value of the <Titanium.Platform.isAdvertisingTrackingEnabled> property.
         * @deprecated Access <Titanium.Platform.isAdvertisingTrackingEnabled> instead.
         */
        static getIsAdvertisingTrackingEnabled(): boolean;

        /**
         * Gets the value of the <Titanium.Platform.lifecycleContainer> property.
         * @deprecated Access <Titanium.Platform.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.Platform.locale> property.
         * @deprecated Access <Titanium.Platform.locale> instead.
         */
        static getLocale(): string;

        /**
         * Gets the value of the <Titanium.Platform.macaddress> property.
         * @deprecated Access <Titanium.Platform.macaddress> instead.
         */
        static getMacaddress(): string;

        /**
         * Gets the value of the <Titanium.Platform.manufacturer> property.
         * @deprecated Access <Titanium.Platform.manufacturer> instead.
         */
        static getManufacturer(): string;

        /**
         * Gets the value of the <Titanium.Platform.model> property.
         * @deprecated Access <Titanium.Platform.model> instead.
         */
        static getModel(): string;

        /**
         * Gets the value of the <Titanium.Platform.name> property.
         * @deprecated Access <Titanium.Platform.name> instead.
         */
        static getName(): string;

        /**
         * Gets the value of the <Titanium.Platform.netmask> property.
         * @deprecated Access <Titanium.Platform.netmask> instead.
         */
        static getNetmask(): string;

        /**
         * Gets the value of the <Titanium.Platform.osname> property.
         * @deprecated Access <Titanium.Platform.osname> instead.
         */
        static getOsname(): string;

        /**
         * Gets the value of the <Titanium.Platform.ostype> property.
         * @deprecated Access <Titanium.Platform.ostype> instead.
         */
        static getOstype(): string;

        /**
         * Gets the value of the <Titanium.Platform.processorCount> property.
         * @deprecated Access <Titanium.Platform.processorCount> instead.
         */
        static getProcessorCount(): number;

        /**
         * Gets the value of the <Titanium.Platform.runtime> property.
         * @deprecated Access <Titanium.Platform.runtime> instead.
         */
        static getRuntime(): string;

        /**
         * Gets the value of the <Titanium.Platform.totalMemory> property.
         * @deprecated Access <Titanium.Platform.totalMemory> instead.
         */
        static getTotalMemory(): number;

        /**
         * Gets the value of the <Titanium.Platform.uptime> property.
         * @deprecated Access <Titanium.Platform.uptime> instead.
         */
        static getUptime(): number;

        /**
         * Gets the value of the <Titanium.Platform.username> property.
         * @deprecated Access <Titanium.Platform.username> instead.
         */
        static getUsername(): string;

        /**
         * Gets the value of the <Titanium.Platform.version> property.
         * @deprecated Access <Titanium.Platform.version> instead.
         */
        static getVersion(): string;

        /**
         * Gets the value of the <Titanium.Platform.versionMajor> property.
         * @deprecated Access <Titanium.Platform.versionMajor> instead.
         */
        static getVersionMajor(): number;

        /**
         * Gets the value of the <Titanium.Platform.versionMinor> property.
         * @deprecated Access <Titanium.Platform.versionMinor> instead.
         */
        static getVersionMinor(): number;

        /**
         * Gets the value of the <Titanium.Platform.versionPatch> property.
         * @deprecated Access <Titanium.Platform.versionPatch> instead.
         */
        static getVersionPatch(): number;

        /**
         * Returns whether the system settings are configured to show times in 24-hour format.
         */
        static is24HourTimeFormat(): boolean;

        /**
         * Opens this URL using the system's default application for its protocol/scheme.
         */
        static openURL(url: string, options?: OpenURLOptions, callback?: (...args: any[]) => void): boolean;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof PlatformEventMap>(name: K, callback: (this: Titanium.Platform, event: PlatformEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Platform.batteryMonitoring> property.
         * @deprecated Set the value using <Titanium.Platform.batteryMonitoring> instead.
         */
        static setBatteryMonitoring(batteryMonitoring: boolean): void;

        /**
         * Sets the value of the <Titanium.Platform.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Platform.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Platform.identifierForAdvertising> property.
         * @deprecated Set the value using <Titanium.Platform.identifierForAdvertising> instead.
         */
        static setIdentifierForAdvertising(identifierForAdvertising: string): void;

        /**
         * Sets the value of the <Titanium.Platform.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Platform.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * The base for all Titanium objects.
     */
    class Proxy {
        /**
         * The name of the API that this proxy corresponds to.
         */
        readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        lifecycleContainer?: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Proxy identifier
         */
        id?: string | number;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Proxy.apiName> property.
         * @deprecated Access <Titanium.Proxy.apiName> instead.
         */
        getApiName(): string;

        /**
         * Gets the value of the <Titanium.Proxy.bubbleParent> property.
         * @deprecated Access <Titanium.Proxy.bubbleParent> instead.
         */
        getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Proxy.lifecycleContainer> property.
         * @deprecated Access <Titanium.Proxy.lifecycleContainer> instead.
         */
        getLifecycleContainer?(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Proxy.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Proxy.bubbleParent> instead.
         */
        setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Proxy.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Proxy.lifecycleContainer> instead.
         */
        setLifecycleContainer?(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * Stream module containing stream utility methods.
     */
    class Stream extends Titanium.Module {
        /**
         * Use with [createStream](Titanium.Stream.createStream) to open a stream in append
         * mode.
         */
        static readonly MODE_APPEND: number;

        /**
         * Use with [createStream](Titanium.Stream.createStream) to open a stream in read
         * mode.
         */
        static readonly MODE_READ: number;

        /**
         * Use with [createStream](Titanium.Stream.createStream) to open a stream in write
         * mode.
         */
        static readonly MODE_WRITE: number;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Creates stream from a `Buffer` or `Blob` object.
         */
        static createStream(params: CreateStreamArgs): Titanium.IOStream;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Stream.apiName> property.
         * @deprecated Access <Titanium.Stream.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Stream.bubbleParent> property.
         * @deprecated Access <Titanium.Stream.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Stream.lifecycleContainer> property.
         * @deprecated Access <Titanium.Stream.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Reads data from input stream and passes it to a handler method.
         */
        static pump(inputStream: Titanium.IOStream, handler: (param0: PumpCallbackArgs) => void, maxChunkSize: number, isAsync?: boolean): void;

        /**
         * Asynchronously reads data from an [IOStream](Titanium.IOStream) into a buffer.
         */
        static read(sourceStream: Titanium.IOStream, buffer: Titanium.Buffer, offset?: number, length?: number, resultsCallback?: (param0: ReadCallbackArgs) => void): void;

        /**
         * Reads all data from the specified [IOStream](Titanium.IOStream).
         */
        static readAll(sourceStream: Titanium.IOStream, buffer?: Titanium.Buffer, resultsCallback?: (param0: ReadCallbackArgs) => void): Titanium.Buffer | void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Stream.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Stream.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Stream.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Stream.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Asynchronously writes data from a buffer to an [IOStream](Titanium.IOStream).
         */
        static write(outputStream: Titanium.IOStream, buffer: Titanium.Buffer, offset?: number, length?: number, resultsCallback?: (param0: WriteCallbackArgs) => void): void;

        /**
         * Writes all data from an input stream to an output stream.
         */
        static writeStream(inputStream: Titanium.IOStream, outputStream: Titanium.IOStream, maxChunkSize: number, resultsCallback?: (param0: WriteStreamCallbackArgs) => void): void;

    }
    /**
     * Base event for class Titanium.UI
     */
    interface UIBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.UI;

    }
    /**
     * Fired when the `userInterfaceStyle` changes.
     */
    interface UI_userinterfacestyle_Event extends UIBaseEvent {
        /**
         * The new userInterfaceStyle value.
         */
        value: number;

    }
    interface UIEventMap extends ProxyEventMap {
        userinterfacestyle: UI_userinterfacestyle_Event;

    }
    /**
     * The main <Titanium.UI> module.
     */
    class UI extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Sets the background color of the master view (when there are no windows or other top-level
         * controls displayed).
         */
        static backgroundColor: string | Titanium.UI.Color;

        /**
         * Local path or URL to an image file for setting a background for the master view (when there
         * are no windows or other top-level controls displayed).
         */
        static backgroundImage: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The currently active tab, if a tab group is open.
         * @deprecated
         */
        static currentTab: never;

        /**
         * The active window associated with the executing JavaScript context.
         * @deprecated
         */
        static readonly currentWindow: never;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Updates the orientation of the current window to the specified orientation value.
         * @deprecated Use [Titanium.UI.Window.orientationModes](Titanium.UI.Window.orientationModes) instead.
         */
        static orientation: never;

        /**
         * The current mode for the device (corresponding to night/dark or light/normal)
         * @deprecated Use [userInterfaceStyle](Titanium.UI.userInterfaceStyle) instead.
         */
        static semanticColorType: string;

        /**
         * Sets the global tint color of the application. It is inherited by the child views and can be
         * overwritten by them using the `tintColor` property.
         */
        static tintColor: string | Titanium.UI.Color;

        /**
         * The style associated with the user interface.
         */
        static readonly userInterfaceStyle: number;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof UIEventMap>(name: K, callback: (this: Titanium.UI, event: UIEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Converts one type of unit to another using the metrics of the main display.
         */
        static convertUnits(convertFromValue: string, convertToUnits: number): number;

        /**
         * Creates and returns an instance of <Titanium.UI.2DMatrix>.
         * @deprecated Use [Titanium.UI.createMatrix2D](Titanium.UI.createMatrix2D) instead.
         */
        static create2DMatrix(parameters?: Matrix2DCreationDict): Titanium.UI.Matrix2D;

        /**
         * Creates and returns an instance of <Titanium.UI.3DMatrix>.
         * @deprecated Use [Titanium.UI.createMatrix3D](Titanium.UI.createMatrix3D) instead.
         */
        static create3DMatrix(parameters?: Matrix3DCreationDict): Titanium.UI.Matrix3D;

        /**
         * Creates and returns an instance of <Titanium.UI.ActivityIndicator>.
         */
        static createActivityIndicator(parameters?: Dictionary<Titanium.UI.ActivityIndicator>): Titanium.UI.ActivityIndicator;

        /**
         * Creates and returns an instance of <Titanium.UI.AlertDialog>.
         */
        static createAlertDialog(parameters?: Dictionary<Titanium.UI.AlertDialog>): Titanium.UI.AlertDialog;

        /**
         * Creates and returns an instance of <Titanium.UI.Animation>.
         */
        static createAnimation(parameters?: Dictionary<Titanium.UI.Animation>): Titanium.UI.Animation;

        /**
         * Creates and returns an instance of <Titanium.UI.AttributedString>.
         */
        static createAttributedString(parameters?: Dictionary<Titanium.UI.AttributedString>): Titanium.UI.AttributedString;

        /**
         * Creates and returns an instance of <Titanium.UI.Button>.
         */
        static createButton(parameters?: Dictionary<Titanium.UI.Button>): Titanium.UI.Button;

        /**
         * Creates and returns an instance of <Titanium.UI.ButtonBar>.
         */
        static createButtonBar(parameters?: Dictionary<Titanium.UI.ButtonBar>): Titanium.UI.ButtonBar;

        /**
         * Creates and returns an instance of <Titanium.UI.Color>.
         */
        static createColor(parameters?: Dictionary<Titanium.UI.Color>): Titanium.UI.Color;

        /**
         * Creates and returns an instance of <Titanium.UI.CoverFlowView>.
         * @deprecated Use [Titanium.UI.iOS.CoverFlowView](Titanium.UI.iOS.CoverFlowView) instead.
         */
        static createCoverFlowView: never;

        /**
         * Creates and returns an instance of <Titanium.UI.DashboardItem>.
         */
        static createDashboardItem(parameters?: Dictionary<Titanium.UI.DashboardItem>): Titanium.UI.DashboardItem;

        /**
         * Creates and returns an instance of <Titanium.UI.DashboardView>.
         */
        static createDashboardView(parameters?: Dictionary<Titanium.UI.DashboardView>): Titanium.UI.DashboardView;

        /**
         * Creates and returns an instance of <Titanium.UI.EmailDialog>.
         */
        static createEmailDialog(parameters?: Dictionary<Titanium.UI.EmailDialog>): Titanium.UI.EmailDialog;

        /**
         * Creates and returns an instance of <Titanium.UI.ImageView>.
         */
        static createImageView(parameters?: Dictionary<Titanium.UI.ImageView>): Titanium.UI.ImageView;

        /**
         * Creates and returns an instance of <Titanium.UI.Label>.
         */
        static createLabel(parameters?: Dictionary<Titanium.UI.Label>): Titanium.UI.Label;

        /**
         * Creates and returns an instance of <Titanium.UI.ListSection>.
         */
        static createListSection(parameters?: Dictionary<Titanium.UI.ListSection>): Titanium.UI.ListSection;

        /**
         * Creates and returns an instance of <Titanium.UI.ListView>.
         */
        static createListView(parameters?: Dictionary<Titanium.UI.ListView>): Titanium.UI.ListView;

        /**
         * Creates and returns an instance of <Titanium.UI.MaskedImage>.
         */
        static createMaskedImage(parameters?: Dictionary<Titanium.UI.MaskedImage>): Titanium.UI.MaskedImage;

        /**
         * Creates and returns an instance of <Titanium.UI.Matrix2D>.
         */
        static createMatrix2D(parameters?: Matrix2DCreationDict): Titanium.UI.Matrix2D;

        /**
         * Creates and returns an instance of <Titanium.UI.Matrix3D>.
         */
        static createMatrix3D(parameters?: Matrix3DCreationDict): Titanium.UI.Matrix3D;

        /**
         * Creates and returns an instance of <Titanium.UI.NavigationWindow>.
         */
        static createNavigationWindow(parameters?: Dictionary<Titanium.UI.NavigationWindow>): Titanium.UI.NavigationWindow;

        /**
         * Creates and returns an instance of <Titanium.UI.Notification>.
         */
        static createNotification(parameters?: Dictionary<Titanium.UI.Notification>): Titanium.UI.Notification;

        /**
         * Creates and returns an instance of <Titanium.UI.OptionDialog>.
         */
        static createOptionDialog(parameters?: Dictionary<Titanium.UI.OptionDialog>): Titanium.UI.OptionDialog;

        /**
         * Creates and returns an instance of <Titanium.UI.Picker>.
         */
        static createPicker(parameters?: Dictionary<Titanium.UI.Picker>): Titanium.UI.Picker;

        /**
         * Creates and returns an instance of <Titanium.UI.PickerColumn>.
         */
        static createPickerColumn(parameters?: Dictionary<Titanium.UI.PickerColumn>): Titanium.UI.PickerColumn;

        /**
         * Creates and returns an instance of <Titanium.UI.PickerRow>.
         */
        static createPickerRow(parameters?: Dictionary<Titanium.UI.PickerRow>): Titanium.UI.PickerRow;

        /**
         * Creates and returns an instance of <Titanium.UI.ProgressBar>.
         */
        static createProgressBar(parameters?: Dictionary<Titanium.UI.ProgressBar>): Titanium.UI.ProgressBar;

        /**
         * Creates and returns an instance of <Titanium.UI.RefreshControl>.
         */
        static createRefreshControl(parameters?: Dictionary<Titanium.UI.RefreshControl>): Titanium.UI.RefreshControl;

        /**
         * Creates and returns an instance of <Titanium.UI.ScrollView>.
         */
        static createScrollView(parameters?: Dictionary<Titanium.UI.ScrollView>): Titanium.UI.ScrollView;

        /**
         * Creates and returns an instance of <Titanium.UI.ScrollableView>.
         */
        static createScrollableView(parameters?: Dictionary<Titanium.UI.ScrollableView>): Titanium.UI.ScrollableView;

        /**
         * Creates and returns an instance of <Titanium.UI.SearchBar>.
         */
        static createSearchBar(parameters?: Dictionary<Titanium.UI.SearchBar>): Titanium.UI.SearchBar;

        /**
         * Creates and returns an instance of <Titanium.UI.Shortcut>.
         */
        static createShortcut(parameters?: Dictionary<Titanium.UI.Shortcut>): Titanium.UI.Shortcut;

        /**
         * Creates and returns an instance of <Titanium.UI.ShortcutItem>.
         */
        static createShortcutItem(parameters?: Dictionary<Titanium.UI.ShortcutItem>): Titanium.UI.ShortcutItem;

        /**
         * Creates and returns an instance of <Titanium.UI.Slider>.
         */
        static createSlider(parameters?: Dictionary<Titanium.UI.Slider>): Titanium.UI.Slider;

        /**
         * Creates and returns an instance of <Titanium.UI.Switch>.
         */
        static createSwitch(parameters?: Dictionary<Titanium.UI.Switch>): Titanium.UI.Switch;

        /**
         * Creates and returns an instance of <Titanium.UI.Tab>.
         */
        static createTab(parameters?: Dictionary<Titanium.UI.Tab>): Titanium.UI.Tab;

        /**
         * Creates and returns an instance of <Titanium.UI.TabGroup>.
         */
        static createTabGroup(parameters?: Dictionary<Titanium.UI.TabGroup>): Titanium.UI.TabGroup;

        /**
         * Creates and returns an instance of <Titanium.UI.TabbedBar>.
         */
        static createTabbedBar(parameters?: Dictionary<Titanium.UI.TabbedBar>): Titanium.UI.TabbedBar;

        /**
         * Creates and returns an instance of <Titanium.UI.TableView>.
         */
        static createTableView(parameters?: Dictionary<Titanium.UI.TableView>): Titanium.UI.TableView;

        /**
         * Creates and returns an instance of <Titanium.UI.TableViewRow>.
         */
        static createTableViewRow(parameters?: Dictionary<Titanium.UI.TableViewRow>): Titanium.UI.TableViewRow;

        /**
         * Creates and returns an instance of <Titanium.UI.TableViewSection>.
         */
        static createTableViewSection(parameters?: Dictionary<Titanium.UI.TableViewSection>): Titanium.UI.TableViewSection;

        /**
         * Creates and returns an instance of <Titanium.UI.TextArea>.
         */
        static createTextArea(parameters?: Dictionary<Titanium.UI.TextArea>): Titanium.UI.TextArea;

        /**
         * Creates and returns an instance of <Titanium.UI.TextField>.
         */
        static createTextField(parameters?: Dictionary<Titanium.UI.TextField>): Titanium.UI.TextField;

        /**
         * Creates and returns an instance of <Titanium.UI.Toolbar>.
         */
        static createToolbar(parameters?: Dictionary<Titanium.UI.Toolbar>): Titanium.UI.Toolbar;

        /**
         * Creates and returns an instance of <Titanium.UI.View>.
         */
        static createView(parameters?: Dictionary<Titanium.UI.View>): Titanium.UI.View;

        /**
         * Creates and returns an instance of <Titanium.UI.WebView>.
         */
        static createWebView(parameters?: Dictionary<Titanium.UI.WebView>): Titanium.UI.WebView;

        /**
         * Creates and returns an instance of <Titanium.UI.Window>.
         */
        static createWindow(parameters?: Dictionary<Titanium.UI.Window>): Titanium.UI.Window;

        /**
         * Fetches the correct color to be used with a UI element dependent on the users current dark mode setting on iOS 13 and above, or the [Titanium.UI.semanticColorType](Titanium.UI.semanticColorType) setting in other instances.
         * Will return a valid string value to be used for color properties on Android. This may be a hex string or an `rgba()` function.
         */
        static fetchSemanticColor(colorName: string): Titanium.UI.Color | string;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof UIEventMap>(name: K, event?: UIEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.UI.apiName> property.
         * @deprecated Access <Titanium.UI.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.UI.backgroundColor> property.
         * @deprecated Access <Titanium.UI.backgroundColor> instead.
         */
        static getBackgroundColor(): string | Titanium.UI.Color;

        /**
         * Gets the value of the <Titanium.UI.backgroundImage> property.
         * @deprecated Access <Titanium.UI.backgroundImage> instead.
         */
        static getBackgroundImage(): string;

        /**
         * Gets the value of the <Titanium.UI.bubbleParent> property.
         * @deprecated Access <Titanium.UI.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.UI.currentTab> property.
         * @deprecated
         */
        static getCurrentTab: never;

        /**
         * Gets the value of the <Titanium.UI.currentWindow> property.
         * @deprecated
         */
        static getCurrentWindow: never;

        /**
         * Gets the value of the <Titanium.UI.lifecycleContainer> property.
         * @deprecated Access <Titanium.UI.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Gets the value of the <Titanium.UI.orientation> property.
         * @deprecated Use [Titanium.UI.Window.orientationModes](Titanium.UI.Window.orientationModes) instead.
         */
        static getOrientation: never;

        /**
         * Gets the value of the <Titanium.UI.semanticColorType> property.
         * @deprecated Use [userInterfaceStyle](Titanium.UI.userInterfaceStyle) instead.
         */
        static getSemanticColorType(): string;

        /**
         * Gets the value of the <Titanium.UI.tintColor> property.
         * @deprecated Access <Titanium.UI.tintColor> instead.
         */
        static getTintColor(): string | Titanium.UI.Color;

        /**
         * Gets the value of the <Titanium.UI.userInterfaceStyle> property.
         * @deprecated Access <Titanium.UI.userInterfaceStyle> instead.
         */
        static getUserInterfaceStyle(): number;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof UIEventMap>(name: K, callback: (this: Titanium.UI, event: UIEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.UI.backgroundColor> property.
         * @deprecated Set the value using <Titanium.UI.backgroundColor> instead.
         */
        static setBackgroundColor(backgroundColor: string | Titanium.UI.Color): void;

        /**
         * Sets the value of the <Titanium.UI.backgroundImage> property.
         * @deprecated Set the value using <Titanium.UI.backgroundImage> instead.
         */
        static setBackgroundImage(backgroundImage: string): void;

        /**
         * Sets the value of the <Titanium.UI.bubbleParent> property.
         * @deprecated Set the value using <Titanium.UI.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.UI.currentTab> property.
         * @deprecated
         */
        static setCurrentTab: never;

        /**
         * Sets the value of the <Titanium.UI.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.UI.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Sets the value of the <Titanium.UI.orientation> property.
         * @deprecated Use [Titanium.UI.Window.orientationModes](Titanium.UI.Window.orientationModes) instead.
         */
        static setOrientation: never;

        /**
         * Sets the value of the <Titanium.UI.semanticColorType> property.
         * @deprecated Use [userInterfaceStyle](Titanium.UI.userInterfaceStyle) instead.
         */
        static setSemanticColorType(semanticColorType: string): void;

        /**
         * Sets the value of the <Titanium.UI.tintColor> property.
         * @deprecated Set the value using <Titanium.UI.tintColor> instead.
         */
        static setTintColor(tintColor: string | Titanium.UI.Color): void;

    }
    /**
     * The top-level Utils module, containing a set of JavaScript methods that are often useful when
     * building applications.
     */
    class Utils extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Returns the specified data decoded from Base64.
         */
        static base64decode(obj: string | Titanium.Blob | Titanium.Filesystem.File): Titanium.Blob;

        /**
         * Returns the specified data encoded to Base64.
         */
        static base64encode(obj: string | Titanium.Blob | Titanium.Filesystem.File): Titanium.Blob;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.Utils.apiName> property.
         * @deprecated Access <Titanium.Utils.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.Utils.bubbleParent> property.
         * @deprecated Access <Titanium.Utils.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.Utils.lifecycleContainer> property.
         * @deprecated Access <Titanium.Utils.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Returns a MD5 digest of the specified data as a hex-based String.
         */
        static md5HexDigest(obj: string | Titanium.Blob): string;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sets the value of the <Titanium.Utils.bubbleParent> property.
         * @deprecated Set the value using <Titanium.Utils.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.Utils.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.Utils.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

        /**
         * Returns a SHA-1 hash of the specified data as a hex-based String.
         */
        static sha1(obj: string | Titanium.Blob): string;

        /**
         * Returns a SHA-256 hash of the specified data as a hex-based String.
         */
        static sha256(obj: string | Titanium.Blob): string;

    }
    /**
     * Base event for class Titanium.WatchSession
     */
    interface WatchSessionBaseEvent extends Ti.Event {
        /**
         * Source object that fired the event.
         */
        source: Titanium.WatchSession;

    }
    /**
     * App received message from apple watch in foreground. Will be called on startup if the
     * incoming message caused the receiver to launch.
     */
    interface WatchSession_receivemessage_Event extends WatchSessionBaseEvent {
        /**
         * The message content
         */
        message: any;

    }
    /**
     * App received app context from apple watch. Will be called on startup if an applicationContext is available.
     */
    interface WatchSession_receiveapplicationcontext_Event extends WatchSessionBaseEvent {
        /**
         * The application Context
         */
        applicationContext: any;

    }
    /**
     * App received user info from apple watch in background. Will be called on startup if the user info finished
     * transferring when the receiver was not running.
     */
    interface WatchSession_receiveuserinfo_Event extends WatchSessionBaseEvent {
        /**
         * The user info content
         */
        userInfo: any;

    }
    /**
     * App received file from apple watch in background.
     */
    interface WatchSession_receivefile_Event extends WatchSessionBaseEvent {
        /**
         * The downloaded data as a Titanium.Blob object.
         */
        data: Titanium.Blob;

        /**
         * Error code if transfer failed.
         */
        errorCode: number;

        /**
         * Error message if any.
         */
        message: string;

        /**
         * Information about the file.
         */
        metaData: any;

        /**
         * If the transfer was successful.
         */
        success: boolean;

    }
    /**
     * The watch state has changed.
     */
    interface WatchSession_watchstatechanged_Event extends WatchSessionBaseEvent {
        /**
         * Returns the current activation state of the watch.  Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.activationState> for more infos.
         */
        activationState: number;

        /**
         * If the apple watch is currently activated. Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.isActivated> for more infos.
         */
        isActivated: boolean;

        /**
         * If the complication is enabled in the apple watch.
         */
        isComplicationEnabled: boolean;

        /**
         * If the device is paired with the apple watch.
         */
        isPaired: boolean;

        /**
         * If apple watch is currently reachable.
         */
        isReachable: boolean;

        /**
         * If the watch app is installed in the apple watch.
         */
        isWatchAppInstalled: boolean;

    }
    /**
     * The watch reachability state has changed.
     */
    interface WatchSession_reachabilitychanged_Event extends WatchSessionBaseEvent {
        /**
         * Returns the current activation state of the watch.  Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.activationState> for more infos.
         */
        activationState: number;

        /**
         * If the apple watch is currently activated. Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.isActivated> for more infos.
         */
        isActivated: boolean;

        /**
         * If the complication is enabled in the apple watch.
         */
        isComplicationEnabled: boolean;

        /**
         * If the device is paired with the apple watch.
         */
        isPaired: boolean;

        /**
         * If apple watch is currently reachable.
         */
        isReachable: boolean;

        /**
         * If the watch app is installed in the apple watch.
         */
        isWatchAppInstalled: boolean;

    }
    /**
     * Fired when the application completed user info transfer to the watch app.
     */
    interface WatchSession_finishuserinfotransfer_Event extends WatchSessionBaseEvent {
        /**
         * Error code if transfer failed.
         */
        errorCode: number;

        /**
         * Error message if any.
         */
        message: string;

        /**
         * If the transfer was successful.
         */
        success: boolean;

        /**
         * The downloaded data as a Titanium.Blob object.
         */
        userInfo: any;

    }
    /**
     * App completed file transfer to watch app.
     */
    interface WatchSession_finishfiletransfer_Event extends WatchSessionBaseEvent {
        /**
         * Error code if transfer failed.
         */
        errorCode: number;

        /**
         * URL of the file transferred.
         */
        fileURL: string;

        /**
         * Error message if any.
         */
        message: string;

        /**
         * meta data of the file transferred.
         */
        metaData: any;

        /**
         * If the transfer was successful.
         */
        success: boolean;

    }
    /**
     * Called when the session can no longer be used to modify or add any new transfers and,
     * all interactive messages will be cancelled, but events for background transfers can still fire.
     * This will happen when the selected watch is being changed.
     */
    interface WatchSession_inactive_Event extends WatchSessionBaseEvent {
        /**
         * Returns the current activation state of the watch.  Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.activationState> for more infos.
         */
        activationState: number;

        /**
         * If the apple watch is currently activated. Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.isActivated> for more infos.
         */
        isActivated: boolean;

        /**
         * If the complication is enabled in the apple watch.
         */
        isComplicationEnabled: boolean;

        /**
         * If the device is paired with the apple watch.
         */
        isPaired: boolean;

        /**
         * If apple watch is currently reachable.
         */
        isReachable: boolean;

        /**
         * If the watch app is installed in the apple watch.
         */
        isWatchAppInstalled: boolean;

    }
    /**
     * Called when all events for the previously selected watch has occurred.
     * The session can be re-activated for the now selected watch using activateSession.
     */
    interface WatchSession_deactivate_Event extends WatchSessionBaseEvent {
        /**
         * Returns the current activation state of the watch.  Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.activationState> for more infos.
         */
        activationState: number;

        /**
         * If the apple watch has currently content pending. Only available on iOS 10.0
         * and later. See <Titanium.WatchSession.hasContentPending> for more infos.
         */
        hasContentPending: boolean;

        /**
         * If the apple watch is currently activated. Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.isActivated> for more infos.
         */
        isActivated: boolean;

        /**
         * If the complication is enabled in the apple watch.
         */
        isComplicationEnabled: boolean;

        /**
         * If the device is paired with the apple watch.
         */
        isPaired: boolean;

        /**
         * If apple watch is currently reachable.
         */
        isReachable: boolean;

        /**
         * If the watch app is installed in the apple watch.
         */
        isWatchAppInstalled: boolean;

        /**
         * If the apple watch has complication userInfo transfers left. Only available on iOS 10.0
         * and later. See <Titanium.WatchSession.remainingComplicationUserInfoTransfers> for more infos.
         */
        remainingComplicationUserInfoTransfers: boolean;

    }
    /**
     * Called when the session has completed activation. If session state is
     * <Titanium.WatchSession.ACTIVATION_STATE_NOT_ACTIVATED> there will be an error
     * with more details.
     */
    interface WatchSession_activationCompleted_Event extends WatchSessionBaseEvent {
        /**
         * Returns the current activation state of the watch.  Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.activationState> for more infos.
         */
        activationState: number;

        /**
         * If the apple watch is currently activated. Only available on iOS 9.3
         * and later. See <Titanium.WatchSession.isActivated> for more infos.
         */
        isActivated: boolean;

        /**
         * If the complication is enabled in the apple watch.
         */
        isComplicationEnabled: boolean;

        /**
         * If the device is paired with the apple watch.
         */
        isPaired: boolean;

        /**
         * If apple watch is currently reachable.
         */
        isReachable: boolean;

        /**
         * If the watch app is installed in the apple watch.
         */
        isWatchAppInstalled: boolean;

    }
    interface WatchSessionEventMap extends ProxyEventMap {
        activationCompleted: WatchSession_activationCompleted_Event;

        deactivate: WatchSession_deactivate_Event;

        finishfiletransfer: WatchSession_finishfiletransfer_Event;

        finishuserinfotransfer: WatchSession_finishuserinfotransfer_Event;

        inactive: WatchSession_inactive_Event;

        reachabilitychanged: WatchSession_reachabilitychanged_Event;

        receiveapplicationcontext: WatchSession_receiveapplicationcontext_Event;

        receivefile: WatchSession_receivefile_Event;

        receivemessage: WatchSession_receivemessage_Event;

        receiveuserinfo: WatchSession_receiveuserinfo_Event;

        watchstatechanged: WatchSession_watchstatechanged_Event;

    }
    /**
     * Used to enable data and file transfers between a watchOS and iOS application.
     */
    class WatchSession extends Titanium.Module {
        /**
         * The watch is currently activated.
         */
        static readonly ACTIVATION_STATE_ACTIVATED: number;

        /**
         * The watch is currently inactive.
         */
        static readonly ACTIVATION_STATE_INACTIVE: number;

        /**
         * The watch is currently not activated.
         */
        static readonly ACTIVATION_STATE_NOT_ACTIVATED: number;

        /**
         * Returns the current activation state of the watch.
         */
        static readonly activationState: number;

        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * Returns `true` if there is more content for the session to deliver.
         */
        static readonly hasContentPending: boolean;

        /**
         * Returns `true` if the watch is currently activated.
         */
        static readonly isActivated: boolean;

        /**
         * Returns `true` if complication is enabled on the installed watch app.
         */
        static readonly isComplicationEnabled: boolean;

        /**
         * Returns `true` if the device is paired with a watch.
         */
        static readonly isPaired: boolean;

        /**
         * Returns `true` if the watch is currently reachable.
         */
        static readonly isReachable: boolean;

        /**
         * Returns `true` if the device supports watch connectivity.
         */
        static readonly isSupported: boolean;

        /**
         * Returns `true` if the accompanying watch app is installed.
         */
        static readonly isWatchAppInstalled: boolean;

        /**
         * The most recent application context sent to the watch app.
         */
        static readonly recentApplicationContext: any;

        /**
         * The number of calls remaining to `transferCurrentComplication` before the system starts
         * transferring the complicationUserInfo as regular userInfos.
         */
        static readonly remainingComplicationUserInfoTransfers: number;

        /**
         * Activates the watch session
         */
        static activateSession(): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener<K extends keyof WatchSessionEventMap>(name: K, callback: (this: Titanium.WatchSession, event: WatchSessionEventMap[K]) => void): void;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Cancels all incomplete file transfers to the apple watch.
         */
        static cancelAllFileTransfers(): void;

        /**
         * Cancels all incomplete transfers to the apple watch.
         */
        static cancelAllTransfers(): void;

        /**
         * Cancels all incomplete user info and complication transfers to the apple watch.
         */
        static cancelAllUserInfoTransfers(): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent<K extends keyof WatchSessionEventMap>(name: K, event?: WatchSessionEventMap[K]): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.WatchSession.activationState> property.
         * @deprecated Access <Titanium.WatchSession.activationState> instead.
         */
        static getActivationState(): number;

        /**
         * Gets the value of the <Titanium.WatchSession.apiName> property.
         * @deprecated Access <Titanium.WatchSession.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.WatchSession.bubbleParent> property.
         * @deprecated Access <Titanium.WatchSession.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.hasContentPending> property.
         * @deprecated Access <Titanium.WatchSession.hasContentPending> instead.
         */
        static getHasContentPending(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isActivated> property.
         * @deprecated Access <Titanium.WatchSession.isActivated> instead.
         */
        static getIsActivated(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isComplicationEnabled> property.
         * @deprecated Access <Titanium.WatchSession.isComplicationEnabled> instead.
         */
        static getIsComplicationEnabled(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isPaired> property.
         * @deprecated Access <Titanium.WatchSession.isPaired> instead.
         */
        static getIsPaired(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isReachable> property.
         * @deprecated Access <Titanium.WatchSession.isReachable> instead.
         */
        static getIsReachable(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isSupported> property.
         * @deprecated Access <Titanium.WatchSession.isSupported> instead.
         */
        static getIsSupported(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.isWatchAppInstalled> property.
         * @deprecated Access <Titanium.WatchSession.isWatchAppInstalled> instead.
         */
        static getIsWatchAppInstalled(): boolean;

        /**
         * Gets the value of the <Titanium.WatchSession.recentApplicationContext> property.
         * @deprecated Access <Titanium.WatchSession.recentApplicationContext> instead.
         */
        static getRecentApplicationContext(): any;

        /**
         * Gets the value of the <Titanium.WatchSession.remainingComplicationUserInfoTransfers> property.
         * @deprecated Access <Titanium.WatchSession.remainingComplicationUserInfoTransfers> instead.
         */
        static getRemainingComplicationUserInfoTransfers(): number;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener<K extends keyof WatchSessionEventMap>(name: K, callback: (this: Titanium.WatchSession, event: WatchSessionEventMap[K]) => void): void;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Sends a message to the apple watch.
         */
        static sendMessage(message: any, reply?: (param0: MessageReply) => void): void;

        /**
         * Sets the value of the <Titanium.WatchSession.bubbleParent> property.
         * @deprecated Set the value using <Titanium.WatchSession.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Transfers complication data to the watch application.
         */
        static transferCurrentComplication(params: any): void;

        /**
         * Transfers a file to the apple watch.
         */
        static transferFile(params: any): void;

        /**
         * Transfers an user info to the apple watch.
         */
        static transferUserInfo(params: any): void;

        /**
         * Sends an app context update to the apple watch.
         */
        static updateApplicationContext(params: any): void;

    }
    /**
     * The top level XML module.  The XML module is used for parsing and processing XML-based content.
     */
    class XML extends Titanium.Module {
        /**
         * The name of the API that this proxy corresponds to.
         */
        static readonly apiName: string;

        /**
         * Indicates if the proxy will bubble an event to its parent.
         */
        static bubbleParent: boolean;

        /**
         * The Window or TabGroup whose Activity lifecycle should be triggered on the proxy.
         */
        static lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Adds the specified callback as an event listener for the named event.
         */
        static addEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Applies the properties to the proxy.
         */
        static applyProperties(props: any): void;

        /**
         * Fires a synthesized event to any registered listeners.
         */
        static fireEvent(name: string, event?: any): void;

        /**
         * Gets the value of the <Titanium.XML.apiName> property.
         * @deprecated Access <Titanium.XML.apiName> instead.
         */
        static getApiName(): string;

        /**
         * Gets the value of the <Titanium.XML.bubbleParent> property.
         * @deprecated Access <Titanium.XML.bubbleParent> instead.
         */
        static getBubbleParent(): boolean;

        /**
         * Gets the value of the <Titanium.XML.lifecycleContainer> property.
         * @deprecated Access <Titanium.XML.lifecycleContainer> instead.
         */
        static getLifecycleContainer(): Titanium.UI.Window | Titanium.UI.TabGroup;

        /**
         * Parses an XML string into a <Titanium.XML.Document> object.
         */
        static parseString(xml: string): Titanium.XML.Document;

        /**
         * Removes the specified callback as an event listener for the named event.
         */
        static removeEventListener(name: string, callback: (param0: Titanium.Event) => void): void;

        /**
         * Serializes a [Node](Titanium.XML.Node) object into a string.
         */
        static serializeToString(node: Titanium.XML.Node): string;

        /**
         * Sets the value of the <Titanium.XML.bubbleParent> property.
         * @deprecated Set the value using <Titanium.XML.bubbleParent> instead.
         */
        static setBubbleParent(bubbleParent: boolean): void;

        /**
         * Sets the value of the <Titanium.XML.lifecycleContainer> property.
         * @deprecated Set the value using <Titanium.XML.lifecycleContainer> instead.
         */
        static setLifecycleContainer(lifecycleContainer: Titanium.UI.Window | Titanium.UI.TabGroup): void;

    }
    /**
     * The top level Yahoo module.  The Yahoo module is used for accessing Yahoo related API services.
     * @deprecated Use the standalone [Ti.Yahoo](https://github.com/appcelerator-modules/ti.yahoo) module instead.
     */
    const Yahoo: never;
}
/**
 * Provide at least the property `identifier` and `url` property to identify a local
 * image, sound or video. If your media is invalid, the API will throw an error log and
 * skip the invalid attachment.
 */
interface UserNotificationAttachment {
    /**
     * The identifier of this attachment.
     */
    identifier: string;

    /**
     * An additional dictionary of options to provide.
     */
    options?: any;

    /**
     * The URL to the attachment's data. If you have obtained this attachment from
     * the notification-center then the URL will be security-scoped.
     */
    url: string;

}
/**
 * Response when receiving pending or local notifications
 * in <Titanium.App.iOS.UserNotificationCenter.getPendingNotifications> and
 * <Titanium.App.iOS.UserNotificationCenter.getDeliveredNotifications>.
 */
interface UserNotificationCallbackResponse {
    /**
     * An array of identifiers used to create notifications.
     */
    notifications?: UserNotificationDictionary[];

}
/**
 * Dictionary of notification data used in the array of `notifications`
 * when receiving pending or local notifications in
 * <Titanium.App.iOS.UserNotificationCenter.getPendingNotifications> and
 * <Titanium.App.iOS.UserNotificationCenter.getDeliveredNotifications>.
 */
interface UserNotificationDictionary {
    /**
     * Alert button text ('Open', by default) or home text ('Press Home to unlock', by default)
     * type: String
     */
    alertAction?: string;

    /**
     * Alert message.
     */
    alertBody?: string;

    /**
     * Image displayed instead of `Default.png` when launching the application.
     */
    alertLaunchImage?: string;

    /**
     * Subtitle of the notification.
     */
    alertSubtitle?: string;

    /**
     * Title of the notification.
     */
    alertTitle?: string;

    /**
     * Application badge value.
     */
    badge?: number;

    /**
     * Category identifier of the notification.
     */
    category?: string;

    /**
     * Date and time when the notification was configured to fire.
     */
    date?: Date;

    /**
     * The notification identifier.
     */
    identifier: string;

    /**
     * Region of the notification.
     */
    region?: any;

    /**
     * Path to the sound file configured to play when the notification was fired.
     */
    sound?: string;

    /**
     * Timezone of the date when the notification was configured to fire.
     */
    timezone?: string;

    /**
     * Custom data object.
     */
    userInfo?: any;

}
/**
 * Dictionary object of parameters used to register the application with local notifications using
 * the <Titanium.App.iOS.registerUserNotificationSettings> method.
 * To retrieve the current notification settings, use the
 * <Titanium.App.iOS.UserNotificationCenter.requestUserNotificationSettings> method.
 */
interface UserNotificationSettings {
    /**
     * Set of categories of user notification actions required by the applicaiton to use.
     */
    categories?: Titanium.App.iOS.UserNotificationCategory[];

    /**
     * Notification types to use.
     */
    types?: number[];

}
/**
 * Dictionary of options for the <Titanium.UI.WebView.addUserScript> method.
 */
interface UserScriptParams {
    /**
     * The time when the script should be injected into the webpage.
     */
    injectionTime?: number;

    /**
     * A Boolean value indicating whether the script should be injected only into the
     * main frame (true) or into all frames (false).
     */
    mainFrameOnly?: boolean;

    /**
     * A script that can be injected into a webpage.
     */
    source?: string;

}
/**
 * Pass an object with the following key-value pairs:
 *   * `view` (Titanium.UI.View): View to insert
 *   * `position` (Number): Position in the [children](Titanium.UI.View.children) array of
 *     the view elment to replace.
 */
interface ViewPositionOptions {
    /**
     * Position in the [children](Titanium.UI.View.children) array of the view element to replace.
     */
    position?: number;

    /**
     * View to insert. Required.
     */
    view: Titanium.UI.View;

}
/**
 * Template that represents a view subcomponent of an <ItemTemplate>.
 */
interface ViewTemplate {
    /**
     * View's ID (or set of IDs) used for data binding. This value must be unique.
     */
    bindId?: string;

    /**
     * Contains an array of subview templates to be added (in order) as children to this view.
     */
    childTemplates?: ViewTemplate[];

    /**
     * Contains key-value pairs of view events and their listeners that are applied to this view component.
     */
    events?: any;

    /**
     * Contains key-value pairs of view properties and their values that are applied to this view component.
     */
    properties?: any;

    /**
     * View's class name, for example, `Ti.UI.Button`.
     */
    type: string;

}
/**
 * The parameter passed to the <Titanium.UI.iOS.WebViewConfiguration.preferences> method.
 */
interface WebViewPreferencesObject {
    /**
     * A Boolean value indicating whether JavaScript can open windows without user interaction.
     */
    javaScriptCanOpenWindowsAutomatically?: boolean;

    /**
     * A Boolean value indicating whether JavaScript is enabled.
     */
    javaScriptEnabled?: boolean;

    /**
     * The minimum font size in points.
     */
    minimumFontSize?: number;

}
/**
 * Argument passed to the write callback when an asynchronous
 * [write](Titanium.Stream.write) operation
 * finishes.
 */
interface WriteCallbackArgs extends ErrorResponse {
    /**
     * Number of bytes processed, or -1 in the event of an error or end of stream.
     */
    bytesProcessed?: number;

    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Text description of the error.
     * @deprecated Use error property to determine error message
     */
    errorDescription: never;

    /**
     * Whether an error was encountered. Set to 1 in the case of an error, 0
     * otherwise.
     * @deprecated Use success or code values to determine error conditions
     */
    errorState: never;

    /**
     * Stream being written to.
     */
    source?: Titanium.IOStream;

    /**
     * Indicates if the operation succeeded.
     */
    success?: boolean;

}
/**
 * Argument passed to the callback when an asynchronous
 * [writeStream](Titanium.Stream.writeStream) operation finishes.
 */
interface WriteStreamCallbackArgs extends ErrorResponse {
    /**
     * Number of bytes processed, or -1 in the event of an error or end of stream.
     */
    bytesProcessed?: number;

    /**
     * Text description of the error.
     * @deprecated Use error property to determine error message
     */
    errorDescription: never;

    /**
     * Whether an error was encountered. Set to 1 in the case of an error, 0
     * otherwise.
     * @deprecated Use success or code values to determine error conditions
     */
    errorState: never;

    /**
     * Stream being read from.
     */
    fromStream?: Titanium.IOStream;

    /**
     * Stream being written to.
     */
    toStream?: Titanium.IOStream;

}
/**
 * Properties passed to a yql callback to report a success or failure.
 */
interface YQLResponse extends ErrorResponse {
    /**
     * Error code. Returns 0 if `success` is `true`.
     */
    code?: number;

    /**
     * The data payload received from the YQL.
     */
    data?: any;

    /**
     * Error message, if any returned.
     */
    error?: string;

    /**
     * Error message, if any returned. Use `error` instead
     * @deprecated
     */
    message?: string;

}
/**
 * Dictionary of options for the <Titanium.UI.Window.close> method.
 */
interface closeWindowParams {
    /**
     * Animation resource to use for the incoming activity.
     */
    activityEnterAnimation?: number;

    /**
     * Animation resource to use for the outgoing activity.
     */
    activityExitAnimation?: number;

    /**
     * Determines whether to use an animated effect when the window is closed. Defaults to `true` on Android, `false` on iOS.
     */
    animated?: boolean;

    /**
     * duration of the animation in milliseconds
     */
    animationDuration?: number;

    /**
     * Transition type to use during a transition animation.
     */
    animationStyle?: number;

}
/**
 * Dictionary containing `daysOfWeek` and `week`.
 */
interface daysOfTheWeekDictionary {
    /**
     * The day of the week. Values are from 1 to 7, with Sunday being 1.
     */
    daysOfWeek?: number;

    /**
     * The week number of the day of the week.
     * Values range from -53 to 53. A negative value indicates a value from the end of
     * the range. 0 indicates the week number is irrelevant.
     */
    week?: number;

}
/**
 * Dictionary of options for the <Titanium.UI.OptionDialog.hide> method.
 */
interface hideParams {
    /**
     * Determines whether to animate the dialog as it is dismissed.
     */
    animated?: boolean;

}
/**
 * Dictionary describing the arguments passed to the application on startup.
 * Use the [getArguments](Titanium.App.getArguments) method to retrieve the launch options.
 */
interface launchOptions {
    /**
     * If set to `true`, this key indicates that the application was launched in response to an
     * incoming location event.
     */
    launchOptionsLocationKey?: boolean;

    /**
     * This key indicates that the application was launched by another
     * application with the specified bundle ID.
     */
    source?: string;

    /**
     * This key indicates that the application was launched in order to open
     * the specified URL.
     */
    url?: string;

}
/**
 * Dictionary of options for the <Titanium.UI.Window.open> method.
 */
interface openWindowParams {
    /**
     * Animation resource to run on the activity being opened.
     */
    activityEnterAnimation?: number;

    /**
     * Animation resource to run on the activity that is being put in background as a window is being opened above it.
     */
    activityExitAnimation?: number;

    /**
     * Determines whether to use an animated effect when the window is shown.
     */
    animated?: boolean;

    /**
     * Window's bottom position, in platform-specific units.
     */
    bottom?: number | string;

    /**
     * Indicates whether the window enforces modal behaviour.
     */
    forceModal?: boolean;

    /**
     * Determines if the window is fullscreen.
     */
    fullscreen?: boolean;

    /**
     * Window's height, in platform-specific units.
     */
    height?: number | string;

    /**
     * Window's left position, in platform-specific units.
     */
    left?: number | string;

    /**
     * Determines whether to open the window modal in front of other windows.
     */
    modal?: boolean;

    /**
     * Presentation style of this modal window.
     */
    modalStyle?: number;

    /**
     * Transition style of this modal window.
     */
    modalTransitionStyle?: number;

    /**
     * For modal windows, hides the nav bar (`true`) or shows the nav bar (`false`).
     */
    navBarHidden?: boolean;

    /**
     * Window's right position, in platform-specific units.
     */
    right?: number | string;

    /**
     * Window's top position, in platform-specific units.
     */
    top?: number | string;

    /**
     * Transition style of this non-modal window.
     */
    transition?: number;

    /**
     * Window's width, in platform-specific units.
     */
    width?: number | string;

}
/**
 * Dictionary containing either `endDate` or `occurrenceCount` property.
 */
interface recurrenceEndDictionary {
    /**
     * End date of the recurrence end, or undefined if the recurrence end is count-based.
     */
    endDate?: Date;

    /**
     * Occurrence count of the recurrence end, or 0 if the recurrence end is date-based.
     */
    occurrenceCount?: number;

}
/**
 * Dictionary describing the shadow effect for text.
 */
interface shadowDict {
    /**
     * Specifies the blur radius of the shadow.
     */
    blurRadius?: number;

    /**
     * Color name or hex triplet specifying the color of the shadow.
     */
    color?: string | Titanium.UI.Color;

    /**
     * <Size> with the properties `width` and `height` used as the horizontal
     * and vertical offset of the shadow, respectively.
     */
    offset?: Size;

}
/**
 * Dictionary of options for the <Titanium.Contacts.showContacts> method.
 */
interface showContactsParams {
    /**
     * Determines whether to animate the show/hide of the contacts picker (iPhone, iPad only.)
     */
    animated?: boolean;

    /**
     * Function to call when selection is canceled.
     */
    cancel?: (param0: any) => void;

    /**
     * Field names to show when selecting properties. By default, shows all available.
     */
    fields?: string[];

    /**
     * Function to call when a person is selected. Must not be used with `selectedProperty` property.
     */
    selectedPerson?: (param0: any) => void;

    /**
     * Function to call when a property is selected. Must not be used with `selectedPerson`
     * property.
     * Note: If ringtone or texttone is selected, null values are returned, since these are unsupported
     * by Apple.
     * Since iOS 9.0, there is a native apple issue whereby it may return null if the birthday property
     * is selected on certain device models.
     * The callback contains the selected property and a 'person' object of type <Titanium.Contacts.Person>.
     * Since iOS 9.0, apple only returns the person object with partial information. Currently it is known to
     * at least contain the selected property and fullName.
     */
    selectedProperty?: (param0: any) => void;

}
/**
 * Dictionary of options for the <Titanium.UI.OptionDialog.show> method.
 */
interface showParams {
    /**
     * Determines whether to animate the dialog as it is shown.
     */
    animated?: boolean;

    /**
     * Array of String instances.
     */
    buttonNames?: string[];

    /**
     * String to be used as a message for the dialog.
     */
    message?: string;

    /**
     * Array of String instances.
     */
    options?: string[];

    /**
     * Positions the arrow of the option dialog relative to the attached view's dimensions.
     */
    rect?: Dimension;

    /**
     * String to be used as title for the dialog.
     */
    title?: string;

    /**
     * View to which to attach the dialog.
     */
    view?: Titanium.UI.View;

}
/**
 * Dictionary object of parameters for the <Titanium.UI.TextArea.selected> event and <Titanium.UI.TextArea.selection> property that describes
 * position and length of the selected text.
 */
interface textAreaSelectedParams {
    /**
     * Number of characters selected.
     */
    length?: number;

    /**
     * Starting position of selected text.
     */
    location?: number;

}
/**
 * Dictionary object of parameters for the <Titanium.UI.TextField.selection> property that describes
 * position and length of the selected text.
 */
interface textFieldSelectedParams {
    /**
     * Number of characters selected.
     */
    length?: number;

    /**
     * Starting position of selected text.
     */
    location?: number;

}
/**
 * Dictionary of options for the <Titanium.UI.Window.titleAttributes> property.
 */
interface titleAttributesParams {
    /**
     * Color of the window title, as a color name or hex triplet.
     */
    color?: string | Titanium.UI.Color;

    /**
     * Font to use for the window title.
     */
    font?: Font;

    /**
     * Shadow color and offset for the window title.
     */
    shadow?: shadowDict;

}
/**
 * Parameter for wakeLock
 */
interface wakeLockOptions {
    /**
     * Wake lock level and flag. See [PowerManager.newWakeLock in the Android API Reference](https://developer.android.com/reference/android/os/PowerManager.html#newWakeLock(int,%20java.lang.String))
     */
    flags?: number;

    /**
     * Minimum time the device will be switched on (plus device switch-off time)
     */
    time?: number;

}
/**
 * Dictionary of options for the <Titanium.UI.Window.setToolbar> method.
 */
interface windowToolbarParam {
    /**
     * Defines if the toolbar appearance is animated.
     */
    animated?: boolean;

    /**
     * Background color for the toolbar, as a color name or hex triplet.
     */
    barColor?: string | Titanium.UI.Color;

    /**
     * The tintColor to apply to the tool bar.
     */
    tintColor?: string | Titanium.UI.Color;

    /**
     * Defines if the toolbar is translucent.
     */
    translucent?: boolean;

}

import Ti = Titanium;
